(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    267859,      10295]*)
(*NotebookOutlinePosition[    270591,      10386]*)
(*  CellTagsIndexPosition[    270261,      10370]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[" Geometry of Circles", "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Courier"],

Cell["by", "Subsubtitle",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[TextData[StyleBox["Rolf Sulanke",
  FontSize->18]], "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center],

Cell["April 14, 1999, last revision October 24, 2003", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection",
  TextAlignment->Left,
  FontFamily->"Times"],

Cell[TextData[{
  "This notebook describes the Moebius invariants for pairs of circles in the \
3-sphere, or, by stereographical projection, in the euclidean 3-space. \
Section 2 contains the needed concepts for the euclidean geometry of circles \
in the 3-space (or in the 3-sphere). On the level of the euclidean 3-space we \
give  a parametrization of the 6-dimensional space of circles. We construct \
two plot commands which plot the circles corresponding to these parameters. \
Furthermore, we define functions giving a parameter representation of the \
circle, and the euclidean invariants radius, center and position vector of \
the circle through three points on the euclidean level. As an application, a \
plot command for tubes of general space curves is developed. Section 3 gives \
the basic concepts for circles in the 3-dimensional M\[ODoubleDot]bius space. \
The circles are bijectively represented by  2-dimensional euclidean subspaces \
of the 5-dimensional pseudo-euclidean vector space of index 1, which are \
defined by orthonormal pairs of vectors. By stereographical projection of the \
3-sphere onto the euclidean 3-space the circles  become usual euclidean \
3D-graphics applied to consider the mutual position of circles in the space. \
We construct procedures giving an adapted frame of the euclidean 2-space in \
terms of the euclidean circle invariants, and vice versa giving the circle as \
function of the euclidean 2-space.  In Section 4 we define a complete system \
of M\[ODoubleDot]bius-geometric invariants for pairs of circles in the \
3-sphere, and try to find out their geometric meaning. Section 5 gives the \
normal forms of the circle pairs in relation to this system of invariants. \
Certain geodesics of the (pseudo-Riemannian) circle space are studied as \
circle orbits and plotted in section 6.  The last section imports  \
ThreeScript and  the program MathGL3d created by J--P- Kuska ",
  ButtonBox["[2]",
    ButtonData:>"K2",
    ButtonStyle->"Hyperlink"],
  ",  which can be applied for animations of the created 3D-graphics. \nMany, \
but not all constructs developed in this notebook are collected in the \
package mcirc.m. This package needs the packages euvec.m, pseuvec.m, and \
mspher.m,  which are loaded automatically if mcirc.m is called. \nThe \
notebook is related to the notebooks Euklid.nb (a new version of \
eusphere.nb), which contain basics of  the metric geometry of spheres, and \
the notebook mspheres.nb, devoted to the M\[ODoubleDot]bius geometry of \
spheres. It uses tools of  pseudo-euclidean linear algebra, developed in the \
notebook pseuklid.nb.  All these notebooks and the packages mentioned above \
are contained on the item ",
  ButtonBox["[5]",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  " ,  the actual version of which is also  available at my ",
  ButtonBox["homepage",
    ButtonData:>"HP",
    ButtonStyle->"Hyperlink"],
  " .\nFor differential geometry with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in the euclidean 3-space see the textbook A. Gray ",
  ButtonBox["[1]",
    ButtonData:>"G1",
    ButtonStyle->"Hyperlink"],
  ". The concepts of M\[ODoubleDot]bius geometry applied here are contained \
in the paper ",
  ButtonBox["[6]",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  ", see also section 2.7 of the book ",
  ButtonBox["[4]",
    ButtonData:>"O-S",
    ButtonStyle->"Hyperlink"],
  " on my homepage. A systematic description of the circle space  can be \
found  in the diploma paper of U. May ",
  ButtonBox["[3]",
    ButtonData:>"M3",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{

Cell["Keywords", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
pseudo-euclidean geometry,  Moebius geometry, 3D-circles, circles defined by \
subspaces, orthogonal circles, isospherical circles, stationary angles, \
eigenspheres, invariants of pairs of circles, normal forms of pairs of \
circles, geodesics in the circle space, MathGL3d.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Version", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "This notebook is a new version of the notebook mcircles.nb,  first \
published  in the item ",
  ButtonBox["[6]",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  " in MathSource. The same is true for the accompanying packages. Since \
these packages contain the most important procedures used in this and other \
notebooks, published first in the  item Spheres,and the contents as well as \
some names are changed, the two versions should not be mixed.   The notebook \
is developed with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v. 4.200. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Copyright", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
This notebook, the linked notebooks, and the accompanying packages are  \
public. Authors who intend to publish a changed or completed version of them \
should do it under their own names with the condition that they cite the \
original notebook with the Internet address or other source where they got \
it. I am not responsible for errors or damages originated by the use of the \
procedures contained in my notebooks or packages; anybody who applies them \
should test carefully whether they are appropriate for his purposes.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  FontFamily->"Times"],

Cell["\<\
First, if not done already,  copy the needed packages  euvec.m, pseuvec.m, \
mspher.m, mcirc.m and this notebook mcircles.nb into your working directory, \
and  insert the path of your working directory, e.g. under Windows, \
\"C:\\Eigene Dateien\\mymath\\spheres.v4\", into the next command line:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetDirectory["\<~/mymath/work\>"]\)], "Input",
  CellLabel->"In[1]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \("/home/rolf/mymath/work"\)], "Output",
  CellLabel->"Out[1]="]
}, Closed]],

Cell[TextData[StyleBox["Now: Activite Kernel/Evaluation/Evaluate \
Initialization from the menu!",
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[BoxData[
    \(Needs["\<mcirc`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["are contained in your working directory.", "Text"],

Cell[TextData[{
  "Before applying commands for graphics3D animations like ThreeScript or \
MVShow3D import first the needed tools, see section ",
  ButtonBox["7",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["1 Preliminaries", "Section",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["1.1 Pseudo-euclidean vector algebra and other prerequisites", \
"Subsection",
  FontFamily->"Times"],

Cell["\<\
M\[ODoubleDot]bius geometry is treated by tools of euclidean and \
pseudo-euclidean linear algebra. The basic concepts are developed in  the \
notebooks eusphere.nb,  pseuklid.nb and contained in the packages euvec.m,  \
pseuvec.m. Basic concepts of M\[ODoubleDot]bius geometry, in particular the M\
\[ODoubleDot]bius geometry of spheres, can be found in the notebook \
mspheres.nb and the package mspher.m. All these constructs are loaded \
automatically if the package mcirc.m is called. The symbols are listed below, \
see section 1.2.\
\>", "Text"],

Cell["\<\
Before using them one has to fix the dimension dim of the underlying vector \
space and the index  ind of the (non-degenerate, symmetric) scalar product. \
These basic constants are now defined by\
\>", "Text"],

Cell[BoxData[
    \(dim\  = \ 5; \ ind\  = \ 1;\)], "Input",
  CellLabel->"In[3]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["\<\
because in this notebook the 3-dimensional sphere is treated as the \
elliptical hyperquadric in the four-dimensional projective  space, which \
belongs to the five-dimensional real vector space. You may change these \
constants any time if you need it.  But remember that these constants enter \
in almost all of the treated concepts.\
\>", "Text",
  Evaluatable->False],

Cell["\<\
The matrix of the scalar products of any orthonormed basis of the \
pseudo-euclidean vector space is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[
      Table[pssp[stb[i], \ stb[j]], {i, dim}, {j, dim}]]\)], "Input",
  CellLabel->"In[4]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", \(-1\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[4]//MatrixForm="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2 The usages", "Subsection",
  FontFamily->"Times"],

Cell["\<\
After a package has been loaded you can get information about the  listed \
concepts in the usual way, e.g.\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(\(?orthonorm\)\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Context[orthonorm]\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell["\<\
For getting the usage and the complete definition, enter e.g.\
\>", "Text"],

Cell[BoxData[
    \(?? spt\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell["\<\
Since the names are prepended by the ContextNames the definition obtained in \
this way are hard to read. Therefore you will find some of them below in the \
original form in unevaluable cells.  It is recommended to look in the \
packages.\
\>", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["Symbols in mcirc.m", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Here you can get information about the commands which are defined in mcirc.m:\
\
\>", "Text"],

Cell[BoxData[
    \(TableForm[{"\<adaptsplframe\>", "\<center\>", "\<posvec\>", \
"\<radius\>", "\<center3pts\>", "\<circle2spv\>", "\<circle3D\>", \
"\<circle3pts\>", "\<circlefamily\>", "\<circleplane\>", \
"\<circlespacevectors\>", "\<control\>", "\<gencircle\>", \
"\<plotcircle2spv\>", "\<plotcircle3D\>", "\<plotcircle3pts\>", \
"\<plotgencircle\>", "\<posvec3pts\>", "\<pp\>", "\<ppdet\>", "\<pptr\>", \
"\<pscomplement\>", "\<radius3pts\>", "\<threepoints\>", "\<tube\>", \
"\<unitvec\>", "\<vspace\>"}]\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell["To get the usages activate the next cell!", "Text"],

Cell[BoxData[
    \(\({\(?"\<adaptsplframe\>"\), \(?"\<center\>"\), \(?"\<posvec\>"\), \(?"\
\<radius\>"\), \(?"\<center3pts\>"\), \ \(?"\<circle2spv\>"\), \ \
\(?"\<circle3D\>"\), \(?"\<circle3pts\>"\), \(?"\<circlefamily\>"\), \
\(?"\<circleplane\>"\), \(?"\<circlespacevectors\>"\), \ \(?"\<control\>"\), \
\ \(?"\<gencircle\>"\), \ \ \ \(?"\<plotcircle2spv\>"\), \
\(?"\<plotcircle3D\>"\), \ \(?"\<plotgencircle\>"\), \
\(?"\<plotcircle3pts\>"\), \(?"\<posvec3pts\>"\), \ \(?"\<pp\>"\), \
\(?"\<ppdet\>"\), \ \(?"\<pptr\>"\), \(?"\<pscomplement\>"\), \
\(?"\<radius3pts\>"\), \(?"\<threepoints\>"\), \ \n\ \(?"\<tube\>"\), \ \
\(?"\<unitvec\>"\), \ \(?"\<vspace\>"\)};\)\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbols in euvec.m", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(TableForm[{"\<cross\>", "\<hyperplane\>", "\<invsterproj\>", \
"\<dotnorme\>", "\<esorthonorm\>", "\<innerprod\>", "\<normed\>", \
"\<print\>", "\<neglect\>", "\<nul\>", "\<orthocomplement\>", "\<outzero\>", \
"\<randomv\>", "\<rank\>", "\<renorm\>", "\<smoothing\>", "\<sphere\>", \
"\<sphereplot3D\>", \ "\<subsphere\>", "\<subspheremf\>", \
"\<sphericalreflection\>", "\<stb\>", "\<sterproj\>", "\<tg4frame\>", "\<unit\
\>", "\<vec\>"}]\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell["To get the usages activate the next cell!", "Text"],

Cell[BoxData[
    \(\({\(?"\<cross\>"\), \(?"\<hyperplane\>"\), \(?"\<invsterproj\>"\), \
\(?"\<dotnorme\>"\), \(?"\<esorthonorm\>"\), \(?"\<innerprod\>"\), \
\(?"\<normed\>"\), \(?"\<print\>"\), \(?"\<neglect\>"\), \(?"\<null\>"\), \
\(?"\<orthocomplement\>"\), \(?"\<outzero\>"\), \(?"\<randomv\>"\), \
\(?"\<rank\>"\), \(?"\<renorm\>"\), \(?"\<smoothing\>"\), \(?"\<sphere\>"\), \
\(?"\<subsphere\>"\), \(?"\<subspheremf\>"\), \(?"\<sphereplot3D\>"\), \
\(?"\<sphericalreflection\>"\), \(?"\<stb\>"\), \(?"\<sterproj\>"\), \
\(?"\<tg4frame\>"\), \(?"\<unit\>"\), \(?"\<vec\>"\)};\)\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? invsterproj\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbols in pseuvec.m", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(TableForm[{"\<ch\>", "\<dual\>", "\<ide\>", "\<normalize\>", \
"\<orthonorm\>", "\<orthopair\>", "\<pr\>", "\<psCross\>", "\<pscross\>", \
"\<psfilter\>", "\<pssp\>"}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell["To get the usages activate the next cell!", "Text"],

Cell[BoxData[
    \(\({\(?"\<ch\>"\), \(?"\<dual\>"\), \(?"\<ide\>"\), \
\(?"\<normalize\>"\), \(?"\<orthonorm\>"\), \(?"\<orthopair\>"\), \(?"\<pr\>"\
\), \(?"\<psCross\>"\), \(?"\<pscross\>"\), \(?"\<psfilter\>"\), \
\(?"\<pssp\>"\)};\)\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?psfilter\)\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? pscross\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? psCross\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbols in mspher.m", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(TableForm[{"\<coxeterinv\>", \ "\<gencos\>", \ "\<invstepro\>", \ "\
\<planevec\>", \ \n"\<euklidsphere\>", \ "\<pstg5frame\>", \ \
"\<euklidsphereplot3D\>", \ "\<vradius\>", \ "\<vcenter\>", \ \
"\<spherevec\>", \n\ "\<spt\>", "\<spunit\>", \ "\<stepro\>"}]\)\(\ \)\)\)], \
"Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell["To get the usages activate the next cell!", "Text"],

Cell[BoxData[
    \(\({\(?"\<coxeterinv\>"\), \ \(?"\<gencos\>"\), \ \(?"\<invstepro\>"\), \
\ \(?"\<planevec\>"\), \ \n\(?"\<euklidsphere\>"\), \ \(?"\<pstg5frame\>"\), \
\ \(?"\<euklidsphereplot3D\>"\), \ \(?"\<vradius\>"\), \ \(?"\<vcenter\>"\), \
\ \(?"\<spherevec\>"\), \n\ \(?"\<spt\>"\), \(?"\<spunit\>"\), \ \(?"\<stepro\
\>"\)};\)\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? spunit\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["1.3 Some tools", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["A general vector, random vectors", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(vec[x_, \ n_:  dim]\  := \ Table[x[i], \ {i, \ n}]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times",
  FontSize->15],

Cell[BoxData[
    \(vec[Sin]\)], "Input",
  CellLabel->"In[16]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[17]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(randomv[n_:  dim]\  := \ Table[Random[], {i, \ n}]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(randomv[]\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Finding orthogonal pairs", "Subsubsection",
  FontFamily->"Times"],

Cell["The following definition is given in pseuklid.m:", "Text"],

Cell[BoxData[
    \(\(?orthopair\)\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"],

Cell["Examples", "Text",
  FontFamily->"Times"],

Cell[BoxData[
    \(orthopair[{0.5, 0.5, 1, 0, 0}]\)], "Input",
  CellLabel->"In[28]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(orthopair[{0.5, 0.5, 1, 1, 1}]\)], "Input",
  CellLabel->"In[29]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ow = %\)], "Input",
  CellLabel->"In[30]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[pssp[ow[\([i]\)], ow[\([j]\)]], {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(orthopair[stb[1]]\)], "Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(orthopair[stb[5]]\)], "Input",
  CellLabel->"In[33]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Context[orthopair]\)], "Input",
  CellLabel->"In[34]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[ow]\)], "Input",
  CellLabel->"In[35]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Smoothing", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "The following function makes an almost zero  number to be zero; the \
sensibility can be regulated by the optional second argument, whose default \
value is ",
  Cell[BoxData[
      \(10\^\(-10\)\)]],
  "; for the difference to Chop see the remark in the notebook chopping.nb on \
my ",
  ButtonBox["homepage",
    ButtonData:>"HP",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(\(smoothing[a_, b_:  10^\(-10\)] := 
        Module[{c = a}, If[b \[Equal] 1, Return[c], If[Abs[c] < b, c = 0]]; \ 
          c];\)\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(Attributes[smoothing]\)], "Input",
  CellLabel->"In[38]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2 Circles in the euclidean 3-space", "Section",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " considers circles in two dimensions only:"
}], "Text"],

Cell[BoxData[
    \(\(?Circle\)\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell["\<\
Therefore, we must first introduce circles as objects of the  \
three-dimensional euclidean space. In 2.1 we consider two parmeter \
representations of  arbitrary circles; since a circle in the 3-space depends \
on 6 parameters the circle spce is a 6-dimensional manifold. In 2.2 we the \
corresponding plot definitions are presented.  In subsection 2.3 the circle \
(or line, or point) defined by a point tripel of the 3-space is calculated \
and plotted. As an application we construct tubes of space curves, especially \
torus knots, in the last subsection. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1 Parametrisation of the circle space. The general circle", \
"Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["\<\
The unit sphere with center o and its tangential unit vectors\
\>", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
unit[2][{u,v}] is the usual parameter representation of the unit sphere in \
the 3-space with the geographical coordinates u, v:    0 <= u < 2Pi,  -Pi/2 < \
v < Pi/2.\
\>", "Text"],

Cell[BoxData[
    \(\(unit[2]\)[{u, v}]\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(unit[2]\)[{u, v}], {u, \ 0, 2\ Pi}, \ {v, \(-Pi\)/2, 
        Pi/2}]\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell["For all values of u,v,t the following vector has norm 1:", "Text"],

Cell[BoxData[
    \(\(?unitvec\)\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? unitvec\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Context[unitvec]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(unitvec[u, v]\)[t]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[\(unitvec[u, v]\)[t] . \(unitvec[u, v]\)[t]]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell["unitvec[u,v][t] is orthogonal to unit[2][{u,v}]:", "Text"],

Cell[BoxData[
    \(Simplify[\(unitvec[u, v]\)[t] . \(unit[2]\)[{u, v}]]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
For u,v fix, t variable, unitvec[u,v][t] is the parameter representation of \
the unit circle in the tangent vector space of the unit sphere at the point \
with parameters u,v. \
\>", "Text"],

Cell[BoxData[
    \(\(tangcircle[u_, v_]\)[
        t_]\  := \(unit[2]\)[{u, v}]\  + \ \(unitvec[u, v]\)[t]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(unitvec[0, Pi/3]\)[t], {t, 0, 2\ Pi}]\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(tangcircle[0, Pi/3]\)[t], {t, 0, 2\ Pi}]\)], "Input",\

  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%%, %}]\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(unitvec[0, Pi/2]\)[t], {t, 0, 2\ Pi}]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(unitvec[Pi/2, Pi/4]\)[t], {t, 0, 2\ Pi}]\)], "Input",\

  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(tangcircle[Pi/2, Pi/4]\)[t], {t, 0, 
        2\ Pi}]\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%%, %}]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cp1\  = \ %\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Definition of circle3D", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?circle3D\)\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle3D[x_, y_, z_, u_, v_, r_]\)[
        t_] := {x, \ y, z}\  + \ \(unitvec[u, v]\)[t]*r\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle3D[x, y, z, u, v, r]\)[t]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "A similar, but more general  definition of Circle3D as a special case of \
an ellipse in the 3-dimensional space is contained in the package \
Hyperbolic/Circle3D.m by Sylvio Levy  (mathsource 1992). Furthermore, it \
includes a plot definition. This package seems to run only under  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v. 2."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(circle3D[2, 0, 0, Pi/2, \ Pi/4, \ 2]\)[t], {t, 0, 
        2\ Pi}]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((u1\  = \ 2\ Pi\ Random[]; \ v1\  = \ Random[]\ Pi/2; \n
      ParametricPlot3D[\(circle3D[0, 0, 0, u1, \ v1, \ 1]\)[t], {t, 0, 
          2\ Pi}])\)\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[\((u1\  = \ 2\ Pi\ Random[]; \ v1\  = \ Random[]\ Pi/2; \n
        ParametricPlot3D[\(circle3D[0, 0, 1, u1, \ v1, \ 1]\)[t], {t, 0, 
            2\ Pi}])\), {i, 10}]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[u1, v1]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Another definition: gencircle", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
In the next definition the radius of the circle is the norm of v:\
\>", "Text"],

Cell[BoxData[
    \(\(?gencircle\)\)], "Input",
  CellLabel->"In[16]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(gencircle[p_List, v_List]\)[t_] := 
      Module[{a\  = \ v . v, b1, \ b2}, \n\t\t\tIf[
          Length[p] != 3 || Length[v] != 3, \ 
          Print["\<Incorrect arguments!!!\>"]; Return[]]; \n\t\ \ \tIf[
          a == \ 0, \ Return[p]]; \n\t\t\tIf[
          v[\([1]\)]\  == \ 0\  && \ v[\([2]\)]\  == 0, \ 
          Return[p\  + \ {Cos[t], \ Sin[t], \ 0}*
                Sqrt[a]]]; \n\t\t\tb1 = {\(-v[\([2]\)]\), \ v[\([1]\)], \ 0}/
            Sqrt[a\  - \ v[\([3]\)]^2]; \n\t\t\tb2\  = \ 
          Cross[v, \ b1]; \n\t\t\tReturn[
          p + b1*Sqrt[a]*Cos[t]\  + b2\ Sin[t]]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(gencircle[{2, 0, 0}, 2*\(unit[2]\)[{Pi/2, Pi/4}]]\)[
        t], {t, 0, 2\ Pi}]\)], "Input",
  CellLabel->"In[17]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(randomv[3]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((p1\  = \ randomv[3]; \ v1\  = \(-randomv[3]\); \n\t
      Print[p1, "\<, \>", \ v1, "\<, \>", \ Sqrt[v1 . v1]]; \ \n
      ParametricPlot3D[\(gencircle[p1, v1]\)[t], {t, 0, 2\ Pi}])\)\)], "Input",\

  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[p1, v1]\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2 The Plot definitions", "Subsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?circle3D\)\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3D[x_, y_, z_, u_, v_, r_, \ opts___] := \ 
      ParametricPlot3D[\n\t\tEvaluate[\(circle3D[x, y, z, u, v, r]\)[
            t]], \ {t, \ 0, \ 2\ Pi}, \ opts]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?gencircle\)\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotgencircle[p_List, v_List, \ opts___] := \ 
      ParametricPlot3D[\n\t\tEvaluate[\(gencircle[p, v]\)[t]], \ {t, \ 0, \ 
          2\ Pi}, \ opts]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotgencircle[null[3], \ stb[3, 3]]\)], "Input",
  CellLabel->"In[16]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotgencircle[null[3], \ 25. *stb[2, 3]]\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotgencircle[\ 2  randomv[3], 5\ randomv[3]]\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3D[1, 1, 1, Pi/2, 0, \ 2]\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3D[1, 5\ Random[], 1, Pi/2, Pi\ Random[], \ 2]\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3 Circles and lines through three points", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Definitions: Position vector, center, radius, and circle", \
"Subsubsection",
  FontFamily->"Times"],

Cell["\<\
The position vector of a circle is a unit vector orthogonal to the plane of \
the circle; it is uniquely defined up to sign, and it can be calculated from \
three points of the circle as follows:\
\>", "Text"],

Cell[BoxData[
    \(posvec3pts[p1_List, p2_List, p3_List]\  := \n\t
      Module[{\ a}, \n\t\ta\  = \ Cross[p2 - p1, \ p3 - p1]; \n\t\tIf[
          a\  \[NotEqual] null[3], Return[smoothing[a/Sqrt[a . a]]], \ 
          Return[null[3]], Return[smoothing[a/Sqrt[a . a]]]]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
For the calculation of the center m of the circle through three points we \
start with  the  formula\
\>", "Text"],

Cell[BoxData[
    \(m\  = \ 
      p3\  + \ \((p1\  - \ p3)\)\ x\  + \ \((p2\  - \ p3)\)\ y\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["Evaluating the conditions", "Text"],

Cell[BoxData[{
    \(\(\((m - p3)\) . \((m - p3)\) \[Equal] \ \((m - p1)\) . \((m - 
              p1)\);\)\), "\[IndentingNewLine]", 
    \(\(\((m - p3)\) . \((m - p3)\) \[Equal] \ \((m - p2)\) . \((m - 
              p2)\);\)\)}], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
we get a linear system for the unknowns x, y. By the \
Cauchy-Schwarz-inequality its determinant dn is zero if and only if the \
points p1, p2, p3 belong to a line. By definition,  then the center is {\
\[Infinity],\[Infinity],\[Infinity]}. Otherwise, Cramer\.b4s rule yields the \
solution.  These considerations lead to the following module:\
\>", "Text"],

Cell[BoxData[
    \(center3pts[p1_List, p2_List, p3_List] := \ 
      Module[{q1 = \ p1\  - \ p3, \ q2\  = p2\  - \ p3, dn, dn1, 
          dn2}, \[IndentingNewLine]dn\  = \ 
          Det[{{q1 . q1, \ q1 . q2}, {q1 . q2, 
                q2 . q2}}]; \[IndentingNewLine]If[dn\  \[Equal] \ 0, \ 
          Return[{Infinity, \ Infinity, 
              Infinity}]]; \[IndentingNewLine]dn1\  = \ 
          Det[{{q1 . q1/2, \ q1 . q2}, {q2 . q2/2, 
                q2 . q2}}]; \[IndentingNewLine]dn2\  = \ 
          Det[{{q1 . q1, \ q1 . q1/2}, {q1 . q2, 
                q2 . q2/2}}]; \[IndentingNewLine]Return[
          p3 + \((dn1*q1\  + \ dn2*q2)\)/dn]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["Knowing the center it is easy to calculate the radius:", "Text"],

Cell[BoxData[{
    \(radius3pts[p1_List, p2_List, p3_List]\  := \n\t
      Module[{\ a}, \n\t\ta\  = \ center3pts[p1, p2, p3]; \n\t\tIf[
          a\  \[Equal] {Infinity, Infinity, Infinity}, \ 
          Return[Infinity]]; \n\t\tReturn[\ 
          Sqrt[\((p1 - a)\) . \((p1\  - \ a)\)]]]\), "\n", 
    \(\t\t\)}], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[TextData[{
  StyleBox["WARNING",
    FontColor->RGBColor[1, 0, 0]],
  ": Always, if there exist a line through the three points, e.g. if the \
points coincide, center3pts and radius3pts are infinite!"
}], "Text"],

Cell[BoxData[
    \(center3pts[stb[1, 3], stb[3, 3], stb[1, 3]]\)], "Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius3pts[stb[1, 3], stb[1, 3], stb[2, 3]]\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell["\<\
Now we  give a definition of a 3D-circle through three points. The circle may \
eventually be a line (circle of infinite radius):\
\>", "Text"],

Cell[BoxData[
    \(\(?circle3pts\)\)], "Input",
  CellLabel->"In[33]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle3pts[p1_List, p2_List, p3_List]\)[t_]\  := \n\t
      Module[{q2\ , \ q3\ , \ a, \ m, r}, \[IndentingNewLine]If[
          p1\  \[Equal] \ {Infinity, Infinity, \ Infinity}, 
          Return[p2\  + \ t*\((p3 - p2)\)]]; \[IndentingNewLine]If[
          p2\  \[Equal] \ {Infinity, Infinity, \ Infinity}, 
          Return[p1\  + \ t*\((p3 - p1)\)]]; \[IndentingNewLine]If[
          p3\  \[Equal] \ {Infinity, Infinity, \ Infinity}, 
          Return[p1\  + \ t*\((p2 - p1)\)]]; \n
        m\  = \ center3pts[p1, p2, p3]; \[IndentingNewLine]If[
          m\  == \ {Infinity, Infinity, Infinity}, 
          If[smoothing[p2\  - p1]\  \[Equal] null[3], \ 
            Return[p1\  + \ t*\((p3\  - \ p1)\)], \ 
            Return[p1\  + \ 
                t*\((p2\  - \ p1)\)]]]; \[IndentingNewLine]r\  = \ 
          Sqrt[\((p1 - m)\) . \((p1\  - \ m)\)]; \t\[IndentingNewLine]\t
        q2\  = \ p2 - p1; \ q3\  = \ p3 - p1; 
        a\  = \ Cross[q2, q3]; \n\t\tq3\  = \ Cross[a, q2]; \n\t\tq2\ \  = \ 
          q2/Sqrt[q2 . q2]; \n\t\tq3\  = \ \ q3/
            Sqrt[q3 . q3]; \n\t\tm\  + \((q2\ *Cos[t]\  + \ q3*Sin[t])\)*
            r]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["Here is the corresponding plot command:", "Text"],

Cell[BoxData[
    \(plotcircle3pts[p1_List, p2_List, p3_List, opt___] := \ 
      ParametricPlot3D[
        Evaluate[\(circle3pts[p1, p2, p3]\)[t]], {t, \ \(-Pi\), \ Pi}, 
        opt]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle3pts[{1, 0, 0}, {0, 1, 0}, {0, \(-1\), 0}]\)[t]\)], "Input",
  CellLabel->"In[93]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3pts[{1, 0, 0}, {0, 1, 0}, {0, \(-1\), 0}]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle3pts[{3, 0, 0}, {3, 1, 0}, {3, \(-1\), 0}]\)[t]\)], "Input",
  CellLabel->"In[95]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3pts[{3, 0, 0}, {3, 1, 0}, {3, \(-1\), 0}]\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times"],

Cell[BoxData[{
    \(a = Random[]; \ b = Random[]; \ c = Random[];\), "\n", 
    \(\(Print[{a, b, c}];\)\), "\n", 
    \(pa = {a, 0, 0}; pb = {0, b, 0}; pc = {0, 0, c};\), "\n", 
    \(\(gr1 = plotcircle3pts[pa, pb, pc];\)\), "\n", 
    \(\(gr2\  = \ 
        Graphics3D[{PointSize[0.05], Point[pa], Point[pb], 
            Point[pc]}];\)\), "\n", 
    \(Show[{gr1, gr2}]\)}], "Input",
  CellLabel->"In[97]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(center3pts[pa, pb, pc]\)], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius3pts[pa, pb, pc]\)], "Input",
  CellLabel->"In[104]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(posvec3pts[pa, pb, pc]\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(% . %\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times"],

Cell[BoxData[{
    \(a = Random[]; \ b = Random[];\), "\n", 
    \(\(Print[{a, b}];\)\), "\n", 
    \(pa = {a, 2*b, 0}; pb = {0, \(-b\), a}; 
    pc = \((pa\  + \ pb)\)/2;\), "\n", 
    \(\(gr1 = plotcircle3pts[pa, pb, pc];\)\), "\n", 
    \(\(gr2\  = \ 
        Graphics3D[{PointSize[0.03], Point[pa], Point[pb], 
            Point[pc]}];\)\), "\n", 
    \(Show[{gr1, gr2}]\)}], "Input",
  CellLabel->"In[107]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[
    \({pa, pb, pc}\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times"],

Cell["If the three points coincide, circle3pts returns the point:", "Text"],

Cell[BoxData[
    \(\(circle3pts[{1, 0, 0}, {1, 0, 0}, {1, 0, 0}]\)[t]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3pts[{1, 0, 0}, {1, 0, 0}, {1, 0, 0}]\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times"],

Cell["\<\
If only two points coincide we get the line through these points:\
\>", "Text"],

Cell[BoxData[
    \(\(circle3pts[{1, 0, 0}, {1, 0, 0}, {2, 0, 0}]\)[t]\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3pts[{1, 0, 0}, {1, 0, 0}, {2, 0, 0}]\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3pts[{1, 3, 0}, {1, 3, 0}, {2, 0, 1}]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle3pts[{1, 3, 0}, {1, 3, 0}, {2, 0, 1}]\)[t]\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle3pts[{1, 0, 0}, {2, 0, 0}, {1, 0, 0}]\)[t]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle3pts[{1, 0, 0}, {2, 0, 0}, {2, 0, 0}]\)[t]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(posvec3pts[{1, 0, 0}, {0, 1, 0}, {0, \(-1\), 0}]\)], "Input",
  CellLabel->"In[122]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(center3pts[{1, 0, 0}, {0, 1, 0}, {0, \(-1\), 0}]\)], "Input",
  CellLabel->"In[123]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(radius3pts[{1, 0, 0}, {0, 1, 0}, {0, \(-1\), 0}]\)], "Input",
  CellLabel->"In[124]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(posvec3pts[{3, 0, 0}, {3, 1, 0}, {3, \(-1\), 0}]\)], "Input",
  CellLabel->"In[125]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(center3pts[{3, 0, 0}, {3, 1, 0}, {3, \(-1\), 0}]\)], "Input",
  CellLabel->"In[126]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(radius3pts[{3, 0, 0}, {3, 1, 0}, {3, \(-1\), 0}]\)], "Input",
  CellLabel->"In[127]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[{
    \(a = 4*Random[]; \ b = 4*Random[]; \ c = 4*Random[];\), "\n", 
    \(\(Print[{a, b, c}];\)\), "\n", 
    \(pa = {a, 0, 0}; pb = {0, b, 0}; pc = {0, 0, c};\), "\n", 
    \(\(pv\  = \ \ posvec3pts[pa, pb, pc];\)\), "\n", 
    \(\(pm\  = \ \ center3pts[pa, pb, pc];\)\), "\n", 
    \(\(Print["\<Position vector = \>", \ pv, "\<, \>", "\<center = \>", 
        pm, "\<, \>", "\<radius = \>", radius3pts[pa, pb, pc]];\)\), "\n", 
    \(\(gr1 = plotcircle3pts[pa, pb, pc];\)\), "\n", 
    \(\(gr2\  = \ 
        Graphics3D[{PointSize[0.05], Point[pa], Point[pb], 
            Point[pc]}];\)\), "\n", 
    \(\(gr3\  = \ Graphics3D[Line[{pm, pm\  + pv}]];\)\), "\n", 
    \(Show[{gr1, gr2, gr3}]\)}], "Input",
  CellLabel->"In[151]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[{
    \(a = Random[]; \ b = Random[];\), "\n", 
    \(\(Print[{a, b}];\)\), "\n", 
    \(pa = {a, b, 0}; pb = {Random[], b, Random[]*a}; 
    pc = \((pa\  + \ pb)\)/2;\), "\n", 
    \(\(Print[center3pts[pa, pb, pc], "\<, \>", 
        radius3pts[pa, pb, pc]];\)\), "\n", 
    \(\(gr1 = plotcircle3pts[pa, pb, pc];\)\), "\n", 
    \(\(gr2\  = \ 
        Graphics3D[{PointSize[0.05], Point[pa], Point[pb], 
            Point[pc]}];\)\), "\n", 
    \(Show[{gr1, gr2}]\)}], "Input",
  CellLabel->"In[138]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[{
    \(pa = 2*randomv[3]; pb = \(-3\)*randomv[3]; 
    pc = \((pa\  + \ pb)\)/2;\), "\n", 
    \(\(Print[center3pts[pa, pb, pc], "\<, \>", 
        radius3pts[pa, pb, pc]];\)\), "\n", 
    \(\(gr1 = plotcircle3pts[pa, pb, pc];\)\), "\n", 
    \(\(gr2\  = \ 
        Graphics3D[{PointSize[0.05], Point[pa], Point[pb], 
            Point[pc]}];\)\), "\n", 
    \(Show[{gr1, gr2}]\)}], "Input",
  CellLabel->"In[145]:=",
  Evaluatable->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[a, b, c, pa, pb, pc, pv, pm, gr1, gr2, gr3]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.4 An application: Tubes of a space curve", "Subsection",
  FontFamily->"Times"],

Cell["We plot a tube around the helix.", "Text"],

Cell[BoxData[
    \(\(?circle3D\)\)], "Input",
  CellLabel->"In[162]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(c1\  = ArcSin[0.5/Sqrt[1.25]]\)], "Input",
  CellLabel->"In[163]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(circle3D[Cos[s], \ Sin[s], \ 0.5\ s, s + Pi/2, c1, 
          0.1]\)[t], {s, \(-6\), 6}, {t, \ 0, \ 2\ Pi}, 
      PlotPoints\  -> \ 60]\)], "Input",
  CellLabel->"In[164]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(heltube = \ %\)], "Input",
  CellLabel->"In[165]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "Animation: Before using ThreeScript first import the package (see section \
7.1 below)! For using MVShow3D load ",
  ButtonBox["MathGL",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"],
  " !"
}], "Text"],

Cell[BoxData[
    \(ThreeScript["\<heltube.ts\>", \ heltube]\)], "Input",
  CellLabel->"In[166]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[heltube]\)], "Input",
  CellLabel->"In[168]:=",
  FontFamily->"Times"],

Cell["\<\
The following example will be generalized in the next definition:\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[\(gencircle[{Cos[s], \ Sin[s], \ 
            0.5\ s}, {\(-Sin[s]\), Cos[s], 0.5}*0.3]\)[t], {s, \(-8\), 
        8}, \n\t{t, \ 0, \ 2\ Pi}, PlotPoints\  -> \ 40]\)], "Input",
  CellLabel->"In[169]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(heltube2 = %\)], "Input",
  CellLabel->"In[170]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<heltube2.ts\>", \ heltube2]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[heltube2]\)], "Input",
  CellLabel->"In[171]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "The following definition is more general than that given in Alfred Gray's \
book",
  ButtonBox[" [1]",
    ButtonData:>"G1",
    ButtonStyle->"Hyperlink"],
  ", because we do not need the normal vectors; regularity is not assumed, \
but applied implicitely. The parameter representation of the curve must be \
one times differentiable."
}], "Text"],

Cell[BoxData[
    \(\(?tube\)\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(tube[x_, \ a_, b_, r_, \ opts___]\  := \ 
      Module[{t, s, \ w, v, \ u}, \n\t\t\t\t\tv[s_]\  := \ 
          D[x[u], u] /. u\  -> \ s; \n\t\t\t\ \ \ \ w[s_] := 
          If[v[s] . v[s] === \ 0. , 
            Return[v[s]], \n\t\t\t\t\ \ Return[\ 
              v[s]/Sqrt[
                  v[s] . v[
                      s]]]]; \n\t\t\t\t\t\t\tParametricPlot3D[\(gencircle[
              x[s], r*w[s]]\)[t], \ {s, a, b}, {t, 0, 2\ Pi}, 
          opts]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(helix1[s_]\  := \ {Cos[s], \ Sin[s], \ 0.5*s}\)], "Input",
  CellLabel->"In[172]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tube[helix1, 0, \ 6\ Pi, 0.3, \ PlotPoints\  -> \ 50]\)], "Input",
  CellLabel->"In[173]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "One finds ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " definitions of numerous examples of space curves  in Appendix A.3 of \
Alfred Gray's book [1].  We construct tubes of some of these space curves."
}], "Text"],

Cell[CellGroupData[{

Cell["Tubes of ast3d", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Here is a curve ast3d with singularities, a space curve analog of the \
astroid:\
\>", "Text"],

Cell[BoxData[
    \(curv[s_]\  := \ {Cos[s]\^3, 1.5`\ Sin[s]\^3, Cos[2\ s]}\)], "Input",
  CellLabel->"In[174]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[curv[s], \ {s, 0, 10}]\)], "Input",
  CellLabel->"In[175]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tube[curv, 0, \ 2\ Pi, 0.08, \ PlotRange\  -> \ All]\)], "Input",
  CellLabel->"In[176]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ast3\  = \ %\)], "Input",
  CellLabel->"In[177]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<ast3.ts\>", \ %]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[ast3]\)], "Input",
  CellLabel->"In[178]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tubes of a bicilinder curve", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
The next curve bicylinder is the intersection of two cylinders:\
\>", "Text"],

Cell[BoxData[
    \(curv[s_]\  := \ {Cos[s], Sin[s], \@\(4 - Sin[s]\^2\)}\)], "Input",
  CellLabel->"In[179]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[curv[s], \ {s, 0, 10}]\)], "Input",
  CellLabel->"In[180]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tube[curv, 0, \ 2\ Pi, 0.08, \ PlotRange\  -> \ All]\)], "Input",
  CellLabel->"In[181]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tubes of a loxodrome", "Subsubsection",
  FontFamily->"Times"],

Cell["Now we shall consider a loxodrome:", "Text"],

Cell[BoxData[
    \(curv[
        s_]\  := \ {\(2\ s\ Cos[Log[s]]\)\/\(1 + s\^2\), \(2\ s\ \
Sin[Log[s]]\)\/\(1 + s\^2\), \(1 - s\^2\)\/\(1 + s\^2\)}\)], "Input",
  CellLabel->"In[182]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[curv[s] . curv[s], \ s > 0]\)], "Input",
  CellLabel->"In[183]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[Log[30]]\)], "Input",
  CellLabel->"In[184]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[curv[s], \ {s, 0.1, 30}, 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[185]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[curv[s], \ {s, 0.0001, 10}]\)], "Input",
  CellLabel->"In[186]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tube[curv, 0.0001, \ 20, 0.02, PlotPoints\  \[Rule] \ 40, \ 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[187]:=",
  FontFamily->"Times"],

Cell["\<\
The following parameter transformation gives simpler formulas for the \
evaluations:\
\>", "Text"],

Cell[BoxData[
    \(Simplify[curv[s] /. \ s \[Rule] Exp[t], \ 
      t \[Element] \ Reals]\)], "Input",
  CellLabel->"In[188]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(curve[t_]\  = \ %\)], "Input",
  CellLabel->"In[189]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[curve[s], \ {s, \(-10\), 10}, 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[190]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tube[curve, \(-3\)*Pi, \ 3\ *Pi, 0.02, \ PlotRange\  -> \ All, 
      PlotPoints\  \[Rule] \ {40, 20}]\)], "Input",
  CellLabel->"In[191]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(loxotube\  = \ %\)], "Input",
  CellLabel->"In[192]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[loxotube]\)], "Input",
  CellLabel->"In[193]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tubes of torus knots", "Subsubsection",
  FontFamily->"Times"],

Cell["Now we introduce a torus knot:", "Text"],

Cell[BoxData[
    \(curv[
        s_]\  := \ {Cos[
            2\ s]\ \((1 + 2\ Cos[3\ s])\), \((1 + 2\ Cos[3\ s])\)\ Sin[2\ s], 
        Sin[3\ s]}\)], "Input",
  CellLabel->"In[194]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[curv[s], \ {s, 0. , 2\ Pi}]\)], "Input",
  CellLabel->"In[195]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(knot1\  = \ %\)], "Input",
  CellLabel->"In[196]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tube[curv, 0, \ 2\ Pi, 0.02, \ PlotRange\  -> \ All, \ 
      PlotPoints \[Rule] {50, 25}]\)], "Input",
  CellLabel->"In[197]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(knot = \ %\)], "Input",
  CellLabel->"In[198]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<knot.ts\>", knot]\)], "Input",
  FontFamily->"Times"],

Cell["\<\
Animation: Before using the next command first link MathGL3d (see section 7.2 \
below)!\
\>", "Text"],

Cell[BoxData[
    \(MVShow3D[knot]\)], "Input",
  CellLabel->"In[200]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[knot1, \ MVLineTubeSize\  -> \ 0.005]\)], "Input",
  CellLabel->"In[199]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[curv]\)], "Input",
  CellLabel->"In[201]:=",
  FontFamily->"Times"],

Cell["The general circular torus is the surface of revolution", "Text"],

Cell[BoxData[
    \(\(torussf[a_, b_]\)[u_, 
        v_] := \ {\((a + b*Cos[u])\)*Cos[v], \((a + b*Cos[u])\)*Sin[v], 
        b*Sin[u]}\)], "Input",
  CellLabel->"In[5]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(torussf[1, \ 1/3]\)[u, v], \ {u, 0, 2*Pi}, \ {v, 0, 
        2*Pi}]\)], "Input",
  CellLabel->"In[217]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(torussf\  = %\)], "Input",
  CellLabel->"In[218]:=",
  FontFamily->"Times"],

Cell["\<\
A torus knot is a curve on the torus with the parameter representation\
\>", "Text"],

Cell[BoxData[
    \(\(\(torkn[a_, b_]\)[p_, q_]\)[
        t_]\  := {\((a + b*Cos[p*t])\)*Cos[q*t], \((a + b*Cos[p*t])\)*
          Sin[q*t], b*Sin[p*t]}\)], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?LCM\)\)], "Input",
  CellLabel->"In[203]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?GCD\)\)], "Input",
  CellLabel->"In[204]:=",
  FontFamily->"Times"],

Cell["\<\
If p,q, are integers torkn is a closed curve, i.e. it is periodic with the \
smallest period 2*Pi/GCD[p,q].\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[\(\(torkn[1, 1/3]\)[2, 3]\)[t], \ {t, 0, 2*Pi}, \ 
      PlotPoints\  \[Rule] \ 100]\)], "Input",
  CellLabel->"In[205]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(kn23 = %\)], "Input",
  CellLabel->"In[206]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<kn23.ts\>", kn23]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[kn23, \ MVLineTubeSize\  \[Rule] \  .02]\)], "Input",
  CellLabel->"In[207]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(curv[t_]\  := \(\(torkn[1, 1/3]\)[2, 3]\)[t]\)], "Input",
  CellLabel->"In[208]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tube[curv, 0, 2*Pi, 0.04, PlotPoints\  \[Rule] {80, 20}]\)], "Input",
  CellLabel->"In[209]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(kntub23\  = \ %\)], "Input",
  CellLabel->"In[210]:=",
  FontFamily->"Times"],

Cell["We join the tube with the torus:", "Text"],

Cell[BoxData[
    \(Show[{torussf, kntub23}]\)], "Input",
  CellLabel->"In[224]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(torkntub23\  = \ %\)], "Input",
  CellLabel->"In[225]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[kntub23]\)], "Input",
  CellLabel->"In[211]:=",
  FontFamily->"Times"],

Cell["\<\
Best picture: use the options appearance/wire frame, toggle the background \
color:\
\>", "Text"],

Cell[BoxData[
    \(MVShow3D[torkntub23]\)], "Input",
  CellLabel->"In[226]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<kntub23.ts\>", kntub23]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(\(torkn[1, 1/3]\)[5, 2]\)[t], \ {t, 0, 2*Pi}, 
      PlotPoints\  \[Rule] \ 100]\)], "Input",
  CellLabel->"In[227]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(kn52\  = \ %\)], "Input",
  CellLabel->"In[228]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<kn52.ts\>", kn52]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[curv]\)], "Input",
  CellLabel->"In[229]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(curv[t_] := \(\(torkn[1, 1/3]\)[5, 2]\)[t]\)], "Input",
  CellLabel->"In[230]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tube[curv, 0, 2*Pi, 0.03, PlotPoints\  \[Rule] {90, 20}]\)], "Input",
  CellLabel->"In[231]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(kntub52 = %\)], "Input",
  CellLabel->"In[232]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{torussf, \ kntub52}]\)], "Input",
  CellLabel->"In[233]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(torkntub52 = %\)], "Input",
  CellLabel->"In[234]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[%]\)], "Input",
  CellLabel->"In[235]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<kntub52.ts\>", kntub52]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[\(\(torkn[1, 1/3]\)[7, 3]\)[t], \ {t, 0, 2*Pi}, 
      PlotPoints\  \[Rule] \ 100]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(kn73\  = \ %\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<kn73.ts\>", kn73]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[curv]\)], "Input",
  CellLabel->"In[212]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(curv[t_] := \(\(torkn[1, 1/3]\)[7, 3]\)[t]\)], "Input",
  CellLabel->"In[213]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tube[curv, 0, 2*Pi, 0.03, PlotPoints\  \[Rule] {90, 20}]\)], "Input",
  CellLabel->"In[214]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(kntub73 = %\)], "Input",
  CellLabel->"In[215]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{torussf, kntub73}]\)], "Input",
  CellLabel->"In[220]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(torkntub73 = %\)], "Input",
  CellLabel->"In[221]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[kntub73]\)], "Input",
  CellLabel->"In[216]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[torkntub73]\)], "Input",
  CellLabel->"In[222]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<kntub73.ts\>", kntub73]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[curv]\)], "Input",
  FontFamily->"Times"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "3 Circles defined by 2-dimensional",
  StyleBox[" euclidean v",
    FontFamily->"Lucidabright"],
  "ector subspaces (dim = 5, ind = 1)"
}], "Section",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "In M\[ODoubleDot]bius geometry a circle in the 3-sphere, or by \
stereographical projection, a circle or a line in the euclidean 3-space, is \
given by a 3-dimensional pseudo-euclidean vector subspace: the generators of \
the isotropic cone of this 3-space are the (projective) points of the circle. \
Equivalently it is defined by the orthogonal complement, that is a \
2-dimensional euclidean subspace of the 5-dimensional pseudo-euclidean vector \
space. The sets of these spaces are open orbits of the M\[ODoubleDot]bius \
group in the corresponding  Grassmann manifolds. The M\[ODoubleDot]bius group \
can be identified with two components of the pseudo-othogonal group O(4,1). \
In this section we develope certain Modules in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " establishing  the equivariant bijection between the manifold of euclidean \
2-spaces of the 5-dimensional pseudo-euclidean vector space of index 1 and \
the manifold of circles in the 3-dimensional M\[ODoubleDot]bius space \
explicitely. In the next section we apply this bijection to calculate the M\
\[ODoubleDot]bius invariants of pairs of circles,"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.1 From the subspace to the circle", "Subsection",
  FontFamily->"Times"],

Cell["\<\
In this subsection we start with an arbitrary basis of an euclidean \
2-subspace, construct a pseudo-orthonormal basis of its orthogonal complement \
and obtain, using this basis and stereographical projection,  parameter \
representation and plots of the corresponding circle.\
\>", "Text"],

Cell[CellGroupData[{

Cell["\<\
The definitions pscomplement, threepoints, circle2spv, plotcircle2spv\
\>", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Let v, w be a pair of  vectors spanning an euclidean 2-space in the \
pseudo-euclidean 5-space. Then one obtaines an pseudo-orthonormal basis of \
the wanted orthogonal complementary 3-space as follows:\
\>", "Text"],

Cell[BoxData[
    \(\(?ch\)\)], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \(\(?pscomplement\)\)], "Input",
  CellLabel->"In[16]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pscomplement[v_List, w_List] := \ 
      Module[{j = 0, w1, w2, w3, chj, d}, \[IndentingNewLine]d\  = \ 
          pssp[v, v]*pssp[w, w]\  - pssp[v, w]^2; \[IndentingNewLine]If[
          d \[LessEqual] \ 0, \ 
          Print["\<The vectors don't span a spacelike 2-space!\>"]; \ 
          Return[]]; \[IndentingNewLine]Label[chj]; \[IndentingNewLine]If[
          j \[Equal] dim, \ 
          Print["\<The complement not found. Vectors do not span an euclidean \
2-space?\>"]; Return[]; Break[], 
          j = j + 1]; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \[IndentingNewLine]\ 
        w1\  = \ pscross[{v, w, stb[j], stb[5]}]; \ \[IndentingNewLine]If[
          w1\  \[Equal] \ null[5], \ Goto[chj], \ 
          w2\  = \ pscross[{v, w, w1, stb[5]}], \[IndentingNewLine]\ 
          w2\  = \ pscross[{v, w, w1, 
                stb[5]}]]; \ \[IndentingNewLine]w3\  = \ 
          pscross[{v, w, w1, w2}]; \[IndentingNewLine]Return[{w1/
              Sqrt[pssp[w1, w1]], w2/Sqrt[pssp[w2, w2]], 
            w3/Sqrt[\(-pssp[w3, w3]\)]}]]\)], "Input",
  CellLabel->"In[259]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "Remark.  For the pseudo-euclidean cross product pscross the following \
identity is true( see exercise 2.2.14 in",
  ButtonBox[" [4]",
    ButtonData:>"O-S",
    ButtonStyle->"Hyperlink"],
  "):"
}], "Text"],

Cell[BoxData[
    \(pssp[pscross[v_List], pscross[w_List]]\  \[Equal] \ \((\(-1\))\)^ind*
        Det[Table[
            pssp[v[\([i]\)], w[\([j]\)]], {i, dim - 1}, \ {j, 
              dim - 1}]]\)], "Input",
  CellLabel->"In[295]:=",
  Evaluatable->False],

Cell["PROOF (in our case, dim = 5, ind = 1).", "Text"],

Cell[BoxData[
    \(am = Table[vec[v[i]], {i, 4}]; \ 
    bm\  = Table[vec[w[i]], {i, 4}]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(Simplify[
      pssp[pscross[am], \ pscross[bm]] + 
        Det[Table[
            pssp[am[\([i]\)], bm[\([j]\)]], {i, 4}, {j, 4}]]]\)], "Input",
  CellLabel->"In[19]:="],

Cell["\<\
Applying this identity one easily proves that the vector w3 in the module \
pscomplement must be timelike  if  the arguments span an euclidean 2-space: \
pssp[w3,w3]< 0.\
\>", "Text"],

Cell["\<\
 The following Modules yield the parameter representation of  the \
corresponding circle in the euclidean 3-space, and the corresponding plot \
command; all these definition are protected and contained in mcirc.m.\
\>", "Text"],

Cell[BoxData[
    \(\(?circle2spv\)\)], "Input",
  CellLabel->"In[17]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle2spv[v_List, w_List]\)[t_] := \ 
      Module[{psc}, \[IndentingNewLine]psc\  = \ 
          pscomplement[v, w]; \[IndentingNewLine]If[psc\  \[Equal] \ Null, \ 
          Return[]]; \[IndentingNewLine]stepro[\(-psc[\([1]\)]\)*Cos[t]\  - 
            psc[\([2]\)]*Sin[t]\  + \ psc[\([3]\)]]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?plotcircle2spv\)\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[v_List, w_List, opt___] := \ 
      ParametricPlot3D[\(circle2spv[v, w]\)[t], \ {t, 0, 2*Pi}, \ 
        opt]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
Another way: we take three  points of the circle corresponding to the \
subspace [v,w]. \
\>", "Text"],

Cell[BoxData[
    \(\(?threepoints\)\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(threepoints[v_, w_] := \ 
      Module[{b = pscomplement[v, w]}, \n\t
        If[b \[Equal] Null, Return[]; 
          Break[]]; \t\t\[IndentingNewLine]{stepro[
            b[\([3]\)] + \ \ b[\([1]\)]], \ 
          stepro[b[\([3]\)]\  - \ b[\([1]\)]], \ 
          stepro[b[\([3]\)] + \ b[\([2]\)]]}]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
Combining threepoints with circle3pts, plotcircle3pts of section 2 one \
obtaines the parameter representation circle3pts2spv[v,w][t], and the \
corresponding plotting procedure plotcircle3pts2spv:\
\>", "Text"],

Cell[BoxData[
    \(\(circle3pts2spv[v_, w_]\)[
        t_]\ \  := \ \(circle3pts[\(threepoints[v, 
              w]\)[\([1]\)], \(threepoints[v, w]\)[\([2]\)], \ \(threepoints[
              v, w]\)[\([3]\)]]\)[t]\)], "Input",
  CellLabel->"In[7]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(\(plotcircle3pts2spv[v_, w_, opt___] := 
      ParametricPlot3D[
        Evaluate[\(circle3pts2spv[v, w]\)[t]], {t, \(-Pi\), Pi}, opt]\)\(\n\)
    \)\)], "Input",
  CellLabel->"In[8]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["The possible options are those of ParametricPlot3D:", "Text"],

Cell[BoxData[
    \(Options[ParametricPlot3D]\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2 Examples, tests", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["First examples", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(pscomplement[stb[2], \ stb[3]]\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pscomplement[stb[2], \ stb[5]]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pscomplement[stb[2], \ stb[2]]\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell["\<\
The arguments v,wof pscomplement, circle2spv, plotcircle2spv  need not to be \
orthogonal or normed:\
\>", "Text"],

Cell[BoxData[
    \(pscomplement[stb[2]*c, \ stb[2] + stb[3]]\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(a = \ {t, 1, 0, 0, 0}; \ b\  = stb[2]*u\  + \ stb[1]*v; \ 
    pscomplement[a, b]\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell["\<\
Of course, it may happen that the spn of two random vectors is not euclidean. \
Try the next cell several times:\
\>", "Text"],

Cell[BoxData[
    \(pscomplement[randomv[], randomv[]]\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[Chop[pssp[%[\([i]\)], %[\([j]\)]]], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(Timing[\(circle2spv[stb[2], \ stb[3]]\)[t]]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[\(circle3pts2spv[stb[2], \ stb[3]]\)[t]]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[stb[2], \ stb[3]]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3pts2spv[stb[2], \ stb[3]]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[\(circle2spv[stb[3], \ stb[4]]\)[t]]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[\(circle3pts2spv[stb[3], \ stb[4]]\)[t]]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[plotcircle2spv[stb[3], \ stb[4]]]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[plotcircle3pts2spv[stb[3], \ stb[4]]]\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[
      plotcircle3pts[stb[1, 3], \ stb[2, 3], \(-stb[1, 3]\)]]\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell["\<\
The next example shows random circles through the point pair \
{{-1,0,0},{1,0,0}}:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      plotcircle3pts[stb[1, 3], \(-\ stb[1, 3]\), 
        randomv[3]], \ {20}]\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell["\<\
Now we construct a more regular picture of circles through the point pair \
{{-1,0,0},{1,0,0}}:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      plotcircle3pts[
        stb[1, 3], \(-\ stb[1, 3]\), {0, Cos[t*Pi], \ Sin[t*Pi]}]\ , \ {t, 0, 
        1, \ Pi/50}]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cirbdl\  = \ %\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(MVShow3D[cirbdl, \ MVLineTubeSize\  -> \ 0.01]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Frame Circles", "Subsubsection",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["The unit circle in the x,y-plane, centered at o:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(grc1 = plotcircle2spv[stb[3], \ stb[4]]\)], "Input",
  CellLabel->"In[9]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D::"ppcom" \(\(:\)\(\ \)\) 
      "Function \!\(\(\(circle2spv[\(\(\(\({0, 0, 1, 0, 0}\)\), \(\({0, 0, 0, \
1, 0}\)\)\)\)]\)\)[mcirc`Private`t]\) cannot be compiled; plotting will \
proceed with the uncompiled function."\)], "Message",
  CellLabel->"From In[9]:="],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.08594 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0569086 1.1665 -9.35124e-17 1.1665 [
[.09049 .22989 -11.8315 -9 ]
[.09049 .22989 .16848 0 ]
[.21891 .17564 -22.6146 -9 ]
[.21891 .17564 1.38537 0 ]
[.35443 .11842 -5.39155 -9 ]
[.35443 .11842 .60845 0 ]
[.49766 .05798 -15.3884 -9 ]
[.49766 .05798 2.61165 0 ]
[.64929 -0.00596 -4.86734 -9 ]
[.64929 -0.00596 1.13266 0 ]
[.00956 .8267 -6.92677 0 ]
[.00956 .8267 5.07323 9 ]
[.12085 .90474 -13.4212 0 ]
[.12085 .90474 10.5788 9 ]
[.22067 .97474 -3.26247 0 ]
[.22067 .97474 2.73753 9 ]
[.3107 1.03786 -9.54564 0 ]
[.3107 1.03786 8.45436 9 ]
[.39232 1.09509 -3.11125 0 ]
[.39232 1.09509 2.88875 9 ]
[.07325 .26221 -12 -2.6177 ]
[.07325 .26221 0 6.3823 ]
[.05474 .37813 -24 -2.72059 ]
[.05474 .37813 0 6.27941 ]
[.03462 .50418 -6 -2.83339 ]
[.03462 .50418 0 6.16661 ]
[.01266 .64173 -18 -2.95759 ]
[.01266 .64173 0 6.04241 ]
[-0.0114 .79243 -6 -3.09501 ]
[-0.0114 .79243 0 5.90499 ]
[ 0 0 0 0 ]
[ 1 1.08594 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08847 .24547 m
.67227 0 L
s
.10066 .24035 m
.10574 .24557 L
s
[(-1)] .09049 .22989 .97192 1 Mshowa
.22857 .18656 m
.2334 .19202 L
s
[(-0.5)] .21891 .17564 .88455 1 Mshowa
.36352 .12982 m
.36806 .13552 L
s
[(0)] .35443 .11842 .79718 1 Mshowa
.5061 .06987 m
.51032 .07581 L
s
[(0.5)] .49766 .05798 .70982 1 Mshowa
.65699 .00642 m
.66085 .01261 L
s
[(1)] .64929 -0.00596 .62245 1 Mshowa
.125 Mabswid
.1257 .22981 m
.12872 .23298 L
s
.15101 .21917 m
.154 .22236 L
s
.17659 .20842 m
.17955 .21164 L
s
.20244 .19755 m
.20537 .2008 L
s
.25498 .17546 m
.25784 .17876 L
s
.28167 .16423 m
.2845 .16757 L
s
.30866 .15289 m
.31145 .15625 L
s
.33594 .14142 m
.3387 .14481 L
s
.3914 .1181 m
.39409 .12155 L
s
.4196 .10624 m
.42225 .10972 L
s
.44811 .09425 m
.45073 .09776 L
s
.47695 .08213 m
.47952 .08567 L
s
.5356 .05747 m
.53809 .06106 L
s
.56542 .04493 m
.56787 .04855 L
s
.5956 .03224 m
.598 .03589 L
s
.62612 .01941 m
.62848 .02309 L
s
.25 Mabswid
0 .80399 m
.40057 1.08594 L
s
.01178 .81229 m
.01289 .80508 L
s
[(-1)] .00956 .8267 .15446 -1 Mshowa
.12256 .89026 m
.12342 .88302 L
s
[(-0.5)] .12085 .90474 .11843 -1 Mshowa
.22194 .96021 m
.22257 .95295 L
s
[(0)] .22067 .97474 .08749 -1 Mshowa
.31158 1.02331 m
.31202 1.01603 L
s
[(0.5)] .3107 1.03786 .06063 -1 Mshowa
.39286 1.08052 m
.39313 1.07323 L
s
[(1)] .39232 1.09509 .03708 -1 Mshowa
.125 Mabswid
.03494 .82859 m
.03558 .82426 L
s
.05759 .84453 m
.05819 .84019 L
s
.07973 .86011 m
.0803 .85577 L
s
.10138 .87535 m
.10192 .87101 L
s
.14329 .90485 m
.14378 .90051 L
s
.16358 .91913 m
.16404 .91478 L
s
.18344 .93311 m
.18388 .92876 L
s
.20289 .9468 m
.2033 .94245 L
s
.2406 .97334 m
.24096 .96898 L
s
.25888 .98621 m
.25922 .98185 L
s
.2768 .99883 m
.27711 .99446 L
s
.29436 1.01119 m
.29465 1.00682 L
s
.32847 1.03519 m
.32871 1.03083 L
s
.34503 1.04685 m
.34525 1.04248 L
s
.36128 1.05829 m
.36148 1.05392 L
s
.37722 1.06951 m
.3774 1.06514 L
s
.25 Mabswid
.08847 .24547 m
0 .80399 L
s
.08671 .25658 m
.09343 .25377 L
s
[(-1)] .07325 .26221 1 -0.41829 Mshowa
.0683 .37277 m
.07508 .37009 L
s
[(-0.5)] .05474 .37813 1 -0.39542 Mshowa
.04829 .49911 m
.05513 .49658 L
s
[(0)] .03462 .50418 1 -0.37036 Mshowa
.02645 .637 m
.03335 .63463 L
s
[(0.5)] .01266 .64173 1 -0.34276 Mshowa
.00252 .78809 m
.00948 .78591 L
s
[(1)] -0.0114 .79243 1 -0.31222 Mshowa
.125 Mabswid
.08314 .27906 m
.08719 .27739 L
s
.07953 .30192 m
.08357 .30026 L
s
.07585 .32514 m
.0799 .3235 L
s
.07211 .34876 m
.07617 .34713 L
s
.06444 .39718 m
.06851 .39559 L
s
.0605 .42201 m
.06458 .42044 L
s
.0565 .44727 m
.06059 .44572 L
s
.05243 .47297 m
.05653 .47143 L
s
.04408 .52572 m
.04819 .52422 L
s
.03979 .55279 m
.0439 .55131 L
s
.03542 .58036 m
.03955 .5789 L
s
.03098 .60842 m
.03511 .60698 L
s
.02184 .6661 m
.02599 .6647 L
s
.01715 .69575 m
.0213 .69437 L
s
.01236 .72595 m
.01652 .7246 L
s
.00749 .75672 m
.01166 .75539 L
s
.25 Mabswid
.08847 .24547 m
0 .80399 L
s
0 .80399 m
.40057 1.08594 L
s
.40057 1.08594 m
.41816 .58173 L
s
.41816 .58173 m
.08847 .24547 L
s
.67227 0 m
.92713 .41517 L
s
.92713 .41517 m
1 .94863 L
s
1 .94863 m
.70621 .58579 L
s
.70621 .58579 m
.67227 0 L
s
.08847 .24547 m
0 .80399 L
s
0 .80399 m
.70621 .58579 L
s
.70621 .58579 m
.67227 0 L
s
.67227 0 m
.08847 .24547 L
s
.41816 .58173 m
.92713 .41517 L
s
.92713 .41517 m
1 .94863 L
s
1 .94863 m
.40057 1.08594 L
s
.40057 1.08594 m
.41816 .58173 L
s
0 0 m
1 0 L
1 1.08594 L
0 1.08594 L
closepath
clip
newpath
.5 Mabswid
.5226 .75304 m
.54698 .75266 L
s
.49824 .75232 m
.5226 .75304 L
s
.54698 .75266 m
.57126 .75118 L
s
.47402 .75051 m
.49824 .75232 L
s
.57126 .75118 m
.59531 .74861 L
s
.45006 .7476 m
.47402 .75051 L
s
.59531 .74861 m
.61901 .74495 L
s
.42649 .74361 m
.45006 .7476 L
s
.61901 .74495 m
.64225 .74022 L
s
.40343 .73855 m
.42649 .74361 L
s
.64225 .74022 m
.66488 .73442 L
s
.381 .73243 m
.40343 .73855 L
s
.66488 .73442 m
.68679 .72758 L
s
.35934 .72528 m
.381 .73243 L
s
.68679 .72758 m
.70785 .71972 L
s
.33856 .71711 m
.35934 .72528 L
s
.70785 .71972 m
.72794 .71086 L
s
.3188 .70795 m
.33856 .71711 L
s
.72794 .71086 m
.74692 .70105 L
s
.30018 .69785 m
.3188 .70795 L
s
.74692 .70105 m
.76467 .6903 L
s
.28284 .68683 m
.30018 .69785 L
s
.76467 .6903 m
.78106 .67868 L
s
.26689 .67494 m
.28284 .68683 L
s
.78106 .67868 m
.79596 .66622 L
s
.25248 .66224 m
.26689 .67494 L
s
.79596 .66622 m
.80924 .65298 L
s
.23972 .64878 m
.25248 .66224 L
s
.80924 .65298 m
.82077 .63904 L
s
.22874 .63462 m
.23972 .64878 L
s
.82077 .63904 m
.83045 .62445 L
s
.21966 .61985 m
.22874 .63462 L
s
.83045 .62445 m
.83814 .6093 L
s
.2126 .60455 m
.21966 .61985 L
s
.83814 .6093 m
.84375 .59367 L
s
.20765 .5888 m
.2126 .60455 L
s
.84375 .59367 m
.84718 .57767 L
s
.20491 .5727 m
.20765 .5888 L
s
.84718 .57767 m
.84833 .5614 L
s
.20448 .55637 m
.20491 .5727 L
s
.84833 .5614 m
.84712 .54497 L
s
.20642 .53991 m
.20448 .55637 L
s
.84712 .54497 m
.84351 .5285 L
s
.21078 .52346 m
.20642 .53991 L
s
.84351 .5285 m
.83744 .51213 L
s
.2176 .50715 m
.21078 .52346 L
s
.83744 .51213 m
.8289 .49599 L
s
.2269 .49111 m
.2176 .50715 L
s
.8289 .49599 m
.81789 .48022 L
s
.23866 .47548 m
.2269 .49111 L
s
.81789 .48022 m
.80444 .46497 L
s
.25286 .46041 m
.23866 .47548 L
s
.80444 .46497 m
.78859 .45038 L
s
.26943 .44605 m
.25286 .46041 L
s
.78859 .45038 m
.77044 .43659 L
s
.28827 .43255 m
.26943 .44605 L
s
.77044 .43659 m
.75009 .42377 L
s
.30926 .42004 m
.28827 .43255 L
s
.75009 .42377 m
.72768 .41203 L
s
.33226 .40867 m
.30926 .42004 L
s
.72768 .41203 m
.7034 .40152 L
s
.35709 .39856 m
.33226 .40867 L
s
.7034 .40152 m
.67743 .39236 L
s
.38353 .38984 m
.35709 .39856 L
s
.67743 .39236 m
.65001 .38465 L
s
.41135 .3826 m
.38353 .38984 L
s
.65001 .38465 m
.62138 .3785 L
s
.44029 .37693 m
.41135 .3826 L
s
.62138 .3785 m
.59182 .37396 L
s
.47008 .37291 m
.44029 .37693 L
s
.59182 .37396 m
.56161 .37111 L
s
.50043 .37058 m
.47008 .37291 L
s
.56161 .37111 m
.53104 .36998 L
s
.53104 .36998 m
.50043 .37058 L
s
.25 Mabswid
.67227 0 m
.92713 .41517 L
s
.92713 .41517 m
1 .94863 L
s
1 .94863 m
.70621 .58579 L
s
.70621 .58579 m
.67227 0 L
s
.08847 .24547 m
0 .80399 L
s
0 .80399 m
.70621 .58579 L
s
.70621 .58579 m
.67227 0 L
s
.67227 0 m
.08847 .24547 L
s
.08847 .24547 m
.67227 0 L
s
.10066 .24035 m
.10574 .24557 L
s
[(-1)] .09049 .22989 .97192 1 Mshowa
.22857 .18656 m
.2334 .19202 L
s
[(-0.5)] .21891 .17564 .88455 1 Mshowa
.36352 .12982 m
.36806 .13552 L
s
[(0)] .35443 .11842 .79718 1 Mshowa
.5061 .06987 m
.51032 .07581 L
s
[(0.5)] .49766 .05798 .70982 1 Mshowa
.65699 .00642 m
.66085 .01261 L
s
[(1)] .64929 -0.00596 .62245 1 Mshowa
.125 Mabswid
.1257 .22981 m
.12872 .23298 L
s
.15101 .21917 m
.154 .22236 L
s
.17659 .20842 m
.17955 .21164 L
s
.20244 .19755 m
.20537 .2008 L
s
.25498 .17546 m
.25784 .17876 L
s
.28167 .16423 m
.2845 .16757 L
s
.30866 .15289 m
.31145 .15625 L
s
.33594 .14142 m
.3387 .14481 L
s
.3914 .1181 m
.39409 .12155 L
s
.4196 .10624 m
.42225 .10972 L
s
.44811 .09425 m
.45073 .09776 L
s
.47695 .08213 m
.47952 .08567 L
s
.5356 .05747 m
.53809 .06106 L
s
.56542 .04493 m
.56787 .04855 L
s
.5956 .03224 m
.598 .03589 L
s
.62612 .01941 m
.62848 .02309 L
s
.25 Mabswid
0 .80399 m
.40057 1.08594 L
s
.01178 .81229 m
.01289 .80508 L
s
[(-1)] .00956 .8267 .15446 -1 Mshowa
.12256 .89026 m
.12342 .88302 L
s
[(-0.5)] .12085 .90474 .11843 -1 Mshowa
.22194 .96021 m
.22257 .95295 L
s
[(0)] .22067 .97474 .08749 -1 Mshowa
.31158 1.02331 m
.31202 1.01603 L
s
[(0.5)] .3107 1.03786 .06063 -1 Mshowa
.39286 1.08052 m
.39313 1.07323 L
s
[(1)] .39232 1.09509 .03708 -1 Mshowa
.125 Mabswid
.03494 .82859 m
.03558 .82426 L
s
.05759 .84453 m
.05819 .84019 L
s
.07973 .86011 m
.0803 .85577 L
s
.10138 .87535 m
.10192 .87101 L
s
.14329 .90485 m
.14378 .90051 L
s
.16358 .91913 m
.16404 .91478 L
s
.18344 .93311 m
.18388 .92876 L
s
.20289 .9468 m
.2033 .94245 L
s
.2406 .97334 m
.24096 .96898 L
s
.25888 .98621 m
.25922 .98185 L
s
.2768 .99883 m
.27711 .99446 L
s
.29436 1.01119 m
.29465 1.00682 L
s
.32847 1.03519 m
.32871 1.03083 L
s
.34503 1.04685 m
.34525 1.04248 L
s
.36128 1.05829 m
.36148 1.05392 L
s
.37722 1.06951 m
.3774 1.06514 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From In[9]:=",
  ImageSize->{265.188, 287.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics3D  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[9]="]
}, Closed]],

Cell["\<\
This is the circle of radius 1 in the x, z-plane with center at the origin:\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(grc2 = plotcircle2spv[stb[2], stb[4]]\)], "Input",
  CellLabel->"In[127]:=",
  FontFamily->"Times"],

Cell["\<\
This is the circle of radius 1 in the y, z-plane with center at the origin:\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(grc3 = plotcircle2spv[stb[1], stb[4]]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times"],

Cell["This is the x-axis:", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(grc4 = plotcircle2spv[stb[2], stb[3]]\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times"],

Cell["This is the y-axis:", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(grc5 = plotcircle2spv[stb[1], stb[3]]\)], "Input",
  CellLabel->"In[130]:=",
  FontFamily->"Times"],

Cell["This is the z-axis:", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(grc6 = plotcircle2spv[stb[1], stb[2]]\)], "Input",
  CellLabel->"In[131]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc1, grc2, grc3, grc4, grc5, grc6}, \ 
      PlotRange\  \[Rule] \ {{\(-1.3\), 1.3}, {\(-1.3\), 1.3}, {\(-1.3\), 
            1.3}}, Boxed\  \[Rule] \ False, \ 
      Axes\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[132]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(framecir\  = \ %\)], "Input",
  CellLabel->"In[133]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Random circle, generated by a 2-space spanned by orthopair[random vector]\
\>", "Subsubsection"],

Cell["\<\
Clearly, the following vector must be spacelike with probability 1:\
\>", "Text"],

Cell[BoxData[
    \(bvec = {2*Random[], \(-2\)*Random[], 1. , 3*Random[], \ Random[]}; 
    ch[bvec]\)], "Input",
  CellLabel->"In[106]:="],

Cell["\<\
Starting with this random vector we choose an orthopair, scetch the \
corresponding circle and the corresponding thrreepoints:\
\>", "Text"],

Cell[BoxData[
    \(\((wr\  = 
        orthopair[{2*Random[], \(-2\)*Random[], 1. , 3*Random[], \ 
            Random[]}]; \ v\  = \ wr[\([1]\)]; w\  = \ wr[\([2]\)]; 
      mwr = threepoints[v, w]; \npa = mwr[\([1]\)]; pb = mwr[\([2]\)]; 
      pc = mwr[\([3]\)]; \ngr1 = plotcircle3pts[pa, pb, pc]; \n
      gr2\  = \ Graphics3D[{PointSize[0.05], Point[pa], Point[pb], 
            Point[pc]}]; \nShow[{gr1, gr2}])\)\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Remove[wr, v, w, mwr, pa, pb, pc, gr1, gr2, \ bvec]\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3 From the circle to the subspace", "Subsection",
  FontFamily->"Times"],

Cell[TextData[{
  "For the geometrical interpretations of the concepts and results defined or \
calculated in the pseudo-euclidean 5-space it is interesting to have \
expressions of the spacelike vectors as functions of the center {x,y,z}, the \
radius r, and the angles u,v which define the position vector of the circle \
in euclidean 3-space. In this and the following sections we find and apply \
such functions.  We begin with a very simple, direct definition which is best \
appropriate for all applications. Defining a distinguished, from the \
euclidean point of view, basis of the euclidean 2-space corresponding to a \
given circle, the vectors of which depend on the mentioned  euclidean \
invariants we get what we wanted.  The choice of such a basis means the \
choice of two spheres which intersect orthogonally in the given circle.  \
There are two such \"spheres\" ",
  StyleBox["canonical associated to the circle:",
    FontColor->RGBColor[1, 0, 0]],
  " The plane  containing the circle, and the sphere with the same radius and \
center containing the circle. Let us consider an arbitrary circle"
}], "Text"],

Cell[BoxData[
    \(Clear[a, b, c, x, y, z, u, v, r, t]\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle3D[x, y, z, u, v, r]\)[t]\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell["\<\
The spacelike vectors defining the associated spheres are orthogonal and span \
the spacelike 2-space of the circle. The vectors belonging to general planes \
and spheres are calculated in the notebook mspheres.nb. For a plane we have\
\>", "Text"],

Cell[BoxData[
    \(\(?planevec\)\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(planevec[a, b, c, p]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(spt[stb[4]\  + \ stb[5]]\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(stepro[stb[4]\  + \ stb[5]]\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[vec[nv], stb[4]\  + \ stb[5]]\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[planevec[a, b, c, p], stb[4]\  + \ stb[5]]\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell["\<\
We know that the property nv[[4]] == nv[[5]] is characteristic for those \
spacelike vectors nv which represent planes. The reason is that all the \
subspheres through the north pole spt[stb[4] + stb[5]] of the 3-sphere, and \
only these, are projected onto planes by the stereographic projection.  Since\
\
\>", "Text"],

Cell[BoxData[
    \({a, b, c} . {a, b, c}\  \[Equal] \ 
      pssp[{a, b, c, p, p}, {a, b, c, p, p}]\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"],

Cell["\<\
for all values of p we may define the normed vector nv easily if we found \
Hesse's normal form \
\>", "Text"],

Cell[BoxData[
    \({a, b, c} . vec[x, 3]\  \[Equal] \ p\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"],

Cell["of the plane containing the circle, with", "Text"],

Cell[BoxData[
    \({a, b, c} . {a, b, c}\  \[Equal] \ 1\)], "Input",
  CellLabel->"In[28]:=",
  FontFamily->"Times"],

Cell["\<\
Here vec[x,3] denotes the running point of the plane.  We write down the \
equation of the plane containing the circle:\
\>", "Text"],

Cell[BoxData[
    \(\((vec[x, 3] - {x, y, z})\) . \(unit[2]\)[{u, v}]\  \[Equal] \ 
      0\)], "Input",
  CellLabel->"In[29]:=",
  FontFamily->"Times"],

Cell["and recognize", "Text"],

Cell[BoxData[
    \({a, b, c}\  = \ \(unit[2]\)[{u, v}]\)], "Input",
  CellLabel->"In[30]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(p\  = \ \(unit[2]\)[{u, v}] . {x, y, z}\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell["This leads to the definition", "Text"],

Cell[BoxData[
    \(circleplane[x_, y_, z_, u_, v_]\  := {Cos[u]\ Cos[v], Cos[v]\ Sin[u], 
        Sin[v], x\ Cos[u]\ Cos[v] + y\ Cos[v]\ Sin[u] + z\ Sin[v], 
        x\ Cos[u]\ Cos[v] + y\ Cos[v]\ Sin[u] + z\ Sin[v]}\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
We emphasize that circleplane does not depend on the radius.  The second \
vector we know already:\
\>", "Text"],

Cell[BoxData[
    \(\(?spherevec\)\)], "Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell["\<\
Thus, a  vector corresponding to the sphere with the same radius and center \
as the circle does not depend on the position variables u,v; it is\
\>", "Text"],

Cell[BoxData[
    \(spherevec[x, y, z, r]\)], "Input",
  CellLabel->"In[33]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(circlespacevectors[x_, y_, z_, u_, v_, 
        r_]\  := {circleplane[x, y, z, u, v], 
        spherevec[x, y, z, r]}\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[a, b, c, p]\)], "Input",
  CellLabel->"In[34]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "Obviously, the circlespacevectors are explicitly defined in terms of  \
euclidean equivariants of the circle: radius, center, position vector. By its \
geometric definition as spacelike unit vectors such that the first \
corresponds to the plane of the circle they form  an orthonormal basis of the \
associated spacelike 2-space which is uniquely defined up to multiplications \
with  -1. If they have the mentioned property we call them ",
  StyleBox["adapted spacelike vectors",
    FontColor->RGBColor[1, 0, 0]],
  " of the circle. For a line any \"sphere\" containing it must be a plane. \
Therefore each vector v of the corresponding spacelike 2-space has the \
characteristic property ",
  Cell[BoxData[
      \(TraditionalForm\`v\_4\)]],
  " == ",
  Cell[BoxData[
      \(TraditionalForm\`v\_5\)]],
  ", and any orthonormal basis of this 2-space will be considered as adapted \
to the line."
}], "Text"],

Cell[CellGroupData[{

Cell["Tests", "Subsubsection",
  FontFamily->"Times"],

Cell["Let us check our considerations:", "Text"],

Cell[BoxData[
    \(Clear[x, y, z, u, v, r]\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(\ \)\(circlespacevectors[x, y, z, u, v, r]\)\)\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[Simplify[pssp[%[\([i]\)], %[\([j]\)]]], {i, 2}, \ {j, 2}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell["\<\
Now we show that the euclidean plotcircle3D defined in section 2 and the plot \
generated by the spacelike vectors coincide:\
\>", "Text"],

Cell[BoxData[
    \(rv\  = \ randomv[6]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tv\  = \ 
      circlespacevectors[rv[\([1]\)], \(-rv[\([2]\)]\), \ rv[\([3]\)], \ 
        rv[\([4]\)], \ rv[\([5]\)], \ 10*rv[\([6]\)]]\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3D[rv[\([1]\)], \(-rv[\([2]\)]\), \ rv[\([3]\)], \ 
      rv[\([4]\)], \ rv[\([5]\)], \ 10*rv[\([6]\)]]\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[tv[\([1]\)], \ tv[\([2]\)]]\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Remove[rv, tv]\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: A circular cylinder", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
We consider the circles generating a cylinder of radius 1 around the \
z-axis:\
\>", "Text"],

Cell[BoxData[
    \(zz[u_] := \ circlespacevectors[0, 0, u, 0, Pi/2, 1]\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(zz[u]\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[
      pssp[\(zz[u]\)[\([i]\)], \ \(zz[u]\)[\([j]\)]], \ {i, 2}, \ {j, 
        2}]\)], "Input",
  CellLabel->"In[28]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[29]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(circle2spv[\(zz[u]\)[\([1]\)], \(zz[u]\)[\([2]\)]]\)[t]\)], "Input",
  CellLabel->"In[30]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ u > 0]\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[
      Table[plotcircle2spv[\(zz[u]\)[\([1]\)], \(zz[u]\)[\([2]\)]], {u, \ 0, 
          5, 1/2}]]\)], "Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[33]:=",
  FontFamily->"Times"],

Cell[" Plotting the cylinder:", "Text"],

Cell[BoxData[
    \(Timing[
      ParametricPlot3D[
        Evaluate[\(circle2spv[\(zz[u]\)[\([1]\)], \(zz[u]\)[\([2]\)]]\)[
            t]], \ {u, \ 0. , 5}, {t, \ 0.01, \ 2\ Pi}, \ 
        PlotPoints\  \[Rule] \ 50]]\)], "Input",
  CellLabel->"In[34]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Remove[zz]\)], "Input",
  CellLabel->"In[35]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4 Adapting the frame", "Subsection",
  FontFamily->"Times"],

Cell["\<\
Often one meets the following situation: one has the euclidean 2-space given \
by an arbitrary basis, and one wants to find the corresponding circle. One \
way to do that is the following: Transform the given frame in an adapted \
frame (defined in the last section), and then read of the euclidean \
parameters from the adapted frame with the help of which one may get the \
parameter representation and the plot of the circle.  The adaption of the \
frame may be done by the following module:\
\>", "Text"],

Cell[BoxData[
    \(\(?adaptsplframe\)\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(adaptsplframe[vx_List, vy_List]\  := \ 
      Module[{aob, d1, d2, q\  = \ 0, v, nor}, \[IndentingNewLine]aob\  = \ 
          orthonorm[{vx, vy}, \ 
            normed\  \[Rule] \ False]; \[IndentingNewLine]If[
          Length[aob] < 
            2, \[IndentingNewLine]Print["\<The span is not \
2-dimensional!\>"]; Return[]]; \[IndentingNewLine]If[
          Simplify[pssp[aob[\([1]\)], \ aob[\([1]\)]]] \[LessEqual] \ 0\  || 
            Simplify[pssp[aob[\([2]\)], \ aob[\([2]\)]]] \[LessEqual] \ 
              0\ , \[IndentingNewLine]Print["\<The span is not  \
euclidean!\>"]; Return[]]; \[IndentingNewLine]d1 = 
          Simplify[\(aob[\([1]\)]\)[\([5]\)]\  - \ \
\(aob[\([1]\)]\)[\([4]\)]]; \[IndentingNewLine]d2 = \ 
          Simplify[\(aob[\([2]\)]\)[\([5]\)]\  - \ \
\(aob[\([2]\)]\)[\([4]\)]]; \[IndentingNewLine]If[d1 \[Equal] \ 0, \ q = 1; 
          Goto[nor]]; \[IndentingNewLine]If[d2 \[Equal] 0, 
          v = aob[\([1]\)]; \ aob[\([1]\)]\  = \ aob[\([2]\)]; 
          aob[\([2]\)] = \ v; q = 1]; \[IndentingNewLine]Label[
          nor]; \[IndentingNewLine]aob[\([1]\)]\  = \ 
          aob[\([1]\)]/
            Sqrt[pssp[aob[\([1]\)], \ 
                aob[\([1]\)]]]; \[IndentingNewLine]aob[\([2]\)]\  = \ 
          aob[\([2]\)]/
            Sqrt[pssp[aob[\([2]\)], \ aob[\([2]\)]]]; \[IndentingNewLine]If[
          q \[Equal] 1, Return[Simplify[aob]]]; \[IndentingNewLine]d1 = 
          Simplify[\(aob[\([1]\)]\)[\([5]\)]\  - \ \
\(aob[\([1]\)]\)[\([4]\)]]; \[IndentingNewLine]d2 = \ 
          Simplify[\(aob[\([2]\)]\)[\([5]\)]\  - \ \
\(aob[\([2]\)]\)[\([4]\)]]; \[IndentingNewLine]q\  = \ 
          Sqrt[d1^2\  + \ d2^2]; \[IndentingNewLine]v\  = \ 
          aob[\([1]\)]; \ \[IndentingNewLine]aob[\([1]\)]\  = \ 
          Simplify[\ \(-v\)*d2/q\  + \ 
              aob[\([2]\)]*d1/q]; \[IndentingNewLine]aob[\([2]\)]\  = 
          Simplify[\ 
            v*d1/q\  + \ aob[\([2]\)]*d2/q]; \[IndentingNewLine]Return[
          aob]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Tests", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(adaptsplframe[stb[1], \ stb[5]]\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(adaptsplframe[stb[1], \ stb[1]]\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(adaptsplframe[stb[1], \ stb[4]]\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(adaptsplframe[{0, Sqrt[2]*Cos[t], Sqrt[2]*Sin[t], 0, 1}, {1, 0, 0, 0, 
        0}]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(adaptsplframe[
      stb[1], {0, Sqrt[2]*Cos[t], Sqrt[2]*Sin[t], 0, 1}]\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(adaptsplframe[stb[1], {0, Cos[t], Sin[t], 0, 1}]\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(adaptsplframe[stb[1], {a, Cos[t], Sin[t], 0, a}]\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(adaptsplframe[{Cosh[s], 0, 0, 0, Sinh[s]}, {a, Cos[t], Sin[t], 0, 
        a}]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(FullSimplify[%, \ s > 0 && a > 0]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[% /. \ a\  \[Rule] \ 0]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], \ {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[49]:="],

Cell["In general, the span needs not to be euclidean", "Text"],

Cell[BoxData[
    \(vv[1] = {Cosh[s], 0, 0, 0, Sinh[s]}; 
    vv[2] = {a, Cos[t], Sin[t], 0, a}\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(Det[Table[pssp[vv[i], vv[j]], {i, 2}, {j, 2}]]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(FullSimplify[%, \ s > 0 && \ a > 0]\)], "Input",
  CellLabel->"In[44]:="],

Cell["In the next example adaptsplframe changes the order only: ", "Text"],

Cell[BoxData[
    \(adaptsplframe[{Sqrt[1 + s^2], 0, 0, 0, s}, {0, Cos[t], Sin[t], 0, 
        0}]\)], "Input",
  CellLabel->"In[28]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vx\  = \ randomv[]; \ vy\  = \ randomv[]; \ 
    ot\  = adaptsplframe[vx, vy]; ot // MatrixForm\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], \ %[\([j]\)]], \ {i, 2}, \ {j, 2}]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[vx, vy]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[ot[\([1]\)], ot[\([2]\)]]\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[vx, vy, ot, s1, t1]\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.5  Radius, center, and position vector as functions of the subspace\
\>", "Subsection",
  FontFamily->"Times"],

Cell["\<\
In this section we calculate the basic euclidean parameters radius, center, \
and position vector of the circle as functions of the  vectors v,w spanning \
an euclidean 2-space in  the pseudo-euclidean 5-space. There are two ways to \
calculate these invariants: one can use the adaption procedure adaptsplframe, \
or one can use threepoints, and the concepts of section 2.3. For numerical \
calculations the speed of both methods is nearly the same. We have chosen the \
first method with the corresponding definitions as standard concepts, and \
included them into the package mcirc.m, since it seems to be better \
appropriate for symbolic calculations.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The euclidean invariants with  frame adaption", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?circlespacevectors\)\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(circlespacevectors[x, y, z, u, v, r]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(posvec[vx_List, vy_List]\  := \ 
      Module[{ab}, \n
        ab = adaptsplframe[vx, 
            vy]; \[IndentingNewLine]If[\(ab[\([2]\)]\)[\([4]\)]\  \[Equal] \ \
\(ab[\([2]\)]\)[\([5]\)], \ Return[{0, 0, 0}]]; \[IndentingNewLine]Return[
          Take[ab[\([1]\)], 3]]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(center[vx_List, vy_List]\  := \ 
      Module[{ab}, \n
        ab = adaptsplframe[vx, 
            vy]; \[IndentingNewLine]If[\(ab[\([2]\)]\)[\([4]\)]\  \[Equal] \ \
\(ab[\([2]\)]\)[\([5]\)], \ 
          Return[{Infinity, Infinity, Infinity}]]; \[IndentingNewLine]Return[
          Take[ab[\([2]\)], 
              3]/\((\(ab[\([2]\)]\)[\([5]\)]\  - \ \
\(ab[\([2]\)]\)[\([4]\)])\)]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[vx_List, vy_List]\  := \ 
      Module[{ab}, \n
        ab = adaptsplframe[vx, 
            vy]; \[IndentingNewLine]If[\(ab[\([2]\)]\)[\([4]\)]\  \[Equal] \ \
\(ab[\([2]\)]\)[\([5]\)], \ Return[Infinity]]; \[IndentingNewLine]Return[
          1/\((\(ab[\([2]\)]\)[\([5]\)]\  - \ \
\(ab[\([2]\)]\)[\([4]\)])\)]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The euclidean invariants with threepoints", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
We take three points of circle2spv[v,w][t] with fixed parameter values, and \
calculate the invariants on the base of these three points applying the \
functions defined in section 2.3.\
\>", "Text"],

Cell[BoxData[
    \(?? threepoints\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    RowBox[{\(posvec1[v_List, w_List]\), ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({p1, p2, p3, b}\), ",", "\n", "\t\t", 
          
          RowBox[{\(b = threepoints[v, w]\), ";", "\n", 
            " ", \(If[b \[Equal] Null, Return[]; Break[]]\), ";", 
            "\[IndentingNewLine]", \(p1 = \ b[\([1]\)]\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"p1", "\[Equal]", " ", 
                  RowBox[{"{", 
                    RowBox[{
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]}], "}"}]}], ",", 
                " ", \(Return[{0, 0, 0}]\)}], "]"}], ";", "\n", 
            "\t\t", \(p2\  = \ b[\([2]\)]\), ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"p2", "\[Equal]", " ", 
                  RowBox[{"{", 
                    RowBox[{
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]}], "}"}]}], ",", 
                " ", \(Return[{0, 0, 0}]\)}], "]"}], ";", "\n", 
            "\t\t", \(p3\  = \ \ b[\([3]\)]\), ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"p3", "\[Equal]", " ", 
                  RowBox[{"{", 
                    RowBox[{
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]}], "}"}]}], ",", 
                " ", \(Return[{0, 0, 0}]\)}], "]"}], ";", "\n", 
            "\t\t", \(posvec3pts[p1, p2, p3]\)}]}], "]"}], "\n"}]], "Input",
  CellLabel->"In[10]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    RowBox[{\(center1[v_List, w_List]\), ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({p1, p2, p3, b}\), ",", "\n", "\t\t", 
          
          RowBox[{\(b = threepoints[v, w]\), ";", "\n", 
            " ", \(If[b \[Equal] Null, Return[]; Break[]]\), ";", "\t", 
            "\[IndentingNewLine]", \(p1 = \ b[\([1]\)]\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"p1", "\[Equal]", " ", 
                  RowBox[{"{", 
                    RowBox[{
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]}], "}"}]}], ",", 
                " ", \(Return[p1]\)}], "]"}], ";", "\n", 
            "\t\t", \(p2\  = \ b[\([2]\)]\), ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"p2", "\[Equal]", " ", 
                  RowBox[{"{", 
                    RowBox[{
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]}], "}"}]}], ",", 
                " ", \(Return[p2]\)}], "]"}], ";", "\n", 
            "\t\t", \(p3\  = \ \ b[\([3]\)]\), ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{"p3", "\[Equal]", " ", 
                  RowBox[{"{", 
                    RowBox[{
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]], ",", 
                      InterpretationBox["\[Infinity]",
                        DirectedInfinity[ 1]]}], "}"}]}], ",", 
                " ", \(Return[p3]\)}], "]"}], ";", "\n", 
            "\t", \(center3pts[p1, p2, p3]\)}]}], " ", "]"}], "\n"}]], "Input",\

  CellLabel->"In[11]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    RowBox[{\(radius1[v_List, w_List]\), ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({p1, p2, p3, a, \ b}\), ",", "\n", "\t\t\t", 
          
          RowBox[{\(b = threepoints[v, w]\), ";", "\[IndentingNewLine]", 
            " ", \(If[b \[Equal] Null, Return[]; Break[]]\), ";", "\t", "\n", 
            "\t\t", \(p1 = \ b[\([1]\)]\), ";", \(p2\  = \ b[\([2]\)]\), 
            ";", \(p3\  = b[\([3]\)]\), ";", "\[IndentingNewLine]", 
            RowBox[{"If", "[", 
              RowBox[{
                RowBox[{
                  RowBox[{"p1", "\[Equal]", " ", 
                    RowBox[{"{", 
                      RowBox[{
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]], ",", 
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]], ",", 
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]]}], "}"}]}], "||", 
                  RowBox[{"p2", "\[Equal]", " ", 
                    RowBox[{"{", 
                      RowBox[{
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]], ",", 
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]], ",", 
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]]}], "}"}]}], "||", 
                  RowBox[{"p3", "\[Equal]", " ", 
                    RowBox[{"{", 
                      RowBox[{
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]], ",", 
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]], ",", 
                        InterpretationBox["\[Infinity]",
                          DirectedInfinity[ 1]]}], "}"}]}]}], ",", 
                " ", \(Return[Infinity]\)}], "]"}], ";", 
            "\n", \(a\  = \ center3pts[p1, p2, p3]\), ";", "\n", 
            "\t\t", \(If[a\  == \ {Infinity, Infinity, Infinity}, 
              Return[Infinity], Sqrt[\((a - p1)\) . \((a - p1)\)], 
              Sqrt[\((a - p1)\) . \((a - p1)\)]]\)}]}], "]"}]}]], "Input",
  CellLabel->"In[12]:=",
  InitializationCell->True,
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Standard controls", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(posvec[stb[3], stb[4]]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(posvec1[stb[3], stb[4]]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(posvec[stb[1], stb[3]]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(posvec1[stb[1], stb[3]]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(center[stb[3], stb[4]]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(center1[stb[3], stb[4]]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(center[stb[2], stb[1]]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(center1[stb[2], stb[1]]\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[stb[3], stb[4]]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell["radius1 gives only non negative values, see the definition.", "Text"],

Cell[BoxData[
    \(radius1[stb[3], stb[4]]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[\(-stb[4]\), stb[1]]\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius1[\(-stb[4]\), stb[1]]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[stb[3], stb[1]]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius1[stb[3], stb[1]]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Test with random space vectors", "Subsubsection"],

Cell[BoxData[
    \(\((wr\  = 
        orthopair[{2*Random[], \(-2\)*Random[], 1. , 3*Random[], \ 
            Random[]}]; \ v\  = \ wr[\([1]\)]; 
      w\  = \ wr[\([2]\)])\)\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[posvec[v, w]]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[posvec1[v, w]]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[center[v, w]]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[center1[v, w]]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[radius[v, w]]\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[radius1[v, w]]\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[v, w]\)], "Input",
  CellLabel->"In[98]:=",
  FontFamily->"Times"],

Cell["Calculations via threepoint:", "Text"],

Cell[BoxData[{
    \(wr\  = 
      orthopair[{2*Random[], \(-2\)*Random[], 1. , 3*Random[], \ 
          Random[]}]; \ v\  = \ wr[\([1]\)]; w\  = \ wr[\([2]\)]; 
    mwr = threepoints[v, w];\), "\n", 
    \(pa = mwr[\([1]\)]; pb = mwr[\([2]\)]; pc = mwr[\([3]\)];\), "\n", 
    \(Timing[\((pv\  = \ \ posvec1[v, w]; \npm\  = \ \ center1[v, w]; \n
        Print["\<Position vector = \>", \ pv, "\<, \>", 
          pv . pv, "\<, \>", "\<center = \>", 
          N[pm], "\<, \>", "\<radius = \>", radius1[v, w]]; \n
        gr1 = plotcircle2spv[v, w]; \n
        gr2\  = \ 
          Graphics3D[{PointSize[0.05], Point[pa], Point[pb], Point[pc]}]; \n
        gr3\  = \ Graphics3D[Line[{pm, \ smoothing[pm\  + pv]}]]; \n
        Show[{gr3, gr1, gr2}])\)]\)}], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times"],

Cell["Calculations via adaptsplframe, for the same vectors:", "Text"],

Cell[BoxData[
    \(Timing[pv\  = \ \ posvec[v, w]; \npm\  = \ \ center[v, w]; \n
      Print["\<Position vector = \>", \ pv, "\<, \>", 
        pv . pv, "\<, \>", "\<center = \>", N[pm], "\<, \>", "\<radius = \>", 
        radius[v, w]]; \ngr1 = plotcircle2spv[v, w]; \n
      gr2\  = \ Graphics3D[{PointSize[0.05], Point[pa], Point[pb], 
            Point[pc]}]; \n
      gr3\  = \ Graphics3D[Line[{pm, \ smoothing[pm\  + pv]}]]; \n
      Show[{gr3, gr1, gr2}]]\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times"],

Cell["The time difference is very small: 0.04 s.", "Text"],

Cell[BoxData[
    \(Remove[wr, v, w, mwr, pa, pb, pc, pv, pm, gr1, gr2, gr3]\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times"],

Cell["\<\
The next example shows a random circle with the canonical adapted plane and \
sphere:\
\>", "Text"],

Cell[BoxData[{
    \(s1\  = \ Random[]; \ t1\  = \ Random[]*Pi;\), "\[IndentingNewLine]", 
    \(\(ot\  = \ 
        adaptsplframe[{Sqrt[1 + s1^2], 0, 0, 0, s1}, {0, Cos[t1], Sin[t1], 0, 
            0}];\)\), "\[IndentingNewLine]", 
    \(\(gt1\  = \ 
        plotcircle2spv[ot[\([1]\)], \ 
          ot[\([2]\)]];\)\), "\[IndentingNewLine]", 
    \(\(gt2\  = 
        euklidsphereplot3D[
          ot[\([1]\)], \(-Abs[radius1[ot[\([1]\)], ot[\([2]\)]]]\), 
          3*Abs[radius1[ot[\([1]\)], ot[\([2]\)]]], \(-2\)*
            Abs[radius1[ot[\([1]\)], ot[\([2]\)]]], 
          2*Abs[radius1[ot[\([1]\)], 
                ot[\([2]\)]]]];\)\), "\[IndentingNewLine]", 
    \(\(gt3 = euklidsphereplot3D[ot[\([2]\)]];\)\), "\[IndentingNewLine]", 
    \(Show[{gt1, gt2, gt3}]\)}], "Input",
  CellLabel->"In[136]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gtest\  = \ %\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times"],

Cell["Use the option wire frame and spin with trackball in MathGL:", "Text"],

Cell[BoxData[
    \(MVShow3D[gtest, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[143]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Remove[ot, s1, t1]\)], "Input",
  CellLabel->"In[144]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.6 From  three points to the subspace of the corresponding circle\
\>", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Definitions", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Let p1, p2, p3 be three pairwise distinct points in the euclidean 3-space. \
Their preimages under the stereographic projection define uniquely a circle \
on the 3-sphere, and the corresponding isotropic vectors span a \
pseudo-euclidean 3-space, the orthogonal complement of which is the euclidean \
subspace we ask for.\
\>", "Text"],

Cell[BoxData[
    \(\(?vspace\)\)], "Input",
  CellLabel->"In[145]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vspace[p1_, p2_, p3_] := 
      Module[{q1, q2, q3, j = 1, w1, w2, chj}, 
        q1 = Simplify[invstepro[p1]]; \[IndentingNewLine]q2 = 
          Simplify[invstepro[p2]]; \[IndentingNewLine]q3 = 
          Simplify[invstepro[p3]]; \[IndentingNewLine]Label[
          chj]; \[IndentingNewLine]If[j \[Equal] dim, 
          Print["\<vspace not found! Points not in general position?\>"]; 
          Return[], j = j + 1]; \[IndentingNewLine]w1 = 
          Simplify[pscross[{q1, q2, q3, stb[j]}]]; \[IndentingNewLine]If[
          smoothing[w1] \[Equal] null[dim], Goto[chj], 
          w1 = Simplify[w1/Sqrt[pssp[w1, w1]]], 
          w1 = Simplify[w1/Sqrt[pssp[w1, w1]]]]; \ \ \ \ \ \ w2 = 
          Simplify[pscross[{q1, q2, q3, w1}]]; \[IndentingNewLine]If[
          w2 \[Equal] null[dim], Goto[chj]]; \[IndentingNewLine]w2 = 
          Simplify[w2/Sqrt[pssp[w2, w2]]]; \t\tReturn[
          smoothing[{w1, w2}]]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(vspace[stb[1, 3], \ {0, 0, 0}, \ {2, 0, 0}]\)], "Input",
  CellLabel->"In[146]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vspace[stb[1, 3], \ {1, 0, 0}, \ {2, 0, 0}]\)], "Input",
  CellLabel->"In[147]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vspace[stb[1], \ {1, 0, 0}, \ {2, 0, 0}]\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[
      plotcircle3pts[{1, 0, 0}, \ {0, 1, 0}, {1, \(-1\), 0}]]\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vspace[{1, 0, 0}, \ {0, 1, 0}, {1, \(-1\), 0}]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vs = %\)], "Input",
  CellLabel->"In[151]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[plotcircle2spv[vs[\([1]\)], vs[\([2]\)]]]\)], "Input",
  CellLabel->"In[152]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[vs[\([1]\)], vs[\([2]\)]]\)], "Input",
  CellLabel->"In[153]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[154]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[center[vs[\([1]\)], vs[\([2]\)]]]\)], "Input",
  CellLabel->"In[155]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(%\  - {1, \ 0, \ 0}\)], "Input",
  CellLabel->"In[156]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Sqrt[% . %]\)], "Input",
  CellLabel->"In[157]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[posvec[vs[\([1]\)], vs[\([2]\)]]]\)], "Input",
  CellLabel->"In[158]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vspace[{1, 0, 0}, \ {0, 0, 0}, {\(-1\), 0, 0}]\)], "Input",
  CellLabel->"In[159]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vs\  = \ %\)], "Input",
  CellLabel->"In[160]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[vs[\([1]\)], vs[\([2]\)]]\)], "Input",
  CellLabel->"In[161]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[vs[\([1]\)], vs[\([2]\)]]\)], "Input",
  CellLabel->"In[162]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(center[vs[\([1]\)], vs[\([2]\)]]\)], "Input",
  CellLabel->"In[163]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle3pts[{1, 0, 0}, \ {0, 0, 0}, {\(-1\), 0, 0}]\)], "Input",
  CellLabel->"In[164]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(posvec[vs[\([1]\)], vs[\([2]\)]]\)], "Input",
  CellLabel->"In[165]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((a\  = \ Random[]; \nb\  = \ 2*Random[]; \nc\  = \ \(-\ Random[]\); \ 
      Print[TableForm[{a, b, c}]]; \n
      Timing[plotcircle3pts[{a, 0, 0}, \ {0, b, 0}, {0, 0, 
            c}]]\n)\)\)], "Input",
  CellLabel->"In[180]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[vspace[{a, 0, 0}, \ {0, b, 0}, {0, 0, c}]]\)], "Input",
  CellLabel->"In[181]:="],

Cell[BoxData[
    \(\(\(\t\)\(vs\  = \ %[\([2]\)]\)\)\)], "Input",
  CellLabel->"In[182]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[plotcircle2spv[vs[\([1]\)], vs[\([2]\)]]]\)], "Input",
  CellLabel->"In[183]:=",
  FontFamily->"Times"],

Cell["\<\
It results what could have been expected: The direct euclidean way \
constructing the circle through 3 points is much faster than constructing the \
circle by the help of vspace.\
\>", "Text"],

Cell[BoxData[
    \(Remove[a, b, c, vs]\)], "Input",
  FontFamily->"Times"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[" 4 M\[ODoubleDot]bius invariants for pairs of circles", "Section",
  FontFamily->"Times"],

Cell[TextData[{
  StyleBox["In this section we apply the general theory, see the paper ",
    FontFamily->"Lucidabright"],
  ButtonBox["[6]",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  StyleBox[",  or the book ",
    FontFamily->"Lucidabright"],
  ButtonBox["[4]",
    ButtonData:>"O-S",
    ButtonStyle->"Hyperlink"],
  StyleBox[", to the case of circles in the 3-sphere and, of course, the \
euclidean 3-space. For t",
    FontFamily->"Lucidabright"],
  "he M\[ODoubleDot]bius geometry of spheres see the notebook  mspheres.nb. \
Invariants for the other possible pairings (",
  Cell[BoxData[
      \(TraditionalForm\`S\^k\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\^m\)]],
  "), 0 \[LessEqual] k, m \[LessEqual] 3, are treated in the notebook \
pairs.nb. The expressions of the M\[ODoubleDot]bius invariants of two circles \
by their euclidean invariants obtained in subsection 4.8 are analogeous to \
the Coxeter invariant of two spheres, see the notebook mspheres.nb. They \
seems to be new (see also ",
  ButtonBox["[4]",
    ButtonData:>"O-S",
    ButtonStyle->"Hyperlink"],
  ", subsection 2.7.4)."
}], "Text"],

Cell[CellGroupData[{

Cell["4.1 Case discussion", "Subsection",
  FontFamily->"Times"],

Cell["\<\
Notations: C0, C1 two distinct circles, W0, W1 the corresponding \
3-dimensional pseudo-euclidean subspaces, U0, U1 their orthogonal (euclidean) \
complements.
Problem: Express the geometric properties and invariants of C0, C1 by \
algebraic properties and invariants of U0, U1.
Since                                  Dim(W0\[Intersection]W1) + Dim(W0 + \
W1) = Dim W0 + Dim W1= 6\t\t\t\t\t\t\t(1)
we distinguish (remember: orthogonal complement[W0\[Intersection]W1] = U0 + \
U1)
1.  Dim(W0\[Intersection]W1) = 1\t<=>Dim(U0 +U1)=4\t\t\t\t
2. Dim(W0\[Intersection]W1) = 2\t<=>Dim(U0 +U1)=3\t\t\t\t\t\t\t\t\t\t\t\t(2)
The geometric meaning of these cases is, because of (1),
Case 1 <=> Dim(W0 + W1) = 5 <=> there does not exist any 2-sphere containing \
C0\[Union]C1 <=> Dim(U0\[Intersection]U1) = 0.\t\t\t(3)
Case 2 <=> Dim(W0 + W1) = 4 <=> there exists a 2-sphere containing \
C0\[Union]C1  <=> Dim(U0\[Intersection]U1) = 1.\t\t\t\t(4)
In each of these cases we have three subcases with obvious geometric \
interpretations:
a) W0\[Intersection]W1 euclidean <=> C0\[Intersection]C1 is empty and C0, C1 \
can be separated by spheres <=> U0 + U1 is pseudo-euclidean.\t\t(5)
case 1 and b) W0\[Intersection]W1 pseudo-euclidean <=> C0\[Intersection]C1 is \
empty, C0, C1 are interlaced <=> U0 + U1 is euclidean, 4-dimensional.\t(6)
case 2 and b) W0\[Intersection]W1 pseudo-euclidean <=> C0\[Intersection]C1 \
={p0,p1} - two points <=> U0 + U1 is euclidean, 3-dimensional.\t\t(7)
c) W0\[Intersection]W1 isotropic <=> C0\[Intersection]C1 = {p} - one point \
<=> U0 + U1 is isotropic.\t\t\t\t\t\t\t\t(8)\
\>", "Text"],

Cell["\<\
Here \"separated by spheres\" means that there exist disjoint spheres S0, S1 \
with C0\[Subset]S0, C1\[Subset]S1; \"interlaced\" means that \
C0\[Intersection]C1 is empty, and such spheres do not exist: any two spheres \
S0,S1 with C0\[Subset]S0, C1\[Subset]S1 must intersect.
In the following we discuss the M\[ODoubleDot]bius invariants of the pairs in \
each of the cases and give examples.  \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2 Invariants for pairs of euclidean 2-subspaces", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Case criterion", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
If U0 and U1 are the euclidean vector subspaces spanned by the orthonormal \
bases {v1, v2}, {w1, w2} respectively, then an important equivariant entity \
for the case characterization is the pseudo-orthogonal cross product \
\>", "Text"],

Cell["C0xC1 := pscross[{v1, v2, w1, w2}].", "Text"],

Cell["\<\
By  (3) we have case 1 iff  C0xC1 does not vanish; from (5) to (8) and the \
orthogonality of C0xC1 to U0 + U1 we see, that the following disjunction \
holds:
case 1.a) <==> ch[C0xC1] = 1;
case 1.b) <==> ch[C0xC1]  = -1;
case 1.c) <==> ch[C0xC1] = 0;
case 2  <==> C0xC1 = o.
Remember:\
\>", "Text"],

Cell[BoxData[
    \(\(?ch\)\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell["Case 2 leads to", "Text"],

Cell[BoxData[
    \(ch[null[]]\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell["\<\
From the general properties of the cross product one easily concludes: 
C0xC1 is independent of the choice of the oriented orthonormal bases spanning \
U0 and U1; it changes the sign if the bases correspond to different \
orientations of U1 or U1. ch[C0xC1] depends only of the (non-oriented) \
circles C0,C1; it does not change under arbitrary, not necessarily orthogonal \
trensformations of the bases..\
\>", "Text"],

Cell[BoxData[
    \(\(\(ftest[
        t_]\)\(\ \)\(:=\)\(\ \)\(pscross[{vec[x]\ Cos[t] + \ 
            vec[y]\ Sin[t], \(-vec[x]\) Sin[t]\  + vec[y] Cos[t], \ vec[u], \ 
          vec[v]}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(D[ftest[t], \ t]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Remove[ftest]\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell["\<\
The equivariance of the vector products yields the following invariant of the \
two circles\
\>", "Text"],

Cell[BoxData[
    \(mgramdet[x_, y_, u_, v_]\  := \ 
      Module[{w}, \ w\  = \ pscross[{x, y, u, v}]; \ pssp[w, w]]\)], "Input",
  CellLabel->"In[13]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(mgramdet[stb[1], stb[2], stb[3], stb[4]]\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Random pair, case 1.a", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
We define  four vector functions such that {va1[t], va2[s]}, {wa1[u], wa2[v]} \
are orthonormal pairs for any values of s,t,u,v:\
\>", "Text"],

Cell[BoxData[
    \(\((va1[t_]\  := \ stb[3]*Cos[t]\  + \ stb[4]*Sin[t]; \ 
      va2\ [s_] := \ stb[5]*\ Sinh[s]\  + \ stb[2]*\ Cosh[s]; \n\t
      wa1[s_]\  := \ stb[3]*Cosh[s]\  + \ stb[5]*Sinh[s]; \ 
      wa2[t_]\  := \ stb[2]*Sin[t]\  + \ stb[4]*\ Cos[t]; \n
      C0xC1\  = \ pscross[{va1[t], va2[s], wa1[s], wa2[t]}])\)\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[ch[%]]\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(mgramdet[va1[t], va2[s], wa1[s], wa2[t]]\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[28]:=",
  FontFamily->"Times"],

Cell["\<\
Remark: For s = 0 or t=(2k+1]Pi/4 we have case 2. For all other values of t,s \
we have case 1. a : Non-intersecting, separated circles.\
\>", "Text"],

Cell[BoxData[{
    \(gr1 = plotcircle2spv[va1[Random[]*Pi], \ va2[Random[]*Pi]]\), "\n", 
    \(gr2\  = \ 
      plotcircle2spv[wa1[Random[]*Pi], \ wa2[Random[]*Pi]]\), "\n", 
    \(Show[{gr1, gr2}, \ PlotRange\  -> \ All]\)}], "Input",
  CellLabel->"In[35]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(separ1\  = \ %\)], "Input",
  FontFamily->"Times"],

Cell["Apply MathGL3D to visualize the mutual position!", "Text"],

Cell[BoxData[
    \(MVShow3D[separ1]\)], "Input",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Random pair, case 1.b", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
We define other four vector functions such that {vb1[t], vb2[s]}, {wb1[u], \
wb2[v]} are orthonormal pairs for any values of s,t,u,v:\
\>", "Text"],

Cell[BoxData[
    \(\((vb1[t_]\  := \ stb[3]*Cos[t]\  + \ stb[4]*Sin[t]; \ 
      vb2\ [s_] := \ \(-stb[1]\)*\ Sin[s]\  + \ stb[2]*\ Cos[s]; \n\t
      wb1[s_]\  := \ stb[1]*Cos[s]\  + \ stb[2]*Sin[s]; \ 
      wb2[t_]\  := \ \(-stb[3]\)*Sin[t]\  + \ stb[4]*\ Cos[t]; \n
      C0xC1\  = \ pscross[{vb1[t], vb2[s], wb1[s], wb2[t]}])\)\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times"],

Cell["\<\
It follows: Any two circles generated by the orthonormal pairs {v1[t], \
v2[s]}, {w1[u], w2[v]} are  interlaced. One can test it evaluating the next \
four cells and applying MathGL3d, see section 7.2 below. (By numerical \
reasons it sometimes happens that the random circles have \"corners\"; try to \
avoid that increasing the number of plotpoints.)\
\>", "Text"],

Cell[BoxData[{
    \(gr1 = plotcircle2spv[vb1[Random[]*Pi], \ vb2[Random[]*Pi]]\), "\n", 
    \(gr2\  = \ 
      plotcircle2spv[wb1[Random[]*Pi], \ wb2[Random[]*Pi]]\), "\n", 
    \(Show[{gr1, gr2}, \ PlotRange\  -> \ All]\)}], "Input",
  CellLabel->"In[123]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(inter1\  = \ %\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[inter1]\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Random pair, case 1.c", "Subsubsection",
  FontFamily->"Times"],

Cell["We shall define random circles intersecting at the origin:", "Text"],

Cell[BoxData[
    \(\((pa = randomv[3]; pb\  = \ randomv[3]; \ qa\  = \ 2*randomv[3]; \ 
      qb\  = \ 2*randomv[3]; \n\tmvp\  = \ vspace[null[3], pa, pb]; \ 
      mvq\  = vspace[null[3], qa, qb]; \n\t
      Print[smoothing[
          pscross[{mvp[\([1]\)], mvp[\([2]\)], mvq[\([1]\)], 
              mvq[\([2]\)]}]]]; \n\t\tPrint[
        ch[pscross[{mvp[\([1]\)], mvp[\([2]\)], mvq[\([1]\)], 
              mvq[\([2]\)]}]]]; \n\t
      gr1\  = \ plotcircle3pts[null[3], pa, pb]; 
      gr2\  = \ plotcircle3pts[null[3], qa, qb]; \n\t
      Show[{gr1, gr2}, \ PlotRange\  -> \ All])\)\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(onept\  = \ %\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[onept, \ MVLineTubeSize\  \[Rule] \ 0.01]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Remove[pa, pb, qa, qb, mvp, \ mvq, \ gr1, gr2]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Stationary angles", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Now we are going to describe the basic invariants for pairs of circles under \
the M\[ODoubleDot]bius group. In the next sections we then shall give further \
examples for which we calculate these invariants. As for stationary angles of \
subspaces of the euclidean space the invariants are found by considering the \
projections defined by the corresponding spacelike subspaces, see [6]. \
\>", "Text"],

Cell["\<\
pp[v1, v2, w1, w2]  is the matrix of the double projection pp= p2\
\[SmallCircle] p1, the composition of the orthogonal projections
\t\tp1: U0 -> U1, and p2: U1 -> U0, 
with respect to the base {v1, v2}. Have in mind that these bases are assumed \
to be orthonormal!\
\>", "Text"],

Cell[BoxData[
    \(\(?pp\)\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(\ \)\(pp[v1_, \ v2_, \ w1_, \ 
        w2_]\  := \ \n\ \ \ \ {{pssp[v1, \ w1]^2\  + \ 
            pssp[v1, \ w2]^2, \ \n\ \ \ \ \ \ pssp[v1, \ w1]*
              pssp[v2, \ w1]\  + \ 
            pssp[v1, \ w2]*pssp[v2, \ w2]}, \ \n\ \ \ \ \ {pssp[v1, \ w1]*
              pssp[v2, \ w1]\  + \ 
            pssp[v1, \ w2]*
              pssp[v2, \ w2], \ \n\ \ \ \ \ \ pssp[v2, \ w1]^2\  + \ 
            pssp[v2, \ w2]^2}}\)\)\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["The invariants of pp are the determinant and the trace:", "Text"],

Cell[BoxData[
    \(ppdet[v1_, \ v2_, \ w1_, \ w2_]\  := \ 
      Det[pp[v1, \ v2, \ w1, \ w2]]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(\ \ \)\(pptr[v1_, \ v2_, \ w1_, \ w2_]\  := \ 
      Sum[\(pp[v1, \ v2, \ w1, \ w2]\)[\([i, i]\)], \ {i, \ 1, \ 
          2}]\)\)\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(pp[v1, v2, w1, w2]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ppdet[v1, v2, w1, w2]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell["\<\
We see that  ppdet  is the square of the determinant of the scalar products \
pssp[xi, yj], i, j = 1, 2, and therefore always non negative:\
\>", "Text"],

Cell[BoxData[
    \(pptr[v1, v2, w1, w2]\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvalues[pp[v1, \ v2, \ w1, \ w2]]\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[58]:="],

Cell["Using the vector object", "Text"],

Cell[BoxData[
    \(vec[w1]\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell["\<\
and the fact that the M\[ODoubleDot]bius group acts transitively on the \
circles, we can always assume that the first circle is the unit circle grc1. \
Since vec[w1], vec[w2] are not orthonormal, in general, the following \
calculations give invariants under the additional assumption of the \
orthonormality of these vectors only. \
\>", "Text"],

Cell[BoxData[
    \(pssp[vec[w1], vec[w2]]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvalues[pp[stb[3], \ stb[4], \ vec[w1], vec[w2]]]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell["\<\
For shortness we write a,b,c,d instead of w1[3]=pssp[v1,w1], w2[4]= \
pssp[v2,w2],  w2[3]=pssp[v1,w2],  w1[4]=pssp[v2,w1], and consider the \
argument of Sqrt:\
\>", "Text"],

Cell[BoxData[
    \(poly[a_, b_, c_, 
        d_]\  := \ \(-4\)*\((c*d\  - \ a*b)\)^2\  + \ \((a^2\  + b^2\  + 
              c^2\  + d^2)\)^2\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Factor[poly[a, b, c, d]]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "Since the square of the first terms in Simplify[Eigenvalues] above \
coincides with ",
  Cell[BoxData[
      \(\((a\^2 + b\^2 + c\^2 + d\^2)\)\^2\)]],
  " and the first term is non negative we conclude for the eigenvalues \
\[Alpha]1, \[Alpha]2 of pp: "
}], "Text"],

Cell["\[Alpha]1 \[GreaterEqual] \[Alpha]2 \[GreaterEqual] 0.", "Text",
  TextAlignment->Center],

Cell[BoxData[
    \(Simplify[\((a\^2 + b\^2 + c\^2 + d\^2)\)\^2\  - \ \((a\^2 + 2\ a\ b + 
              b\^2 + c\^2 - 2\ c\ d + d\^2)\)\ \((a\^2 - 2\ a\ b + b\^2 + 
              c\^2 + 2\ c\ d + d\^2)\)]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?ppdet\)\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[w1, w2]\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ppdet[stb[3], \ stb[4], \ vec[w1], vec[w2]]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(mgramdet[stb[3], \ stb[4], \ vec[w1], vec[w2]]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The orthogonal case", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "If U0, U1 are mutually orthogonal, we say that the corresponding circles \
are ",
  StyleBox["orthogonal",
    FontColor->RGBColor[1, 0, 1]],
  ". Obviously, then we have case 1.b: the circles are interlaced, and the \
eigenvalues fulfil \[Alpha]1 = \[Alpha]2 = 0. Two circles are called",
  StyleBox[" isogonal",
    FontColor->RGBColor[1, 0, 1]],
  ", if the eigenvalues satisfy \[Alpha]1 = \[Alpha]2. The question about the \
existence  of non-orthogonal isogonal circles will be answered positively in \
section 4.4 with the construction of examples. Obviously, orthogonal circles \
exist:"
}], "Text"],

Cell[BoxData[
    \(gr1\  = \ plotcircle2spv[stb[1], \ stb[2]]; 
    Show[{gr1, grc1}]\)], "Input",
  CellLabel->"In[136]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pp[stb[1], stb[2], stb[3], stb[4]] // MatrixForm\)], "Input",
  CellLabel->"In[135]:=",
  FontFamily->"Times"],

Cell["\<\
The intersection angle of two spheres containing each one of the circles \
equals Pi/2:\
\>", "Text"],

Cell[BoxData[
    \(pssp[stb[1]*Cos[a] + stb[2]*Sin[a], 
      stb[3]*Cos[b]\  + stb[4]*Sin[b]]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Two circles intersecting orthogonally", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
The euclidean 2-space defining the unit circle with centre (1,0,0) in the \
x,y-plane is spanned by the orthonormal vectors\
\>", "Text"],

Cell[BoxData[
    \(c100 = circlespacevectors[1, 0, 0, 0, Pi/2, 1]\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[%[\([1]\)], %[\([2]\)]]\)], "Input",
  CellLabel->"In[85]:="],

Cell["\<\
We consider this circle together with the z-axis; the matrix of the double \
projection has eigenvalues 0, 1:\
\>", "Text"],

Cell[BoxData[
    \(pp[stb[1], stb[2], stb[3], c100[\([2]\)]]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(rank[{stb[1], stb[2], stb[3], c100[\([2]\)]}]\)], "Input",
  CellLabel->"In[81]:="],

Cell["\<\
Spheres, containing each one of these circles, are tangent to each other or \
intersect in an arbitrary angle:\
\>", "Text"],

Cell[BoxData[
    \(Clear[a, b]; \ 
    pssp[stb[1]*Cos[a]\  + \ stb[2]*Sin[a], 
      stb[3]*Cos[b] + \ c100[\([2]\)]*Sin[b]]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell["\<\
Now we replace the z-axis by the x-axis, and calculate the double \
projection\
\>", "Text"],

Cell[BoxData[
    \(pp[stb[3], stb[2], stb[3], c100[\([2]\)]]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times"],

Cell["\<\
The same matrix, but, of course,  the rank-condition is hurt:\
\>", "Text"],

Cell[BoxData[
    \(rank[{stb[3], stb[2], stb[3], c100[\([2]\)]}]\)], "Input",
  CellLabel->"In[80]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3 Case 1.a: disjoint,  non-interlaced circles", "Subsection",
  FontFamily->"Times"],

Cell["\<\
Take two disjoint spheres and a circle in each. There are lot of examples. \
\>", "Text"],

Cell[BoxData[
    \(\((v1\  = \ {1, \ 0, \ 1, \ \(-1\), \ 0}/Sqrt[3]; \ 
      v2\  = \ stb[2]\ ; \n\tw1\  = \ {3\/\@2, 1\/\@2, 0, 1\/\@2, 3\/\@2}; \ 
      w2\  = \ stb[3]\ ; \n
      C0xC1\  = \ pscross[{v1, v2, w1, w2}])\)\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ch[%]\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell["\<\
It follows: case 1.a; the circles are disjoint and separated.\
\>", "Text"],

Cell[BoxData[
    \(mgramdet[v1, v2, w1, w2]\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ppdet[v1, v2, w1, w2]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \({plotcircle2spv[v1, v2], plotcircle2spv[w1, w2]}\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%, PlotRange\  \[Rule] All]\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(testgr\  = \ %\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(pp[v1, v2, w1, \ w2]\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvalues[pp[v1, v2, w1, \ w2]]\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "The stationary values of the M\[ODoubleDot]bius invariant of two spheres  \
S0,S1 with C0\[Subset]S0, C1\[Subset]S1 are the square roots of the \
eigenvalues (see ",
  ButtonBox["below",
    ButtonData:>"stat",
    ButtonStyle->"Hyperlink"],
  ")"
}], "Text"],

Cell[BoxData[
    \(Sqrt[%]\)], "Input",
  CellLabel->"In[28]:=",
  FontFamily->"Times"],

Cell["\<\
As it follows from the general theory [6], for case 1.a is characteristic \
that the maximal eigenvalue must be greater than 1, and has multiplicity 1. \
Therefore, in case 1.a may not exist isogonal circle pairs.\
\>", "Text"],

Cell[BoxData[
    \(Eigenvectors[pp[v1, v2, w1, \ w2]]\)], "Input",
  CellLabel->"In[29]:=",
  FontFamily->"Times"],

Cell["\<\
Therefore the \"eigenspheres\" (spheres corresponding to the eigenvectors) \
containing the circle C0 are\
\>", "Text"],

Cell[BoxData[
    \(eigenv1\  = \ 
      normalize[\(-v1\)*\(\(-3\) + \@57\)\/\(4\ \@3\)\  + \ v2]\)], "Input",
  CellLabel->"In[30]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv2\  = \ 
      normalize[v1\ *\(3 + \@57\)\/\(4\ \@3\)\  + \ v2]\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell["\<\
They intersect orthogonally in the circle C0. We construct the corresponding \
picture. \
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[eigenv1]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(sp1 = %\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(euklidsphereplot3D[eigenv2]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(sp2\  = \ %\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(Show[{sp1, sp2}]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(sp12\  = \ %\)], "Input",
  CellLabel->"In[38]:="],

Cell["Now the circle C0:", "Text"],

Cell[BoxData[
    \(plotcircle2spv[v1, v2]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(grcir0\  = \ %\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(Show[{sp12, \ grcir0}]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(tgr\  = \ %\)], "Input",
  CellLabel->"In[42]:="],

Cell[TextData[{
  "Apply the option Appearance, wire frame in ",
  ButtonBox["MathGL",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[
    \(MVShow3D[tgr, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[44]:=",
  FontFamily->"Times"],

Cell["\<\
The spheres containing the circles C0, C1 are the one-parameter families \
S0[t]\[Superset]C0, S1[s]\[Superset] C1, respectively, defined by the \
spacelike unit vectors\
\>", "Text"],

Cell[BoxData[{
    \(\(uv0[t_] := \ eigenv1\ Cos[t]\  + \ \ eigenv2\ Sin[t];\)\ \), "\n", 
    \(\(uv1[s_]\  := \ w1\ Cos[s]\  + \ w2\ Sin[s];\)\)}], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell["\<\
 For the generalized cosinus of the intersection angle (see the notebook \
mspheres.nb) we calculate\
\>", "Text"],

Cell[BoxData[
    \(pssp[uv0[t], \ uv1[s]]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(fctr[s_, t_]\  = \ %;\)\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot3D[fctr[s, t], {s, 0, \ 2\ Pi}, {t, 0, 2\ Pi}]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell["\<\
The first eigenvector  of pp[v1,v2,w1,w2] corresponds to t=0 or Pi, where the \
spheres uv1[s] have the following generalized cosinus with the sphere \
eigenv1,  in this case being the cosinus of the intersection angle \
(|fctr[s,0]|<1) . It follows that all spheres containing C1 intersect the \
eigensphere eigenv1.\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ 0], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell["\<\
For t = Pi/2, 3Pi/2 we get correspondingly for the second eigenvector:\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ Pi/2], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell["\<\
It follows that there exist spheres containing C1 which do not intersect the \
sphere eigenv2, since the amplitude is larger than 1. \
\>", "Text"],

Cell[BoxData[
    \(N[fctr[0.5, Pi/2]]\)], "Input",
  CellLabel->"In[80]:="],

Cell["\<\
The amplitudes correspond to the square roots {0.347631,1.17437} of the \
corresponding eigenvalues.\
\>", "Text",
  CellTags->"stat"],

Cell["The two distinguished spheres are", "Text"],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[uv1[s\ *2\ Pi], \(-1\), 1, \(-1\), 1, \ 
        PlotPoints\  -> \ 30], \ {s, \ 0.3, \ 0.5, \ 0.1}]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(testgr1 = \ %\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[testgr1]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(testgr1\  = \ %\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[w1, w2]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(grcir1\  = \ %\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(Show[{tgr, testgr1, grcir1}]\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(collpic\  = \ %\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \(MVShow3D[collpic, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell["\<\
Now we find a sphere containing C1, and not intersecting the sphere eigenv2, \
namely\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[uv1[Pi]]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(sphpi\  = \ %\)], "Input",
  CellLabel->"In[85]:="],

Cell["\<\
In the next picture the big visible sphere is the eigensphere sp2 containing \
the circle C0; within it we have the not intersecting sphere sphpi containing \
the circle C1. The two spheres separate the circles. Use MVShow3D as in the \
next cell, and apply Appearance/ wire frame to see them.\
\>", "Text"],

Cell[BoxData[
    \(Show[{sphpi, sp2, \ grcir0, grcir1}]\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \(sepsphs\  = %\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(MVShow3D[sepsphs, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times"],

Cell["There are many possibilities for experimental graphics...", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.4 Case 1.b: Interlaced circles", "Subsection",
  FontFamily->"Times"],

Cell["\<\
Already in section 4.2, the orthogonal case,  we have seen the standard unit \
circle in the x,y-plane and the z-axis are interlaced \"circles\". We give \
now examples of isogonal and non-isogonal interlaced circle pairs.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Example: Isogonal circles", "Subsubsection",
  FontFamily->"Times"],

Cell["A first example  of an isogonal pair: ", "Text"],

Cell[BoxData[
    \(\((w1\  = {1, 0, 1, 1, 0}/Sqrt[3]; \ 
      w2\  = \ {0, 1, \(-1\), 1, 0}/Sqrt[3]; \n
      griso\  = \ plotcircle2spv[w1, w2])\)\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc1, griso}]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isosph = %\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[isosph, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times"],

Cell["\<\
We again got an interlaced pair of circles.  The unique eigenvalue is 2/3:\
\>", "Text"],

Cell[BoxData[
    \(pp[stb[3], \ stb[4], w1, \ w2]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times"],

Cell["\<\
The spheres containing the circles C0, C1 are the one-parameter families \
S0[t]\[Superset]C0, S1[s]\[Superset] C1 defined by the spacelike unit vectors\
\
\>", "Text"],

Cell[BoxData[{
    \(\(uv0[t_] := \ stb[3]\ Cos[t]\  + \ \ stb[4]\ Sin[t];\)\ \), "\n", 
    \(\(uv1[s_]\  := \ w1\ Cos[s]\  + \ w2\ Sin[s];\)\)}], "Input",
  CellLabel->"In[122]:=",
  FontFamily->"Times"],

Cell["\<\
Any pair (S0[t], S1[s]]) intersects in a certain circle, since (C0,C1) are \
interlaced. For the cosinus of the intersection angle (see the notebook \
mspheres.nb) we calculate\
\>", "Text"],

Cell[BoxData[
    \(Simplify[pssp[uv0[t], \ uv1[s]]]\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctr[s_, t_]\  = \ %\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot3D[fctr[s, t], {t, 0, 2\ Pi}, \ {s, 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[126]:=",
  FontFamily->"Times"],

Cell["\<\
We do not have distinguished eigenspheres: since the eigenvalue has \
multiplicity 2, any sphere S0[t] \[Superset] C0 generates the same angle \
function with the family (S1[s]) (up to a phase translation). Therefore we \
called the circle pair (C0, C1) isogonal. In concordance with the  general \
theory  the maximum is the square root of the eigenvalue:\
\>", "Text"],

Cell[BoxData[
    \(fctr[0, \ Pi/4]\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctr[0, \ 5\ Pi/4]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times"],

Cell["\<\
Since pssp[-n, m] = - pssp[n, m], we get all relative minimal values as the \
negatives of the relative maximal values, changing the orientation of one of \
the spheres.  \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Family of circles,  isogonal to the unit circle grc1", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "Now we construct a family of isogonal pairs containing examples for any \
eigenvalue between 0 and 1. By the general theory it follows, that any pair \
of isogonal circles is M\[ODoubleDot]bius equivalent to a uniquely defined \
member of this family.\nArgumentation: By theorem 6 of ",
  ButtonBox["[6]",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  " the eigenvalues are a complete system of invariants for pairs of circles \
not contained in a 2-sphere.  From the case discussion in this paper, cases 1 \
and 4, there exists at most one eigenvalue \[GreaterEqual] 1, and then it has \
multiplicity 1. Since the eigenvalues are all non-negative, in the isogonal \
case  the unique eigenvalue \[Alpha] fulfils 0 \[LessEqual] \[Alpha] < 1. For \
 \[Alpha] = 0 the circles are orthogonal, and this is a special case of \
isogonal. We shall see that in the family we are going to construct exists \
for any  \[Alpha], 0 < \[Alpha]  < 1,  exactly one member. "
}], "Text"],

Cell[BoxData[{
    \(\(iso1[s_]\  := \ {1, \ 0, \ 1/Cosh[s]\ , \ 1/Sinh[s], 0}/
          Sqrt[1\  + \ 1/Cosh[s]^2 + 1/Sinh[s]^2];\)\), "\n", 
    \(\t\t\(iso2[s_]\  := \ {0, 1, \ 1/Sinh[s]\ , \ \(-1\)/Cosh[s], 0}/
          Sqrt[1\  + \ 1/Cosh[s]^2 + 1/Sinh[s]^2];\)\), "\n", 
    \(grisofam[s_]\  := \ {iso1[s], iso2[s]}\)}], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(grisofam[s]\)\(\ \)\)\)], "Input",
  CellLabel->"In[154]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(iso2[s]\)], "Input",
  CellLabel->"In[155]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[pssp[iso1[s], iso1[s]]]\)], "Input",
  CellLabel->"In[156]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pp[stb[3], \ stb[4], \ iso1[s], \ iso2[s]]\)], "Input",
  CellLabel->"In[157]:=",
  FontFamily->"Times"],

Cell["\<\
This diagonal matrix show that for any value of s the eigenvalues coincide; \
as a function of s thecommon eigenvalue is\
\>", "Text"],

Cell["\<\
f[s_] := Csch[s]^2/(1 + Csch[s]^2 + Sech[s]^2) + 
   Sech[s]^2/(1 + Csch[s]^2 + Sech[s]^2)\
\>", "Input",
  CellLabel->"In[159]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(f[s]\  - \ \((Cosh[s]^2\  + \ Sinh[s]^2)\)/\((Cosh[s]^2\  + \ 
            Sinh[s]^2\  + Cosh[s]^2\ *Sinh[s]^2)\)\)], "Input",
  CellLabel->"In[160]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Together[%]\)], "Input",
  CellLabel->"In[161]:=",
  FontFamily->"Times"],

Cell["\<\
Therefore avoiding the poles will give a better definition for f:\
\>", "Text"],

Cell[BoxData[
    \(f[s_]\  := \ \((Cosh[s]^2\  + \ Sinh[s]^2)\)/\((Cosh[s]^2\  + \ 
            Sinh[s]^2\  + Cosh[s]^2\ *Sinh[s]^2)\)\)], "Input",
  CellLabel->"In[162]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[f[s], \ {s, 0, 5}]\)], "Input",
  CellLabel->"In[163]:=",
  FontFamily->"Times"],

Cell["\<\
The case s= 0 , f(0) = 1, does not give a circle since s = 0 is a singularity \
of grisofam:\
\>", "Text"],

Cell[BoxData[
    \(grisofam[0]\)], "Input",
  CellLabel->"In[164]:=",
  FontFamily->"Times"],

Cell["\<\
Sometimes it is useful to create a circle family instead of a circle surface. \
In mcirc.m is defined\
\>", "Text"],

Cell[BoxData[
    \(circlefamily[v_, w_, t_, a_, b_, \ d_:  20, \ opt___]\  := \ 
      Table[plotcircle2spv[v[t], w[t], opt], {t, \ a, \ 
          b, \ \((b - a)\)/d}]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(circlefamily[iso1, iso2, t, 0.1, 2.1, 10, \ 
      PlotPoints \[Rule] 80]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isofam\  = \ {grc1, %}\)], "Input",
  CellLabel->"In[166]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[167]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isofam = \ %\)], "Input",
  CellLabel->"In[168]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[isofam, \ MVLineTubeSize\  \[Rule] 0.02]\)], "Input",
  CellLabel->"In[169]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<isofam.ts\>", isofam]\)], "Input",
  FontFamily->"Times"],

Cell["The circle family isofam is contained in the circle surface ", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[\(circle2spv[\(grisofam[s]\)[\([1]\)], \ \(grisofam[
              s]\)[\([2]\)]]\)[t], \n\t{s, \ 0.1, 2.1}, \ {t, 0, \ 
        2\ \ Pi}, \ PlotPoints\  -> \ 20]\)], "Input",
  CellLabel->"In[172]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isosf\  = \ %\)], "Input",
  CellLabel->"In[173]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc1, isosf}]\)], "Input",
  CellLabel->"In[174]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isosf = \ %\)], "Input",
  CellLabel->"In[175]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[isosf, \ MVLineTubeSize\  \[Rule] 0.02]\)], "Input",
  CellLabel->"In[176]:=",
  FontFamily->"Times"],

Cell["\<\
Constructing smaller parts of the circle surface, e.g.  for 0.5 < s < 1.5, is \
recommended.\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[\(circle2spv[\(grisofam[s]\)[\([1]\)], \ \(grisofam[
              s]\)[\([2]\)]]\)[t], \n\t{s, \ 0.4, 1.7}, \ {t, 0, \ 
        2\ \ Pi}, \ PlotPoints\  \[Rule] 20]\)], "Input",
  CellLabel->"In[177]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isosfb\  = \ %\)], "Input",
  CellLabel->"In[178]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc1, isosfb}]\)], "Input",
  CellLabel->"In[179]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isosfb = %\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(isosfc = {isosfb, \ grc1}\)], "Input",
  CellLabel->"In[181]:="],

Cell[BoxData[
    \(Show[isosfc]\)], "Input",
  CellLabel->"In[184]:="],

Cell[BoxData[
    \(isosfc\  = \ %\)], "Input",
  CellLabel->"In[185]:="],

Cell[BoxData[
    \(MVShow3D[isosfc, \ MVLineTubeSize\  \[Rule] 0.02]\)], "Input",
  CellLabel->"In[186]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<isosfb.ts\>", isosfb]\)], "Input",
  FontFamily->"Times"],

Cell["\<\
This surface has no selfintersections, but its border  consists of two \
interlaced circles:\
\>", "Text"],

Cell[BoxData[
    \(plotcircle2spv[\(grisofam[ .4]\)[\([1]\)], \ \(grisofam[ \
.4]\)[\([2]\)]]\)], "Input",
  CellLabel->"In[187]:="],

Cell[BoxData[
    \(isoc1\  = \ %\)], "Input",
  CellLabel->"In[188]:="],

Cell[BoxData[
    \(plotcircle2spv[\(grisofam[1.7]\)[\([1]\)], \ \(grisofam[
          1.7]\)[\([2]\)]]\)], "Input",
  CellLabel->"In[189]:="],

Cell[BoxData[
    \(isoc2 = %\)], "Input",
  CellLabel->"In[190]:="],

Cell[BoxData[
    \(Show[{isoc1, isoc2}]\)], "Input",
  CellLabel->"In[191]:="],

Cell[BoxData[
    \(isocs\  = \ %\)], "Input",
  CellLabel->"In[192]:="],

Cell[BoxData[
    \(MVShow3D[isocs, \ MVLineTubeSize\  \[Rule] 0.02]\)], "Input",
  CellLabel->"In[193]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The geometric meaning of  'isogonal'", "Subsubsection",
  FontFamily->"Times"],

Cell["Spheres, containing the circles:", "Text",
  FontSize->18],

Cell[BoxData[
    \(Clear[fct, s, b, a, \ sph2]\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(sph1[a_]\  := \ {0, 0, Cos[a], \ Sin[a], 0}\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(sph2[s_, b_]\  := \ iso1[s]*Cos[b]\  + \ iso2[s]*Sin[b]\)], "Input",
  CellLabel->"In[33]:=",
  FontFamily->"Times"],

Cell["\<\
The cosinus of the intersection angle of two of such spheres is:\
\>", "Text"],

Cell[BoxData[
    \(\(fct[s_]\)[a_, b_] := \ pssp[sph1[a], \ sph2[s, b]]\)], "Input",
  CellLabel->"In[36]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(fct[s]\)[a, b]\)], "Input",
  CellLabel->"In[37]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[38]:=",
  FontFamily->"Times"],

Cell["\<\
Clearly, for fixed a (or b) the resulting functions of  b (resp. a) are \
cos--functions with the same amplitude, depending on s only, and distinct \
phases.  For non isogonal interlaced circle pairs the amplitude is not \
constant (see the next subsection).\
\>", "Text"],

Cell[BoxData[
    \(Plot3D[\(fct[1. ]\)[a, b], {a, 0, 2*Pi}, {b, 0, 2*Pi}]\)], "Input",
  CellLabel->"In[39]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tgri = \ %\)], "Input",
  CellLabel->"In[40]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[tgri]\)], "Input",
  CellLabel->"In[42]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[a, b]; \ a\  = 2*Pi*\ Random[]; \ 
    Plot[\(fct[1. ]\)[a, b], {b, 0, 2*Pi}]; a\)], "Input",
  CellLabel->"In[43]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[\ \((a\  = 2*Pi*Random[]; \ 
        Plot[\(fct[1. ]\)[a, b], {b, 0, 2*Pi}])\), {5}]\)], "Input",
  CellLabel->"In[44]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Intersection angle for spheres containing  interlaced, but non isogonal \
circles\
\>", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[a, b, br1, br2, sph1, \ sph2]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(sph1[a_]\  := \ {0, 0, Cos[a], \ Sin[a], 0}\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell["Here are two orthonormal vectors defined \"at random\":", "Text"],

Cell[BoxData[
    \(br1\  = \ {\(-0.72439280526\), 0, 0.6893874554, 0, 0}\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(br2 = \ {0, \(-0.33744663644\), 0, 0.9413446593, 0}\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[br1, br2]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[br1, br1]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[br2, br2]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pscross[{stb[3], stb[4], br1, br2}]\)], "Input",
  CellLabel->"In[74]:="],

Cell["Clearly, this is case 1 b); the circles are interlaced.", "Text"],

Cell[BoxData[
    \(pp[stb[3], stb[4], br1, br2]\)], "Input",
  CellLabel->"In[63]:="],

Cell["The eigenvalues differ; the circles are not isogonal.", "Text"],

Cell[BoxData[
    \(plotcircle2spv[br1, br2]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(tcir\  = \ %\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(Show[{grc1, tcir}]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(MVShow3D[%, \[IndentingNewLine]\ MVLineTubeSize\  -> \ 0.03]\)], "Input",\

  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell["\<\
Again we calculate the M\[ODoubleDot]bius invariant (the cosinus of the \
intersection angle) of two spheres each containing one of the  circles:\
\>", "Text"],

Cell[BoxData[
    \(sph2[b_]\  := br1*Cos[b]\  + br2*Sin[b]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fct2[a_, b_] := \ pssp[sph1[a], \ sph2[b]]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fct2[a, b]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot3D[fct2[a, b], {a, 0, 2*Pi}, {b, 0, 2*Pi}]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ptgr\  = \ %\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[ptgr]\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell["\<\
For fixed a (or b) we again have cos-functions; now the amplitude depends on \
a:\
\>", "Text"],

Cell[BoxData[
    \(Clear[a, b]; \ a\  = \ Random[]; \ Plot[fct2[a, b], {b, 0, 2*Pi}]; 
    a\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[a]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell["The amplitude of fct2[.,b] as function of a is", "Text"],

Cell[BoxData[
    \(amplitude[a_]\  := 
      Sqrt[\((0.689387455\ Cos[a]\ )\)^2 + \((0.9413446593\ *
                Sin[a])\)^2]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[amplitude[a], \ {a, 0, 2*Pi}]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.5 Case 1c: Circles intersecting in exactly one point", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["First example", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
See also the random pair, case 1.c, in section 4.2. Now we take circles \
intersecting at the origin in orthogonal planes:\
\>", "Text"],

Cell[BoxData[
    \(circlespacevectors[0, 1, 0, 0, Pi/2, \ 1]\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v1\  = \ %[\([1]\)]\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v2\  = \ %%[\([2]\)]\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[v1, \ v2]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cir1\  = \ %\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(radius[v1, v2]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(center[v1, v2]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(posvec[v1, v2]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(circlespacevectors[0, 0, 1, 0, 0, \ 1]\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(w1\  = \ %[\([1]\)]\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(w2\  = \ %%[\([2]\)]\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[w1, w2]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(center[w1, w2]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(posvec[w1, w2]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(plotcircle2spv[w1, w2]\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cir2\  = \ %\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(pscross[{v1, v2, w1, w2}]\)], "Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell["\<\
The isotropic vector corresponding to the intersection must be orthogonal to \
v1,v2,w1,w2; thus, the intersection is\
\>", "Text"],

Cell[BoxData[
    \(stepro[%]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(ch[%%]\)], "Input",
  CellLabel->"In[34]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(rank[{v1, v2, w1, w2}]\)], "Input",
  CellLabel->"In[28]:="],

Cell["\<\
It follows: case 1.c; the circles are intersecting in one point and are in \
\"general position\", as show the graphics: \
\>", "Text"],

Cell[BoxData[
    \(Show[{cir1, cir2}]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(testgr\  = \ %\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[testgr, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell["The matrix of the double projection", "Text"],

Cell[BoxData[
    \(pp[v1, v2, w1, \ w2]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell["has eigenvalues 1 and 0.  The corresponding eigenvectors ", "Text"],

Cell[BoxData[
    \(Eigenvectors[pp[v1, v2, w1, \ w2]]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell["\<\
give the \"eigenspheres\" (spheres corresponding to the eigenvectors) \
containing the circle C0:\
\>", "Text"],

Cell[BoxData[
    \(eigenv1\  = v1\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv2\  = \ v2\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?euklidsphereplot3D\)\)], "Input",
  CellLabel->"In[52]:="],

Cell["Graphics of the two  eigenspheres are given by", "Text"],

Cell[BoxData[
    \({euklidsphereplot3D[eigenv1, \ \(-1\), 1, 0, 2], 
      euklidsphereplot3D[eigenv2]}\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%, \ 
      PlotRange\  -> \ {{\(-1\), 1}, {0, 2}, {\(-1\), 1}}]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigensph\  = \ %\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigensph\  = {%, \ cir1}\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(eigensph\  = \ %\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(MVShow3D[eigensph, \ MVLineTubeSize\  -> \ 0.02]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell["\<\
They intersect orthogonally in the circle C0. The spheres containing the \
circles C0, C1 are the one-parameter families S0[t]\[Superset]C0, S1[s]\
\[Superset] C1 defined by the spacelike unit vectors\
\>", "Text"],

Cell[BoxData[{
    \(\(uv0[t_] := \ eigenv1\ Cos[t]\  + \ \ eigenv2\ Sin[t];\)\ \), "\n", 
    \(\(uv1[s_]\  := \ w1\ Cos[s]\  + \ w2\ Sin[s];\)\)}], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell["\<\
 For the generalized cosinus of the intersection angle (see the notebook \
mspheres.nb) we calculate\
\>", "Text"],

Cell[BoxData[
    \(pssp[uv0[t], \ uv1[s]]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctr[s_, t_]\  = \ %\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot3D[fctr[s, t], {s, 0, \ 2\ Pi}, {t, 0, 2\ Pi}]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell["\<\
The first eigenvector  of pp[v1,v2,w1,w2] corresponds to t=0 or Pi, where the \
spheres uv1[s] have the generalized cosinus with the sphere eigenv1 . Its \
maaximum is the square root of the eigenvlue, 1 in our case:\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ 0], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(uv1[Pi/2]\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \(euklidsphereplot3D[%]\)], "Input",
  CellLabel->"In[106]:="],

Cell[TextData[{
  "For t = Pi/2, 3Pi/2 we get correspondingly to the second eigenvector the \
value 0; but here ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " calculates too much:"
}], "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ Pi/2], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell["\<\
Clearly, that means zero; we have only numerical errors,  remember:\
\>", "Text"],

Cell[BoxData[
    \(fctr[s, t]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctr[s, Pi/2]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times"],

Cell["\<\
It is a surprise by plotting zero to get a  sin curve. Try better\
\>", "Text"],

Cell[BoxData[
    \(Plot[Evaluate[fctr[s, \ Pi/2]], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[80]:=",
  FontFamily->"Times"],

Cell["Here are five spheres through the circle C1:", "Text"],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[uv1[s\ *\ Pi], \(-1\), 1, \(-1\), 1, \ 
        PlotPoints\  -> \ 20], \ {s, \ 0. , \ 0.5, \ 0.1}]\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(testgr1 = \ %\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[126]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[eigenv1, \ \(-1\), 7, \(-4\), 4]\)], "Input",
  CellLabel->"In[127]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(testgr2 = \ Flatten[{%%, cir2, %}]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(testgr2\  = \ %\)], "Input",
  CellLabel->"In[130]:=",
  FontFamily->"Times"],

Cell["\<\
The next picture visualize the intersection angle of the spheres through C1 \
with the eigensphere to the eigenvalue 1, beiing the x,y-plane (use \
wireframe)\
\>", "Text"],

Cell[BoxData[
    \(MVShow3D[testgr2, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[133]:="],

Cell["\<\
Remark: The value s = 0 gives the y,z-plane, and s= Pi/2 yields the maximum \
value 1: the sphere is tangent to eigenv1, the x,y-plane: \
\>", "Text"],

Cell[BoxData[
    \(Table[vradius[uv1[s\ *\ Pi]], \ {s, \ 0. , \ 0.5, \ 0.1}]\)], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \(Table[vcenter[uv1[s\ *\ Pi]], \ {s, \ 0. , \ 0.5, \ 0.1}]\)], "Input",
  CellLabel->"In[132]:="],

Cell["\<\
Now we shall visualize the intersection angle with the second eigensphere, \
which  equals Pi/2 cor ll values of s:\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[eigenv2]\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(ev2\  = \ %\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \(Show[Flatten[{ev2, cir2, testgr1}]]\)], "Input",
  CellLabel->"In[136]:="],

Cell[BoxData[
    \(testgr3\  = \ %\)], "Input",
  CellLabel->"In[137]:="],

Cell["\<\
The small sphere not containing C1 is the eigensphere; use Appearance, wire \
frame in the next picture.\
\>", "Text"],

Cell[BoxData[
    \(MVShow3D[testgr3, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[139]:="],

Cell["There are many possibilities for experimental graphics...", "Text"],

Cell[BoxData[
    \(Remove[testgr2, v1, v2, w1, w2, fctr, testgr1, testgr, testgr2, 
      testgr3, \ grsph1, uv1, uv0]\)], "Input",
  CellLabel->"In[140]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["===>>>Another example", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(vspace[{1, 0, 0}, {2, 0.5, 1.5}, {2.8, 0, 0}]\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(bsp\  = \ smoothing[%]\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v1\  = stb[3]\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v2\  = \ stb[4]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(w1\  = \ bsp[\([1]\)]\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(w2\  = \ bsp[\([2]\)]\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \({plotcircle2spv[v1, \ v2], plotcircle2spv[w1, w2]}\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(exp1c2\  = \ %\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pscross[{v1, v2, w1, w2}]\)], "Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ch[%]\)], "Input",
  CellLabel->"In[33]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Chop[stepro[%%]]\)], "Input",
  CellLabel->"In[34]:="],

Cell["\<\
This corresponds to case 1.c. The unique intersection point is {1,0,0}.\
\>", "Text"],

Cell[BoxData[
    \(pp[v1, v2, w1, \ w2]\)], "Input",
  CellLabel->"In[35]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvalues[%]\)], "Input",
  CellLabel->"In[36]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvectors[pp[v1, v2, w1, \ w2]]\)], "Input",
  CellLabel->"In[37]:=",
  FontFamily->"Times"],

Cell["\<\
Therefore the \"eigenspheres\" (spheres corresponding to the eigenvectors) \
containing the circle C0 are\
\>", "Text"],

Cell[BoxData[
    \(eigenv1\  = 
      normalize[\(-v1\)*0.532813269686138823`\  - \ 
          v2*0.846232840089750837`]\)], "Input",
  CellLabel->"In[38]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv2\  = 
      normalize[
        v2*0.532813269686138823`\  - \ v1*0.846232840089750837`]\)], "Input",
  CellLabel->"In[39]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \({euklidsphereplot3D[eigenv1], euklidsphereplot3D[eigenv2]}\)], "Input",
  CellLabel->"In[40]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%, \ PlotRange\  -> All]\)], "Input",
  CellLabel->"In[41]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigensph\  = \ %\)], "Input",
  CellLabel->"In[42]:=",
  FontFamily->"Times"],

Cell["\<\
They intersect orthogonally in the circle C0. The spheres containing the \
circles C0, C1 are the one-parameter families S0[t]\[Superset]C0, S1[s]\
\[Superset] C1 defined by the spacelike unit vectors\
\>", "Text"],

Cell[BoxData[{
    \(\(uv0[t_] := \ eigenv1\ Cos[t]\  + \ \ eigenv2\ Sin[t];\)\ \), "\n", 
    \(\(uv1[s_]\  := \ w1\ Cos[s]\  + \ w2\ Sin[s];\)\)}], "Input",
  CellLabel->"In[43]:=",
  FontFamily->"Times"],

Cell["\<\
 For the generalized cosinus of the intersection angle (see the notebook \
mspheres.nb) we calculate\
\>", "Text"],

Cell[BoxData[
    \(pssp[uv0[t], \ uv1[s]]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctr[s_, t_]\  = \ %\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot3D[fctr[s, t], {s, 0, \ 2\ Pi}, {t, 0, 2\ Pi}]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell["\<\
The first eigenvector  of pp[v1,v2,w1,w2] corresponds to t=0 or Pi, where the \
spheres uv1[s] have the followwing generalized cosinus with the sphere \
eigenv1 :\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ 0], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell["\<\
For t = Pi/2, 3Pi/2 we get correspondingly for the second eigenvector:\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ Pi/2], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[eigenv1, uv1[s]]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(uv1[s]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv1\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell["\<\
The amplitudes correspond to the square roots of the corresponding \
eigenvalues: 1., .\
\>", "Text"],

Cell[BoxData[
    \(Sqrt[0.0737033666969973921`]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Remove[bsb, eigenv1, eigenv2, eigensph, explc2, v1, v2, w1, w2, fctr, 
      uv1, uv0]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.6 The cases 2", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Definition of vspace 2d", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
 A general circle in the x,y-plane with center {x, y} and radius r has the \
vspace spanne by\
\>", "Text"],

Cell[BoxData[
    \(circlespacevectors[x, y, 0, 0, Pi/2, r]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell["\<\
This formula leads to the definition (we consider the circles in the \
x,y-plane as special 3D-objects):\
\>", "Text"],

Cell["\<\
vspace2d[x_, y_, r_] := 
  {{x/r, y/r, 0, 
    -(1 + r^2 - x^2 - y^2)/(2*r), (1 - r^2 + x^2 + y^2)/(2*r)}, 
   stb[3]}\
\>", "Input",
  CellLabel->"In[14]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(vspace2d[x, y, r]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[%[\([1]\)], %[\([1]\)]]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Together[%]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((w1\  = \(vspace2d[0, 1, 1]\)[\([1]\)]; \ 
      w2\  = \(vspace2d[0, 1, 1]\)[\([2]\)]; \n
      plotcircle2spv[w1, w2])\)\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["a) Two disjoint circles:", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((v1\  = \ stb[3]; \ v2\  = \ stb[4]\ ; \n\t
      w1\  = \(vspace2d[0, 1/2, \ 3]\)[\([1]\)]; 
      w2\  = \(vspace2d[0, 1/2, \ 3]\)[\([2]\)]; \n
      C0xC1\  = \ pscross[{v1, v2, w1, w2}])\)\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell["\<\
Indeed, since dimension(U0 + U1) = 3 the vectors must be linearily dependent.\
\
\>", "Text"],

Cell[BoxData[
    \({w1, w2}\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ma = {v1, v2, w1}\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Det[Table[pssp[ma[\([i]\)], \ ma[\([j]\)]], {i, 3}, {j, 3}]]\)], "Input",\

  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell["\<\
It follows: case 2.a; the circles are disjoint and separated; the sum U0+U1 = \
span[ma] is pseudo-euclidean.\
\>", "Text"],

Cell[BoxData[
    \({plotcircle2spv[v1, v2], plotcircle2spv[w1, w2]}\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pp[v1, v2, w1, \ w2]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvalues[%]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvectors[pp[v1, v2, w1, \ w2]]\)], "Input",
  CellLabel->"In[80]:=",
  FontFamily->"Times"],

Cell["\<\
Therefore the \"eigenspheres\" (spheres corresponding to the eigenvectors) \
containing the circle C0 are v1,v2\
\>", "Text"],

Cell[BoxData[
    \({euklidsphereplot3D[v1], euklidsphereplot3D[v2]}\)], "Input",
  CellLabel->"In[81]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[82]:=",
  FontFamily->"Times"],

Cell["\<\
They intersect orthogonally in the circle C0. The spheres containing the \
circles C0, C1 are the one-parameter families S0[t]\[Superset]C0, S1[s]\
\[Superset] C1 defined by the spacelike unit vectors\
\>", "Text"],

Cell[BoxData[{
    \(\(uv0[t_] := v1\ Cos[t]\  + \ \ v2\ Sin[t];\)\ \), "\n", 
    \(\(uv1[s_]\  := \ w1\ Cos[s]\  + \ w2\ Sin[s];\)\)}], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times"],

Cell["\<\
 For the generalized cosinus of the intersection angle (see the notebook \
mspheres.nb) we calculate\
\>", "Text"],

Cell[BoxData[
    \(pssp[uv0[t], \ uv1[s]]\)], "Input",
  CellLabel->"In[85]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctr[s_, t_]\  = \ %\)], "Input",
  CellLabel->"In[86]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot3D[fctr[s, t], {s, 0, \ 2\ Pi}, {t, 0, 2\ Pi}]\)], "Input",
  CellLabel->"In[87]:=",
  FontFamily->"Times"],

Cell["\<\
The first eigenvector  of pp[v1,v2,w1,w2] corresponds to t=0 or Pi, where the \
spheres uv1[s] have the following generalized cosinus with the sphere v1:\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ 0], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times"],

Cell["\<\
We remark that v1 = stb[3]  = w2 spans U0\[Intersection]U1 and defines the \
\"sphere\" containing both circles: the x,y-plane.  uv1[0] defines the sphere \
intersecting the x,y-plane orthogonally in the circle C1.\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[uv1[0]]\)], "Input",
  CellLabel->"In[89]:=",
  FontFamily->"Times"],

Cell["Of course s= Pi/2 yields the x,y-plane:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[uv1[Pi/2]]\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times"],

Cell["\<\

For t = Pi/2, 3Pi/2 we get correspondingly for the second eigenvector v2 = \
stb[4] the unit sphere through o; :\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ Pi/2], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"],

Cell["\<\
For s = Pi/2 - the x,y-plane uv1[Pi/2] and the unitsphere intersect \
orthogonally. At the points with Abs[fctr[s, Pi/2]] = 1 the sphere uv1[s] and \
the unit sphere are tangent to each other, and for Abs[fctr[s, Pi/2]] > 1 \
both spheres are disjoint. The amplitudes correspond to the square roots of \
the corresponding eigenvalues.\
\>", "Text"],

Cell[BoxData[
    \(Sqrt[2.640625`]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["b) Two intersecting circles:", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((v1\  = \ stb[3]; \ v2\  = \ stb[4]\ ; \n\t
      w1\  = \(vspace2d[0, 1/2, \ 0.7]\)[\([1]\)]; 
      w2\  = \(vspace2d[0, 1/2, \ 0.7]\)[\([2]\)]; \n
      C0xC1\  = \ pscross[{v1, v2, w1, w2}])\)\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times"],

Cell["\<\
Indeed, since dimension(U0 + U1) = 3 the vectors must be linearily dependant.\
\
\>", "Text"],

Cell[BoxData[
    \({w1, w2}\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ma = {v1, v2, w1}\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Det[Table[pssp[ma[\([i]\)], \ ma[\([j]\)]], {i, 3}, {j, 3}]]\)], "Input",\

  CellLabel->"In[96]:=",
  FontFamily->"Times"],

Cell["\<\
It follows: case 2.b; the circles intersect; the sum U0+U1 = span[ma] is \
euclidean.\
\>", "Text"],

Cell[BoxData[
    \({plotcircle2spv[v1, v2], plotcircle2spv[w1, w2]}\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[98]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pp[v1, v2, w1, \ w2]\)], "Input",
  CellLabel->"In[99]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvectors[pp[v1, v2, w1, \ w2]]\)], "Input",
  CellLabel->"In[100]:=",
  FontFamily->"Times"],

Cell["\<\
Therefore the \"eigenspheres\" (spheres corresponding to the eigenvectors) \
containing the circle C0 are v1,v2\
\>", "Text"],

Cell[BoxData[
    \({euklidsphereplot3D[v1], euklidsphereplot3D[v2]}\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times"],

Cell["\<\
They intersect orthogonally in the circle C0. The spheres containing the \
circles C0, C1 are the one-parameter families S0[t]\[Superset]C0, S1[s]\
\[Superset] C1 defined by the spacelike unit vectors\
\>", "Text"],

Cell[BoxData[{
    \(\(uv0[t_] := v1\ Cos[t]\  + \ \ v2\ Sin[t];\)\ \), "\n", 
    \(\(uv1[s_]\  := \ w1\ Cos[s]\  + \ w2\ Sin[s];\)\)}], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times"],

Cell["\<\
 For the generalized cosinus of the intersection angle (see the notebook \
mspheres.nb) we calculate\
\>", "Text"],

Cell[BoxData[
    \(pssp[uv0[t], \ uv1[s]]\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctr[s_, t_]\  = \ %\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot3D[fctr[s, t], {s, 0, \ 2\ Pi}, {t, 0, 2\ Pi}]\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times"],

Cell["\<\
The first eigenvector  of pp[v1,v2,w1,w2] corresponds to t=0 or Pi, where the \
spheres uv1[s] have the following generalized cosinus with the sphere v1:\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ 0], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times"],

Cell["\<\
We remark that v1 = stb[3]  = w2 spans U0\[Intersection]U1 and defines the \
\"sphere\" containing both circles: the x,y-plane.  uv1[0] defines the sphere \
intersecting the x,y-plane orthogonally in the circle C1.\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[uv1[0]]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times"],

Cell["Of course s= Pi/2 yields the x,y-plane:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[uv1[Pi/2]]\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times"],

Cell["\<\

For t = Pi/2, 3Pi/2 we get correspondingly for the second eigenvector v2 = \
stb[4] the unit sphere through o :\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ Pi/2], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times"],

Cell["\<\
Of course, any two spheres S0[t], S1[s] intersect: the \"generalized\" \
cosinus is the usual cosinus of the intersection angle.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["c) Two tangent circles:", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\((v1\  = \ stb[3]; \ v2\  = \ stb[4]\ ; \n\t
      w1\  = \(vspace2d[0, 1/2, \ 1/2]\)[\([1]\)]; 
      w2\  = \(vspace2d[0, 1/2, \ 1/2]\)[\([2]\)]; \n
      C0xC1\  = \ pscross[{v1, v2, w1, w2}])\)\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times"],

Cell["\<\
Indeed, since dimension(U0 + U1) = 3 the vectors must be linearily dependant.\
\
\>", "Text"],

Cell[BoxData[
    \({w1, w2}\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ma = {v1, v2, w1}\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Det[Table[pssp[ma[\([i]\)], \ ma[\([j]\)]], {i, 3}, {j, 3}]]\)], "Input",\

  CellLabel->"In[115]:=",
  FontFamily->"Times"],

Cell["\<\
It follows: case 2.c; the circles are tangent to each other; the sum U0+U1 = \
span[ma] is isotropic: the vector v2 + w1 is orthogonal to U0+U1.\
\>", "Text"],

Cell[BoxData[
    \({plotcircle2spv[v1, v2], plotcircle2spv[w1, w2]}\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pp[v1, v2, w1, \ w2]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvectors[pp[v1, v2, w1, \ w2]]\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times"],

Cell["\<\
Therefore the \"eigenspheres\" (spheres corresponding to the eigenvectors) \
containing the circle C0 are v1,v2\
\>", "Text"],

Cell[BoxData[
    \({euklidsphereplot3D[v1], euklidsphereplot3D[v2]}\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times"],

Cell["\<\
They intersect orthogonally in the circle C0. The spheres containing the \
circles C0, C1 are the one-parameter families S0[t]\[Superset]C0, S1[s]\
\[Superset] C1 defined by the spacelike unit vectors\
\>", "Text"],

Cell[BoxData[{
    \(\(uv0[t_] := v1\ Cos[t]\  + \ \ v2\ Sin[t];\)\ \), "\n", 
    \(\(uv1[s_]\  := \ w1\ Cos[s]\  + \ w2\ Sin[s];\)\)}], "Input",
  CellLabel->"In[122]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[uv0[t], \ uv1[s]]\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctr[s_, t_]\  = \ %\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot3D[fctr[s, t], {s, 0, \ 2\ Pi}, {t, 0, 2\ Pi}]\)], "Input",
  CellLabel->"In[126]:=",
  FontFamily->"Times"],

Cell["\<\
The first eigenvector  of pp[v1,v2,w1,w2] corresponds to t=0 or Pi, where the \
spheres uv1[s] have the following generalized cosinus with the sphere v1:\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ 0], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[127]:=",
  FontFamily->"Times"],

Cell["\<\
We remark that v1 = stb[3]  = w2 spans U0\[Intersection]U1 and defines the \
\"sphere\" containing both circles: the x,y-plane.  uv1[0] defines the sphere \
intersecting the x,y-plane orthogonally in the circle C1.\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[uv1[0]]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times"],

Cell["Of course s= Pi/2 yields the x,y-plane:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[uv1[Pi/2]]\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times"],

Cell["\<\

For t = Pi/2, 3Pi/2 we get correspondingly for the second eigenvector v2 = \
stb[4] the unit sphere through o:\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctr[s, \ Pi/2], \ {s, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[130]:=",
  FontFamily->"Times"],

Cell["\<\
Of course, any two spheres S0[t], S1[s] intersect: the \"generalized\" \
cosinus is the usual cosinus of the intersection angle. Only for s = k Pi  we \
have S1[s] tangent to the unitsphere:\
\>", "Text"],

Cell[BoxData[
    \({euklidsphereplot3D[v2], \ euklidsphereplot3D[uv1[0]]}\)], "Input",
  CellLabel->"In[131]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[132]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(testgr\  = \ %\)], "Input",
  CellLabel->"In[133]:=",
  FontFamily->"Times"],

Cell["Call MathGL3d (section 7.2) with testgr and use wire frame!", "Text"],

Cell[BoxData[
    \(MVShow3D[testgr]\)], "Input",
  CellLabel->"In[134]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.7 Further examples", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["\<\
The x-axis and the standard unit circle compared with  circle families\
\>", "Subsubsection",
  FontFamily->"Times"],

Cell["The x-axis", "Text"],

Cell[BoxData[
    \(plotcircle2spv[stb[2], \ stb[3]]\)], "Input",
  CellLabel->"In[135]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gro\  = \ %\)], "Input",
  CellLabel->"In[136]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cv[t_] := circlespacevectors[0, 0, t, 0, Pi/2, 1]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cv[t]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cv1[t_]\  := \(cv[t]\)[\([1]\)]; 
    cv2[t_] := \ \(cv[t]\)[\([2]\)]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(circlefamily[cv1, cv2, t, \(-1\), 1]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{gro, %}]\)], "Input",
  CellLabel->"In[141]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cvpp[t_]\  := \ pp[stb[2], stb[3], \ cv1[t], \ cv2[t]]\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cvpp[t]\)], "Input",
  CellLabel->"In[143]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "The circles for t \[NotEqual]0 are disjoint to the x-axis; the maximal \
eigenvalue is 1+",
  Cell[BoxData[
      \(t\^2\)]],
  ">1corresponding to case 1a."
}], "Text"],

Cell[BoxData[
    \(pscross[{stb[2], stb[3], \ cv1[t], \ cv2[t]}]\)], "Input",
  CellLabel->"In[144]:=",
  FontFamily->"Times"],

Cell["Replacing the x-axis by the standard unit circle we obtain", "Text"],

Cell[BoxData[
    \(Clear[cvpp]\)], "Input",
  CellLabel->"In[145]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cvpp[t_]\  := \ pp[stb[3], stb[4], \ cv1[t], \ cv2[t]]\)], "Input",
  CellLabel->"In[146]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cvpp[t]\)], "Input",
  CellLabel->"In[147]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvalues[%]\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times"],

Cell["\<\
R e m a r k. In this example the circle pair is not in general position:\
\>", "Text"],

Cell[BoxData[
    \(pscross[{stb[3], stb[4], \ cv1[t], \ cv2[t]}]\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times"],

Cell["The sphere", "Text"],

Cell[BoxData[
    \(vn[t_]\  := 
      spherevec[0, 0, t/2, \ Sqrt[1\  + \ \((t/2)\)^2]]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vn[t]\)], "Input",
  CellLabel->"In[151]:=",
  FontFamily->"Times"],

Cell["\<\
contains both circles of the pair belonging to the parameter t. For the \
standard unit circle this is obvious. On the other hand, considering\
\>", "Text"],

Cell[BoxData[
    \(compl[t_] := \ pscomplement[cv1[t], cv2[t]]\)], "Input",
  CellLabel->"In[152]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(compl[t]\)], "Input",
  CellLabel->"In[153]:=",
  FontFamily->"Times"],

Cell["we obtain", "Text"],

Cell[BoxData[
    \(Table[
      Simplify[pssp[vn[t], \ \(compl[t]\)[\([i]\)]]], \ {i, 3}]\)], "Input",
  CellLabel->"In[154]:=",
  FontFamily->"Times"],

Cell["\<\
what proves the statement. Therefore, the fact that there exist two \
eigenvalues greater or equal 1 does not contradict to the statement after \
formula (50) of the paper [6], since assumption B is not fulfilled, which is \
essential for the proof of the eigenvalue properties.\
\>", "Text"],

Cell[BoxData[
    \(Eigenvectors[cvpp[t]]\)], "Input",
  CellLabel->"In[155]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[eigenv1]\)], "Input",
  CellLabel->"In[156]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv1[t_]\  := \ normalize[{0, 0, \(-t\)/2, \ 1, 0}]\)], "Input",
  CellLabel->"In[157]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv1[t]\)], "Input",
  CellLabel->"In[158]:=",
  FontFamily->"Times"],

Cell["\<\
This again is the sphere containing both circles of the pair (up to \
orientation): \
\>", "Text"],

Cell[BoxData[
    \(Simplify[vn[t]\  + \ eigenv1[t], \ t > \ 0]\)], "Input",
  CellLabel->"In[159]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[eigenv2]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv2[t_]\  := \ normalize[{0, 0, 2/t, 1, 0}]\)], "Input",
  CellLabel->"In[160]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv2[t]\)], "Input",
  CellLabel->"In[161]:=",
  FontFamily->"Times"],

Cell["For t= 1 we get the corresponding eigenspheres", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[eigenv1[1. ]]\)], "Input",
  CellLabel->"In[162]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(es1\  = \ %\)], "Input",
  CellLabel->"In[163]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[eigenv2[1. ]]\)], "Input",
  CellLabel->"In[164]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(es2\  = \ %\)], "Input",
  CellLabel->"In[165]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{es1, es2}]\)], "Input",
  CellLabel->"In[166]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vradius[eigenv1[t]]\)], "Input",
  CellLabel->"In[167]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[168]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[vcenter[eigenv1[t]]]\)], "Input",
  CellLabel->"In[169]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[euklidsphereplot3D[eigenv1[t]], {t, \ 0, 5}]\)], "Input",
  CellLabel->"In[170]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[171]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[vradius[eigenv2[t]]]\)], "Input",
  CellLabel->"In[172]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[vcenter[eigenv2[t]]]\)], "Input",
  CellLabel->"In[173]:=",
  FontFamily->"Times"],

Cell["\<\
The normed projections of eigenv1,eigenv2 on the vspace spanned by cv1,cv2 \
are\
\>", "Text"],

Cell[BoxData[
    \(projeigenv1[t_]\  := \ 
      normalize[
        cv1[t]*pssp[eigenv1[t], cv1[t]] + 
          cv2[t]*pssp[eigenv1[t], cv2[t]]]\)], "Input",
  CellLabel->"In[174]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(projeigenv2[t_]\  := \ 
      normalize[
        cv1[t]*pssp[eigenv2[t], cv1[t]] + 
          cv2[t]*pssp[eigenv2[t], cv2[t]]]\)], "Input",
  CellLabel->"In[175]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[pssp[projeigenv1[t], projeigenv2[t]]]\)], "Input",
  CellLabel->"In[176]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[projeigenv1[1. ]]\)], "Input",
  CellLabel->"In[177]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pes1\  = \ %\)], "Input",
  CellLabel->"In[178]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[projeigenv2[1. ]]\)], "Input",
  CellLabel->"In[179]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pes2\  = \ %\)], "Input",
  CellLabel->"In[180]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{pes1, pes2}]\)], "Input",
  CellLabel->"In[181]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vradius[projeigenv1[t]]\)], "Input",
  CellLabel->"In[182]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[183]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[vcenter[projeigenv1[t]]]\)], "Input",
  CellLabel->"In[184]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[vcenter[projeigenv2[t]]]\)], "Input",
  CellLabel->"In[185]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[vradius[projeigenv2[t]], \ t > 0]\)], "Input",
  CellLabel->"In[187]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[cv, cvpp, eigenv1, vn, eigenv2]\)], "Input",
  CellLabel->"In[188]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Standard unit circle compared with a circle family with increasing radius\
\>", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(cv[t_]\  := \ circlespacevectors[1, 0, 0, Pi/2, 0, t]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cv1[t_]\  := \(cv[t]\)[\([1]\)]; 
    cv2[t_] := \ \(cv[t]\)[\([2]\)]\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(circlefamily[cv1, cv2, t, 0.1, 3]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc1, %}]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cvpp[t_]\  := \ pp[stb[3], stb[4], \ cv1[t], \ cv2[t]]\)], "Input",
  CellLabel->"In[193]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cvpp[t]\)], "Input",
  CellLabel->"In[194]:=",
  FontFamily->"Times"],

Cell["For all t >0 we have case 2:", "Text"],

Cell[BoxData[
    \(pscross[{stb[3], stb[4], \ cv1[t], \ cv2[t]}]\)], "Input",
  CellLabel->"In[195]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fct[t_]\  = pssp[%, %]\)], "Input",
  CellLabel->"In[196]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Together[Simplify[fct[t]]]\)], "Input",
  CellLabel->"In[197]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[fct[t], {t, 0, 3}]\)], "Input",
  CellLabel->"In[198]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "Since the maximal eigenvalue is ",
  Cell[BoxData[
      \(t\^2\/4\)]],
  ", we have for 0<t<2 circles interlaced with grc1, for t = 2 a circle \
intersecting grc1 in one point, and for t>2 two disjoint circles which may be \
separated by spheres."
}], "Text"],

Cell[BoxData[
    \(circlefamily[cv1, cv2, t, 0.2, 3.2, 10]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%, grc1}]\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cfv1\  = \ %\)], "Input",
  CellLabel->"In[202]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[cfv1]\)], "Input",
  CellLabel->"In[203]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.8 The M\[ODoubleDot]bius invariants expressed by euclidean \
invariants", "Subsection",
  FontFamily->"Times"],

Cell["\<\
 A complete system of euclidean invariants of  a pair (C0,C1) of circles is \
obtained by the following entities:
The radii r of C0, R of C1,
the distance d of the  centers,
the angle a between the position vectors nc0, nc1,
the angle b between the position vector nc0, and the line connecting the \
centers,
the angle c between the position vector nc1, and the line connecting the \
centers.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The calculation of the expressions", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
We assume that the circle  C0 belongs to the  x,y-plane, has the center in \
the origin, and Radius r:\
\>", "Text"],

Cell[BoxData[
    \(csv0\  = circlespacevectors[0, 0, 0, 0, Pi/2, \ r]\)], "Input",
  CellLabel->"In[204]:=",
  FontFamily->"Times"],

Cell["\<\
We choose the coordinate x-axis  in the euclidean 3-space such that the \
center of the second circle belongs to the x,z-plane:\
\>", "Text"],

Cell[BoxData[
    \(csv1 = \ circlespacevectors[x, 0, z, u, v, R]\)], "Input",
  CellLabel->"In[205]:=",
  FontFamily->"Times"],

Cell["The matrix of the corresponding double projection is", "Text"],

Cell[BoxData[
    \(matrpp\  = \ 
      pp[csv0[\([1]\)], csv0[\([2]\)], csv1[\([1]\)], 
        csv1[\([2]\)]]\)], "Input",
  CellLabel->"In[206]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(FullSimplify[matrpp]\)], "Input",
  CellLabel->"In[207]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvalues[%]\)], "Input",
  CellLabel->"In[208]:=",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[%, r > 0 && R > 0]\)], "Input",
  CellLabel->"In[107]:=",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \($Aborted\)], "Output",
  CellLabel->"Out[107]=",
  FontFamily->"Times"]
}, Closed]],

Cell["\<\
After 50 minutes no result. Therefore it seems better to evaluate the \
determinant and the trace of pp:\
\>", "Text"],

Cell[BoxData[
    \(ppdet[csv0[\([1]\)], csv0[\([2]\)], csv1[\([1]\)], 
      csv1[\([2]\)]]\)], "Input",
  CellLabel->"In[209]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[210]:=",
  FontFamily->"Times"],

Cell["\<\
invdet = (2*x*z*Cos[u]*Cos[v] + (r^2 + R^2 - x^2 + z^2)*Sin[v])^2/(4*r^2*R^2)\
\
\>", "Input",
  CellLabel->"In[211]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pptr[csv0[\([1]\)], csv0[\([2]\)], csv1[\([1]\)], 
      csv1[\([2]\)]]\)], "Input",
  CellLabel->"In[212]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(FullSimplify[Together[%]]\)], "Input",
  CellLabel->"In[213]:=",
  FontFamily->"Times"],

Cell["\<\
invtr = (1/(4*r^2*R^2))*(r^4 + R^4 - 2*R^2*x^2 + 2*r^2*(2*R^2 - x^2 + z^2) + 
    (x^2 + z^2)^2 + 2*R^2*((-(r^2 + z^2))*Cos[2*v] + 2*x*Cos[u]*Cos[v]*
       (x*Cos[u]*Cos[v] + 2*z*Sin[v])))\
\>", "Input",
  CellLabel->"In[214]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[r, R, d, a, b, c]\)], "Input",
  CellLabel->"In[215]:=",
  FontFamily->"Times"],

Cell["\<\
Now we express the coordinates x,z,u,v by  the euclidean invariants described \
above, and use these expression as substitution rules. We have\
\>", "Text"],

Cell[BoxData[
    \(subrules\  = \ {x \[Rule] \ d*Sin[b], \ z \[Rule] d*Cos[b], \ 
        Sin[v] \[Rule] \ Cos[a], \ Cos[v]\  \[Rule] \ Sin[a], 
        Cos[u] \[Rule] \((Cos[c] - Cos[a]*Cos[b])\)/\((Sin[a]*
                Sin[b])\)}\)], "Input",
  CellLabel->"In[216]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(invdet //. subrules\)], "Input",
  CellLabel->"In[217]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[218]:=",
  FontFamily->"Times"],

Cell["\<\
euforminvdet[r_, R_, d_, a_, b_, c_] := 
  ((-d^2 + r^2 + R^2)*Cos[a] + 2*d^2*Cos[b]*Cos[c])^2/(4*r^2*R^2)\
\>", "Input",
  CellLabel->"In[15]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(invtr //. subrules\)], "Input",
  CellLabel->"In[225]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(% //. Cos[2*v] \[Rule] Cos[v]^2 - Sin[v]^2\)], "Input",
  CellLabel->"In[226]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(% //. subrules\)], "Input",
  CellLabel->"In[227]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[228]:=",
  FontFamily->"Times"],

Cell["\<\
euforminvtr[r_, R_, d_, a_, b_, c_] := 
  (d^4 + r^4 + 4*r^2*R^2 + R^4 + 2*r^2*R^2*Cos[2*a] + 
    2*d^2*(r^2*Cos[2*b] + R^2*Cos[2*c]))/(4*r^2*R^2)\
\>", "Input",
  CellLabel->"In[16]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["\<\
The functions euforminvdet, euforminvtre are the wanted expressions; as \
usually one may find the eigenvalues of pp using these functions.\
\>", "Text"],

Cell[BoxData[
    \(euforminvdet[r, R, d, a, b, c]\)], "Input",
  CellLabel->"In[229]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euforminvtr[r, R, d, a, b, c]\)], "Input",
  CellLabel->"In[230]:=",
  FontFamily->"Times"],

Cell["\<\
Finally, we consider  the case d=0, in which the angles b and c are not \
defined. In this case we have x = z = 0, and\
\>", "Text"],

Cell["\<\
invdet = (2*x*z*Cos[u]*Cos[v] + (r^2 + R^2 - x^2 + \
z^2)*Sin[v])^2/(4*r^2*R^2)/. {x\[Rule]0, z\[Rule]0}\
\>", "Input",
  CellLabel->"In[231]:=",
  FontFamily->"Times"],

Cell["\<\
Replacing Sin[v] by Cos[a], as before, we see that the function euforminvdet \
is valid in this case, too, since the terms containing b or c vanish. \
Analogeously:\
\>", "Text"],

Cell["\<\
invtr = (1/(4*r^2*R^2))*(r^4 + R^4 - 2*R^2*x^2 + 2*r^2*(2*R^2 - x^2 + z^2) + 
    (x^2 + z^2)^2 + 2*R^2*((-(r^2 + z^2))*Cos[2*v] + 2*x*Cos[u]*Cos[v]*
       (x*Cos[u]*Cos[v] + 2*z*Sin[v])))/. {x\[Rule]0, z\[Rule]0}\
\>", "Input",
  CellLabel->"In[232]:=",
  FontFamily->"Times"],

Cell["\<\
Replacing Cos[2v]= Cos[v]^2 -Sin[v]^2 by Sin[a]^2 -Cos[a]^2 = -Cos[2a] we \
conclude again the validity of the expression euforminvtr.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Test", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
We take two circles with in part random parameters, find their \
circlespacevectors, and define their invariants ppdet, pptr. Then we find \
their euclidean invariants and calculate the corresponding values of \
euforminvdet, euforminvtr, and compare their values with those of ppdet, \
pptr; furthermore, we compare the values of the given random radii r00, r11 \
with the radii r0,r1 calculated by the functions radius of the generated \
vectors. All the differences are numerically small, see the last cells of \
this subsection. 
Also we calculate the eigenvalues of pp (see the last cell); calling MVShow3D \
in the next subsection one may study the mutual position of the two random \
circles.

The random circles:\
\>", "Text"],

Cell[BoxData[
    \(r00 = 2*Random[]; 
    vc0\  = \ circlespacevectors[Random[], Random[], Random[], 
        2*Pi*Random[], \ Random[]*Pi/2, \ r00]\)], "Input",
  CellLabel->"In[917]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(r11 = 2*Random[]; 
    vc1\  = \ circlespacevectors[Random[], 0, Random[], 2*Pi*Random[], \ 
        Random[]*Pi/2, \ r11]\)], "Input",
  CellLabel->"In[918]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[vc0[\([1]\)], vc0[\([2]\)]]\)], "Input",
  CellLabel->"In[919]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(grc0 = %\)], "Input",
  CellLabel->"In[920]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[vc1[\([1]\)], vc1[\([2]\)]]\)], "Input",
  CellLabel->"In[921]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(grc1\  = %\)], "Input",
  CellLabel->"In[922]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc0, grc1}]\)], "Input",
  CellLabel->"In[923]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(shgr = \ %\)], "Input",
  CellLabel->"In[924]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(adet\  = \ 
      ppdet[vc0[\([1]\)], vc0[\([2]\)], vc1[\([1]\)], 
        vc1[\([2]\)]]\)], "Input",
  CellLabel->"In[925]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(atr\  = \ 
      pptr[vc0[\([1]\)], vc0[\([2]\)], vc1[\([1]\)], vc1[\([2]\)]]\)], "Input",\

  CellLabel->"In[926]:=",
  FontFamily->"Times"],

Cell["The euclidean equivariants of the circle C0:", "Text"],

Cell[BoxData[
    \(r0 = radius[vc0[\([1]\)], vc0[\([2]\)]]\)], "Input",
  CellLabel->"In[927]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pos0 = posvec[vc0[\([1]\)], vc0[\([2]\)]]\)], "Input",
  CellLabel->"In[928]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cent0\  = center[vc0[\([1]\)], vc0[\([2]\)]]\)], "Input",
  CellLabel->"In[929]:=",
  FontFamily->"Times"],

Cell["The euclidean equivariants of the circle C1:", "Text"],

Cell[BoxData[
    \(r1 = radius[vc1[\([1]\)], vc1[\([2]\)]]\)], "Input",
  CellLabel->"In[930]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pos1 = posvec[vc1[\([1]\)], vc1[\([2]\)]]\)], "Input",
  CellLabel->"In[931]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cent1\  = center[vc1[\([1]\)], vc1[\([2]\)]]\)], "Input",
  CellLabel->"In[932]:=",
  FontFamily->"Times"],

Cell["The distance of the centers", "Text"],

Cell[BoxData[
    \(vcentdiff01\  = \ cent1\  - cent0\)], "Input",
  CellLabel->"In[933]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(d01\  = \ Sqrt[vcentdiff01 . vcentdiff01]\)], "Input",
  CellLabel->"In[934]:=",
  FontFamily->"Times"],

Cell["The angle between the position vectors", "Text"],

Cell[BoxData[
    \(a01 = ArcCos[pos0 . pos1]\)], "Input",
  CellLabel->"In[935]:=",
  FontFamily->"Times"],

Cell["\<\
The angles between the positionvectors and the line connecting the centers:\
\>", "Text"],

Cell[BoxData[
    \(b01\  = ArcCos[pos0 . vcentdiff01/d01]\)], "Input",
  CellLabel->"In[936]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(c01\  = ArcCos[pos1 . vcentdiff01/d01]\)], "Input",
  CellLabel->"In[937]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euforminvdet[r0, r1, d01, a01, b01, c01]\)], "Input",
  CellLabel->"In[938]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(adet - %\)], "Input",
  CellLabel->"In[939]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euforminvtr[r0, r1, d01, a01, b01, c01]\)], "Input",
  CellLabel->"In[940]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(atr - %\)], "Input",
  CellLabel->"In[941]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \({r00 - r0, r11 - r1}\)], "Input",
  CellLabel->"In[942]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvalues[
      pp[vc0[\([1]\)], vc0[\([2]\)], vc1[\([1]\)], vc1[\([2]\)]]]\)], "Input",\

  CellLabel->"In[943]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[r0, r00, r1, r11, d01, a01, b01, c01, vc0, vc1, 
      vcentdiff01]\)], "Input",
  CellLabel->"In[944]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["MVShow3D", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[shgr, \ MVLineTubeSize\  -> \ 0.02]\)], "Input",
  CellLabel->"In[945]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5 Normal forms of pairs of circles ",
  FontFamily->"Helvetica"]], "Section",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell[TextData[{
  "In the general classification of pairs {k-sphere, l-sphere} contained in \
an n-sphere  ( see ",
  ButtonBox["[6]",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  ") we obtained normal forms for the bases of the generating vector spaces, \
where the coefficients of one base with respect to the other are defined by \
the invariant  eigenvalues of the matrix pp. In this section we describe \
these normal forms for each of the cases mentioned in the subsection \"Case \
discussion\" above.  The advantage of the normal form representation is that \
the relations between the invariants and the geometry of the circle pair can \
be studied directly. For the first circle we always take the unit circle grc1 \
= plotcircle2spv [stb[3],stb[4]] with center o in the x,y-plane, defined with \
the initialization; the other circle is given by the corrresponding normal \
form of the base. We remark that the case numbering, the numbering of the \
basis vectors, and the notations differ from those used in [6]. \nATTENTION: \
For getting the normal forms the definitions in subsection 5.1 are needed. \
Evaluate 5.1 first!"
}], "Text"],

Cell[BoxData[
    \(Show\ [grc1]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
5.1 Some vector functions needed for the definition of the normal forms\
\>", "Subsection",
  FontFamily->"Times",
  CellTags->"v5.1"],

Cell[BoxData[
    \(v3[a_]\  := \ {0, Sin[a], 0, Cos[a], 0}\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v4[a_]\  := \ {0, 0, Cosh[a], 0, Sinh[a]}\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v5[a_]\  := \ {Sin[a], 0, Cos[a], 0, 0}\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2 Case 1a: disjoint, non-interlaced circles", "Subsection",
  FontFamily->"Times"],

Cell[TextData[{
  "This case corresponds to case 1, n =5, m = l =1, in ",
  ButtonBox["[6]",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[BoxData[
    \(pscross[{stb[3], \ stb[4], v4[a], v3[b]}]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times"],

Cell["\<\
For b = k\[Pi] , or a =0 we have case 2; for other values of a, b this vector \
is spacelike; therefore U0 + U1 is pseudo-euclidean:case 1.a.\
\>", "Text"],

Cell[BoxData[
    \(MatrixForm[Evaluate[pp[stb[3], \ stb[4], \ v4[a], \ v3[b]]]]\)], "Input",\

  CellLabel->"In[80]:=",
  FontFamily->"Times"],

Cell["The corresponding circle is plotted by", "Text"],

Cell[BoxData[
    \(circ1a[a_, \ b_]\  := \ plotcircle2spv[v4[a], \ v3[b]]\)], "Input",
  CellLabel->"In[81]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(circ1a[1.5, 1.7]\)], "Input",
  CellLabel->"In[83]:="],

Cell["For a = b = 0 we get ste standard circle grc1 again.", "Text"],

Cell[BoxData[
    \(circ1a[0, 0]\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%%, %}]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(MVShow3D[%, \ MVLineTubeSize\  -> \ 0.02]\)], "Input",
  CellLabel->"In[86]:=",
  FontFamily->"Times"],

Cell["We calculate center and radius of the circles circ1a[a,b]", "Text"],

Cell[BoxData[
    \(\(?center\)\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(center[v4[a], \ v3[b]]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, {\ a \[Element] Reals, b \[Element] Reals}]\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(centfct[a_, 
        b_]\  := \ {0, \(-\(Sin[2\ b]\/\(Cos[2\ b] + Cosh[2\ a]\)\)\), 
        Sinh[2\ a]\/\(Cos[2\ b] + Cosh[2\ a]\)}\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell["All the centers lie in the y,z-plane.", "Text"],

Cell[BoxData[
    \(\(?radius\)\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[v4[a], \ v3[b]]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, {\ a \[Element] Reals, b \[Element] Reals}]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radfct[a_, b_]\  := \ \@2\/\@\(Cos[2\ b] + Cosh[2\ a]\)\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell["\<\
Obviously, this function has poles for a = 0, b = Pi/2 + k*Pi, k integer\
\>", "Text"],

Cell[BoxData[
    \(Plot3D[radfct[a, b], {a, \ \(-1\), \ 1}, {b, \ \(-Pi\), \ Pi}, 
      PlotPoints\  \[Rule] 60, \ PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(radfct[0, Pi/2]\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(pp[v4[a1], v3[b1], v4[a2], v3[b2]]\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \(pscross[{v4[a1], v3[b1], v4[a2], v3[b2]}]\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[98]:="],

Cell["\<\
It follows that any pair of circles of the 2-parameter family under \
consideration fulfil the conditions of case 1 a) - i.e. are in general \
position and may be separated by spheres - wth the exception of the values a1 \
= a2 or b1 = b2 + k*Pi (k integer),  where the circles are not in general \
position (case 2, or they are equal).\
\>", "Text"],

Cell[CellGroupData[{

Cell["Example of a circlefamily and a circle surface", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(vv[t_]\  := \ v3[t + 1]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(circlefamily[v4, vv, t, \(-3\), 3]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(cfam1a\  = \ %\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(MVShow3D[cfam1a, \ MVLineTubeSize\  -> \ 0.02]\)], "Input",
  CellLabel->"In[36]:=",
  FontFamily->"Times"],

Cell["Centers and radii of this circle family are:", "Text"],

Cell[BoxData[
    \(cf1aradius[t_]\  := \ radius[v4[t], \ vv[t]]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(cf1acenter[t_]\  := \ center[v4[t], \ vv[t]]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(Plot[cf1aradius[t], {t, \(-8\), 8}]\)], "Input",
  CellLabel->"In[41]:="],

Cell["Oner may localize the maximum of the radius graphically:", "Text"],

Cell[BoxData[
    \(Plot[cf1aradius[t], {t,  .26,  .28}]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(cf1aradius[t]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(Simplify[%, \ t > 0]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(f1a[t_]\  = \ %\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(D[f1a[t], t]\)], "Input",
  CellLabel->"In[46]:="],

Cell["Here is a numerical solution:", "Text"],

Cell[BoxData[
    \(FindRoot[\ {Sin[2 + 2\ t] == \ Sinh[2\ t]}, \ {t, \ 0.26}]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(cf1aradius[t] /. %\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(ParametricPlot3D[cf1acenter[t], \ {t, \ \(-8\), 8}, \ 
      PlotPoints\  \[Rule] \ 100, PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(cf1acenter[t]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(Simplify[%, \ t > 0]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(ParametricPlot[{\(-\(Sin[2 + 2\ t]\/\(Cos[2 + 2\ t] + Cosh[2\ t]\)\)\), 
        Sinh[2\ t]\/\(Cos[2 + 2\ t] + Cosh[2\ t]\)}, \ {t, \(-8\), 8}, 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[54]:="],

Cell["We compare the series of circles with grc1", "Text"],

Cell[BoxData[
    \(Table[
      Show[{grc1, circ1a[a, \ a + 1]}], {a, \ 0.7, 3.2, \ 0.5}]\)], "Input",
  CellLabel->"In[30]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%, \ PlotRange\  -> All, Axes \[Rule] False, \ 
      Boxed \[Rule] False]\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(nf1a\  = %\)], "Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[nf1a, \ MVLineTubeSize\  -> \ 0.02]\)], "Input",
  CellLabel->"In[34]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Export["\<nf1a.eps\>", nf1a]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell["A surface generated by the circles circ1a[a,a+1]:", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[
      Evaluate[\(circle2spv[v4[a], \ v3[a + 1]]\)[t]], {a, \(-4\), \ 
        4}, \ {t, \ 0, \ 2\ Pi}, PlotPoints\  -> \ 50, \ 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ngr1a\  = %\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[ngr1a]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell["\<\
The limits of the generating circles of the surface ngr1a are the points \
{0,0,1}, {0,0,-1}:\
\>", "Text"],

Cell[BoxData[
    \(Limit[\(circle2spv[v4[a], \ v3[a + 1]]\)[t], \ 
      a\  \[Rule] \ Infinity]\)], "Input",
  CellLabel->"In[38]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Limit[\(circle2spv[v4[\(-a\)], \ v3[\(-a\) + 1]]\)[t], \ 
      a\  \[Rule] \ Infinity]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell["ThreeScript[\"nf1a.ts\", nf1a]", "Input",
  FontFamily->"Times"],

Cell["ThreeScript[\"ngr1a.ts\", ngr1a]", "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc1, \ ngr1a}, \ PlotRange\  -> All]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ngr1a1\  = \ %\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[ngr1a1, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell["ThreeScript[\"ngr1a1.ts\", ngr1a1]", "Input",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.3 Case 1b: interlaced circles", "Subsection",
  FontFamily->"Times"],

Cell[TextData[{
  "This case corresponds to case 3, n =5, m = l =1, in ",
  ButtonBox["[6]",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  ". Run first ",
  ButtonBox["5.1",
    ButtonData:>"v5.1",
    ButtonStyle->"Hyperlink"],
  " !"
}], "Text"],

Cell[BoxData[
    \(pscross[{stb[3], \ stb[4], v5[a], v3[b]}]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell["\<\
For b = k\[Pi] , or a = k\[Pi]  we have case 2; for other values of a, b this \
vector is timelike; therefore U0 + U1 is euclidean:case 1.b.\
\>", "Text"],

Cell[BoxData[
    \(MatrixForm[Evaluate[pp[stb[3], \ stb[4], \ v5[a], \ v3[b]]]]\)], "Input",\

  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(circ1b[a_, \ b_]\  := \ plotcircle2spv[v5[a], v3[b]]\)], "Input",
  CellLabel->"In[38]:=",
  FontFamily->"Times"],

Cell["\<\
For a = b = 0 we get the standard circle grc1 again. For a = b > 0 the \
pairing with grc1 yields the family of isogonal circles.\
\>", "Text"],

Cell[BoxData[
    \(circ1b[0, 0]\)], "Input",
  CellLabel->"In[39]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(circ1b[Pi/4, Pi/2]\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%, %%}]\)], "Input",
  CellLabel->"In[26]:="],

Cell[CellGroupData[{

Cell["Radius, center, position vector", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Center and radius do not depend on a, all the centers lie on the y-axis:\
\>", "Text"],

Cell[BoxData[
    \(center[v5[a], \ v3[b]]\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[v5[a], \ v3[b]]\)], "Input",
  CellLabel->"In[28]:=",
  FontFamily->"Times"],

Cell["\<\
Obviously, this function has poles for a = 0, b = Pi/2 + k*Pi, k integer\
\>", "Text"],

Cell[BoxData[
    \(Plot[\(-Sec[b]\), {b, \ \(-Pi\), \ Pi}]\)], "Input",
  CellLabel->"In[30]:="],

Cell[TextData[{
  "It follows: All circles circ1b[a, ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "], ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "= constant, lie on the sphere with center {0,-Tan[ ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "],0} and radius Abs[Sec[ ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "]]. This \"sphere\" is a plane in case  ",
  Cell[BoxData[
      \(TraditionalForm\`b\_0\)]],
  "= Pi/2 + k*Pi:"
}], "Text"],

Cell[BoxData[
    \(v3[b]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(euklidsphereplot3D[v3[Pi/2]]\)], "Input",
  CellLabel->"In[37]:="],

Cell["The position vector does not depend on b:", "Text"],

Cell[BoxData[
    \(posvec[v5[a], \ v3[b]]\)], "Input",
  CellLabel->"In[38]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pp[v5[a1], v3[b1], v5[a2], v3[b2]]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(pscross[{v5[a1], v3[b1], v5[a2], v3[b2]}]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[34]:="],

Cell["\<\
It follows that any pair of circles of the 2-parameter family under \
consideration fulfil the conditions of case 1 b) - i.e. are in general \
position and interlaced - wth the exception of the values a1 = a2+k*Pi or b1 \
= b2 + k*Pi (k integer),  where the circles are not in general position (case \
2, or they are equal).\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The spherical invariant function", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
The M\[ODoubleDot]bius invariant (generalized cosinus) of two spheres \
containing the standard unit circle resp. the circle circ[1,b] is\
\>", "Text"],

Cell[BoxData[
    \(Clear[a, b, s, t]\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(sphinv[a_, b_]\)[s_, t_]\  := \ 
      pssp[stb[3]*Cos[t]\  + stb[4]*Sin[t], 
        v5[a]*Cos[s] + v3[b]*Sin[s]]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(sphinv[a, b]\)[s, t]\)], "Input",
  CellLabel->"In[41]:=",
  FontFamily->"Times"],

Cell["\<\
The relative extrema of the function sphinv[a,b] are in the points (s,t) = \
(0,0), (Pi/2, Pi/2); their values coincide with the roots of the eigenvalues, \
as expected.\
\>", "Text"],

Cell[BoxData[
    \(Table[\(sphinv[0.3, 1.5]\)[0, i/10], \ {i, \ \(-10\), 10}]\)], "Input",
  CellLabel->"In[42]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[\(sphinv[0.3, 1.5]\)[Pi/2, Pi/2\  + \ i/50], \ {i, \ \(-10\), 
        10}]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \({Cos[ .3], \ Cos[1.5]}\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(Plot3D[\(sphinv[0.3, 1.5]\)[s, t], \ {t, 0, 2*Pi}, {s, 0, 2*Pi}, \ 
      PlotPoints\  \[Rule] \ 50]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(graph1\  = \ %\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(sphinv[0.3, 1.5]\)[0, 0]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(\(sphinv[0.3, 1.5]\)[Pi/2, Pi/2]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(Export["\<graph1.eps\>", \ graph1]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["A circle family and a circle suface", "Subsubsection",
  FontSize->10],

Cell["\<\
A family of to grc1  non-isogonal, with grc1 interlaced circles:\
\>", "Text"],

Cell[BoxData[
    \(Table[circ1b[a, \ 2*a], {a, \ 1, 2, \ 0.25}]\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%\ , grc1}, \ PlotRange\  -> All]\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(nf1b\  = %\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell["\<\
MVShow3D[nf1b, MVLineTubeSize \[Rule] 0.03]\
\>", "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"],

Cell["A corresponding surface:", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[
      Evaluate[\(circle2spv[v5[a], \ v3[1.2*a]]\)[
          t]], {a, \  .1, \  .9}, \ {t, \ 0, \ 2\ Pi}, 
      PlotPoints\  \[Rule] \ 25]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ngr1b\  = \ %\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc1, \ ngr1b}]\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ngr1b1\  = \ %\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell["\<\
MVShow3D[ngr1b1, MVLineTubeSize \[Rule] 0.02]\
\>", "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The circle family and the circle suface with b = 1.2", "Subsubsection",
  FontSize->10],

Cell[BoxData[
    \(ParametricPlot3D[
      Evaluate[\(circle2spv[v5[a], \ v3[1.2]]\)[
          t]], {a, \  .1, \  .9}, \ {t, \ 0, \ 2\ Pi}, 
      PlotPoints\  \[Rule] \ 25]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(sf1b\  = \ %\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(Show[{%, \ grc1}]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(sf1b1\  = \ %\)], "Input",
  CellLabel->"In[55]:="],

Cell["\<\
MVShow3D[sf1b1, MVLineTubeSize \[Rule] 0.02]\
\>", "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vv[a_]\  := \ v3[1.2]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(circlefamily[v5, vv, a,  .1,  .9, 10]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(cirf1b\  = %\)], "Input",
  CellLabel->"In[67]:="],

Cell["\<\
MVShow3D[cirf1b, MVLineTubeSize \[Rule] 0.02]\
\>", "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell["The sphere containing all these circles is", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[v3[1.2]]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(sph12\  = %\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(Show[{sph12, \ cirf1b}]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(cirfsph1b\  = \ %\)], "Input",
  CellLabel->"In[72]:="],

Cell["\<\
MVShow3D[%, MVLineTubeSize \[Rule] 0.02]\
\>", "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{cirfsph1b, \ grc1}]\)], "Input",
  CellLabel->"In[74]:="],

Cell["\<\
MVShow3D[%, MVLineTubeSize \[Rule] 0.02]\
\>", "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell["\<\
In the sphere  defined by v3[1.2] our family coincides with the bundle of \
circles through two points which we calculate now:\
\>", "Text"],

Cell[BoxData[
    \(Solve[{pssp[vec[x], \ v5[a]] \[Equal] 0, \ 
        pssp[vec[x], v3[1.2]] \[Equal] \ 0, \ 
        pssp[vec[x], v5[1. ]] \[Equal] \ 0, 
        pssp[vec[x], vec[x]] \[Equal] \ 0}, \ vec[x]]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(vec[x] /. %\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(\(\(pts12\)\(\ \)\(=\)\(%\)\(\ \)\)\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(pssp[pts12[\([1]\)], pts12[\([1]\)]]\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(Chop[%]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(pssp[pts12[\([2]\)], pts12[\([2]\)]]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(Chop[%]\)], "Input",
  CellLabel->"In[82]:="],

Cell["In the euclidean space these points have the coordinates ", "Text"],

Cell[BoxData[
    \(eupts\  = \ 
      Chop[{stepro[pts12[\([1]\)]], \ stepro[pts12[\([2]\)]]}]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(Map[Point, eupts]\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(Show[Graphics3D[{PointSize[0.03], %}]]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \(grpts12\  = \ %\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \(Show[{cirfsph1b, \ grpts12}]\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \(togb12\  = \ %\)], "Input",
  CellLabel->"In[90]:="],

Cell["\<\
The next picture illustrates our statements; animate  with the option wire \
frame:\
\>", "Text"],

Cell["\<\
MVShow3D[togb12, MVPointSphereSize\[Rule]3.8, MVLineTubeSize \[Rule] 0.01]\
\>", "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The circle family and the circle suface with a = 1.", "Subsubsection",
  FontSize->10],

Cell[BoxData[
    \(ParametricPlot3D[
      Evaluate[\(circle2spv[v5[1. ], \ v3[b]]\)[
          t]], {b, \  .1, \  .9}, \ {t, \ 0, \ 2\ Pi}, 
      PlotPoints\  \[Rule] \ 25]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cirsf1b2\  = \ %\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(Show[{%, grc1}]\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(cirsfb2c1 = %\)], "Input",
  CellLabel->"In[96]:="],

Cell["MVShow3D gives a strange, incomplete  picture:", "Text"],

Cell["\<\
MVShow3D[cirsfb2c1, MVLineTubeSize \[Rule] 0.02]\
\>", "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times"],

Cell["\<\
For any a v5[a] defines a plane containing the y-axis: the family {v5[a]} \
coincides with the bundle of planes through the y-axis:\
\>", "Text"],

Cell[BoxData[
    \(v5[a]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(Table[euklidsphereplot3D[v5[a*Pi]], \ {a, 0, 1,  .1}]\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[103]:="],

Cell["Especially we have", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[v5[1. ], \(-4\), 2, \(-3\), 1]\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(pl1b\  = %\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(Show[{pl1b, cirsf1b2}]\)], "Input",
  CellLabel->"In[117]:="],

Cell["\<\
The next picture is yet more strange; the circle surface should be a subset \
of the plane pl1b!\
\>", "Text"],

Cell[BoxData[
    \(MVShow3D[%]\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(Show[{pl1b, cirsf1b2, grc1}]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(MVShow3D[%, MVLineTubeSize \[Rule] 0.02\ ]\)], "Input",
  CellLabel->"In[120]:="],

Cell["For the euclidean invarints we have", "Text"],

Cell[BoxData[
    \(radius[v5[1. ], \ v3[b]]\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(center[v5[1. ], \ v3[b]]\)], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \(posvec[v5[1. ], \ v3[b]]\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \(Table[circ1b[1. , t], \ {t, \  .1, 1,  .1}]\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \(cirfam1b\  = \ %\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(\(\(Show[{%, pl1b}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(cirfam1bpl1\  = \ %\)], "Input",
  CellLabel->"In[128]:="],

Cell["\<\
Indeed, the circle lie in the plane pl1b defined by v5[1.]; now MVShow3D \
shows a correct picture:\
\>", "Text"],

Cell["\<\
MVShow3D[%, MVLineTubeSize \[Rule] 0.02]\
\>", "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times"],

Cell["\<\
In the plane pl1b our circle family coincides with the bundle of circles \
through two points which we calculate now:\
\>", "Text"],

Cell[BoxData[
    \(Solve[{pssp[vec[x], \ v5[1. ]] \[Equal] 0, \ 
        pssp[vec[x], v3[1. ]] \[Equal] \ 0, \ 
        pssp[vec[x], v3[a]] \[Equal] \ 0, 
        pssp[vec[x], vec[x]] \[Equal] \ 0}, \ vec[x]]\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(sol1\  = \ vec[x] /. %[\([1]\)]\)], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \(sol2\  = \ vec[x] /. %%[\([2]\)]\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(pssp[sol1, sol1]\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \({stepro[sol1], stepro[sol2]}\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(Chop[%]\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \(Show[Graphics3D[Line[%]]]\)], "Input",
  CellLabel->"In[136]:="],

Cell[BoxData[
    \(l1b\  = \ %\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    \(Show[
      Graphics3D[{PointSize[0.03], 
          Point[{0.5403023058681398`, 0, \(-0.8414709848078965`\)}], 
          Point[{\(-0.5403023058681398`\), 0, 
              0.8414709848078965`}]}]]\)], "Input",
  CellLabel->"In[138]:="],

Cell[BoxData[
    \(pts1b\  = \ %\)], "Input",
  CellLabel->"In[139]:="],

Cell[BoxData[
    \(Show[{pts1b, l1b, cirfam1b, \ pl1b}]\)], "Input",
  CellLabel->"In[143]:="],

Cell[BoxData[
    \(tog1b = %\)], "Input",
  CellLabel->"In[144]:="],

Cell["Animate the next picture:", "Text"],

Cell["\<\
MVShow3D[tog1b, MVPointSphereSize\[Rule]3.8, MVLineTubeSize \[Rule] 0.01]\
\>", "Input",
  CellLabel->"In[145]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The isogonal case", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Setting a = b we get the family of isogonal circle pairs, we plot a paart of \
this family:\
\>", "Text"],

Cell[BoxData[
    \(\(?circlefamily\)\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(circlefamily[v5, v3, a, 0. , 1. , 10]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(grison = %\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[grison]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[grison, \ MVLineTubeSize\  \[Rule] \ 0.03]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?ThreeScript\)\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(ThreeScript["\<grison.ts\>", grison]\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(Export["\<grison.eps\>", grison]\)], "Input",
  CellLabel->"In[83]:="],

Cell["A corresponding surface:", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[
      Evaluate[\(circle2spv[v5[a], \ v3[a]]\)[t]], {a, \ 0, \ 1. }, \ {t, \ 
        0, \ 2\ Pi}, PlotPoints\  \[Rule] 40]\)], "Input",
  CellLabel->"In[86]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(grisosf\  = %\)], "Input",
  CellLabel->"In[87]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[grisosf]\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[grisosf, \ Boxed \[Rule] \ False, Axes \[Rule] \ False]\)], "Input",\

  CellLabel->"In[89]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Export["\<grisosf.eps\>", %]\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times"],

Cell["Radius, center, position vector", "Text",
  FontFamily->"Times"],

Cell["\<\
Center and radius do not depend on a, all the centers lie on the y-axis:\
\>", "Text"],

Cell[BoxData[
    \(center[v5[a], \ v3[a]]\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[v5[a], \ v3[a]]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times"],

Cell["Remember", "Text"],

Cell[BoxData[
    \(Plot[%, \ {a, \(-Pi\), Pi}]\)], "Input",
  CellLabel->"In[96]:="],

Cell["\<\
Thus the radius goes to infinity very fast for a-> Pi/2; for a = Pi/2 we \
obtain the z-axis:\
\>", "Text"],

Cell[BoxData[
    \(circ1b[Pi/2, Pi/2]\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(posvec[v5[a], \ v3[a]]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pp[v5[a1], v3[a1], v5[a2], v3[a2]]\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(pscross[{v5[a1], v3[a1], v5[a2], v3[a2]}]\)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[105]:="],

Cell["\<\
It follows that any pair of circles of the 1-parameter family circ1b[a,a]  \
fulfil the conditions of case 1 b) - i.e. are in general position and \
isogonal - wth the exception of the values a1 = a2+k*Pi  (k integer),  where \
the circles coincide (up to orientation). \
\>", "Text"],

Cell["\<\
For the spherical invariant function one has the simple form, as mentioned \
already in subsection 4.4, in  specil case. \
\>", "Text",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(sphinv[a, a]\)[s, t]\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(Plot3D[\(sphinv[0.6, 0.6]\)[s, t], \ {t, 0, 2*Pi}, {s, 0, 2*Pi}, \ 
      PlotPoints\  \[Rule] \ 50]\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(graph2\  = \ %\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Export["\<graph2.eps\>", \ graph2]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.4 Case 2a: Non intersecting circles on a sphere", "Subsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(b4\  = \ stb[4]\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"],

Cell["The eigenvalues are obtained from the normal form", "Text"],

Cell[BoxData[
    \(pp[stb[3], \ stb[4], \ v4[a], \ stb[4]]\)], "Input",
  CellLabel->"In[22]:=",
  FontFamily->"Times"],

Cell["\<\
 Both circles lie on the standard unit sphere. U0 +U1 is spanned by stb[3], \
stb[4], v4[a]. We set\
\>", "Text"],

Cell[BoxData[
    \(mat[a_]\  := \ {stb[3], \ stb[4], v4[a]}\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[" and calculate", "Text"],

Cell[BoxData[
    \(Det[
      Table[pssp[\(mat[a]\)[\([i]\)], \(mat[a]\)[\([j]\)]], \ {i, 3}, \ {j, 
          3}]]\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"],

Cell["\<\
It follows that  for a \[NotEqual] 0 the subspace U0 + U1 is \
pseudo-euclidean: case 2.a\
\>", "Text"],

Cell[BoxData[
    \(Table[plotcircle2spv[v4[a], stb[4]], {a, \ 0.2, 3.2, \ 0.5}]\)], "Input",\

  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(nf2a = \ %\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[
      Evaluate[\(circle2spv[v4[a], \ stb[4]]\)[t]], {a, \ 0, \ Pi}, \ {t, \ 
        0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[28]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ngr2a\  = \ %\)], "Input",
  CellLabel->"In[29]:=",
  FontFamily->"Times"],

Cell["ThreeScript[\"nf2a.ts\", nf2a]", "Input",
  FontFamily->"Times"],

Cell["ThreeScript[\"ngr2a.ts\", ngr2a]", "Input",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.5 Case 2b: 2-point intersecting circles in the x,y-plane", \
"Subsection",
  FontFamily->"Times"],

Cell["\<\
This case one gets specialising case 1a to a = 0. Then the eigenvalues are 1, \
cos^2[b]:\
\>", "Text"],

Cell[BoxData[
    \(pp[stb[3], \ stb[4], \ stb[3], \ v3[b]]\)], "Input",
  CellLabel->"In[30]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(mat[b_]\  := \ {stb[3], \ stb[4], v3[b]}\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell[" and calculate", "Text"],

Cell[BoxData[
    \(Det[
      Table[pssp[\(mat[b]\)[\([i]\)], \(mat[b]\)[\([j]\)]], \ {i, 3}, \ {j, 
          3}]]\)], "Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell["\<\
It follows that  for a \[NotEqual] 0 the subspace U0 + U1 is euclidean: case \
2.b\
\>", "Text"],

Cell[BoxData[
    \(vb[b_] := stb[3]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(circlefamily[vb, v3, b, 0.1, 1. , 10]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(bdl4\  = \ %\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(MVShow3D[bdl4, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{bdl4, \ grc1}]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(nf2a = \ %\)], "Input",
  FontFamily->"Times"],

Cell["\<\
All the circles belong to the x,y-plane and intersect the standard unit \
circle grc1. The common intersection points are the unit points x = \
\[PlusMinus]1, y = 0.\
\>", "Text"],

Cell[BoxData[
    \(vec[x]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Solve[{pssp[\(mat[b]\)[\([1]\)], vec[\ x]] == 0, \ 
        pssp[\(mat[b]\)[\([2]\)], vec[\ x]] == 
          0, \n\t\tpssp[\(mat[b]\)[\([3]\)], vec[\ x]] == 0\ , 
        pssp[vec[x], vec[\ x]] == 0}, vec[x]]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vec[x] /. %\)], "Input",
  CellLabel->"In[56]:="],

Cell["The solutions are, as stated:", "Text"],

Cell[BoxData[
    \({stepro[{\(-1\), 0, 0, 0, 1}], \ 
      stepro[{1, \ 0, \ 0, \ 0, 1}]}\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell["\<\
Obviously, we have the case 2b), and the argument b is the intersection angle \
of the two circles.  For b = k \[Pi]  we obtain the trivial pair {grc1,grc1}.\
\
\>", "Text"],

Cell[BoxData[
    \(plotcircle2spv[stb[3], v3[Pi/2]]\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%, \ grc1]\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.6 Cases 1c and 2c: Circles intersecting in one point", "Subsection",
  FontFamily->"Times"],

Cell["\<\
For the normal form in this case we use v5[b] and the vector \
\>", "Text"],

Cell[BoxData[
    \(b4\  := \ {0, 1, 0, \(-1\), 1}\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell["Therefore all the considered circles lie on the sphere", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[b4]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MatrixForm[Evaluate[pp[stb[3], \ stb[4], \ v5[b], \ b4]]]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pscross[{stb[3], \ stb[4], v5[b], \ b4}]\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell["\<\
For all values of b \[NotEqual] k\[Pi]  this is an isotropic vector; \
therefore we have case 1.c: all the corresponding circles intersect the unit \
circle in a uniquely defined point.\
\>", "Text"],

Cell[BoxData[
    \(circ1c[\ b_]\  := \ plotcircle2spv[v5[b], \ b4\ ]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[\ 
      plotcircle2spv[v5[b*Pi], \ b4], \ {b, \ 0.1, \ 1, \ 0.3}]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(sertest1\  = %\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{sertest1, grc1}]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(test1c = %\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(matc[b_]\  := \ {stb[3], \ stb[4], v5[b], \ b4}\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Solve[{pssp[\(matc[b]\)[\([1]\)], vec[x]\ ] == \ 0, 
        pssp[\(matc[b]\)[\([2]\)], vec[x]\ ] == \ 0, 
        pssp[\(matc[b]\)[\([3]\)], vec[x]\ ] == \ 0, 
        pssp[\(matc[b]\)[\([4]\)], vec[x]\ ] == \ 0}, \ vec[x]]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vec[x] /. %\)], "Input",
  CellLabel->"In[72]:="],

Cell["\<\
All the circles intersect the standard unit circle in the uniquely defined \
point\
\>", "Text"],

Cell[BoxData[
    \(stepro[{0, \ 1, 0, 0, 1}]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell["\<\
All the circles of the family defined by {b4, v5[b]} intersect in two points:\
\
\>", "Text"],

Cell[BoxData[
    \(Solve[{pssp[\(matc[b]\)[\([3]\)], vec[x]\ ] == \ 0, 
        pssp[\(matc[b]\)[\([4]\)], vec[x]\ ] == \ 0, 
        pssp[\(matc[0]\)[\([3]\)], vec[x]] == \ 0, \ 
        pssp[vec[x], \ vec[x]] == \ 0}, \ vec[x]]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vec[x] /. %\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \({stepro[{0, 0, 0, \(-1\), 1}], \ stepro[{0, 1, 0, 0, 1}]}\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell["\<\
Thus we have a family of circles through the point {0,1,0}. Especially we get\
\
\>", "Text"],

Cell[BoxData[
    \(plotcircle2spv[v5[Pi], \ b4]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc1, \ %}]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell["\<\
This is a tangent circle to grc1 in the point {0,1,0}: case 2.c. The matrix \
pp has the diagonal form\
\>", "Text"],

Cell[BoxData[
    \(MatrixForm[Evaluate[pp[stb[3], \ stb[4], \ v5[Pi], \ b4]]]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pscross[{stb[3], \ stb[4], v5[Pi], \ b4}]\)], "Input",
  CellLabel->"In[80]:=",
  FontFamily->"Times"],

Cell["\<\
If b4 is replaced by the vector {0,1,0,1,1} one gets  a family of lines lying \
in the plane y = 1 through the point {0,1,0}.\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[{0, 1, 0, 1, 1}]\)], "Input",
  CellLabel->"In[81]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v5[t]\)], "Input",
  CellLabel->"In[82]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(radius[v5[t], \ {0, 1, 0, 1, 1}]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(center[v5[t], \ {0, 1, 0, 1, 1}]\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[
      plotcircle2spv[v5[s], \ {0, 1, 0, 1, 1}], {s, 0, 5, 0.5}]\)], "Input",
  CellLabel->"In[85]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[86]:=",
  FontFamily->"Times"],

Cell["Especially we get the tangent:", "Text"],

Cell[BoxData[
    \(plotcircle2spv[v5[Pi], \ {0, 1, 0, 1, 1}]\)], "Input",
  CellLabel->"In[87]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc1, \ %}]\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times"],

Cell["Of course, we have the same invariants:", "Text"],

Cell[BoxData[
    \(MatrixForm[
      Evaluate[pp[stb[3], \ stb[4], \ v5[Pi], \ {0, 1, 0, 1, 1}]]]\)], "Input",\

  CellLabel->"In[89]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pscross[{stb[3], \ stb[4], v5[Pi], \ {0, 1, 0, 1, 1}}]\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[x, y, z, u, v, r, ma]\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["6 Circle surfaces, circle orbits, geodesics in the \
circle space",
  FontFamily->"Helvetica"]], "Section",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["6.1 Introduction", "Subsection",
  FontFamily->"Times"],

Cell["\<\
A circle surface is a surface in the 3-space through any point of which \
exists a circle contained in the surface. With other words: A circle surface \
can be described  as a curve in the circle space. The spheres (and planes) \
are the simplest circle surfaces. The tubes considered in section 2.4 are \
circle surfaces. More general, envelopes of one-parameter sphere families: \
the canal surfaces, are circle surfaces.  A special case are the Dupin \
cyclides, which are canal surfaces in a twofold way. That means, that there \
exists two different sphere curves whose envelopes is the same canal surface: \
tori, circular coni,  circular cylinders, and their images under Moebius \
transformations. Other special circle surfaces are the orbits of  1-parameter \
subgroups of the M\[ODoubleDot]bius group in the circle space.\
\>", "Text"],

Cell[TextData[{
  "The circle space is pseudo-Riemannian symmetric of rank two. The geodesics \
of the circle space are orbits of certain 1-parameter subgroups of the M\
\[ODoubleDot]bius group.   As in all reductive spaces, the geodesics through \
an element C are the orbits of  one-parameter subgroups exp(At) C, t \
\[Element] R, where in our case C is the standard unit circle grc1 and A an \
element of the orthogonal complement of the isotropy algebra of C in the Lie \
algebra o(5,1); here orthogonality is defined by the Killing form  of the Lie \
algebra o(5,1), see my notebook liealgeb.nb, in ",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  " ",
  ButtonBox["[7]",
    ButtonData:>"S5",
    ButtonStyle->"Hyperlink"],
  StyleBox[". ", "MathCaption"],
  " It would be interesting to investigate the relation between the \
pseudo-Riemannian geometry of the circle space and the circle manifolds more \
basically. But this may be the subject of another notebook. Some results \
about the M\[ODoubleDot]bius geometry of circle surfaces are contained in the \
diploma paper  ",
  ButtonBox["[3]",
    ButtonData:>"M3",
    ButtonStyle->"Hyperlink"],
  " of Uwe May; especially the geodesics defined in the next subsections can \
be found there. We emphasize that we do not give here a classification of all \
the geodesics with respect to the M\[ODoubleDot]bius group. We only treat \
three simple cases of geodesics lying in a 2-sphere."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["6.2 Spacelike geodesics", "Subsection",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[TextData[{
  "The following matrix function defines the 1-parameter subgroup exp[Uh*t], \
where Uh is an element of the Lie algebra o(n,1) orthogonal to the isotropy \
algebra of grc1 and spacelike with respect to the Killing form of o(n,1) (see \
 the notebook ",
  ButtonBox["liealgeb.nb",
    ButtonData:>"S5",
    ButtonStyle->"Hyperlink"],
  " mentioned above):"
}], "Text"],

Cell[BoxData[
    \(Uh\  = \ {{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 
          0, 1}, {0, 0, 0, 1, 0}}\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gUh[t_]\ \  := \ MatrixExp[Uh\ t]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MatrixForm[gUh[t]]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vh1[t_] := \ gUh[t] . stb[4]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vh1[t]\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times"],

Cell["\<\
Obviously, stb[3] is fixed under gUh[t]. Therefore the orbit of {stb[3], \
stb[4]} is given by\
\>", "Text"],

Cell[BoxData[
    \(hypgeodesic[t_, u_] := \(circle2spv[vh1[t], stb[3]]\)[u]\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[
      hypgeodesic[t, u], {t, \(-0.5\), 1}, {u, 0, 2\ \[Pi]}]\)], "Input",
  CellLabel->"In[98]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(hypgeo\  = \ %\)], "Input",
  CellLabel->"In[99]:=",
  FontFamily->"Times"],

Cell["\<\
This is the family of concentric circles in the x,y-plane containing the \
standard unit circle grc1 (for t = 0).\
\>", "Text"],

Cell[BoxData[
    \(ThreeScript["\<hypgeo.ts\>", hypgeo]\)], "Input",
  FontFamily->"Times"],

Cell[TextData[{
  "The group is the group of all dilatations in the euclidean picture, \
leaving the \"north pole\" of ",
  Cell[BoxData[
      \(TraditionalForm\`S\^3\)]],
  " fixed."
}], "Text"],

Cell[CellGroupData[{

Cell["The invariants along the hyperbolic geodesic", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(invpp[s_, t_] := \ pp[vh1[t], stb[3], vh1[s], stb[3]]\)], "Input",
  CellLabel->"In[100]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(invpp[s, t]\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times"],

Cell["\<\
The Invariants are the elements of the diagonal; the variable one is (for s \
\[NotEqual]t) always greater than 1, we show this: \
\>", "Text"],

Cell[BoxData[
    \(ftt[s_, t_]\  := \ 
      1\/4\ \[ExponentialE]\^\(\(-2\)\ \((s + t)\)\)\ \((\[ExponentialE]\^\(2\
\ s\) + \[ExponentialE]\^\(2\ t\))\)\^2\)], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot3D[ftt[s, t], {s, \(-1\), 1}, \ {t, \(-1\), 1}]\)], "Input",
  CellLabel->"In[104]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ftt1[s_, t_] := \ D[ftt[s1, t], s1] /. s1 \[Rule] s\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ftt2[s_, t_] := \ D[ftt[s, t1], t1] /. t1 \[Rule] t\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[ftt1[s, t]]\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[ftt2[s, t]]\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times"],

Cell["\<\
The derivatives are zero for s = t only; obviously, for any fixed t, ftt[s,t] \
reaches its minimum for s = t, and this minimum is\
\>", "Text"],

Cell[BoxData[
    \(ftt[s, s]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times"],

Cell["The radius of the circle as function of t is", "Text"],

Cell[BoxData[
    \(radius[vh1[t], stb[3]]\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times"],

Cell["\<\
For the varying invariant expressed as a function of the radius we obtain\
\>", "Text"],

Cell[BoxData[
    \(\(invpp[t, \ 0]\)[\([1, 1]\)] /. \[ExponentialE]\^t \[Rule] \ 
        r\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(% /. \[ExponentialE]\^\(-t\) \[Rule] \ r^\((\(-1\))\)\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[\((1\/\(2\ r\) + r\/2)\)\^2, {r, \ 0.2, 5}]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Equivalent description on the 2-sphere", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(U3h\  = \ {{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 1}, {0, 0, 0, 
          0, 0}, {0, 0, 1, 0, 0}}\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MatrixForm[U3h]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(gU3h[t_]\ \  := \ MatrixExp[U3h\ t]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MatrixForm[gU3h[t]]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(v3h1[t_] := gU3h[t] . stb[3]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(v3h1[t]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(hyp3geodesic[t_, u_] := \(circle2spv[v3h1[t], stb[4]]\)[u]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[
      hyp3geodesic[t, u], {t, \(-1. \), 1}, {u, 0, 2\ \[Pi]}]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(hyp3geo\  = %\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?circlefamily\)\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(xy[t_] := \ stb[4]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(circlefamily[v3h1, xy, t, 0, \ 1. , 10, \ 
      PlotPoints\  \[Rule] \ 100]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(hgeofam\  = \ %\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<hgeofam.ts\>", hgeofam]\)], "Input",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3 Timelike geodesics", "Subsection",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
The following matrix function defines the 1-parameter subgroup exp[Ue*t], \
where Ue is an element of the Lie algebra o(n,1) orthogonal to the isotropy \
algebra of grc1 and timelike with respect to the Killing form of o(n,1) (see \
liealgeb.nb ):\
\>", "Text"],

Cell[BoxData[
    \(Ue\  = \ {{0, 0, 1, 0, 0}, {0, 0, 0, 0, 0}, {\(-1\), 0, 0, 0, 0}, {0, 
          0, 0, 0, 0}, {0, 0, 0, 0, 0}}\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gUe[t_] := MatrixExp[Ue\ t]\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gUe[t] // MatrixForm\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ve1[t_]\  := \ gUe[t] . stb[3]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ve1[t]\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ve2[t_]\  := \ stb[4]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(circlefamily[ve1, ve2, t, \(-N[Pi]\), N[Pi], \ 30]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Ue\  = \ {{0, 0, 1, 0, 0}, {0, 0, 0, 0, 0}, {\(-1\), 0, 0, 0, 0}, {0, 
          0, 0, 0, 0}, {0, 0, 0, 0, 0}}\)], "Input",
  CellLabel->"In[122]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gUe[t_] := MatrixExp[Ue\ t]\)], "Input",
  CellLabel->"In[123]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gUe[t] // MatrixForm\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ve1[t_]\  := \ gUe[t] . stb[3]\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ve1[t]\)], "Input",
  CellLabel->"In[126]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ve2[t_]\  := \ stb[4]\)], "Input",
  CellLabel->"In[127]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(circlefamily[ve1, ve2, t, \(-N[Pi]\), N[Pi], \ 30]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ellgeo\  = \ %\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[ellgeo]\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(MVShow3D[%]\)], "Input",
  CellLabel->"In[131]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<ellgeo.ts\>", ellgeo]\)], "Input",
  FontFamily->"Times"],

Cell["\<\
The standard circle rotates around the y-axis. The surface creation  yields \
the unit sphere, with two omitted sections:\
\>", "Text"],

Cell[BoxData[
    \(ellgeodesic[t_, u_] := \(circle2spv[ve1[t], stb[4]]\)[u]\)], "Input",
  CellLabel->"In[132]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[
      ellgeodesic[t, u], {t, \(-Pi\)/2, Pi/2}, {u, 0, 2\ Pi}, \ 
      PlotPoints\  \[Rule] \ 30]\)], "Input",
  CellLabel->"In[133]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[%]\)], "Input",
  CellLabel->"In[134]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "The strange behaviour of the picture at the borders t = Pi/2, -Pi/2 comes \
from the careful calculation of the expression ellgeodesic[t,u] by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " :"
}], "Text"],

Cell[BoxData[
    \(ellgeodesic[t, u]\)], "Input",
  CellLabel->"In[135]:=",
  FontFamily->"Times"],

Cell["\<\
Simplification with the condition  t>-Pi/2&&t<Pi/2 yields a usual parameter \
representation of the unit sphere:\
\>", "Text"],

Cell[BoxData[
    \(Simplify[%, \ t > \(-Pi\)/2 && t < Pi/2]\)], "Input",
  CellLabel->"In[136]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[ellgeodesic]\)], "Input",
  CellLabel->"In[137]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ellgeodesic[t_, u_] := \ {Cos[t]\ Sin[u], \ 
        Cos[u], \(-\ Sin[t]\)\ Sin[u]}\)], "Input",
  CellLabel->"In[138]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[
      ellgeodesic[t, u], {t, \(-Pi\)/2, Pi/2}, {u, 0, 2\ Pi}, \ 
      PlotPoints\  \[Rule] \ 30]\)], "Input",
  CellLabel->"In[139]:=",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["The invariants along the elliptic geodesic", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(invellpp[s_, t_]\  := \ pp[ve1[s], stb[4], ve1[t], stb[4]]\)], "Input",
  CellLabel->"In[140]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[invellpp[s, t]]\)], "Input",
  CellLabel->"In[141]:=",
  FontFamily->"Times"],

Cell["\<\
As expected, the only essential invariant is the cosinus square of the \
intersection angle.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.4 Isotropic geodesics", "Subsection",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[TextData[{
  "The following matrix function defines the 1-parameter subgroup exp[U*t], \
where U is an element of the Lie algebra o(n,1) orthogonal to the isotropy \
algebra of grc1 and isotropic with respect to the Killing form of o(n,1) (see \
",
  ButtonBox["[7]",
    ButtonData:>"S5",
    ButtonStyle->"Hyperlink"],
  ", liealgeb.nb ):"
}], "Text"],

Cell[BoxData[
    \(U\  = {{0, 0, 1, 0, 0}, {0, 0, 0, 0, 0}, {\(-1\), 0, 0, 0, 1}, {0, 0, 
          0, 0, 0}, {0, 0, 1, 0, 0}}\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MatrixForm[U]\)], "Input",
  CellLabel->"In[143]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isotropugr[t_] := \ MatrixExp[U*t]\)], "Input",
  CellLabel->"In[144]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isotropugr[t]\)], "Input",
  CellLabel->"In[145]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gh[t_] := \ isotropugr[t]\)], "Input",
  CellLabel->"In[146]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[
      Table[pssp[\(gh[t]\)[\([i]\)], \ \(gh[t]\)[\([j]\)]], {i, 5}, {j, 
          5}]]\)], "Input",
  CellLabel->"In[147]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v1c[t_]\  := \ gh[t] . stb[3]\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v2c[t_]\  := \ gh[t] . stb[4]\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v1c[t]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v2c[t]\)], "Input",
  CellLabel->"In[151]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[v1c[1. ], v2c[1. ]]\)], "Input",
  CellLabel->"In[152]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(circlefamily[v1c, v2c, t, 0, 10, \ 20, PlotRange\  -> \ All]\)], "Input",\

  CellLabel->"In[153]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \(circlefamily[v1c, v2c, t, \(-10\), 0, \ 20, 
      PlotRange\  -> \ All]\)], "Input",
  CellLabel->"In[155]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[156]:="],

Cell[BoxData[
    \(circlefamily[v1c, v2c, t, \(-3\), 3, \ 30, 
      PlotRange\  -> \ All]\)], "Input",
  CellLabel->"In[157]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[158]:="],

Cell[BoxData[
    \(isotrop\  = \ %\)], "Input",
  CellLabel->"In[159]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[Graphics3D[{PointSize[0.05], \ Point[{1, 0, 0}]}]]\)], "Input",
  CellLabel->"In[160]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isoge\  = {%, \ isotrop}\)], "Input",
  CellLabel->"In[161]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[162]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isoge\  = \ %\)], "Input",
  CellLabel->"In[164]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ThreeScript["\<isoge.ts\>", isoge]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[isoge, MVPointSphereSize \[Rule] 0.5, \[IndentingNewLine]\ 
      MVLineTubeSize\  -> \ 0.01]\)], "Input",
  CellLabel->"In[165]:=",
  FontFamily->"Times"],

Cell["\<\
 This is a 1-parameter circle family on the unit sphere consisting of all \
circles tangent to the equator at the point {1,0,0}. We check this using \
Solve:\
\>", "Text"],

Cell[BoxData[
    \(Solve[{pssp[stb[4], vec[x]] == \ 0, \ pssp[stb[3], vec[x]] == \ 0, \ 
        pssp[v1c[1. ], vec[x]] == \ 0, \ pssp[v1c[ .5], vec[x]] == \ 0}, 
      vec[x]]\)], "Input",
  CellLabel->"In[178]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vec[x] /. %\)], "Input",
  CellLabel->"In[179]:="],

Cell["The solution is", "Text"],

Cell[BoxData[
    \(pz\  = Flatten[%]\)], "Input",
  CellLabel->"In[180]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[pz, pz]\)], "Input",
  CellLabel->"In[181]:=",
  FontFamily->"Times"],

Cell["\<\
Since the points correspond to isotropic vectors, the uniquely defined \
solution is given by x[2]= 0:\
\>", "Text"],

Cell[BoxData[
    \(pzz\  = \ {t, 0, 0, 0, t}; stepro[pzz]\)], "Input",
  CellLabel->"In[182]:=",
  FontFamily->"Times"],

Cell["The representation as circle surface can be obtained with", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[\(circle2spv[v1c[t], v2c[t]]\)[u], \ {t, \(-Pi\), 
        Pi}, {u, \ 0, \ 2\ Pi}]\)], "Input",
  CellLabel->"In[183]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[%]\)], "Input",
  CellLabel->"In[184]:=",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["The invariants along the isotropic geodesic", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(invisopp[s_, t_]\  := \ pp[v1c[s], v2c[s], v1c[t], v2c[t]]\)], "Input",
  CellLabel->"In[185]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[invisopp[s, t]]\)], "Input",
  CellLabel->"In[186]:=",
  FontFamily->"Times"],

Cell["\<\
As can be proved easily by elementary considerations, any two pairs of two \
tangent circles are M\[ODoubleDot]bius equivalent.\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7 ThreeScript, MathGL3d", "Section",
  FontFamily->"Times",
  CellTags->"MathGL"],

Cell[TextData[{
  "If you want to generate *.ts files for animations outside of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", activate the next section. To use the animation program MathGl3d in this \
notebook, activate section 7.2."
}], "Text"],

Cell[CellGroupData[{

Cell["7.1 Threescript ", "Subsection",
  FontFamily->"Times"],

Cell["\<\
 The ThreeScript commands generate *.ts files appropriate  for certain \
animation programs. The good freeware program  MathGL3d  created by Jens-Peer \
Kuska (for Windows95, Linux and other platforms) can be downloaded from \
[2].\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Under Windows the commercial 3D-Animation programs MathLive and \
DynamicVisualizer are available. To produce .ts-files one \
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(Needs["\<Graphics`ThreeScript`\>"]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?ThreeScript\)\)], "Input",
  FontFamily->"Times"],

Cell["\<\
The standard extension of these files is ts: \"filename.ts\" or \
\"Path/filename.ts\"\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(ThreeScript["\<isofam.ts\>", \ isofam]\)], "Input",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 MathGL3d", "Subsection",
  FontFamily->"Times"],

Cell[TextData[{
  "The free animation program MathGL3d by Jens-Peer Kuska [2] can be used \
from a command line and within a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. A new version of this program is in preparation. Jens-Peer Kuska \
has sent me a new startup file OpenGLViewer.m, and friendly permitted to add \
it to the item \"Spheres\". Replace the old file OpenGLViewer.m by this new \
OpenGLViewer.m. If you did this, changes of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ParametricPlot3D, especially the sometimes disturbing generating of \
MeshGraphics3D objects, will not take place.\nEstablish the link to the \
current ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session with the command:"
}], "Text"],

Cell[BoxData[
    \(Get["\<MathGL3d`OpenGLViewer`\>"]\)], "Input",
  CellLabel->"In[17]:=",
  FontFamily->"Times"],

Cell["If you want to close the link, enter", "Text"],

Cell["MVClose[]", "Text"],

Cell["\<\
The following command clears the Viewer window; this and other MathGL3d \
commands you may enter also with  palettes.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(MVClear[];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(MVShow3D[\[Placeholder], MVPolygonShading \[Rule] MVSmooth, 
      MVGrayBackground \[Rule] False, MVTexture \[Rule] None, 
      MVTextureMapType \[Rule] MVMeshUVMapping, 
      MVScaleTexture \[Rule] {1, 1}, 
      MVTranslateTextureTarget \[Rule] Automatic, 
      MVRotateTextureTarget \[Rule] Automatic, 
      MVScaleTextureTarget \[Rule] Automatic]\)}], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[testgr, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[isoge, MVPointSphereSize \[Rule] 0.5, \[IndentingNewLine]\ 
      MVLineTubeSize\  -> \ 0.01]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[tgr3, \ MVPointSphereSize\  \[Rule] \ 1.8]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[ex123, MVPointSphereSize \[Rule] 1.8]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[hyp3geo]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(Options[MVShow3D]\)], "Input",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVClose[]\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
[1] Alfred Gray. Modern Differential Geometry of Curves and Surfaces. CRC \
PRESS, 1993 (German translation: Spektrum Akademischer Verlag 1994)\
\>", "Text",
  Evaluatable->False,
  CellTags->"G1"],

Cell["\<\
[2] Jens-Peer Kuska. http://phong.informatik.uni-leipzig.de/ \
~kuska/mview3d.html.\
\>", "Text",
  Evaluatable->False,
  CellTags->"K2"],

Cell["\<\
[3] U. May. Der Raum der Kreise in der Sph\[ADoubleDot]re. Diplomarbeit, \
Humboldt-Universit\[ADoubleDot]t, Berlin, 1993.\
\>", "Text",
  Evaluatable->False,
  CellTags->"M3"],

Cell[TextData[{
  "[4] A. L. Oniscik, R. Sulanke. Projektive und Cayley-Kleinsche Geometrien. \
 2003.  May be downloaded from my ",
  ButtonBox["homepage",
    ButtonData:>"HP",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"O-S"],

Cell["\<\
[5] Sulanke, Rolf. Spheres.  1999.  \
http://mathsource.com/Content/Enhancements/Geometry/0210-092\
\>", "Text",
  CellTags->"S1"],

Cell[TextData[{
  "[6] R. Sulanke. M\[ODoubleDot]bius invariants for pairs (",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\%m\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\_2\%l\)]],
  ") of spheres in the M\[ODoubleDot]bius space ",
  Cell[BoxData[
      \(TraditionalForm\`S\^n\)]],
  ". Beitr\[ADoubleDot]ge zur Algebra und Geometrie.41 (2000), No.1, 233-246. \
 Preprint No. 373, SFB 288, Berlin 1999.  \
http://xxx.lanl.gov/abs/math.MG/9902131. "
}], "Text",
  Evaluatable->False,
  CellTags->"S4"],

Cell["\<\
[7] R. Sulanke. Lie Algebras. \
http://www.mathsource.com/cgi-bin/msitem?0210-845\
\>", "Text",
  Evaluatable->False,
  CellTags->"S5"]
}, Closed]],

Cell[CellGroupData[{

Cell["Author's address", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
Homepage:
http://www-irm.mathematik.hu-berlin.de/~sulanke
e-Mail:\
\>", "Text",
  CellTags->"HP"],

Cell["sulanke@mathematik.hu-berlin.de", "Text"],

Cell["\<\
The author will be very thankful for hints, corrections, comments.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for X",
ScreenRectangle->{{0, 1024}, {0, 768}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
WindowSize->{859, 680},
WindowMargins->{{22, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "rolf", "mymath", \
"spheres.v3"}, "mcircles.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
SpellingDictionaries->{"CorrectWords"->{
  "Erhard", "orthonormalization", "semisimple", "Activite", 
    "Orthonormalization", "Cartan", "spacelike", "timelike", "Lorentz", 
    "Inspiron", "symplectic", "nullmatrices", "conformality", "subalgebra", 
    "Jacoby", "ch"}},
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "stat"->{
    Cell[138072, 5103, 144, 4, 40, "Text",
      CellTags->"stat"]},
  "v5.1"->{
    Cell[206216, 7811, 144, 4, 39, "Subsection",
      CellTags->"v5.1"]},
  "MathGL"->{
    Cell[262045, 10076, 87, 2, 58, "Section",
      CellTags->"MathGL"]},
  "G1"->{
    Cell[265875, 10213, 207, 5, 59, "Text",
      Evaluatable->False,
      CellTags->"G1"]},
  "K2"->{
    Cell[266085, 10220, 147, 5, 40, "Text",
      Evaluatable->False,
      CellTags->"K2"]},
  "M3"->{
    Cell[266235, 10227, 186, 5, 40, "Text",
      Evaluatable->False,
      CellTags->"M3"]},
  "O-S"->{
    Cell[266424, 10234, 246, 8, 40, "Text",
      CellTags->"O-S"]},
  "S1"->{
    Cell[266673, 10244, 140, 4, 40, "Text",
      CellTags->"S1"]},
  "S4"->{
    Cell[266816, 10250, 515, 15, 59, "Text",
      Evaluatable->False,
      CellTags->"S4"]},
  "S5"->{
    Cell[267334, 10267, 145, 5, 40, "Text",
      Evaluatable->False,
      CellTags->"S5"]},
  "HP"->{
    Cell[267581, 10280, 107, 5, 102, "Text",
      CellTags->"HP"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"stat", 269234, 10328},
  {"v5.1", 269315, 10331},
  {"MathGL", 269404, 10334},
  {"G1", 269488, 10337},
  {"K2", 269592, 10341},
  {"M3", 269696, 10345},
  {"O-S", 269801, 10349},
  {"S1", 269880, 10352},
  {"S4", 269958, 10355},
  {"S5", 270063, 10359},
  {"HP", 270167, 10363}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 143, 4, 75, "Title",
  Evaluatable->False],
Cell[1922, 59, 222, 8, 31, "Subsubtitle",
  Evaluatable->False],
Cell[2147, 69, 145, 4, 31, "Text",
  Evaluatable->False],
Cell[2295, 75, 166, 4, 27, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2486, 83, 78, 2, 36, "Subsubsection"],
Cell[2567, 87, 3652, 69, 481, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[6256, 161, 56, 1, 36, "Subsubsection"],
Cell[6315, 164, 299, 5, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6651, 174, 55, 1, 30, "Subsubsection"],
Cell[6709, 177, 596, 14, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7342, 196, 57, 1, 30, "Subsubsection"],
Cell[7402, 199, 552, 8, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7991, 212, 59, 1, 39, "Subsection"],
Cell[8053, 215, 321, 5, 65, "Text"],

Cell[CellGroupData[{
Cell[8399, 224, 141, 4, 33, "Input",
  InitializationCell->True],
Cell[8543, 230, 82, 2, 28, "Output"]
}, Closed]],
Cell[8640, 235, 156, 3, 31, "Text"],
Cell[8799, 240, 127, 4, 33, "Input",
  InitializationCell->True],
Cell[8929, 246, 56, 0, 27, "Text"],
Cell[8988, 248, 239, 7, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[9264, 260, 57, 1, 58, "Section"],

Cell[CellGroupData[{
Cell[9346, 265, 106, 2, 44, "Subsection"],
Cell[9455, 269, 562, 9, 84, "Text"],
Cell[10020, 280, 220, 4, 46, "Text"],
Cell[10243, 286, 135, 4, 32, "Input",
  InitializationCell->True],
Cell[10381, 292, 381, 7, 65, "Text",
  Evaluatable->False],
Cell[10765, 301, 124, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[10914, 308, 176, 5, 32, "Input",
  InitializationCell->True],
Cell[11093, 315, 413, 11, 70, "Output"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[11555, 332, 59, 1, 44, "Subsection"],
Cell[11617, 335, 153, 4, 27, "Text",
  Evaluatable->False],
Cell[11773, 341, 95, 3, 32, "Input"],
Cell[11871, 346, 99, 3, 32, "Input"],
Cell[11973, 351, 85, 2, 27, "Text"],
Cell[12061, 355, 87, 3, 32, "Input"],
Cell[12151, 360, 285, 6, 46, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[12461, 370, 66, 1, 36, "Subsubsection"],
Cell[12530, 373, 103, 3, 27, "Text"],
Cell[12636, 378, 572, 10, 128, "Input"],
Cell[13211, 390, 57, 0, 23, "Text"],
Cell[13271, 392, 735, 12, 152, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14043, 409, 66, 1, 36, "Subsubsection"],
Cell[14112, 412, 520, 9, 128, "Input"],
Cell[14635, 423, 57, 0, 27, "Text"],
Cell[14695, 425, 645, 10, 128, "Input"],
Cell[15343, 437, 95, 3, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15475, 445, 68, 1, 36, "Subsubsection"],
Cell[15546, 448, 262, 5, 56, "Input"],
Cell[15811, 455, 57, 0, 27, "Text"],
Cell[15871, 457, 299, 6, 56, "Input"],
Cell[16173, 465, 94, 3, 32, "Input"],
Cell[16270, 470, 91, 3, 32, "Input"],
Cell[16364, 475, 91, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16492, 483, 67, 1, 30, "Subsubsection"],
Cell[16562, 486, 355, 7, 80, "Input"],
Cell[16920, 495, 57, 0, 27, "Text"],
Cell[16980, 497, 400, 7, 104, "Input"],
Cell[17383, 506, 90, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17522, 515, 59, 1, 44, "Subsection"],

Cell[CellGroupData[{
Cell[17606, 520, 80, 1, 36, "Subsubsection"],
Cell[17689, 523, 144, 4, 31, "Input",
  Evaluatable->False],
Cell[17836, 529, 89, 3, 32, "Input"],
Cell[17928, 534, 85, 3, 32, "Input"],
Cell[18016, 539, 128, 3, 32, "Input",
  Evaluatable->False],
Cell[18147, 544, 90, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18274, 552, 72, 1, 36, "Subsubsection"],
Cell[18349, 555, 64, 0, 27, "Text"],
Cell[18416, 557, 95, 3, 32, "Input"],
Cell[18514, 562, 47, 1, 27, "Text"],
Cell[18564, 565, 111, 3, 32, "Input"],
Cell[18678, 570, 111, 3, 32, "Input"],
Cell[18792, 575, 87, 3, 32, "Input"],
Cell[18882, 580, 134, 3, 32, "Input"],
Cell[19019, 585, 98, 3, 32, "Input"],
Cell[19120, 590, 98, 3, 32, "Input"],
Cell[19221, 595, 99, 3, 32, "Input"],
Cell[19323, 600, 90, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19450, 608, 57, 1, 30, "Subsubsection"],
Cell[19510, 611, 400, 12, 46, "Text"],
Cell[19913, 625, 209, 5, 32, "Input",
  Evaluatable->False],
Cell[20125, 632, 102, 3, 32, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20288, 642, 76, 1, 58, "Section"],

Cell[CellGroupData[{
Cell[20389, 647, 55, 1, 36, "Subsubsection"],
Cell[20447, 650, 126, 4, 27, "Text"],
Cell[20576, 656, 92, 3, 32, "Input"],
Cell[20671, 661, 585, 9, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[21293, 675, 106, 2, 38, "Subsection"],

Cell[CellGroupData[{
Cell[21424, 681, 117, 3, 36, "Subsubsection"],
Cell[21544, 686, 190, 4, 46, "Text"],
Cell[21737, 692, 100, 3, 32, "Input"],
Cell[21840, 697, 168, 4, 32, "Input"],
Cell[22011, 703, 72, 0, 27, "Text"],
Cell[22086, 705, 93, 3, 32, "Input"],
Cell[22182, 710, 91, 3, 32, "Input"],
Cell[22276, 715, 97, 3, 32, "Input"],
Cell[22376, 720, 101, 3, 32, "Input"],
Cell[22480, 725, 134, 3, 32, "Input"],
Cell[22617, 730, 64, 0, 27, "Text"],
Cell[22684, 732, 133, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[22854, 740, 56, 1, 36, "Subsubsection"],
Cell[22913, 743, 201, 4, 46, "Text"],
Cell[23117, 749, 168, 4, 32, "Input"],
Cell[23288, 755, 137, 3, 32, "Input"],
Cell[23428, 760, 142, 4, 32, "Input"],
Cell[23573, 766, 94, 3, 32, "Input"],
Cell[23670, 771, 137, 3, 32, "Input"],
Cell[23810, 776, 142, 4, 32, "Input"],
Cell[23955, 782, 152, 4, 32, "Input"],
Cell[24110, 788, 94, 3, 32, "Input"],
Cell[24207, 793, 92, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24336, 801, 70, 1, 36, "Subsubsection"],
Cell[24409, 804, 94, 3, 32, "Input"],
Cell[24506, 809, 171, 4, 32, "Input",
  Evaluatable->False],
Cell[24680, 815, 114, 3, 32, "Input"],
Cell[24797, 820, 380, 8, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[25214, 833, 55, 1, 36, "Subsubsection"],
Cell[25272, 836, 166, 4, 32, "Input"],
Cell[25441, 842, 232, 5, 56, "Input"],
Cell[25676, 849, 252, 5, 56, "Input"],
Cell[25931, 856, 88, 3, 32, "Input"],
Cell[26022, 861, 94, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26153, 869, 77, 1, 30, "Subsubsection"],
Cell[26233, 872, 89, 2, 27, "Text"],
Cell[26325, 876, 95, 3, 32, "Input"],
Cell[26423, 881, 668, 13, 200, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[27128, 899, 56, 1, 36, "Subsubsection"],
Cell[27187, 902, 179, 4, 32, "Input"],
Cell[27369, 908, 66, 2, 32, "Input"],
Cell[27438, 912, 269, 6, 80, "Input"],
Cell[27710, 920, 94, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27853, 929, 69, 1, 38, "Subsection"],
Cell[27925, 932, 94, 3, 32, "Input"],
Cell[28022, 937, 247, 5, 56, "Input",
  Evaluatable->False],
Cell[28272, 944, 95, 3, 32, "Input"],
Cell[28370, 949, 227, 5, 56, "Input",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[28622, 958, 56, 1, 36, "Subsubsection"],
Cell[28681, 961, 116, 3, 32, "Input"],
Cell[28800, 966, 121, 3, 32, "Input"],
Cell[28924, 971, 126, 3, 32, "Input"],
Cell[29053, 976, 116, 3, 32, "Input"],
Cell[29172, 981, 137, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[29358, 990, 87, 1, 38, "Subsection"],

Cell[CellGroupData[{
Cell[29470, 995, 106, 2, 36, "Subsubsection"],
Cell[29579, 999, 219, 4, 46, "Text"],
Cell[29801, 1005, 330, 6, 128, "Input",
  Evaluatable->False],
Cell[30134, 1013, 124, 3, 27, "Text"],
Cell[30261, 1018, 149, 4, 32, "Input",
  Evaluatable->False],
Cell[30413, 1024, 41, 0, 27, "Text"],
Cell[30457, 1026, 286, 6, 56, "Input",
  Evaluatable->False],
Cell[30746, 1034, 367, 6, 65, "Text"],
Cell[31116, 1042, 713, 14, 176, "Input",
  Evaluatable->False],
Cell[31832, 1058, 70, 0, 27, "Text"],
Cell[31905, 1060, 369, 8, 152, "Input",
  Evaluatable->False],
Cell[32277, 1070, 217, 5, 27, "Text"],
Cell[32497, 1077, 124, 3, 32, "Input"],
Cell[32624, 1082, 124, 3, 32, "Input"],
Cell[32751, 1087, 153, 3, 27, "Text"],
Cell[32907, 1092, 96, 3, 32, "Input"],
Cell[33006, 1097, 1223, 22, 368, "Input",
  Evaluatable->False],
Cell[34232, 1121, 55, 0, 27, "Text"],
Cell[34290, 1123, 242, 6, 56, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[34569, 1134, 56, 1, 36, "Subsubsection"],
Cell[34628, 1137, 157, 4, 32, "Input",
  Evaluatable->True],
Cell[34788, 1143, 133, 3, 32, "Input"],
Cell[34924, 1148, 157, 4, 32, "Input",
  Evaluatable->True],
Cell[35084, 1154, 133, 3, 32, "Input"],
Cell[35220, 1159, 454, 11, 152, "Input",
  Evaluatable->True],
Cell[35677, 1172, 104, 3, 32, "Input"],
Cell[35784, 1177, 104, 3, 32, "Input"],
Cell[35891, 1182, 104, 3, 32, "Input"],
Cell[35998, 1187, 87, 3, 32, "Input"],
Cell[36088, 1192, 458, 12, 152, "Input",
  Evaluatable->True],
Cell[36549, 1206, 94, 3, 32, "Input"],
Cell[36646, 1211, 75, 0, 27, "Text"],
Cell[36724, 1213, 132, 3, 32, "Input"],
Cell[36859, 1218, 129, 3, 32, "Input"],
Cell[36991, 1223, 89, 2, 27, "Text"],
Cell[37083, 1227, 132, 3, 32, "Input"],
Cell[37218, 1232, 129, 3, 32, "Input"],
Cell[37350, 1237, 129, 3, 32, "Input"],
Cell[37482, 1242, 132, 3, 32, "Input"],
Cell[37617, 1247, 132, 3, 32, "Input"],
Cell[37752, 1252, 132, 3, 32, "Input"],
Cell[37887, 1257, 151, 4, 32, "Input",
  Evaluatable->True],
Cell[38041, 1263, 151, 4, 32, "Input",
  Evaluatable->True],
Cell[38195, 1269, 151, 4, 32, "Input",
  Evaluatable->True],
Cell[38349, 1275, 151, 4, 32, "Input",
  Evaluatable->True],
Cell[38503, 1281, 151, 4, 32, "Input",
  Evaluatable->True],
Cell[38657, 1287, 151, 4, 32, "Input",
  Evaluatable->True],
Cell[38811, 1293, 791, 16, 248, "Input",
  Evaluatable->True],
Cell[39605, 1311, 561, 14, 176, "Input",
  Evaluatable->True],
Cell[40169, 1327, 475, 12, 128, "Input",
  Evaluatable->True],
Cell[40647, 1341, 131, 3, 28, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[40827, 1350, 87, 1, 44, "Subsection"],
Cell[40917, 1353, 48, 0, 27, "Text"],
Cell[40968, 1355, 95, 3, 32, "Input"],
Cell[41066, 1360, 111, 3, 32, "Input"],
Cell[41180, 1365, 237, 5, 56, "Input"],
Cell[41420, 1372, 95, 3, 32, "Input"],
Cell[41518, 1377, 231, 7, 27, "Text"],
Cell[41752, 1386, 122, 3, 32, "Input"],
Cell[41877, 1391, 99, 3, 32, "Input"],
Cell[41979, 1396, 89, 2, 27, "Text"],
Cell[42071, 1400, 261, 5, 56, "Input"],
Cell[42335, 1407, 94, 3, 32, "Input"],
Cell[42432, 1412, 98, 2, 32, "Input"],
Cell[42533, 1416, 100, 3, 32, "Input"],
Cell[42636, 1421, 367, 9, 46, "Text"],
Cell[43006, 1432, 65, 2, 32, "Input"],
Cell[43074, 1436, 536, 12, 152, "Input",
  Evaluatable->False],
Cell[43613, 1450, 127, 3, 32, "Input"],
Cell[43743, 1455, 135, 3, 32, "Input"],
Cell[43881, 1460, 246, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[44152, 1470, 62, 1, 36, "Subsubsection"],
Cell[44217, 1473, 104, 3, 27, "Text"],
Cell[44324, 1478, 137, 3, 35, "Input"],
Cell[44464, 1483, 121, 3, 32, "Input"],
Cell[44588, 1488, 134, 3, 32, "Input"],
Cell[44725, 1493, 94, 3, 32, "Input"],
Cell[44822, 1498, 87, 2, 32, "Input"],
Cell[44912, 1502, 96, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[45045, 1510, 75, 1, 36, "Subsubsection"],
Cell[45123, 1513, 87, 2, 27, "Text"],
Cell[45213, 1517, 135, 3, 47, "Input"],
Cell[45351, 1522, 121, 3, 32, "Input"],
Cell[45475, 1527, 134, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[45646, 1535, 68, 1, 36, "Subsubsection"],
Cell[45717, 1538, 50, 0, 27, "Text"],
Cell[45770, 1540, 211, 5, 60, "Input"],
Cell[45984, 1547, 118, 3, 32, "Input"],
Cell[46105, 1552, 92, 3, 32, "Input"],
Cell[46200, 1557, 157, 4, 32, "Input"],
Cell[46360, 1563, 126, 3, 32, "Input"],
Cell[46489, 1568, 175, 4, 32, "Input"],
Cell[46667, 1574, 108, 3, 27, "Text"],
Cell[46778, 1579, 152, 4, 32, "Input"],
Cell[46933, 1585, 99, 3, 32, "Input"],
Cell[47035, 1590, 162, 4, 32, "Input"],
Cell[47200, 1596, 184, 4, 32, "Input"],
Cell[47387, 1602, 98, 3, 32, "Input"],
Cell[47488, 1607, 100, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[47625, 1615, 68, 1, 36, "Subsubsection"],
Cell[47696, 1618, 46, 0, 27, "Text"],
Cell[47745, 1620, 210, 6, 32, "Input"],
Cell[47958, 1628, 126, 3, 32, "Input"],
Cell[48087, 1633, 95, 3, 32, "Input"],
Cell[48185, 1638, 172, 4, 32, "Input"],
Cell[48360, 1644, 92, 3, 32, "Input"],
Cell[48455, 1649, 88, 2, 32, "Input"],
Cell[48546, 1653, 111, 3, 27, "Text"],
Cell[48660, 1658, 96, 3, 32, "Input"],
Cell[48759, 1663, 128, 3, 32, "Input"],
Cell[48890, 1668, 93, 3, 32, "Input"],
Cell[48986, 1673, 71, 0, 27, "Text"],
Cell[49060, 1675, 223, 6, 32, "Input",
  InitializationCell->True],
Cell[49286, 1683, 168, 4, 32, "Input"],
Cell[49457, 1689, 95, 3, 32, "Input"],
Cell[49555, 1694, 94, 2, 27, "Text"],
Cell[49652, 1698, 241, 6, 32, "Input",
  InitializationCell->True],
Cell[49896, 1706, 90, 3, 32, "Input"],
Cell[49989, 1711, 90, 3, 32, "Input"],
Cell[50082, 1716, 131, 3, 27, "Text"],
Cell[50216, 1721, 183, 4, 32, "Input"],
Cell[50402, 1727, 90, 3, 32, "Input"],
Cell[50495, 1732, 88, 2, 32, "Input"],
Cell[50586, 1736, 131, 3, 32, "Input"],
Cell[50720, 1741, 126, 3, 32, "Input"],
Cell[50849, 1746, 138, 3, 32, "Input"],
Cell[50990, 1751, 97, 3, 32, "Input"],
Cell[51090, 1756, 48, 0, 27, "Text"],
Cell[51141, 1758, 106, 3, 32, "Input"],
Cell[51250, 1763, 100, 3, 32, "Input"],
Cell[51353, 1768, 99, 3, 32, "Input"],
Cell[51455, 1773, 107, 3, 27, "Text"],
Cell[51565, 1778, 102, 3, 32, "Input"],
Cell[51670, 1783, 94, 2, 32, "Input"],
Cell[51767, 1787, 181, 4, 32, "Input"],
Cell[51951, 1793, 94, 3, 32, "Input"],
Cell[52048, 1798, 88, 2, 32, "Input"],
Cell[52139, 1802, 93, 3, 32, "Input"],
Cell[52235, 1807, 124, 3, 32, "Input"],
Cell[52362, 1812, 138, 3, 32, "Input"],
Cell[52503, 1817, 93, 3, 32, "Input"],
Cell[52599, 1822, 108, 3, 32, "Input"],
Cell[52710, 1827, 96, 3, 32, "Input"],
Cell[52809, 1832, 93, 3, 32, "Input"],
Cell[52905, 1837, 94, 2, 32, "Input"],
Cell[53002, 1841, 155, 3, 32, "Input"],
Cell[53160, 1846, 68, 2, 32, "Input"],
Cell[53231, 1850, 88, 2, 32, "Input"],
Cell[53322, 1854, 93, 3, 32, "Input"],
Cell[53418, 1859, 124, 3, 32, "Input"],
Cell[53545, 1864, 138, 3, 32, "Input"],
Cell[53686, 1869, 93, 3, 32, "Input"],
Cell[53782, 1874, 106, 3, 32, "Input"],
Cell[53891, 1879, 96, 3, 32, "Input"],
Cell[53990, 1884, 99, 3, 32, "Input"],
Cell[54092, 1889, 102, 3, 32, "Input"],
Cell[54197, 1894, 94, 2, 32, "Input"],
Cell[54294, 1898, 67, 2, 32, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[54422, 1907, 192, 6, 59, "Section"],

Cell[CellGroupData[{
Cell[54639, 1917, 55, 1, 36, "Subsubsection"],
Cell[54697, 1920, 1174, 18, 160, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[55908, 1943, 80, 1, 39, "Subsection"],
Cell[55991, 1946, 301, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[56317, 1955, 125, 3, 36, "Subsubsection"],
Cell[56445, 1960, 226, 4, 46, "Text"],
Cell[56674, 1966, 66, 2, 32, "Input"],
Cell[56743, 1970, 98, 3, 32, "Input"],
Cell[56844, 1975, 1112, 20, 296, "Input"],
Cell[57959, 1997, 226, 7, 27, "Text"],
Cell[58188, 2006, 257, 6, 56, "Input",
  Evaluatable->False],
Cell[58448, 2014, 54, 0, 27, "Text"],
Cell[58505, 2016, 127, 3, 32, "Input"],
Cell[58635, 2021, 190, 5, 56, "Input"],
Cell[58828, 2028, 193, 4, 46, "Text"],
Cell[59024, 2034, 237, 4, 46, "Text"],
Cell[59264, 2040, 96, 3, 32, "Input"],
Cell[59363, 2045, 376, 7, 104, "Input",
  Evaluatable->False],
Cell[59742, 2054, 100, 3, 32, "Input"],
Cell[59845, 2059, 202, 5, 56, "Input",
  Evaluatable->False],
Cell[60050, 2066, 112, 3, 27, "Text"],
Cell[60165, 2071, 97, 3, 32, "Input"],
Cell[60265, 2076, 379, 9, 80, "Input",
  Evaluatable->False],
Cell[60647, 2087, 221, 4, 46, "Text"],
Cell[60871, 2093, 279, 6, 80, "Input",
  InitializationCell->True],
Cell[61153, 2101, 259, 7, 80, "Input",
  InitializationCell->True],
Cell[61415, 2110, 67, 0, 27, "Text"],
Cell[61485, 2112, 106, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[61640, 2121, 64, 1, 39, "Subsection"],

Cell[CellGroupData[{
Cell[61729, 2126, 62, 1, 36, "Subsubsection"],
Cell[61794, 2129, 111, 3, 32, "Input"],
Cell[61908, 2134, 111, 3, 32, "Input"],
Cell[62022, 2139, 111, 3, 32, "Input"],
Cell[62136, 2144, 124, 3, 27, "Text"],
Cell[62263, 2149, 122, 3, 32, "Input"],
Cell[62388, 2154, 162, 4, 32, "Input"],
Cell[62553, 2160, 136, 3, 27, "Text"],
Cell[62692, 2165, 115, 3, 32, "Input"],
Cell[62810, 2170, 115, 2, 32, "Input"],
Cell[62928, 2174, 124, 3, 32, "Input"],
Cell[63055, 2179, 128, 3, 32, "Input"],
Cell[63186, 2184, 113, 3, 32, "Input"],
Cell[63302, 2189, 117, 3, 32, "Input"],
Cell[63422, 2194, 124, 3, 32, "Input"],
Cell[63549, 2199, 128, 3, 32, "Input"],
Cell[63680, 2204, 121, 3, 32, "Input"],
Cell[63804, 2209, 125, 3, 32, "Input"],
Cell[63932, 2214, 150, 4, 32, "Input"],
Cell[64085, 2220, 106, 3, 27, "Text"],
Cell[64194, 2225, 167, 5, 32, "Input"],
Cell[64364, 2232, 88, 3, 32, "Input"],
Cell[64455, 2237, 119, 3, 27, "Text"],
Cell[64577, 2242, 209, 6, 32, "Input"],
Cell[64789, 2250, 88, 3, 32, "Input"],
Cell[64880, 2255, 72, 2, 32, "Input"],
Cell[64955, 2259, 127, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[65119, 2267, 87, 2, 30, "Subsubsection",
  Evaluatable->False],
Cell[65209, 2271, 64, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[65298, 2275, 147, 4, 32, "Input",
  InitializationCell->True],
Cell[65448, 2281, 299, 5, 70, "Message"],
Cell[65750, 2288, 9610, 734, 70, 9455, 729, "GraphicsData", "PostScript", \
"Graphics",
  ImageCacheValid->False],
Cell[75363, 3024, 156, 4, 70, "Output"]
}, Closed]],
Cell[75534, 3031, 121, 3, 27, "Text",
  Evaluatable->False],
Cell[75658, 3036, 119, 3, 32, "Input"],
Cell[75780, 3041, 121, 3, 27, "Text",
  Evaluatable->False],
Cell[75904, 3046, 119, 3, 32, "Input"],
Cell[76026, 3051, 57, 1, 27, "Text",
  Evaluatable->False],
Cell[76086, 3054, 119, 3, 32, "Input"],
Cell[76208, 3059, 57, 1, 27, "Text",
  Evaluatable->False],
Cell[76268, 3062, 119, 3, 32, "Input"],
Cell[76390, 3067, 57, 1, 27, "Text",
  Evaluatable->False],
Cell[76450, 3070, 119, 3, 32, "Input"],
Cell[76572, 3075, 279, 6, 56, "Input"],
Cell[76854, 3083, 98, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[76989, 3091, 106, 2, 36, "Subsubsection"],
Cell[77098, 3095, 91, 2, 27, "Text"],
Cell[77192, 3099, 139, 3, 56, "Input"],
Cell[77334, 3104, 150, 3, 27, "Text"],
Cell[77487, 3109, 479, 9, 152, "Input"],
Cell[77969, 3120, 133, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[78151, 3129, 80, 1, 39, "Subsection"],
Cell[78234, 3132, 1127, 17, 160, "Text"],
Cell[79364, 3151, 116, 3, 32, "Input"],
Cell[79483, 3156, 114, 3, 32, "Input"],
Cell[79600, 3161, 258, 4, 46, "Text"],
Cell[79861, 3167, 94, 3, 32, "Input"],
Cell[79958, 3172, 101, 3, 32, "Input"],
Cell[80062, 3177, 105, 3, 32, "Input"],
Cell[80170, 3182, 108, 3, 32, "Input"],
Cell[80281, 3187, 115, 3, 32, "Input"],
Cell[80399, 3192, 128, 3, 32, "Input"],
Cell[80530, 3197, 330, 6, 65, "Text"],
Cell[80863, 3205, 161, 4, 32, "Input"],
Cell[81027, 3211, 120, 3, 27, "Text"],
Cell[81150, 3216, 117, 3, 32, "Input"],
Cell[81270, 3221, 56, 0, 27, "Text"],
Cell[81329, 3223, 117, 3, 32, "Input"],
Cell[81449, 3228, 143, 3, 27, "Text"],
Cell[81595, 3233, 152, 4, 32, "Input"],
Cell[81750, 3239, 29, 0, 27, "Text"],
Cell[81782, 3241, 116, 3, 32, "Input"],
Cell[81901, 3246, 120, 3, 32, "Input"],
Cell[82024, 3251, 44, 0, 27, "Text"],
Cell[82071, 3253, 275, 5, 80, "Input",
  Evaluatable->False],
Cell[82349, 3260, 122, 3, 27, "Text"],
Cell[82474, 3265, 95, 3, 32, "Input"],
Cell[82572, 3270, 168, 3, 27, "Text"],
Cell[82743, 3275, 102, 3, 32, "Input"],
Cell[82848, 3280, 195, 5, 32, "Input",
  Evaluatable->False],
Cell[83046, 3287, 98, 3, 32, "Input"],
Cell[83147, 3292, 930, 19, 122, "Text"],

Cell[CellGroupData[{
Cell[84102, 3315, 53, 1, 36, "Subsubsection"],
Cell[84158, 3318, 48, 0, 27, "Text"],
Cell[84209, 3320, 104, 3, 32, "Input"],
Cell[84316, 3325, 131, 3, 32, "Input"],
Cell[84450, 3330, 165, 4, 32, "Input"],
Cell[84618, 3336, 148, 3, 27, "Text"],
Cell[84769, 3341, 100, 3, 32, "Input"],
Cell[84872, 3346, 218, 5, 32, "Input"],
Cell[85093, 3353, 194, 4, 32, "Input"],
Cell[85290, 3359, 123, 3, 32, "Input"],
Cell[85416, 3364, 95, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[85548, 3372, 76, 1, 36, "Subsubsection"],
Cell[85627, 3375, 102, 3, 27, "Text"],
Cell[85732, 3380, 132, 3, 32, "Input"],
Cell[85867, 3385, 86, 3, 32, "Input"],
Cell[85956, 3390, 170, 5, 32, "Input"],
Cell[86129, 3397, 92, 3, 32, "Input"],
Cell[86224, 3402, 138, 3, 32, "Input"],
Cell[86365, 3407, 101, 3, 32, "Input"],
Cell[86469, 3412, 186, 5, 32, "Input"],
Cell[86658, 3419, 97, 3, 32, "Input"],
Cell[86758, 3424, 39, 0, 27, "Text"],
Cell[86800, 3426, 280, 7, 56, "Input"],
Cell[87083, 3435, 91, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[87223, 3444, 67, 1, 39, "Subsection"],
Cell[87293, 3447, 518, 8, 84, "Text"],
Cell[87814, 3457, 76, 2, 32, "Input"],
Cell[87893, 3461, 2051, 38, 512, "Input",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[89969, 3503, 53, 1, 36, "Subsubsection"],
Cell[90025, 3506, 112, 3, 32, "Input"],
Cell[90140, 3511, 112, 3, 32, "Input"],
Cell[90255, 3516, 112, 3, 32, "Input"],
Cell[90370, 3521, 163, 4, 32, "Input"],
Cell[90536, 3527, 152, 4, 32, "Input"],
Cell[90691, 3533, 129, 3, 32, "Input"],
Cell[90823, 3538, 129, 3, 32, "Input"],
Cell[90955, 3543, 159, 4, 32, "Input"],
Cell[91117, 3549, 114, 3, 32, "Input"],
Cell[91234, 3554, 113, 3, 32, "Input"],
Cell[91350, 3559, 111, 2, 32, "Input"],
Cell[91464, 3563, 79, 2, 32, "Input"],
Cell[91546, 3567, 62, 0, 27, "Text"],
Cell[91611, 3569, 133, 3, 56, "Input"],
Cell[91747, 3574, 104, 2, 32, "Input"],
Cell[91854, 3578, 69, 2, 32, "Input"],
Cell[91926, 3582, 93, 2, 32, "Input"],
Cell[92022, 3586, 74, 0, 27, "Text"],
Cell[92099, 3588, 159, 4, 32, "Input"],
Cell[92261, 3594, 176, 4, 56, "Input"],
Cell[92440, 3600, 138, 3, 32, "Input"],
Cell[92581, 3605, 103, 3, 32, "Input"],
Cell[92687, 3610, 121, 3, 32, "Input"],
Cell[92811, 3615, 106, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[92966, 3624, 122, 3, 39, "Subsection"],
Cell[93091, 3629, 680, 10, 103, "Text"],

Cell[CellGroupData[{
Cell[93796, 3643, 93, 1, 36, "Subsubsection"],
Cell[93892, 3646, 79, 2, 32, "Input"],
Cell[93974, 3650, 92, 2, 32, "Input"],
Cell[94069, 3654, 351, 8, 104, "Input",
  Evaluatable->False],
Cell[94423, 3664, 462, 11, 104, "Input",
  Evaluatable->False],
Cell[94888, 3677, 395, 9, 104, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[95320, 3691, 89, 1, 30, "Subsubsection"],
Cell[95412, 3694, 209, 4, 46, "Text"],
Cell[95624, 3700, 95, 3, 32, "Input"],
Cell[95722, 3705, 2383, 50, 272, "Input",
  InitializationCell->True],
Cell[98108, 3757, 2373, 51, 272, "Input",
  InitializationCell->True],
Cell[100484, 3810, 2347, 46, 200, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[102868, 3861, 65, 1, 30, "Subsubsection"],
Cell[102936, 3864, 103, 3, 32, "Input"],
Cell[103042, 3869, 104, 3, 32, "Input"],
Cell[103149, 3874, 103, 3, 32, "Input"],
Cell[103255, 3879, 104, 3, 32, "Input"],
Cell[103362, 3884, 103, 3, 32, "Input"],
Cell[103468, 3889, 104, 3, 32, "Input"],
Cell[103575, 3894, 103, 3, 32, "Input"],
Cell[103681, 3899, 104, 3, 32, "Input"],
Cell[103788, 3904, 103, 3, 32, "Input"],
Cell[103894, 3909, 75, 0, 27, "Text"],
Cell[103972, 3911, 104, 3, 32, "Input"],
Cell[104079, 3916, 108, 3, 32, "Input"],
Cell[104190, 3921, 109, 3, 32, "Input"],
Cell[104302, 3926, 103, 3, 32, "Input"],
Cell[104408, 3931, 104, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[104549, 3939, 55, 0, 30, "Subsubsection"],
Cell[104607, 3941, 236, 6, 56, "Input"],
Cell[104846, 3949, 101, 3, 32, "Input"],
Cell[104950, 3954, 102, 3, 32, "Input"],
Cell[105055, 3959, 101, 3, 32, "Input"],
Cell[105159, 3964, 102, 3, 32, "Input"],
Cell[105264, 3969, 101, 3, 32, "Input"],
Cell[105368, 3974, 102, 3, 32, "Input"],
Cell[105473, 3979, 92, 3, 32, "Input"],
Cell[105568, 3984, 44, 0, 27, "Text"],
Cell[105615, 3986, 814, 16, 272, "Input"],
Cell[106432, 4004, 69, 0, 27, "Text"],
Cell[106504, 4006, 525, 10, 200, "Input"],
Cell[107032, 4018, 58, 0, 27, "Text"],
Cell[107093, 4020, 138, 3, 32, "Input"],
Cell[107234, 4025, 109, 3, 27, "Text"],
Cell[107346, 4030, 837, 18, 200, "Input"],
Cell[108186, 4050, 95, 3, 32, "Input"],
Cell[108284, 4055, 76, 0, 27, "Text"],
Cell[108363, 4057, 127, 3, 32, "Input"],
Cell[108493, 4062, 100, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[108642, 4071, 119, 3, 39, "Subsection"],

Cell[CellGroupData[{
Cell[108786, 4078, 59, 1, 36, "Subsubsection"],
Cell[108848, 4081, 345, 6, 65, "Text"],
Cell[109196, 4089, 93, 3, 32, "Input"],
Cell[109292, 4094, 995, 18, 272, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[110324, 4117, 56, 1, 36, "Subsubsection"],
Cell[110383, 4120, 125, 3, 32, "Input"],
Cell[110511, 4125, 125, 3, 32, "Input"],
Cell[110639, 4130, 122, 3, 32, "Input"],
Cell[110764, 4135, 151, 4, 32, "Input"],
Cell[110918, 4141, 128, 3, 32, "Input"],
Cell[111049, 4146, 88, 3, 32, "Input"],
Cell[111140, 4151, 130, 3, 32, "Input"],
Cell[111273, 4156, 114, 3, 32, "Input"],
Cell[111390, 4161, 86, 3, 32, "Input"],
Cell[111479, 4166, 117, 3, 32, "Input"],
Cell[111599, 4171, 101, 3, 32, "Input"],
Cell[111703, 4176, 93, 3, 32, "Input"],
Cell[111799, 4181, 117, 3, 32, "Input"],
Cell[111919, 4186, 128, 3, 32, "Input"],
Cell[112050, 4191, 92, 3, 32, "Input"],
Cell[112145, 4196, 122, 3, 32, "Input"],
Cell[112270, 4201, 114, 3, 32, "Input"],
Cell[112387, 4206, 114, 3, 32, "Input"],
Cell[112504, 4211, 136, 3, 32, "Input"],
Cell[112643, 4216, 114, 3, 32, "Input"],
Cell[112760, 4221, 274, 6, 128, "Input"],
Cell[113037, 4229, 108, 2, 32, "Input"],
Cell[113148, 4233, 115, 3, 32, "Input"],
Cell[113266, 4238, 130, 3, 32, "Input"],
Cell[113399, 4243, 202, 4, 46, "Text"],
Cell[113604, 4249, 75, 2, 32, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[113740, 4258, 95, 1, 58, "Section"],
Cell[113838, 4261, 1143, 30, 105, "Text"],

Cell[CellGroupData[{
Cell[115006, 4295, 64, 1, 44, "Subsection"],
Cell[115073, 4298, 1618, 27, 449, "Text"],
Cell[116694, 4327, 419, 7, 77, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[117150, 4339, 94, 1, 38, "Subsection"],

Cell[CellGroupData[{
Cell[117269, 4344, 62, 1, 36, "Subsubsection"],
Cell[117334, 4347, 248, 4, 46, "Text"],
Cell[117585, 4353, 51, 0, 27, "Text"],
Cell[117639, 4355, 308, 9, 201, "Text"],
Cell[117950, 4366, 88, 3, 32, "Input"],
Cell[118041, 4371, 31, 0, 27, "Text"],
Cell[118075, 4373, 91, 3, 32, "Input"],
Cell[118169, 4378, 429, 7, 96, "Text"],
Cell[118601, 4387, 261, 6, 32, "Input"],
Cell[118865, 4395, 97, 3, 32, "Input"],
Cell[118965, 4400, 94, 3, 32, "Input"],
Cell[119062, 4405, 115, 3, 27, "Text"],
Cell[119180, 4410, 206, 5, 32, "Input",
  InitializationCell->True],
Cell[119389, 4417, 121, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[119547, 4425, 78, 1, 30, "Subsubsection"],
Cell[119628, 4428, 152, 3, 27, "Text"],
Cell[119783, 4433, 388, 7, 104, "Input"],
Cell[120174, 4442, 92, 3, 32, "Input"],
Cell[120269, 4447, 96, 3, 32, "Input"],
Cell[120368, 4452, 121, 3, 32, "Input"],
Cell[120492, 4457, 92, 3, 32, "Input"],
Cell[120587, 4462, 160, 3, 27, "Text"],
Cell[120750, 4467, 284, 6, 80, "Input"],
Cell[121037, 4475, 70, 2, 32, "Input"],
Cell[121110, 4479, 64, 0, 27, "Text"],
Cell[121177, 4481, 72, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[121286, 4488, 78, 1, 30, "Subsubsection"],
Cell[121367, 4491, 157, 3, 27, "Text"],
Cell[121527, 4496, 395, 7, 80, "Input"],
Cell[121925, 4505, 93, 3, 28, "Input"],
Cell[122021, 4510, 376, 6, 61, "Text"],
Cell[122400, 4518, 285, 6, 80, "Input"],
Cell[122688, 4526, 96, 3, 28, "Input"],
Cell[122787, 4531, 98, 3, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[122922, 4539, 78, 1, 30, "Subsubsection"],
Cell[123003, 4542, 74, 0, 27, "Text"],
Cell[123080, 4544, 648, 13, 152, "Input"],
Cell[123731, 4559, 69, 2, 32, "Input"],
Cell[123803, 4563, 106, 2, 32, "Input"],
Cell[123912, 4567, 127, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[124076, 4575, 65, 1, 36, "Subsubsection"],
Cell[124144, 4578, 413, 6, 65, "Text"],
Cell[124560, 4586, 290, 6, 89, "Text"],
Cell[124853, 4594, 88, 3, 32, "Input"],
Cell[124944, 4599, 510, 11, 128, "Input",
  Evaluatable->False],
Cell[125457, 4612, 71, 0, 27, "Text"],
Cell[125531, 4614, 153, 4, 32, "Input",
  Evaluatable->False],
Cell[125687, 4620, 212, 5, 32, "Input",
  Evaluatable->False],
Cell[125902, 4627, 99, 3, 32, "Input"],
Cell[126004, 4632, 102, 3, 32, "Input"],
Cell[126109, 4637, 92, 3, 32, "Input"],
Cell[126204, 4642, 163, 3, 27, "Text"],
Cell[126370, 4647, 101, 3, 32, "Input"],
Cell[126474, 4652, 118, 3, 32, "Input"],
Cell[126595, 4657, 69, 2, 32, "Input"],
Cell[126667, 4661, 39, 0, 27, "Text"],
Cell[126709, 4663, 88, 3, 32, "Input"],
Cell[126800, 4668, 357, 6, 65, "Text"],
Cell[127160, 4676, 103, 3, 32, "Input"],
Cell[127266, 4681, 134, 3, 32, "Input"],
Cell[127403, 4686, 92, 3, 32, "Input"],
Cell[127498, 4691, 183, 4, 46, "Text"],
Cell[127684, 4697, 203, 5, 32, "Input"],
Cell[127890, 4704, 105, 3, 32, "Input"],
Cell[127998, 4709, 284, 7, 47, "Text"],
Cell[128285, 4718, 95, 1, 27, "Text"],
Cell[128383, 4721, 241, 4, 38, "Input"],
Cell[128627, 4727, 91, 3, 32, "Input"],
Cell[128721, 4732, 94, 3, 32, "Input"],
Cell[128818, 4737, 124, 3, 32, "Input"],
Cell[128945, 4742, 127, 3, 32, "Input"],
Cell[129075, 4747, 92, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[129204, 4755, 67, 1, 30, "Subsubsection"],
Cell[129274, 4758, 625, 13, 84, "Text"],
Cell[129902, 4773, 148, 4, 32, "Input"],
Cell[130053, 4779, 130, 3, 32, "Input"],
Cell[130186, 4784, 111, 3, 27, "Text"],
Cell[130300, 4789, 156, 4, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[130493, 4798, 94, 1, 30, "Subsubsection"],
Cell[130590, 4801, 147, 3, 27, "Text"],
Cell[130740, 4806, 127, 3, 32, "Input"],
Cell[130870, 4811, 96, 2, 32, "Input"],
Cell[130969, 4815, 133, 3, 27, "Text"],
Cell[131105, 4820, 122, 3, 32, "Input"],
Cell[131230, 4825, 103, 2, 32, "Input"],
Cell[131336, 4829, 134, 3, 27, "Text"],
Cell[131473, 4834, 187, 5, 32, "Input"],
Cell[131663, 4841, 102, 3, 27, "Text"],
Cell[131768, 4846, 122, 3, 32, "Input"],
Cell[131893, 4851, 85, 2, 27, "Text"],
Cell[131981, 4855, 126, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[132156, 4864, 92, 1, 44, "Subsection"],
Cell[132251, 4867, 99, 2, 27, "Text"],
Cell[132353, 4871, 286, 6, 193, "Input"],
Cell[132642, 4879, 86, 3, 32, "Input"],
Cell[132731, 4884, 85, 2, 27, "Text"],
Cell[132819, 4888, 105, 3, 32, "Input"],
Cell[132927, 4893, 102, 3, 32, "Input"],
Cell[133032, 4898, 129, 3, 32, "Input"],
Cell[133164, 4903, 113, 3, 32, "Input"],
Cell[133280, 4908, 70, 2, 32, "Input"],
Cell[133353, 4912, 101, 3, 32, "Input"],
Cell[133457, 4917, 92, 3, 32, "Input"],
Cell[133552, 4922, 114, 3, 32, "Input"],
Cell[133669, 4927, 85, 3, 32, "Input"],
Cell[133757, 4932, 278, 8, 27, "Text"],
Cell[134038, 4942, 88, 3, 32, "Input"],
Cell[134129, 4947, 237, 4, 46, "Text"],
Cell[134369, 4953, 115, 3, 32, "Input"],
Cell[134487, 4958, 129, 3, 27, "Text"],
Cell[134619, 4963, 159, 4, 72, "Input"],
Cell[134781, 4969, 151, 4, 72, "Input"],
Cell[134935, 4975, 112, 3, 27, "Text"],
Cell[135050, 4980, 85, 2, 32, "Input"],
Cell[135138, 4984, 65, 2, 32, "Input"],
Cell[135206, 4988, 85, 2, 32, "Input"],
Cell[135294, 4992, 69, 2, 32, "Input"],
Cell[135366, 4996, 74, 2, 32, "Input"],
Cell[135443, 5000, 70, 2, 32, "Input"],
Cell[135516, 5004, 34, 0, 27, "Text"],
Cell[135553, 5006, 80, 2, 32, "Input"],
Cell[135636, 5010, 72, 2, 32, "Input"],
Cell[135711, 5014, 80, 2, 32, "Input"],
Cell[135794, 5018, 69, 2, 32, "Input"],
Cell[135866, 5022, 161, 6, 27, "Text"],
Cell[136030, 5030, 124, 3, 32, "Input"],
Cell[136157, 5035, 193, 4, 46, "Text"],
Cell[136353, 5041, 206, 4, 56, "Input"],
Cell[136562, 5047, 124, 3, 27, "Text"],
Cell[136689, 5052, 103, 3, 32, "Input"],
Cell[136795, 5057, 102, 3, 32, "Input"],
Cell[136900, 5062, 106, 3, 32, "Input"],
Cell[137009, 5067, 131, 3, 32, "Input"],
Cell[137143, 5072, 341, 6, 65, "Text"],
Cell[137487, 5080, 120, 3, 32, "Input"],
Cell[137610, 5085, 94, 2, 27, "Text"],
Cell[137707, 5089, 123, 3, 32, "Input"],
Cell[137833, 5094, 157, 3, 27, "Text"],
Cell[137993, 5099, 76, 2, 32, "Input"],
Cell[138072, 5103, 144, 4, 40, "Text",
  CellTags->"stat"],
Cell[138219, 5109, 49, 0, 27, "Text"],
Cell[138271, 5111, 212, 5, 32, "Input"],
Cell[138486, 5118, 94, 3, 32, "Input"],
Cell[138583, 5123, 94, 3, 32, "Input"],
Cell[138680, 5128, 96, 3, 32, "Input"],
Cell[138779, 5133, 80, 2, 32, "Input"],
Cell[138862, 5137, 72, 2, 32, "Input"],
Cell[138937, 5141, 86, 2, 32, "Input"],
Cell[139026, 5145, 73, 2, 32, "Input"],
Cell[139102, 5149, 128, 3, 32, "Input"],
Cell[139233, 5154, 109, 3, 27, "Text"],
Cell[139345, 5159, 85, 2, 32, "Input"],
Cell[139433, 5163, 71, 2, 32, "Input"],
Cell[139507, 5167, 317, 5, 65, "Text"],
Cell[139827, 5174, 95, 2, 32, "Input"],
Cell[139925, 5178, 72, 2, 32, "Input"],
Cell[140000, 5182, 129, 3, 32, "Input"],
Cell[140132, 5187, 73, 0, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[140242, 5192, 77, 1, 38, "Subsection"],
Cell[140322, 5195, 246, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[140593, 5203, 73, 1, 36, "Subsubsection"],
Cell[140669, 5206, 54, 0, 27, "Text"],
Cell[140726, 5208, 211, 5, 56, "Input"],
Cell[140940, 5215, 101, 3, 32, "Input"],
Cell[141044, 5220, 92, 3, 32, "Input"],
Cell[141139, 5225, 128, 3, 32, "Input"],
Cell[141270, 5230, 98, 2, 27, "Text"],
Cell[141371, 5234, 112, 3, 32, "Input"],
Cell[141486, 5239, 178, 4, 27, "Text"],
Cell[141667, 5245, 205, 4, 56, "Input"],
Cell[141875, 5251, 200, 4, 46, "Text"],
Cell[142078, 5257, 114, 3, 32, "Input"],
Cell[142195, 5262, 102, 3, 32, "Input"],
Cell[142300, 5267, 134, 3, 32, "Input"],
Cell[142437, 5272, 380, 6, 65, "Text"],
Cell[142820, 5280, 97, 3, 32, "Input"],
Cell[142920, 5285, 86, 3, 32, "Input"],
Cell[143009, 5290, 100, 3, 32, "Input"],
Cell[143112, 5295, 195, 4, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[143344, 5304, 100, 1, 36, "Subsubsection"],
Cell[143447, 5307, 998, 16, 153, "Text"],
Cell[144448, 5325, 384, 7, 104, "Input"],
Cell[144835, 5334, 107, 3, 32, "Input"],
Cell[144945, 5339, 89, 3, 32, "Input"],
Cell[145037, 5344, 114, 3, 32, "Input"],
Cell[145154, 5349, 124, 3, 32, "Input"],
Cell[145281, 5354, 144, 3, 27, "Text"],
Cell[145428, 5359, 164, 5, 61, "Input"],
Cell[145595, 5366, 195, 4, 32, "Input"],
Cell[145793, 5372, 93, 3, 32, "Input"],
Cell[145889, 5377, 89, 2, 27, "Text"],
Cell[145981, 5381, 197, 4, 32, "Input"],
Cell[146181, 5387, 105, 3, 32, "Input"],
Cell[146289, 5392, 116, 3, 27, "Text"],
Cell[146408, 5397, 93, 3, 32, "Input"],
Cell[146504, 5402, 125, 3, 27, "Text"],
Cell[146632, 5407, 227, 5, 56, "Input",
  Evaluatable->False],
Cell[146862, 5414, 154, 4, 32, "Input"],
Cell[147019, 5420, 104, 3, 32, "Input"],
Cell[147126, 5425, 89, 3, 32, "Input"],
Cell[147218, 5430, 94, 3, 32, "Input"],
Cell[147315, 5435, 131, 3, 32, "Input"],
Cell[147449, 5440, 92, 2, 32, "Input"],
Cell[147544, 5444, 76, 0, 27, "Text"],
Cell[147623, 5446, 261, 5, 56, "Input"],
Cell[147887, 5453, 95, 3, 32, "Input"],
Cell[147985, 5458, 101, 3, 32, "Input"],
Cell[148089, 5463, 93, 3, 32, "Input"],
Cell[148185, 5468, 130, 3, 32, "Input"],
Cell[148318, 5473, 116, 3, 27, "Text"],
Cell[148437, 5478, 264, 5, 56, "Input"],
Cell[148704, 5485, 96, 3, 32, "Input"],
Cell[148803, 5490, 102, 3, 32, "Input"],
Cell[148908, 5495, 66, 2, 32, "Input"],
Cell[148977, 5499, 84, 2, 32, "Input"],
Cell[149064, 5503, 71, 2, 32, "Input"],
Cell[149138, 5507, 73, 2, 32, "Input"],
Cell[149214, 5511, 131, 3, 32, "Input"],
Cell[149348, 5516, 92, 2, 32, "Input"],
Cell[149443, 5520, 116, 3, 27, "Text"],
Cell[149562, 5525, 133, 3, 32, "Input"],
Cell[149698, 5530, 72, 2, 32, "Input"],
Cell[149773, 5534, 142, 3, 32, "Input"],
Cell[149918, 5539, 68, 2, 32, "Input"],
Cell[149989, 5543, 79, 2, 32, "Input"],
Cell[150071, 5547, 72, 2, 32, "Input"],
Cell[150146, 5551, 130, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[150313, 5559, 84, 1, 30, "Subsubsection"],
Cell[150400, 5562, 64, 1, 31, "Text"],
Cell[150467, 5565, 108, 3, 32, "Input"],
Cell[150578, 5570, 124, 3, 32, "Input"],
Cell[150705, 5575, 136, 3, 32, "Input"],
Cell[150844, 5580, 88, 2, 27, "Text"],
Cell[150935, 5584, 133, 3, 32, "Input"],
Cell[151071, 5589, 97, 3, 32, "Input"],
Cell[151171, 5594, 92, 3, 32, "Input"],
Cell[151266, 5599, 282, 5, 46, "Text"],
Cell[151551, 5606, 135, 3, 32, "Input"],
Cell[151689, 5611, 91, 3, 32, "Input"],
Cell[151783, 5616, 95, 3, 32, "Input"],
Cell[151881, 5621, 167, 4, 32, "Input"],
Cell[152051, 5627, 171, 4, 32, "Input"],
Cell[152225, 5633, 88, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[152350, 5641, 137, 4, 36, "Subsubsection"],
Cell[152490, 5647, 116, 3, 32, "Input"],
Cell[152609, 5652, 124, 3, 32, "Input"],
Cell[152736, 5657, 71, 0, 27, "Text"],
Cell[152810, 5659, 134, 3, 32, "Input"],
Cell[152947, 5664, 132, 3, 32, "Input"],
Cell[153082, 5669, 95, 3, 32, "Input"],
Cell[153180, 5674, 95, 3, 32, "Input"],
Cell[153278, 5679, 95, 3, 32, "Input"],
Cell[153376, 5684, 93, 2, 32, "Input"],
Cell[153472, 5688, 71, 0, 27, "Text"],
Cell[153546, 5690, 86, 2, 32, "Input"],
Cell[153635, 5694, 69, 0, 27, "Text"],
Cell[153707, 5696, 82, 2, 32, "Input"],
Cell[153792, 5700, 70, 2, 32, "Input"],
Cell[153865, 5704, 76, 2, 32, "Input"],
Cell[153944, 5708, 143, 4, 56, "Input"],
Cell[154090, 5714, 169, 3, 27, "Text"],
Cell[154262, 5719, 120, 3, 32, "Input"],
Cell[154385, 5724, 123, 3, 32, "Input"],
Cell[154511, 5729, 91, 3, 32, "Input"],
Cell[154605, 5734, 127, 3, 32, "Input"],
Cell[154735, 5739, 93, 3, 32, "Input"],
Cell[154831, 5744, 95, 3, 32, "Input"],
Cell[154929, 5749, 105, 3, 27, "Text"],
Cell[155037, 5754, 154, 4, 32, "Input"],
Cell[155194, 5760, 89, 3, 32, "Input"],
Cell[155286, 5765, 62, 0, 27, "Text"],
Cell[155351, 5767, 191, 5, 32, "Input"],
Cell[155545, 5774, 115, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[155709, 5783, 99, 1, 38, "Subsection"],

Cell[CellGroupData[{
Cell[155833, 5788, 61, 1, 36, "Subsubsection"],
Cell[155897, 5791, 146, 3, 27, "Text"],
Cell[156046, 5796, 122, 3, 32, "Input"],
Cell[156171, 5801, 100, 3, 32, "Input"],
Cell[156274, 5806, 101, 3, 32, "Input"],
Cell[156378, 5811, 105, 3, 32, "Input"],
Cell[156486, 5816, 70, 2, 32, "Input"],
Cell[156559, 5820, 72, 2, 32, "Input"],
Cell[156634, 5824, 72, 2, 32, "Input"],
Cell[156709, 5828, 72, 2, 32, "Input"],
Cell[156784, 5832, 119, 3, 32, "Input"],
Cell[156906, 5837, 100, 3, 32, "Input"],
Cell[157009, 5842, 101, 3, 32, "Input"],
Cell[157113, 5847, 72, 2, 32, "Input"],
Cell[157188, 5851, 72, 2, 32, "Input"],
Cell[157263, 5855, 72, 2, 32, "Input"],
Cell[157338, 5859, 103, 3, 32, "Input"],
Cell[157444, 5864, 70, 2, 32, "Input"],
Cell[157517, 5868, 106, 3, 32, "Input"],
Cell[157626, 5873, 141, 3, 27, "Text"],
Cell[157770, 5878, 67, 2, 32, "Input"],
Cell[157840, 5882, 87, 3, 32, "Input"],
Cell[157930, 5887, 80, 2, 32, "Input"],
Cell[158013, 5891, 145, 3, 27, "Text"],
Cell[158161, 5896, 99, 3, 32, "Input"],
Cell[158263, 5901, 95, 3, 32, "Input"],
Cell[158361, 5906, 127, 3, 32, "Input"],
Cell[158491, 5911, 51, 0, 27, "Text"],
Cell[158545, 5913, 101, 3, 32, "Input"],
Cell[158649, 5918, 73, 0, 27, "Text"],
Cell[158725, 5920, 115, 3, 32, "Input"],
Cell[158843, 5925, 121, 3, 27, "Text"],
Cell[158967, 5930, 95, 3, 32, "Input"],
Cell[159065, 5935, 97, 3, 32, "Input"],
Cell[159165, 5940, 81, 2, 32, "Input"],
Cell[159249, 5944, 62, 0, 27, "Text"],
Cell[159314, 5946, 165, 4, 32, "Input"],
Cell[159482, 5952, 150, 4, 32, "Input"],
Cell[159635, 5958, 97, 3, 32, "Input"],
Cell[159735, 5963, 82, 2, 32, "Input"],
Cell[159820, 5967, 65, 2, 32, "Input"],
Cell[159888, 5971, 74, 2, 32, "Input"],
Cell[159965, 5975, 129, 3, 32, "Input"],
Cell[160097, 5980, 224, 4, 46, "Text"],
Cell[160324, 5986, 206, 4, 56, "Input"],
Cell[160533, 5992, 124, 3, 27, "Text"],
Cell[160660, 5997, 103, 3, 32, "Input"],
Cell[160766, 6002, 101, 3, 32, "Input"],
Cell[160870, 6007, 131, 3, 32, "Input"],
Cell[161004, 6012, 240, 4, 46, "Text"],
Cell[161247, 6018, 120, 3, 32, "Input"],
Cell[161370, 6023, 68, 2, 32, "Input"],
Cell[161441, 6027, 80, 2, 32, "Input"],
Cell[161524, 6031, 204, 6, 27, "Text"],
Cell[161731, 6039, 123, 3, 32, "Input"],
Cell[161857, 6044, 91, 2, 27, "Text"],
Cell[161951, 6048, 91, 3, 32, "Input"],
Cell[162045, 6053, 94, 3, 32, "Input"],
Cell[162142, 6058, 89, 2, 27, "Text"],
Cell[162234, 6062, 133, 3, 32, "Input"],
Cell[162370, 6067, 60, 0, 27, "Text"],
Cell[162433, 6069, 212, 5, 32, "Input"],
Cell[162648, 6076, 95, 3, 32, "Input"],
Cell[162746, 6081, 89, 3, 32, "Input"],
Cell[162838, 6086, 133, 3, 32, "Input"],
Cell[162974, 6091, 116, 3, 32, "Input"],
Cell[163093, 6096, 89, 3, 32, "Input"],
Cell[163185, 6101, 97, 3, 32, "Input"],
Cell[163285, 6106, 182, 4, 46, "Text"],
Cell[163470, 6112, 106, 2, 32, "Input"],
Cell[163579, 6116, 160, 3, 27, "Text"],
Cell[163742, 6121, 116, 2, 32, "Input"],
Cell[163861, 6125, 116, 2, 32, "Input"],
Cell[163980, 6129, 139, 3, 27, "Text"],
Cell[164122, 6134, 86, 2, 32, "Input"],
Cell[164211, 6138, 70, 2, 32, "Input"],
Cell[164284, 6142, 94, 2, 32, "Input"],
Cell[164381, 6146, 74, 2, 32, "Input"],
Cell[164458, 6150, 128, 3, 27, "Text"],
Cell[164589, 6155, 106, 2, 32, "Input"],
Cell[164698, 6159, 73, 0, 27, "Text"],
Cell[164774, 6161, 181, 4, 56, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[164992, 6170, 69, 1, 30, "Subsubsection"],
Cell[165064, 6173, 126, 3, 32, "Input"],
Cell[165193, 6178, 103, 3, 32, "Input"],
Cell[165299, 6183, 94, 3, 32, "Input"],
Cell[165396, 6188, 96, 3, 32, "Input"],
Cell[165495, 6193, 102, 3, 32, "Input"],
Cell[165600, 6198, 102, 3, 32, "Input"],
Cell[165705, 6203, 131, 3, 32, "Input"],
Cell[165839, 6208, 88, 3, 32, "Input"],
Cell[165930, 6213, 95, 3, 32, "Input"],
Cell[166028, 6218, 106, 3, 32, "Input"],
Cell[166137, 6223, 86, 3, 32, "Input"],
Cell[166226, 6228, 74, 2, 32, "Input"],
Cell[166303, 6232, 95, 2, 27, "Text"],
Cell[166401, 6236, 101, 3, 32, "Input"],
Cell[166505, 6241, 95, 3, 32, "Input"],
Cell[166603, 6246, 115, 3, 32, "Input"],
Cell[166721, 6251, 129, 3, 27, "Text"],
Cell[166853, 6256, 182, 5, 32, "Input"],
Cell[167038, 6263, 175, 5, 32, "Input"],
Cell[167216, 6270, 139, 3, 32, "Input"],
Cell[167358, 6275, 110, 3, 32, "Input"],
Cell[167471, 6280, 97, 3, 32, "Input"],
Cell[167571, 6285, 224, 4, 46, "Text"],
Cell[167798, 6291, 206, 4, 56, "Input"],
Cell[168007, 6297, 124, 3, 27, "Text"],
Cell[168134, 6302, 103, 3, 32, "Input"],
Cell[168240, 6307, 101, 3, 32, "Input"],
Cell[168344, 6312, 131, 3, 32, "Input"],
Cell[168478, 6317, 186, 4, 46, "Text"],
Cell[168667, 6323, 120, 3, 32, "Input"],
Cell[168790, 6328, 94, 2, 27, "Text"],
Cell[168887, 6332, 123, 3, 32, "Input"],
Cell[169013, 6337, 102, 3, 32, "Input"],
Cell[169118, 6342, 87, 3, 32, "Input"],
Cell[169208, 6347, 88, 3, 32, "Input"],
Cell[169299, 6352, 111, 3, 27, "Text"],
Cell[169413, 6357, 109, 3, 32, "Input"],
Cell[169525, 6362, 167, 4, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[169741, 6372, 60, 1, 38, "Subsection"],

Cell[CellGroupData[{
Cell[169826, 6377, 71, 1, 36, "Subsubsection"],
Cell[169900, 6380, 117, 3, 27, "Text"],
Cell[170020, 6385, 120, 3, 32, "Input"],
Cell[170143, 6390, 128, 3, 27, "Text"],
Cell[170274, 6395, 219, 8, 111, "Input",
  InitializationCell->True],
Cell[170496, 6405, 98, 3, 32, "Input"],
Cell[170597, 6410, 109, 3, 32, "Input"],
Cell[170709, 6415, 92, 3, 32, "Input"],
Cell[170804, 6420, 205, 5, 56, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[171046, 6430, 72, 1, 36, "Subsubsection"],
Cell[171121, 6433, 275, 6, 80, "Input"],
Cell[171399, 6441, 103, 3, 27, "Text"],
Cell[171505, 6446, 89, 3, 32, "Input"],
Cell[171597, 6451, 98, 3, 32, "Input"],
Cell[171698, 6456, 143, 4, 32, "Input"],
Cell[171844, 6462, 133, 3, 27, "Text"],
Cell[171980, 6467, 129, 3, 32, "Input"],
Cell[172112, 6472, 88, 3, 32, "Input"],
Cell[172203, 6477, 101, 3, 32, "Input"],
Cell[172307, 6482, 95, 3, 32, "Input"],
Cell[172405, 6487, 85, 3, 32, "Input"],
Cell[172493, 6492, 115, 3, 32, "Input"],
Cell[172611, 6497, 135, 3, 27, "Text"],
Cell[172749, 6502, 129, 3, 32, "Input"],
Cell[172881, 6507, 88, 3, 32, "Input"],
Cell[172972, 6512, 224, 4, 46, "Text"],
Cell[173199, 6518, 194, 4, 56, "Input"],
Cell[173396, 6524, 124, 3, 27, "Text"],
Cell[173523, 6529, 103, 3, 32, "Input"],
Cell[173629, 6534, 101, 3, 32, "Input"],
Cell[173733, 6539, 131, 3, 32, "Input"],
Cell[173867, 6544, 177, 3, 46, "Text"],
Cell[174047, 6549, 120, 3, 32, "Input"],
Cell[174170, 6554, 238, 4, 46, "Text"],
Cell[174411, 6560, 107, 3, 32, "Input"],
Cell[174521, 6565, 55, 0, 27, "Text"],
Cell[174579, 6567, 110, 3, 32, "Input"],
Cell[174692, 6572, 137, 4, 58, "Text"],
Cell[174832, 6578, 123, 3, 32, "Input"],
Cell[174958, 6583, 358, 6, 65, "Text"],
Cell[175319, 6591, 96, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[175452, 6599, 76, 1, 30, "Subsubsection"],
Cell[175531, 6602, 279, 6, 80, "Input"],
Cell[175813, 6610, 103, 3, 27, "Text"],
Cell[175919, 6615, 89, 3, 32, "Input"],
Cell[176011, 6620, 98, 3, 32, "Input"],
Cell[176112, 6625, 143, 4, 32, "Input"],
Cell[176258, 6631, 109, 3, 27, "Text"],
Cell[176370, 6636, 129, 3, 32, "Input"],
Cell[176502, 6641, 88, 3, 32, "Input"],
Cell[176593, 6646, 101, 3, 32, "Input"],
Cell[176697, 6651, 116, 3, 32, "Input"],
Cell[176816, 6656, 135, 3, 27, "Text"],
Cell[176954, 6661, 130, 3, 32, "Input"],
Cell[177087, 6666, 89, 3, 32, "Input"],
Cell[177179, 6671, 224, 4, 46, "Text"],
Cell[177406, 6677, 195, 4, 56, "Input"],
Cell[177604, 6683, 124, 3, 27, "Text"],
Cell[177731, 6688, 104, 3, 32, "Input"],
Cell[177838, 6693, 102, 3, 32, "Input"],
Cell[177943, 6698, 132, 3, 32, "Input"],
Cell[178078, 6703, 177, 3, 46, "Text"],
Cell[178258, 6708, 121, 3, 32, "Input"],
Cell[178382, 6713, 238, 4, 46, "Text"],
Cell[178623, 6719, 108, 3, 32, "Input"],
Cell[178734, 6724, 55, 0, 27, "Text"],
Cell[178792, 6726, 111, 3, 32, "Input"],
Cell[178906, 6731, 136, 4, 58, "Text"],
Cell[179045, 6737, 124, 3, 32, "Input"],
Cell[179172, 6742, 152, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[179361, 6750, 71, 1, 30, "Subsubsection"],
Cell[179435, 6753, 280, 6, 80, "Input"],
Cell[179718, 6761, 103, 3, 27, "Text"],
Cell[179824, 6766, 90, 3, 32, "Input"],
Cell[179917, 6771, 99, 3, 32, "Input"],
Cell[180019, 6776, 144, 4, 32, "Input"],
Cell[180166, 6782, 168, 3, 46, "Text"],
Cell[180337, 6787, 130, 3, 32, "Input"],
Cell[180470, 6792, 89, 3, 32, "Input"],
Cell[180562, 6797, 102, 3, 32, "Input"],
Cell[180667, 6802, 116, 3, 32, "Input"],
Cell[180786, 6807, 135, 3, 27, "Text"],
Cell[180924, 6812, 130, 3, 32, "Input"],
Cell[181057, 6817, 89, 3, 32, "Input"],
Cell[181149, 6822, 224, 4, 46, "Text"],
Cell[181376, 6828, 195, 4, 56, "Input"],
Cell[181574, 6834, 104, 3, 32, "Input"],
Cell[181681, 6839, 102, 3, 32, "Input"],
Cell[181786, 6844, 132, 3, 32, "Input"],
Cell[181921, 6849, 177, 3, 46, "Text"],
Cell[182101, 6854, 121, 3, 32, "Input"],
Cell[182225, 6859, 238, 4, 46, "Text"],
Cell[182466, 6865, 108, 3, 32, "Input"],
Cell[182577, 6870, 55, 0, 27, "Text"],
Cell[182635, 6872, 111, 3, 32, "Input"],
Cell[182749, 6877, 135, 4, 58, "Text"],
Cell[182887, 6883, 124, 3, 32, "Input"],
Cell[183014, 6888, 214, 4, 46, "Text"],
Cell[183231, 6894, 136, 3, 32, "Input"],
Cell[183370, 6899, 89, 3, 32, "Input"],
Cell[183462, 6904, 96, 3, 32, "Input"],
Cell[183561, 6909, 75, 0, 27, "Text"],
Cell[183639, 6911, 98, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[183786, 6920, 65, 1, 38, "Subsection"],

Cell[CellGroupData[{
Cell[183876, 6925, 126, 3, 36, "Subsubsection"],
Cell[184005, 6930, 26, 0, 27, "Text"],
Cell[184034, 6932, 114, 3, 32, "Input"],
Cell[184151, 6937, 93, 3, 32, "Input"],
Cell[184247, 6942, 130, 3, 32, "Input"],
Cell[184380, 6947, 86, 3, 32, "Input"],
Cell[184469, 6952, 150, 4, 32, "Input"],
Cell[184622, 6958, 117, 3, 32, "Input"],
Cell[184742, 6963, 96, 3, 32, "Input"],
Cell[184841, 6968, 136, 3, 32, "Input"],
Cell[184980, 6973, 89, 3, 32, "Input"],
Cell[185072, 6978, 188, 6, 27, "Text"],
Cell[185263, 6986, 127, 3, 32, "Input"],
Cell[185393, 6991, 74, 0, 27, "Text"],
Cell[185470, 6993, 93, 3, 32, "Input"],
Cell[185566, 6998, 136, 3, 32, "Input"],
Cell[185705, 7003, 89, 3, 32, "Input"],
Cell[185797, 7008, 96, 3, 32, "Input"],
Cell[185896, 7013, 96, 2, 27, "Text"],
Cell[185995, 7017, 127, 3, 32, "Input"],
Cell[186125, 7022, 26, 0, 27, "Text"],
Cell[186154, 7024, 150, 4, 32, "Input"],
Cell[186307, 7030, 87, 3, 32, "Input"],
Cell[186397, 7035, 166, 3, 27, "Text"],
Cell[186566, 7040, 125, 3, 32, "Input"],
Cell[186694, 7045, 90, 3, 32, "Input"],
Cell[186787, 7050, 25, 0, 27, "Text"],
Cell[186815, 7052, 152, 4, 32, "Input"],
Cell[186970, 7058, 302, 5, 46, "Text"],
Cell[187275, 7065, 103, 3, 32, "Input"],
Cell[187381, 7070, 96, 3, 32, "Input"],
Cell[187480, 7075, 136, 3, 32, "Input"],
Cell[187619, 7080, 92, 3, 32, "Input"],
Cell[187714, 7085, 108, 3, 27, "Text"],
Cell[187825, 7090, 125, 3, 32, "Input"],
Cell[187953, 7095, 70, 2, 32, "Input"],
Cell[188026, 7099, 129, 3, 32, "Input"],
Cell[188158, 7104, 92, 3, 32, "Input"],
Cell[188253, 7109, 62, 0, 27, "Text"],
Cell[188318, 7111, 114, 3, 32, "Input"],
Cell[188435, 7116, 93, 3, 32, "Input"],
Cell[188531, 7121, 114, 3, 32, "Input"],
Cell[188648, 7126, 93, 3, 32, "Input"],
Cell[188744, 7131, 98, 3, 32, "Input"],
Cell[188845, 7136, 101, 3, 32, "Input"],
Cell[188949, 7141, 93, 3, 32, "Input"],
Cell[189045, 7146, 111, 3, 32, "Input"],
Cell[189159, 7151, 132, 3, 32, "Input"],
Cell[189294, 7156, 89, 3, 32, "Input"],
Cell[189386, 7161, 111, 3, 32, "Input"],
Cell[189500, 7166, 111, 3, 32, "Input"],
Cell[189614, 7171, 104, 3, 27, "Text"],
Cell[189721, 7176, 208, 6, 56, "Input"],
Cell[189932, 7184, 208, 6, 56, "Input"],
Cell[190143, 7192, 128, 3, 32, "Input"],
Cell[190274, 7197, 118, 3, 32, "Input"],
Cell[190395, 7202, 94, 3, 32, "Input"],
Cell[190492, 7207, 118, 3, 32, "Input"],
Cell[190613, 7212, 94, 3, 32, "Input"],
Cell[190710, 7217, 100, 3, 32, "Input"],
Cell[190813, 7222, 105, 3, 32, "Input"],
Cell[190921, 7227, 93, 3, 32, "Input"],
Cell[191017, 7232, 115, 3, 32, "Input"],
Cell[191135, 7237, 115, 3, 32, "Input"],
Cell[191253, 7242, 124, 3, 32, "Input"],
Cell[191380, 7247, 119, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[191536, 7255, 129, 3, 36, "Subsubsection"],
Cell[191668, 7260, 134, 3, 32, "Input"],
Cell[191805, 7265, 150, 4, 32, "Input"],
Cell[191958, 7271, 114, 3, 32, "Input"],
Cell[192075, 7276, 96, 3, 32, "Input"],
Cell[192174, 7281, 136, 3, 32, "Input"],
Cell[192313, 7286, 89, 3, 32, "Input"],
Cell[192405, 7291, 44, 0, 27, "Text"],
Cell[192452, 7293, 127, 3, 32, "Input"],
Cell[192582, 7298, 104, 3, 32, "Input"],
Cell[192689, 7303, 108, 3, 32, "Input"],
Cell[192800, 7308, 105, 3, 32, "Input"],
Cell[192908, 7313, 279, 7, 51, "Text"],
Cell[193190, 7322, 120, 3, 32, "Input"],
Cell[193313, 7327, 96, 3, 32, "Input"],
Cell[193412, 7332, 94, 3, 32, "Input"],
Cell[193509, 7337, 96, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[193654, 7346, 118, 2, 38, "Subsection"],
Cell[193775, 7350, 416, 10, 182, "Text"],

Cell[CellGroupData[{
Cell[194216, 7364, 82, 1, 36, "Subsubsection"],
Cell[194301, 7367, 126, 3, 27, "Text"],
Cell[194430, 7372, 132, 3, 32, "Input"],
Cell[194565, 7377, 151, 3, 27, "Text"],
Cell[194719, 7382, 127, 3, 32, "Input"],
Cell[194849, 7387, 68, 0, 27, "Text"],
Cell[194920, 7389, 173, 5, 32, "Input"],
Cell[195096, 7396, 102, 3, 32, "Input"],
Cell[195201, 7401, 96, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[195322, 7408, 135, 4, 32, "Input",
  Evaluatable->False],
Cell[195460, 7414, 91, 3, 28, "Output"]
}, Closed]],
Cell[195566, 7420, 128, 3, 23, "Text"],
Cell[195697, 7425, 154, 4, 32, "Input"],
Cell[195854, 7431, 97, 3, 32, "Input"],
Cell[195954, 7436, 153, 5, 36, "Input"],
Cell[196110, 7443, 153, 4, 32, "Input"],
Cell[196266, 7449, 107, 3, 32, "Input"],
Cell[196376, 7454, 263, 6, 86, "Input"],
Cell[196642, 7462, 105, 3, 32, "Input"],
Cell[196750, 7467, 166, 3, 46, "Text"],
Cell[196919, 7472, 297, 6, 56, "Input"],
Cell[197219, 7480, 101, 3, 32, "Input"],
Cell[197323, 7485, 97, 3, 32, "Input"],
Cell[197423, 7490, 207, 6, 61, "Input",
  InitializationCell->True],
Cell[197633, 7498, 100, 3, 32, "Input"],
Cell[197736, 7503, 124, 3, 32, "Input"],
Cell[197863, 7508, 96, 3, 32, "Input"],
Cell[197962, 7513, 97, 3, 32, "Input"],
Cell[198062, 7518, 248, 7, 86, "Input",
  InitializationCell->True],
Cell[198313, 7527, 163, 3, 27, "Text"],
Cell[198479, 7532, 112, 3, 32, "Input"],
Cell[198594, 7537, 111, 3, 32, "Input"],
Cell[198708, 7542, 142, 3, 27, "Text"],
Cell[198853, 7547, 178, 5, 36, "Input"],
Cell[199034, 7554, 188, 4, 46, "Text"],
Cell[199225, 7560, 288, 6, 86, "Input"],
Cell[199516, 7568, 158, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[199711, 7576, 52, 1, 36, "Subsubsection"],
Cell[199766, 7579, 744, 14, 196, "Text"],
Cell[200513, 7595, 211, 5, 80, "Input"],
Cell[200727, 7602, 204, 5, 56, "Input"],
Cell[200934, 7609, 124, 3, 32, "Input"],
Cell[201061, 7614, 90, 3, 32, "Input"],
Cell[201154, 7619, 124, 3, 32, "Input"],
Cell[201281, 7624, 92, 3, 32, "Input"],
Cell[201376, 7629, 100, 3, 32, "Input"],
Cell[201479, 7634, 92, 3, 32, "Input"],
Cell[201574, 7639, 170, 5, 32, "Input"],
Cell[201747, 7646, 161, 5, 32, "Input"],
Cell[201911, 7653, 60, 0, 27, "Text"],
Cell[201974, 7655, 121, 3, 32, "Input"],
Cell[202098, 7660, 123, 3, 32, "Input"],
Cell[202224, 7665, 126, 3, 32, "Input"],
Cell[202353, 7670, 60, 0, 27, "Text"],
Cell[202416, 7672, 121, 3, 32, "Input"],
Cell[202540, 7677, 123, 3, 32, "Input"],
Cell[202666, 7682, 126, 3, 32, "Input"],
Cell[202795, 7687, 43, 0, 27, "Text"],
Cell[202841, 7689, 115, 3, 32, "Input"],
Cell[202959, 7694, 123, 3, 32, "Input"],
Cell[203085, 7699, 54, 0, 27, "Text"],
Cell[203142, 7701, 107, 3, 32, "Input"],
Cell[203252, 7706, 99, 2, 27, "Text"],
Cell[203354, 7710, 120, 3, 32, "Input"],
Cell[203477, 7715, 120, 3, 32, "Input"],
Cell[203600, 7720, 122, 3, 32, "Input"],
Cell[203725, 7725, 90, 3, 32, "Input"],
Cell[203818, 7730, 121, 3, 32, "Input"],
Cell[203942, 7735, 89, 3, 32, "Input"],
Cell[204034, 7740, 102, 3, 32, "Input"],
Cell[204139, 7745, 162, 5, 32, "Input"],
Cell[204304, 7752, 155, 4, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[204496, 7761, 56, 1, 36, "Subsubsection"],
Cell[204555, 7764, 126, 3, 32, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[204742, 7774, 124, 2, 60, "Section"],

Cell[CellGroupData[{
Cell[204891, 7780, 32, 0, 36, "Subsubsection"],
Cell[204926, 7782, 1157, 19, 172, "Text"],
Cell[206086, 7803, 93, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[206216, 7811, 144, 4, 39, "Subsection",
  CellTags->"v5.1"],
Cell[206363, 7817, 120, 3, 32, "Input"],
Cell[206486, 7822, 122, 3, 32, "Input"],
Cell[206611, 7827, 120, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[206768, 7835, 90, 1, 39, "Subsection"],
Cell[206861, 7838, 163, 6, 27, "Text"],
Cell[207027, 7846, 122, 3, 32, "Input"],
Cell[207152, 7851, 165, 3, 27, "Text"],
Cell[207320, 7856, 143, 4, 32, "Input"],
Cell[207466, 7862, 54, 0, 27, "Text"],
Cell[207523, 7864, 135, 3, 32, "Input"],
Cell[207661, 7869, 74, 2, 32, "Input"],
Cell[207738, 7873, 68, 0, 27, "Text"],
Cell[207809, 7875, 93, 3, 32, "Input"],
Cell[207905, 7880, 71, 2, 32, "Input"],
Cell[207979, 7884, 122, 3, 32, "Input"],
Cell[208104, 7889, 73, 0, 27, "Text"],
Cell[208180, 7891, 67, 2, 32, "Input"],
Cell[208250, 7895, 103, 3, 32, "Input"],
Cell[208356, 7900, 136, 3, 32, "Input"],
Cell[208495, 7905, 213, 5, 60, "Input"],
Cell[208711, 7912, 53, 0, 27, "Text"],
Cell[208767, 7914, 67, 2, 32, "Input"],
Cell[208837, 7918, 103, 3, 32, "Input"],
Cell[208943, 7923, 136, 3, 32, "Input"],
Cell[209082, 7928, 136, 3, 73, "Input"],
Cell[209221, 7933, 96, 2, 27, "Text"],
Cell[209320, 7937, 181, 3, 56, "Input"],
Cell[209504, 7942, 73, 2, 32, "Input"],
Cell[209580, 7946, 92, 2, 32, "Input"],
Cell[209675, 7950, 69, 2, 32, "Input"],
Cell[209747, 7954, 99, 2, 32, "Input"],
Cell[209849, 7958, 69, 2, 32, "Input"],
Cell[209921, 7962, 360, 6, 65, "Text"],

Cell[CellGroupData[{
Cell[210306, 7972, 94, 1, 36, "Subsubsection"],
Cell[210403, 7975, 81, 2, 32, "Input"],
Cell[210487, 7979, 92, 2, 32, "Input"],
Cell[210582, 7983, 65, 2, 32, "Input"],
Cell[210650, 7987, 72, 2, 32, "Input"],
Cell[210725, 7991, 127, 3, 32, "Input"],
Cell[210855, 7996, 60, 0, 27, "Text"],
Cell[210918, 7998, 102, 2, 32, "Input"],
Cell[211023, 8002, 102, 2, 32, "Input"],
Cell[211128, 8006, 93, 2, 32, "Input"],
Cell[211224, 8010, 72, 0, 27, "Text"],
Cell[211299, 8012, 94, 2, 32, "Input"],
Cell[211396, 8016, 71, 2, 32, "Input"],
Cell[211470, 8020, 78, 2, 32, "Input"],
Cell[211551, 8024, 73, 2, 32, "Input"],
Cell[211627, 8028, 70, 2, 32, "Input"],
Cell[211700, 8032, 45, 0, 27, "Text"],
Cell[211748, 8034, 116, 2, 32, "Input"],
Cell[211867, 8038, 76, 2, 32, "Input"],
Cell[211946, 8042, 173, 3, 56, "Input"],
Cell[212122, 8047, 71, 2, 32, "Input"],
Cell[212196, 8051, 78, 2, 32, "Input"],
Cell[212277, 8055, 235, 4, 86, "Input"],
Cell[212515, 8061, 58, 0, 27, "Text"],
Cell[212576, 8063, 151, 4, 32, "Input"],
Cell[212730, 8069, 160, 4, 32, "Input"],
Cell[212893, 8075, 91, 3, 32, "Input"],
Cell[212987, 8080, 125, 3, 32, "Input"],
Cell[213115, 8085, 109, 3, 32, "Input"],
Cell[213227, 8090, 65, 0, 27, "Text"],
Cell[213295, 8092, 259, 6, 56, "Input"],
Cell[213557, 8100, 92, 3, 32, "Input"],
Cell[213652, 8105, 96, 3, 32, "Input"],
Cell[213751, 8110, 117, 3, 27, "Text"],
Cell[213871, 8115, 158, 4, 32, "Input"],
Cell[214032, 8121, 168, 4, 32, "Input"],
Cell[214203, 8127, 70, 1, 36, "Input"],
Cell[214276, 8130, 72, 1, 36, "Input"],
Cell[214351, 8133, 124, 3, 32, "Input"],
Cell[214478, 8138, 95, 3, 32, "Input"],
Cell[214576, 8143, 127, 3, 32, "Input"],
Cell[214706, 8148, 74, 1, 36, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[214829, 8155, 76, 1, 39, "Subsection"],
Cell[214908, 8158, 256, 10, 27, "Text"],
Cell[215167, 8170, 122, 3, 32, "Input"],
Cell[215292, 8175, 91, 3, 32, "Input"],
Cell[215386, 8180, 164, 3, 27, "Text"],
Cell[215553, 8185, 143, 4, 32, "Input"],
Cell[215699, 8191, 133, 3, 32, "Input"],
Cell[215835, 8196, 153, 3, 27, "Text"],
Cell[215991, 8201, 93, 3, 32, "Input"],
Cell[216087, 8206, 99, 3, 32, "Input"],
Cell[216189, 8211, 71, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[216285, 8217, 79, 1, 36, "Subsubsection"],
Cell[216367, 8220, 96, 2, 27, "Text"],
Cell[216466, 8224, 103, 3, 32, "Input"],
Cell[216572, 8229, 103, 3, 32, "Input"],
Cell[216678, 8234, 96, 2, 27, "Text"],
Cell[216777, 8238, 97, 2, 32, "Input"],
Cell[216877, 8242, 484, 17, 46, "Text"],
Cell[217364, 8261, 63, 2, 32, "Input"],
Cell[217430, 8265, 86, 2, 32, "Input"],
Cell[217519, 8269, 57, 0, 27, "Text"],
Cell[217579, 8271, 103, 3, 32, "Input"],
Cell[217685, 8276, 92, 2, 32, "Input"],
Cell[217780, 8280, 69, 2, 32, "Input"],
Cell[217852, 8284, 99, 2, 32, "Input"],
Cell[217954, 8288, 69, 2, 32, "Input"],
Cell[218026, 8292, 348, 6, 65, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[218411, 8303, 80, 1, 30, "Subsubsection"],
Cell[218494, 8306, 161, 3, 27, "Text"],
Cell[218658, 8311, 99, 3, 32, "Input"],
Cell[218760, 8316, 198, 5, 32, "Input"],
Cell[218961, 8323, 103, 3, 32, "Input"],
Cell[219067, 8328, 193, 4, 46, "Text"],
Cell[219263, 8334, 139, 3, 32, "Input"],
Cell[219405, 8339, 162, 4, 32, "Input"],
Cell[219570, 8345, 80, 2, 32, "Input"],
Cell[219653, 8349, 181, 4, 32, "Input"],
Cell[219837, 8355, 95, 3, 32, "Input"],
Cell[219935, 8360, 84, 2, 32, "Input"],
Cell[220022, 8364, 90, 2, 32, "Input"],
Cell[220115, 8368, 115, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[220267, 8376, 76, 1, 28, "Subsubsection"],
Cell[220346, 8379, 88, 2, 27, "Text"],
Cell[220437, 8383, 125, 3, 32, "Input"],
Cell[220565, 8388, 120, 3, 32, "Input"],
Cell[220688, 8393, 91, 3, 32, "Input"],
Cell[220782, 8398, 116, 4, 36, "Input"],
Cell[220901, 8404, 40, 0, 27, "Text"],
Cell[220944, 8406, 238, 6, 56, "Input"],
Cell[221185, 8414, 94, 3, 32, "Input"],
Cell[221282, 8419, 102, 3, 32, "Input"],
Cell[221387, 8424, 95, 3, 32, "Input"],
Cell[221485, 8429, 118, 4, 36, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[221640, 8438, 93, 1, 28, "Subsubsection"],
Cell[221736, 8441, 236, 6, 56, "Input"],
Cell[221975, 8449, 70, 2, 32, "Input"],
Cell[222048, 8453, 75, 2, 32, "Input"],
Cell[222126, 8457, 71, 2, 32, "Input"],
Cell[222200, 8461, 117, 4, 36, "Input"],
Cell[222320, 8467, 79, 2, 32, "Input"],
Cell[222402, 8471, 95, 2, 32, "Input"],
Cell[222500, 8475, 65, 2, 32, "Input"],
Cell[222568, 8479, 70, 2, 32, "Input"],
Cell[222641, 8483, 118, 4, 36, "Input"],
Cell[222762, 8489, 58, 0, 27, "Text"],
Cell[222823, 8491, 85, 2, 32, "Input"],
Cell[222911, 8495, 69, 2, 32, "Input"],
Cell[222983, 8499, 81, 2, 32, "Input"],
Cell[223067, 8503, 75, 2, 32, "Input"],
Cell[223145, 8507, 113, 4, 36, "Input"],
Cell[223261, 8513, 83, 2, 32, "Input"],
Cell[223347, 8517, 113, 4, 36, "Input"],
Cell[223463, 8523, 150, 3, 27, "Text"],
Cell[223616, 8528, 247, 5, 56, "Input"],
Cell[223866, 8535, 69, 2, 32, "Input"],
Cell[223938, 8539, 93, 2, 32, "Input"],
Cell[224034, 8543, 94, 2, 32, "Input"],
Cell[224131, 8547, 65, 2, 32, "Input"],
Cell[224199, 8551, 94, 2, 32, "Input"],
Cell[224296, 8555, 65, 2, 32, "Input"],
Cell[224364, 8559, 73, 0, 27, "Text"],
Cell[224440, 8561, 133, 3, 32, "Input"],
Cell[224576, 8566, 75, 2, 32, "Input"],
Cell[224654, 8570, 96, 2, 32, "Input"],
Cell[224753, 8574, 73, 2, 32, "Input"],
Cell[224829, 8578, 86, 2, 32, "Input"],
Cell[224918, 8582, 72, 2, 32, "Input"],
Cell[224993, 8586, 107, 3, 27, "Text"],
Cell[225103, 8591, 147, 4, 36, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[225287, 8600, 92, 1, 28, "Subsubsection"],
Cell[225382, 8603, 236, 6, 56, "Input"],
Cell[225621, 8611, 74, 2, 32, "Input"],
Cell[225698, 8615, 73, 2, 32, "Input"],
Cell[225774, 8619, 71, 2, 32, "Input"],
Cell[225848, 8623, 62, 0, 27, "Text"],
Cell[225913, 8625, 121, 4, 36, "Input"],
Cell[226037, 8631, 155, 3, 27, "Text"],
Cell[226195, 8636, 63, 2, 32, "Input"],
Cell[226261, 8640, 112, 2, 32, "Input"],
Cell[226376, 8644, 66, 2, 32, "Input"],
Cell[226445, 8648, 34, 0, 27, "Text"],
Cell[226482, 8650, 108, 2, 32, "Input"],
Cell[226593, 8654, 69, 2, 32, "Input"],
Cell[226665, 8658, 81, 2, 32, "Input"],
Cell[226749, 8662, 120, 3, 27, "Text"],
Cell[226872, 8667, 70, 2, 32, "Input"],
Cell[226945, 8671, 87, 2, 32, "Input"],
Cell[227035, 8675, 101, 2, 32, "Input"],
Cell[227139, 8679, 51, 0, 27, "Text"],
Cell[227193, 8681, 83, 2, 32, "Input"],
Cell[227279, 8685, 83, 2, 32, "Input"],
Cell[227365, 8689, 83, 2, 32, "Input"],
Cell[227451, 8693, 102, 2, 32, "Input"],
Cell[227556, 8697, 75, 2, 32, "Input"],
Cell[227634, 8701, 88, 2, 32, "Input"],
Cell[227725, 8705, 78, 2, 32, "Input"],
Cell[227806, 8709, 123, 3, 27, "Text"],
Cell[227932, 8714, 114, 4, 36, "Input"],
Cell[228049, 8720, 141, 3, 27, "Text"],
Cell[228193, 8725, 248, 5, 56, "Input"],
Cell[228444, 8732, 90, 2, 32, "Input"],
Cell[228537, 8736, 91, 2, 32, "Input"],
Cell[228631, 8740, 75, 2, 32, "Input"],
Cell[228709, 8744, 87, 2, 32, "Input"],
Cell[228799, 8748, 66, 2, 32, "Input"],
Cell[228868, 8752, 84, 2, 32, "Input"],
Cell[228955, 8756, 70, 2, 32, "Input"],
Cell[229028, 8760, 256, 6, 128, "Input"],
Cell[229287, 8768, 72, 2, 32, "Input"],
Cell[229362, 8772, 95, 2, 32, "Input"],
Cell[229460, 8776, 68, 2, 32, "Input"],
Cell[229531, 8780, 41, 0, 27, "Text"],
Cell[229575, 8782, 147, 4, 36, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[229759, 8791, 65, 1, 30, "Subsubsection"],
Cell[229827, 8794, 115, 3, 27, "Text"],
Cell[229945, 8799, 75, 2, 32, "Input"],
Cell[230023, 8803, 95, 2, 32, "Input"],
Cell[230121, 8807, 88, 3, 32, "Input"],
Cell[230212, 8812, 91, 3, 32, "Input"],
Cell[230306, 8817, 93, 3, 32, "Input"],
Cell[230402, 8822, 132, 3, 32, "Input"],
Cell[230537, 8827, 74, 2, 32, "Input"],
Cell[230614, 8831, 94, 2, 32, "Input"],
Cell[230711, 8835, 90, 2, 32, "Input"],
Cell[230804, 8839, 40, 0, 27, "Text"],
Cell[230847, 8841, 221, 5, 56, "Input"],
Cell[231071, 8848, 94, 3, 32, "Input"],
Cell[231168, 8853, 98, 3, 32, "Input"],
Cell[231269, 8858, 143, 4, 32, "Input"],
Cell[231415, 8864, 109, 3, 32, "Input"],
Cell[231527, 8869, 70, 1, 27, "Text"],
Cell[231600, 8872, 96, 2, 27, "Text"],
Cell[231699, 8876, 103, 3, 32, "Input"],
Cell[231805, 8881, 103, 3, 32, "Input"],
Cell[231911, 8886, 24, 0, 27, "Text"],
Cell[231938, 8888, 85, 2, 32, "Input"],
Cell[232026, 8892, 117, 3, 27, "Text"],
Cell[232146, 8897, 76, 2, 32, "Input"],
Cell[232225, 8901, 103, 3, 32, "Input"],
Cell[232331, 8906, 93, 2, 32, "Input"],
Cell[232427, 8910, 70, 2, 32, "Input"],
Cell[232500, 8914, 100, 2, 32, "Input"],
Cell[232603, 8918, 70, 2, 32, "Input"],
Cell[232676, 8922, 294, 5, 46, "Text"],
Cell[232973, 8929, 168, 4, 27, "Text"],
Cell[233144, 8935, 104, 3, 32, "Input"],
Cell[233251, 8940, 70, 2, 32, "Input"],
Cell[233324, 8944, 182, 4, 32, "Input"],
Cell[233509, 8950, 95, 3, 32, "Input"],
Cell[233607, 8955, 115, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[233771, 8964, 94, 1, 39, "Subsection"],
Cell[233868, 8967, 96, 3, 32, "Input"],
Cell[233967, 8972, 65, 0, 27, "Text"],
Cell[234035, 8974, 120, 3, 32, "Input"],
Cell[234158, 8979, 123, 3, 27, "Text"],
Cell[234284, 8984, 121, 3, 32, "Input"],
Cell[234408, 8989, 30, 0, 27, "Text"],
Cell[234441, 8991, 177, 5, 32, "Input"],
Cell[234621, 8998, 113, 3, 27, "Text"],
Cell[234737, 9003, 143, 4, 32, "Input"],
Cell[234883, 9009, 88, 3, 32, "Input"],
Cell[234974, 9014, 91, 3, 32, "Input"],
Cell[235068, 9019, 196, 5, 32, "Input"],
Cell[235267, 9026, 94, 3, 32, "Input"],
Cell[235364, 9031, 70, 1, 36, "Input"],
Cell[235437, 9034, 72, 1, 36, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[235546, 9040, 105, 2, 39, "Subsection"],
Cell[235654, 9044, 113, 3, 27, "Text"],
Cell[235770, 9049, 120, 3, 32, "Input"],
Cell[235893, 9054, 121, 3, 32, "Input"],
Cell[236017, 9059, 30, 0, 27, "Text"],
Cell[236050, 9061, 177, 5, 32, "Input"],
Cell[236230, 9068, 106, 3, 27, "Text"],
Cell[236339, 9073, 74, 2, 32, "Input"],
Cell[236416, 9077, 95, 2, 32, "Input"],
Cell[236514, 9081, 65, 2, 32, "Input"],
Cell[236582, 9085, 70, 2, 32, "Input"],
Cell[236655, 9089, 125, 3, 32, "Input"],
Cell[236783, 9094, 101, 3, 32, "Input"],
Cell[236887, 9099, 66, 2, 32, "Input"],
Cell[236956, 9103, 189, 4, 46, "Text"],
Cell[237148, 9109, 62, 2, 32, "Input"],
Cell[237213, 9113, 290, 6, 80, "Input"],
Cell[237506, 9121, 69, 2, 32, "Input"],
Cell[237578, 9125, 45, 0, 27, "Text"],
Cell[237626, 9127, 151, 4, 32, "Input"],
Cell[237780, 9133, 183, 4, 46, "Text"],
Cell[237966, 9139, 113, 3, 32, "Input"],
Cell[238082, 9144, 96, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[238215, 9152, 99, 1, 39, "Subsection"],
Cell[238317, 9155, 85, 2, 27, "Text"],
Cell[238405, 9159, 111, 3, 32, "Input"],
Cell[238519, 9164, 70, 0, 27, "Text"],
Cell[238592, 9166, 103, 3, 32, "Input"],
Cell[238698, 9171, 138, 3, 32, "Input"],
Cell[238839, 9176, 121, 3, 32, "Input"],
Cell[238963, 9181, 209, 4, 46, "Text"],
Cell[239175, 9187, 130, 3, 32, "Input"],
Cell[239308, 9192, 153, 4, 32, "Input"],
Cell[239464, 9198, 88, 3, 32, "Input"],
Cell[239555, 9203, 95, 3, 32, "Input"],
Cell[239653, 9208, 103, 3, 32, "Input"],
Cell[239759, 9213, 91, 3, 32, "Input"],
Cell[239853, 9218, 128, 3, 32, "Input"],
Cell[239984, 9223, 305, 6, 56, "Input"],
Cell[240292, 9231, 69, 2, 32, "Input"],
Cell[240364, 9235, 106, 3, 27, "Text"],
Cell[240473, 9240, 106, 3, 32, "Input"],
Cell[240582, 9245, 103, 3, 27, "Text"],
Cell[240688, 9250, 291, 6, 56, "Input"],
Cell[240982, 9258, 69, 2, 32, "Input"],
Cell[241054, 9262, 138, 3, 32, "Input"],
Cell[241195, 9267, 103, 3, 27, "Text"],
Cell[241301, 9272, 109, 3, 32, "Input"],
Cell[241413, 9277, 98, 3, 32, "Input"],
Cell[241514, 9282, 126, 3, 27, "Text"],
Cell[241643, 9287, 139, 3, 32, "Input"],
Cell[241785, 9292, 122, 3, 32, "Input"],
Cell[241910, 9297, 149, 3, 27, "Text"],
Cell[242062, 9302, 116, 3, 32, "Input"],
Cell[242181, 9307, 86, 3, 32, "Input"],
Cell[242270, 9312, 113, 3, 32, "Input"],
Cell[242386, 9317, 113, 3, 32, "Input"],
Cell[242502, 9322, 151, 4, 32, "Input"],
Cell[242656, 9328, 88, 3, 32, "Input"],
Cell[242747, 9333, 46, 0, 27, "Text"],
Cell[242796, 9335, 122, 3, 32, "Input"],
Cell[242921, 9340, 98, 3, 32, "Input"],
Cell[243022, 9345, 55, 0, 27, "Text"],
Cell[243080, 9347, 161, 5, 32, "Input"],
Cell[243244, 9354, 135, 3, 32, "Input"],
Cell[243382, 9359, 108, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[243539, 9368, 176, 4, 60, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[243740, 9376, 61, 1, 44, "Subsection"],
Cell[243804, 9379, 855, 12, 122, "Text"],
Cell[244662, 9393, 1465, 28, 179, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[246164, 9426, 90, 2, 44, "Subsection",
  Evaluatable->False],
Cell[246257, 9430, 384, 9, 46, "Text"],
Cell[246644, 9441, 186, 4, 32, "Input"],
Cell[246833, 9447, 114, 3, 32, "Input"],
Cell[246950, 9452, 99, 3, 32, "Input"],
Cell[247052, 9457, 109, 3, 32, "Input"],
Cell[247164, 9462, 87, 3, 32, "Input"],
Cell[247254, 9467, 118, 3, 27, "Text"],
Cell[247375, 9472, 137, 3, 32, "Input"],
Cell[247515, 9477, 159, 4, 32, "Input"],
Cell[247677, 9483, 95, 3, 32, "Input"],
Cell[247775, 9488, 137, 3, 27, "Text"],
Cell[247915, 9493, 92, 2, 32, "Input"],
Cell[248010, 9497, 196, 6, 27, "Text"],

Cell[CellGroupData[{
Cell[248231, 9507, 92, 1, 36, "Subsubsection"],
Cell[248326, 9510, 135, 3, 32, "Input"],
Cell[248464, 9515, 93, 3, 32, "Input"],
Cell[248560, 9520, 93, 3, 32, "Input"],
Cell[248656, 9525, 153, 3, 27, "Text"],
Cell[248812, 9530, 220, 5, 56, "Input"],
Cell[249035, 9537, 133, 3, 32, "Input"],
Cell[249171, 9542, 133, 3, 32, "Input"],
Cell[249307, 9547, 133, 3, 32, "Input"],
Cell[249443, 9552, 102, 3, 32, "Input"],
Cell[249548, 9557, 102, 3, 32, "Input"],
Cell[249653, 9562, 154, 3, 27, "Text"],
Cell[249810, 9567, 91, 3, 32, "Input"],
Cell[249904, 9572, 60, 0, 27, "Text"],
Cell[249967, 9574, 104, 3, 32, "Input"],
Cell[250074, 9579, 93, 3, 32, "Input"],
Cell[250170, 9584, 97, 2, 27, "Text"],
Cell[250270, 9588, 154, 4, 32, "Input"],
Cell[250427, 9594, 135, 3, 32, "Input"],
Cell[250565, 9599, 130, 3, 59, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[250732, 9607, 86, 1, 30, "Subsubsection"],
Cell[250821, 9610, 162, 3, 54, "Input"],
Cell[250986, 9615, 71, 2, 31, "Input"],
Cell[251060, 9619, 91, 2, 31, "Input"],
Cell[251154, 9623, 75, 2, 31, "Input"],
Cell[251232, 9627, 84, 2, 31, "Input"],
Cell[251319, 9631, 63, 2, 31, "Input"],
Cell[251385, 9635, 114, 2, 31, "Input"],
Cell[251502, 9639, 135, 3, 31, "Input"],
Cell[251640, 9644, 69, 2, 31, "Input"],
Cell[251712, 9648, 73, 2, 31, "Input"],
Cell[251788, 9652, 74, 2, 31, "Input"],
Cell[251865, 9656, 132, 3, 31, "Input"],
Cell[252000, 9661, 71, 2, 31, "Input"],
Cell[252074, 9665, 94, 2, 31, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[252217, 9673, 89, 2, 44, "Subsection",
  Evaluatable->False],
Cell[252309, 9677, 271, 5, 46, "Text"],
Cell[252583, 9684, 192, 4, 32, "Input"],
Cell[252778, 9690, 109, 3, 32, "Input"],
Cell[252890, 9695, 102, 3, 32, "Input"],
Cell[252995, 9700, 112, 3, 32, "Input"],
Cell[253110, 9705, 88, 3, 32, "Input"],
Cell[253201, 9710, 103, 3, 32, "Input"],
Cell[253307, 9715, 132, 3, 32, "Input"],
Cell[253442, 9720, 192, 4, 32, "Input"],
Cell[253637, 9726, 109, 3, 32, "Input"],
Cell[253749, 9731, 102, 3, 32, "Input"],
Cell[253854, 9736, 112, 3, 32, "Input"],
Cell[253969, 9741, 88, 3, 32, "Input"],
Cell[254060, 9746, 103, 3, 32, "Input"],
Cell[254166, 9751, 132, 3, 32, "Input"],
Cell[254301, 9756, 96, 3, 32, "Input"],
Cell[254400, 9761, 71, 2, 32, "Input"],
Cell[254474, 9765, 93, 3, 32, "Input"],
Cell[254570, 9770, 92, 2, 32, "Input"],
Cell[254665, 9774, 145, 3, 27, "Text"],
Cell[254813, 9779, 138, 3, 32, "Input"],
Cell[254954, 9784, 197, 5, 32, "Input"],
Cell[255154, 9791, 93, 3, 32, "Input"],
Cell[255250, 9796, 235, 6, 46, "Text"],
Cell[255488, 9804, 99, 3, 32, "Input"],
Cell[255590, 9809, 136, 3, 27, "Text"],
Cell[255729, 9814, 122, 3, 32, "Input"],
Cell[255854, 9819, 100, 3, 32, "Input"],
Cell[255957, 9824, 165, 4, 32, "Input"],
Cell[256125, 9830, 197, 5, 32, "Input"],

Cell[CellGroupData[{
Cell[256347, 9839, 90, 1, 36, "Subsubsection"],
Cell[256440, 9842, 140, 3, 32, "Input"],
Cell[256583, 9847, 106, 3, 32, "Input"],
Cell[256692, 9852, 116, 3, 27, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[256857, 9861, 90, 2, 38, "Subsection",
  Evaluatable->False],
Cell[256950, 9865, 358, 9, 46, "Text"],
Cell[257311, 9876, 189, 4, 32, "Input"],
Cell[257503, 9882, 95, 3, 32, "Input"],
Cell[257601, 9887, 116, 3, 32, "Input"],
Cell[257720, 9892, 95, 3, 32, "Input"],
Cell[257818, 9897, 107, 3, 32, "Input"],
Cell[257928, 9902, 179, 5, 32, "Input"],
Cell[258110, 9909, 111, 3, 32, "Input"],
Cell[258224, 9914, 111, 3, 32, "Input"],
Cell[258338, 9919, 88, 3, 32, "Input"],
Cell[258429, 9924, 88, 3, 32, "Input"],
Cell[258520, 9929, 116, 3, 32, "Input"],
Cell[258639, 9934, 144, 4, 32, "Input"],
Cell[258786, 9940, 66, 2, 32, "Input"],
Cell[258855, 9944, 154, 4, 32, "Input"],
Cell[259012, 9950, 66, 2, 32, "Input"],
Cell[259081, 9954, 153, 4, 32, "Input"],
Cell[259237, 9960, 66, 2, 32, "Input"],
Cell[259306, 9964, 97, 3, 32, "Input"],
Cell[259406, 9969, 137, 3, 32, "Input"],
Cell[259546, 9974, 106, 3, 32, "Input"],
Cell[259655, 9979, 89, 3, 32, "Input"],
Cell[259747, 9984, 95, 3, 32, "Input"],
Cell[259845, 9989, 90, 2, 32, "Input"],
Cell[259938, 9993, 184, 4, 56, "Input"],
Cell[260125, 9999, 181, 4, 46, "Text"],
Cell[260309, 10005, 239, 5, 56, "Input"],
Cell[260551, 10012, 70, 2, 32, "Input"],
Cell[260624, 10016, 31, 0, 27, "Text"],
Cell[260658, 10018, 99, 3, 32, "Input"],
Cell[260760, 10023, 94, 3, 32, "Input"],
Cell[260857, 10028, 126, 3, 27, "Text"],
Cell[260986, 10033, 120, 3, 32, "Input"],
Cell[261109, 10038, 73, 0, 27, "Text"],
Cell[261185, 10040, 181, 4, 32, "Input"],
Cell[261369, 10046, 93, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[261487, 10053, 91, 1, 36, "Subsubsection"],
Cell[261581, 10056, 140, 3, 32, "Input"],
Cell[261724, 10061, 106, 3, 32, "Input"],
Cell[261833, 10066, 151, 3, 27, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[262045, 10076, 87, 2, 58, "Section",
  CellTags->"MathGL"],
Cell[262135, 10080, 259, 6, 46, "Text"],

Cell[CellGroupData[{
Cell[262419, 10090, 61, 1, 45, "Subsection"],
Cell[262483, 10093, 277, 6, 48, "Text",
  Evaluatable->False],
Cell[262763, 10101, 170, 4, 28, "Text",
  Evaluatable->False],
Cell[262936, 10107, 90, 2, 31, "Input"],
Cell[263029, 10111, 72, 2, 31, "Input"],
Cell[263104, 10115, 132, 4, 28, "Text",
  Evaluatable->False],
Cell[263239, 10121, 94, 2, 31, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[263370, 10128, 57, 1, 39, "Subsection"],
Cell[263430, 10131, 771, 17, 115, "Text"],
Cell[264204, 10150, 114, 3, 33, "Input"],
Cell[264321, 10155, 52, 0, 27, "Text"],
Cell[264376, 10157, 25, 0, 27, "Text"],
Cell[264404, 10159, 141, 3, 27, "Text"],
Cell[264548, 10164, 493, 10, 158, "Input"],
Cell[265044, 10176, 102, 2, 33, "Input"],
Cell[265149, 10180, 158, 3, 58, "Input"],
Cell[265310, 10185, 107, 2, 33, "Input"],
Cell[265420, 10189, 102, 2, 33, "Input"],
Cell[265525, 10193, 73, 2, 33, "Input"],
Cell[265601, 10197, 73, 2, 33, "Input"],
Cell[265677, 10201, 90, 3, 33, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[265816, 10210, 56, 1, 23, "Subsubtitle"],
Cell[265875, 10213, 207, 5, 59, "Text",
  Evaluatable->False,
  CellTags->"G1"],
Cell[266085, 10220, 147, 5, 40, "Text",
  Evaluatable->False,
  CellTags->"K2"],
Cell[266235, 10227, 186, 5, 40, "Text",
  Evaluatable->False,
  CellTags->"M3"],
Cell[266424, 10234, 246, 8, 40, "Text",
  CellTags->"O-S"],
Cell[266673, 10244, 140, 4, 40, "Text",
  CellTags->"S1"],
Cell[266816, 10250, 515, 15, 59, "Text",
  Evaluatable->False,
  CellTags->"S4"],
Cell[267334, 10267, 145, 5, 40, "Text",
  Evaluatable->False,
  CellTags->"S5"]
}, Closed]],

Cell[CellGroupData[{
Cell[267516, 10277, 62, 1, 23, "Subsubtitle"],
Cell[267581, 10280, 107, 5, 102, "Text",
  CellTags->"HP"],
Cell[267691, 10287, 47, 0, 27, "Text"],
Cell[267741, 10289, 90, 2, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

