(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    105129,       3766]*)
(*NotebookOutlinePosition[    107323,       3841]*)
(*  CellTagsIndexPosition[    107079,       3828]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["M\[ODoubleDot]bius Geometry of Spheres", "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center],

Cell["by", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Times New Roman",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell["Rolf Sulanke", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontSize->24],

Cell["March 1, 1999, last revision October 15, 2003", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontSlant->"Italic"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell[TextData[{
  "This notebook treates 2-spheres within the 3-sphere,or the euclidean \
3-space, as objects of M\[ODoubleDot]bius Geometry. First we introduce some \
basic objects of n-dimensional M\[ODoubleDot]bius geometry, which is the \
conformal geometry of the n-sphere. We emphasize the case n=3, in which M\
\[ODoubleDot]bius geometry can be visualized in the Euclidean 3-space by \
stereographical projection from the north pole. For this purpose we construct \
a version of the stereographical projection,and its inversion,which relates \
isotropic vectors of the pseudo-euclidean 5-space and points of the \
3-space.The bijective relation between subspheres of the 3-sphere and \
one-dimensional euclidean subspaces of the 5-dimensional pseudo-euclidean \
vector space is established. Functions describing this bijection are \
constructed. Finally we find and visualize the geodesics of the sphere space.\
\nThe concepts developed in this notebook are collected in the package \
mspher.m.\nThis notebook continues the notebook ",
  ButtonBox["Euklid.nb",
    ButtonData:>{
      FrontEnd`FileName[ {$RootDirectory, "home", "rolf", "mymath", "work", 
        ".", "."}, "Euklid.nb", CharacterEncoding -> "iso8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " , which contains the metric geometry of spheres. It uses tools of \
pseudo-euclidean linear algebra, developed in the notebook ",
  ButtonBox["pseuklid.nb",
    ButtonData:>{
      FrontEnd`FileName[ {$RootDirectory, "home", "rolf", "mymath", "work", 
        ".", ".", "."}, "pseuklid.nb", CharacterEncoding -> "iso8859-1"], 
      None},
    ButtonStyle->"Hyperlink"],
  ".\nFor the concepts of M\[ODoubleDot]bius geometry applied here see e.g.  \
",
  ButtonBox["[6]",
    ButtonData:>"S2",
    ButtonStyle->"Hyperlink"],
  " and my ",
  ButtonBox["homepage",
    ButtonData:>"HP",
    ButtonStyle->"Hyperlink"],
  ", also ",
  ButtonBox["[4]",
    ButtonData:>"O-S",
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Keywords", "Subsubsection"],

Cell["\<\
Generalized angles between spheres. Conformal invariants. Inversive distance. \
 Spheres defined by spacelike vectors. Random spacelike unit vectors. Random \
spheres. Spacelike vectors corresponding to spheres and planes.  Spheres \
through four points. Stereographical projection of isotropic vectors.  Space \
of all spheres. Geodesics in the sphere space; spacelike, timelike, and \
isotropic geodesics. The manifold of all spheres. Hyperboloid.  Moving frame \
of the sphere manifold.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Version", "Subsubsection"],

Cell[TextData[{
  "This notebook is a new version of the notebook mspheres.nb,  first \
published  in the item ",
  ButtonBox["[4]",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  " in MathSource. The same is true for the accompanying packages. ",
  "Since these packages contain the most important procedures used in this \
and other notebooks, published first in the  item Spheres,and the contents as \
well as some names are changed, the two versions should not be mixed.   The \
notebook is developed with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v. 4.200. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Copyright", "Subsubsection"],

Cell["\<\
This notebook, the linked notebooks, and the accompanying packages are  \
public. Authors who intend to publish a changed or completed version of them \
should do it under their own names with the condition that they cite the \
original notebook with the Internet address or other source where they got \
it. I am not responsible for errors or damages originated by the use of the \
procedures contained in my notebooks or packages; anybody who applies them \
should test carefully whether they are appropriate for his purposes.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  FontFamily->"Times"],

Cell["\<\
First, if not done already,  copy the needed packages  euvec.m, pseuvec.m, \
mspher.m  and this notebook mspheres.nb into your working directory, and  \
insert the path of your working directory, e.g. under Windows, \"C:\\Eigene \
Dateien\\mymath\\spheres.v4\", into the next command line:\
\>", "Text"],

Cell[BoxData[
    \(SetDirectory["\<~/mymath/work\>"]\)], "Input",
  CellLabel->"In[1]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[TextData[StyleBox["Now: Activite Kernel/Evaluation/Evaluate \
Initialization from the menu!",
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[BoxData[
    \(Needs["\<mspher`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["\<\
If you want to use the links contained in this notebook, make sure, that also \
the files Euklid.nb and pseuklid.nb \
\>", "Text"],

Cell["are contained in your working directory.", "Text"],

Cell[TextData[{
  "Before applying commands for graphics3D animations like ThreeScript or \
MVShow3D import first the needed tools, see section ",
  ButtonBox["6",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"]
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1  Introduction. Usages", "Section"],

Cell[CellGroupData[{

Cell["1.1 Pseudo-euclidean vector algebra and other prerequisites", \
"Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
We consider the n-dimensional sphere, shortly n-sphere, as the standard \
hyperellipsoid in the (n+1)-dimensional projective space. In homogeneous \
coordinates x \[RightTeeArrow] (x[1], ..., x[n+2])  its equation is\
\>", "Text"],

Cell[BoxData[
    \(\[Sum]\+\(i = 1\)\%\(n + 1\)\((x[i])\)\^2 - \((x[n + 2])\)\^2 = 
      0\)], "Text",
  CellLabel->"In[5]:=",
  TextAlignment->Center],

Cell[TextData[{
  "By Liouville's theorem (and some elementary consideration about functions \
of one complex variable in the case n=2) the conformal group of the n-sphere \
(n>1) coincides with the group of  all projective transformations preserving \
this hyperellipsoid. Elementary linear algebra can be used to show, that this \
group can be represented as the pseudo-orthogonal group  (factored by \
\[MinusPlus] identity) of the (n+2)-dimensional real vector space underlying \
the (n+1)-dimensional projective space. Therefore M\[ODoubleDot]bius geometry \
is treated by tools of pseudo-euclidean linear algebra. The basic concepts of \
pseudo-euclidean linear algebra are developed in the notebook ",
  ButtonBox["pseuklid.nb",
    ButtonData:>{
      FrontEnd`FileName[ {$RootDirectory, "home", "rolf", "mymath", "work", 
        ".", ".", "."}, "pseuklid.nb", CharacterEncoding -> "iso8859-1"], 
      None},
    ButtonStyle->"Hyperlink"],
  " and contained in the package pseuvec.m. They are called automatically if \
mspher.m is loaded.  Before using them one has to fix the dimension dim of \
the underlying vector space and the index  ind of the (non-degenerate, \
symmetric) scalar product. These basic constants are now defined by"
}], "Text"],

Cell[BoxData[
    \(dim\  = \ 5; \ ind\  = \ 1;\)], "Input",
  CellLabel->"In[3]:=",
  InitializationCell->True],

Cell["\<\
because in this notebook we are mainly interested in the 3-dimensional \
sphere. You can change these constants any time. But remember that they enter \
in almost all of the treated concepts; therefore they should be defined if \
using the packages. \
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["\<\
The basic invariant of pseudo-eulidean linear algebra is the scalar \
product:\
\>", "Text"],

Cell[BoxData[
    \(\(?pssp\)\)], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
The matrix of the scalar products in any orthonormed basis, e.g. the standard \
basis {stb[1],...,stb[5]}, is\
\>", "Text"],

Cell[BoxData[
    \(MatrixForm[Table[pssp[stb[i], \ stb[j]], {i, 5}, {j, 5}]]\)], "Input",
  CellLabel->"In[40]:=",
  InitializationCell->True],

Cell[TextData[
"Terminology: Spheres are usual 2-dimenional spheres if we consider the \
3-dimensional spherical geometry; more generally one may consider m-spheres \
in the n-sphere, where m, n with 0\[LessEqual]m\[LessEqual]n denote the \
dimensions. For  m = n-1 the (n-1)-spheres are called  hyperspheres.  "], 
  "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell["\<\
In 1.2 you can find the used names and symbols and evoke the corresponding \
usages. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2 The usages", "Subsection"],

Cell["\<\
After a package has been loaded you can get information about the  listed \
concepts in the usual way, e.g.\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?orthonorm\)\)], "Input",
  CellLabel->"In[41]:="],

Cell["\<\
For getting the usage and the complete definition, enter e.g.\
\>", "Text"],

Cell[BoxData[
    \(?? spt\)], "Input",
  CellLabel->"In[42]:="],

Cell["\<\
Since the names are prepended by the ContextNames the definition obtained in \
this way are hard to read. Therefore you will find some of them in the \
original form in unevaluable cells.  It is recommended to look in the \
packages.\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "Here you can get information about the commands which are defined in \
mspher.m. For the functions and modules defined in the packages euvec.m, \
pseuvec.m  see the notebooks ",
  ButtonBox["Euklid.nb",
    ButtonData:>{
      FrontEnd`FileName[ {$RootDirectory, "home", "rolf", "mymath", "work", 
        "."}, "Euklid.nb", CharacterEncoding -> "iso8859-1"], None},
    ButtonStyle->"Hyperlink"],
  " , ",
  ButtonBox["pseuklid.nb",
    ButtonData:>{
      FrontEnd`FileName[ {$RootDirectory, "home", "rolf", "mymath", "work", 
        ".", ".", ".", "."}, "pseuklid.nb", CharacterEncoding -> "iso8859-1"],
       None},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[BoxData[
    \(\(?spt\)\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(\(?stepro\)\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(\(?invstepro\)\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(\(?coxeterinv\)\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(coxeterinv[r1, \ r2, \ d]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(\(?gencos\)\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(\(?euklidsphere\)\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(\(?euklidsphereplot3D\)\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(\(?spunit\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(\(?pstg5frame\)\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(\(?vradius\)\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(\(?vcenter\)\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(\(?spherevec\)\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(\(?sph4ptsvec\)\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(\(?planevec\)\)], "Input",
  CellLabel->"In[57]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["2  Points: Adaption of the stereographical projection", "Section"],

Cell[CellGroupData[{

Cell["2.1 Stereographical projection of isotropic vectors", "Subsection"],

Cell["\<\
In the projective context, the points of the 3-sphere are the generating \
lines of the isotropic cone\
\>", "Text"],

Cell[TextData[{
  "pssp[x,x]  = ",
  Cell[BoxData[
      \(x[1]\^2 + x[2]\^2 + x[3]\^2 + x[4]\^2 - x[5]\^2\)]],
  "= 0,"
}], "Text",
  TextAlignment->Center],

Cell["\<\
analogously in higher dimensions. Our aim is to describe the point of the \
euclidean 3-space obtained by stereographical projection sterproj (defined in \
pseuvec.m) of the 3-sphere onto its equatorial hyperplane as a function of \
the isotropic vector x. There exists a natural bijection between the  lines \
intersecting the hyperplane \
\>", "Text"],

Cell["- pssp[stb[5], x] = x[5]  = 1 \t\t\t\t\t\t(H)", "Text",
  TextAlignment->0.5],

Cell["\<\
of the 5-space and the points of the euclidean 4-space  defined by\
\>", "Text"],

Cell[BoxData[
    \(\(?spt\)\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(spt[v_List]\  := \ 
      Module[{w, u, d = Length[v]}, 
        w\  = v[\([d]\)]; \n\t\t\tIf[
          w === 0, \ \ Return[
            Print[v\ , "\< has last component \>", w]], \n\t\t\t\tu = 
            Take[v/w, d - 1]; Return[u]]]\)], "Input",
  CellLabel->"In[20]:=",
  Evaluatable->False],

Cell["\<\
Now remember that the  3-sphere appears as  intersection of the hyperplane \
(H) with the isotropic cone. If we restrict spt onto the isotropic cone and \
combine it with the general stereographical projection\
\>", "Text"],

Cell[BoxData[
    \(\(?sterproj\)\)], "Input",
  CellLabel->"In[23]:="],

Cell["we obtain the wanted map", "Text"],

Cell[BoxData[
    \(\(?stepro\)\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(stepro[v_List]\  := \ sterproj[spt[v]]\)], "Input",
  Evaluatable->False],

Cell["Its inverse is generated by the vector", "Text"],

Cell[BoxData[
    \(invstepro[v_List]\  := \ Append[invsterproj[v], 1]\)], "Input",
  Evaluatable->False],

Cell[BoxData[
    \(\(?invstepro\)\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(\(?invsterproj\)\)], "Input",
  CellLabel->"In[27]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2 Examples", "Subsection"],

Cell[BoxData[
    \(spt[{2, 2, 2, 2, 2, 2, 2, 2, 4}]\)], "Input",
  CellLabel->"In[28]:="],

Cell["vec[x] ", "Input",
  CellLabel->"In[5]:=",
  InitializationCell->True],

Cell["spt[vec[x]]", "Input",
  CellLabel->"In[29]:="],

Cell["spt[stb[1]+stb[2]]", "Input",
  CellLabel->"In[30]:="],

Cell["spt[stb[5]]", "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(spt[stb[5] + stb[2] Cos[t] + stb[3] Sin[t]]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(stepro[stb[5] + stb[2] Cos[t] + stb[3] Sin[t]]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(invstepro[%]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[35]:="],

Cell["\<\
If one applies stepro on non-isotropic vectors one obtains incorrect results \
without any warning! If there are any doubts one should control the character \
ch of the arguments! Here is such an example:\
\>", "Text"],

Cell[BoxData[
    \(vf[s_, t_]\  := 
      stb[1] + \((stb[2] Cos[t] + stb[3] Sin[t])\) Cos[s]\  + 
        stb[5] Sin[s]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(vf[s, t]\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(ch[vf[s, t]]\)], "Input",
  CellLabel->"In[38]:="],

Cell["since ch[vf[s,t]]depends on s,t!", "Text"],

Cell[BoxData[
    \(pssp[vf[s, t], vf[s, t]]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(fct[s_]\  = \ Simplify[%]\)], "Input",
  CellLabel->"In[55]:="],

Cell["\<\
Therefore vf[s,t] is spacelike with exception of the solutions of Cos[s]== 0.\
\
\>", "Text"],

Cell[BoxData[
    \(spt[vf[s, t]]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(stepro[vf[s, t]]\)], "Input",
  CellLabel->"In[62]:="],

Cell["\<\
Thus, we obtained a result for all values of t, but it corresponds to  a \
point of a the sphere only for solutions of Cos[s] == 0.\
\>", "Text"],

Cell[BoxData[
    \(Simplify[% . %, s > 0 && t > 0]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(ftest[s_]\  = %\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(Plot[%, \ {s, 0, 2*Pi}]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Plot[ftest[s], \ {s, 0.2, 3}]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(ftest[Pi/2]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(vf[Pi/2, t]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(sterproj[spt[vf[Pi/2, \ t]]]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(invstepro[%]\)], "Input",
  CellLabel->"In[46]:="],

Cell["spt[null[]]", "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(invstepro[null[3]]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(Remove[vf, \ fct, ftest]\)], "Input",
  CellLabel->"In[69]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3 A formula for the scalar products", "Subsection"],

Cell["\<\
As an example for symbolic calculation we derive a formula, which expresses \
the pseudo-euclidean scalar products of the images by investepro of two \
points in terms of the euclidean scalar products of their radius vectors. The \
 points are\
\>", "Text"],

Cell[BoxData[
    \(vx\  = vec[x, 3]; \ vy\  = \ vec[y, 3];\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \({vx, vy} // MatrixForm\)], "Input",
  CellLabel->"In[71]:="],

Cell["The preimages are the rows of the matrix", "Text"],

Cell[BoxData[
    \({invstepro[vx], \ invstepro[vy]}\)], "Input",
  CellLabel->"In[72]:="],

Cell["The preimages  are isotropic:", "Text"],

Cell[BoxData[
    \(Simplify[Together[pssp[%[\([1]\)], %[\([1]\)]]]]\)], "Input",
  CellLabel->"In[73]:="],

Cell["Their pseudo-euclidean scalar product is", "Text"],

Cell[BoxData[
    \(pssp[invstepro[vx], \ invstepro[vy]]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[75]:="],

Cell[BoxData[
    \(Simplify[% /. {x[1]\^2 + x[2]\^2 + x[3]\^2 \[Rule] \ nvx^2, 
          y[1]\^2 + y[2]\^2 + y[3]\^2 \[Rule] nvy^2}]\)], "Input",
  CellLabel->"In[76]:="],

Cell["Therefore, the following formula is true:", "Text"],

Cell[BoxData[
    \(Simplify[
      pssp[invstepro[vx], \ 
          invstepro[
            vy]] \[Equal] \ \(-2\)*\((vx - vy)\) . \((vx - 
                  vy)\)/\((\((1 + vx . vx)\)*\((1 + vy . vy)\))\)]\)], "Input",\

  CellLabel->"In[77]:="],

Cell["\<\
Thus we obtained the wanted formula, which symbolically can be written as\
\>", "Text"],

Cell[BoxData[
    \(\(\(pssp[invstepro[x], invstepro[y]]\)\(\[IndentingNewLine]\)\(==\)\) | 
      x - y | \(\(^\)\(2\)\)/\((\((\(\(1\)\(+\)\) | 
                x | \(\(^\)\(2\)\))\)*\((\(\(1\)\(+\)\) | 
                y | \(\(^\)\(2\)\))\))\)\)], "Input",
  CellLabel->"In[73]:=",
  Evaluatable->False],

Cell[TextData[{
  StyleBox["Remark.",
    FontColor->RGBColor[1, 0, 0]],
  "  The isotropic vector "
}], "Text"],

Cell[BoxData[
    \(invstepro[{x1, x2, x3}]\)], "Input",
  CellLabel->"In[78]:="],

Cell["is a special representant of the corresponding point", "Text"],

Cell[BoxData[
    \(stepro[invstepro[{x1, x2, x3}]]\)], "Input",
  CellLabel->"In[79]:="],

Cell["defined by the condition", "Text"],

Cell[BoxData[
    \(pssp[invstepro[{x1, x2, x3}], \ stb[5]] \[Equal] \ \(-1\)\)], "Input",
  CellLabel->"In[80]:="],

Cell["\<\
Thus, the calculated scalar product does not have any invariant meaning in M\
\[ODoubleDot]bius geometry. In M\[ODoubleDot]bius geometry all pairs of \
(distinct) points are equivalent.\
\>", "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3 Spheres", "Section"],

Cell[TextData[{
  "In this section we  establish the basic bijection between spheres \
(including planes as spheres of infinite radius) of the euclidean 3-space ",
  Cell[BoxData[
      \(TraditionalForm\`E\^3\)]],
  " and one-dimensional euclidean subspaces of the 5-dimensional \
pseudo-euclidean vector space ",
  Cell[BoxData[
      \(TraditionalForm\`V\^5\)]],
  ". Any spacelike vector defines the orthogonal complement of its span, \
being a 4-dimensional pseudo-euclidean subspace, the isotropic vectors of \
which correspond to a sphere contained in the M\[ODoubleDot]bius space ",
  Cell[BoxData[
      \(TraditionalForm\`S\^3\)]],
  ". In the converse direction, the span of the isotropic vectors \
representing the points of such a sphere is a pseudoeuclidean 4-space, \
defining its normal, an euclidean 1-space. "
}], "Text"],

Cell[CellGroupData[{

Cell["\<\
3.1 Spheres through four points and corresponding spacelike vectors: vradius, \
vcenter, sphereplot3D\
\>", "Subsection"],

Cell[CellGroupData[{

Cell["\<\
The definitions of the spacelike vector functions sph4ptsvec, spherevec\
\>", "Subsubsection"],

Cell[TextData[{
  "Given  four points ofthe euclideanspace ",
  Cell[BoxData[
      \(TraditionalForm\`E\^3\)]],
  "in general position (i.e.  not belonging to a circle or a line). By the \
pseudo-eucldean inverse stereographical projection invstepro we obtain the \
corresponding isotropic vecors, whose span must be a pseuo-euclidean 4-space. \
Therefore their cross product pscross yields a spacelike vector orthogonal to \
the isotropic vectors, saying vec[nn]. Then the family of vectors satisfying \
the equations  "
}], "Text"],

Cell[BoxData[
    \(pssp[vec[x], vec[x]] \[Equal] \ 0\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(pssp[vec[x], vec[nn]] \[Equal] \ 0\)], "Input",
  CellLabel->"In[9]:="],

Cell["\<\
are representing the sphere through the four points: to get the sphere one \
has to apply stepro on the solution.\
\>", "Text"],

Cell["\<\
The following Module yields an unnormed spacelike vector which we want to \
find:\
\>", "Text"],

Cell[BoxData[
    \(\(?sph4ptsvec\)\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(\(\(sph4ptsvec[p1_List, p2_List, p3_List, 
        p4_List]\)\(:=\)\(Module[{v = null[5]}, 
        If[Length[p1] \[NotEqual] 3 || Length[p2] \[NotEqual] 3 || 
            Length[p3] \[NotEqual] 3 || Length[p4] \[NotEqual] 3, 
          Print["\<An argument does not have the correct
dimension!\>"] Return[]]; \ \tv = 
          Simplify[
            pscross[{invstepro[p1], invstepro[p2], invstepro[p3], 
                invstepro[p4]}]]; \[IndentingNewLine]If[v === null[5], 
          Print["\<The points are not in general
position!\>"]; Return[], Return[v], Return[v]]]\)\(\t\)\)\)], "Input",
  CellLabel->"In[14]:=",
  Evaluatable->False],

Cell[TextData[{
  "Now, given a sphere with center{x,y,z} and radius r in ",
  Cell[BoxData[
      \(TraditionalForm\`E\^3\)]],
  ", we choose four of its points, and apply the procedure sph4ptsvec. We \
obtain after some simplifications (see below) the formula"
}], "Text"],

Cell[BoxData[
    \(\(?spherevec\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(vn\  = spherevec[x, y, z, r]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(Simplify[pssp[vn, vn]]\)], "Input",
  CellLabel->"In[77]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples, applications", "Subsubsection"],

Cell[BoxData[
    \(\(?euklidsphereplot3D\)\)], "Input",
  CellLabel->"In[10]:="],

Cell["\<\
We use euklidsphereplot3D to plot the corresponding sphere or plane. For a \
detailed discussion see subsection 3.3. 
Here we get the standard unit sphere:\
\>", "Text"],

Cell[BoxData[
    \(sph4ptsvec[stb[1, 3], \ stb[2, 3], \ 
      stb[3, 3], \ \(-stb[3, 3]\)]\)], "Input",
  CellLabel->"In[8]:="],

Cell["The resulting sphere is the standard unit sphere:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[%]\)], "Input",
  CellLabel->"In[9]:="],

Cell["\<\
In M\[ODoubleDot]bius geometry, planes appear as stereographical projections \
of spheres through the pole; sph4ptsvec includes this case:\
\>", "Text"],

Cell[BoxData[
    \(sph4ptsvec[null[3], \ stb[2, 3], \ \(-stb[2, 3]\), \ 
      stb[3, 3]]\)], "Input",
  CellLabel->"In[10]:="],

Cell["The resulting \"sphere\" is the y,z-plane:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[%]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(sph4ptsvec[stb[1, 3], \ \(-stb[1, 3]\), \ 
      stb[2, 3], \ \(-2\) stb[2, 3]]\)], "Input",
  CellLabel->"In[12]:="],

Cell["\<\
If the four points ly on a circle, one gets a corresponding message:\
\>", "Text"],

Cell[BoxData[
    \(sph4ptsvec[stb[1, 3], \ \(-stb[1, 3]\), \ 
      stb[2, 3], \ \(-stb[2, 3]\)]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({invstepro[stb[1, 3]], \ invstepro[\(-stb[1, 3]\)], 
      invstepro[\ stb[2, 3]], \ invstepro[\(-stb[2, 3]\)]}\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(pscross[%]\)], "Input",
  CellLabel->"In[16]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
The spacelike vector  as a funtion of center and radius of the sphere: \
spherevec\
\>", "Subsubsection"],

Cell["\<\
We demonstrate the developing of the procedure spherevec mentioned above. \
This is the spacelike vector corresponding to the sphere with center \
{x,y,z}and radius r:\
\>", "Text"],

Cell[BoxData[
    \(sph4ptsvec[{x, y, z} + r*stb[1, 3], {x, y, z} - 
        r*stb[1, 3], \n\t\t{x, y, z} + r*stb[2, 3], \ {x, y, z} + 
        r*stb[3, 3]]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(%*\((1 + r\^2 - 2\ r\ x + x\^2 + y\^2 + z\^2)\)\ \((1 + r\^2 + 
          2\ r\ x + x\^2 + y\^2 + z\^2)\)\ \((1 + r\^2 + x\^2 + 2\ r\ y + 
          y\^2 + z\^2)\)\ \((1 + r\^2 + x\^2 + y\^2 + 2\ r\ z + 
          z\^2)\)\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(%/\((16  r^3)\)\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(Simplify[
      pssp[{2\ x, 2\ y, 2\ z, \(-1\) - r\^2 + x\^2 + y\^2 + z\^2, 
          1 - r\^2 + x\^2 + y\^2 + z\^2}, \ \n\t\t{2\ x, 2\ y, 
          2\ z, \(-1\) - r\^2 + x\^2 + y\^2 + z\^2, 
          1 - r\^2 + x\^2 + y\^2 + z\^2}]]\)], "Input",
  CellLabel->"In[20]:="],

Cell["\<\
Norming the obtained vector we  defined in the package mspher.m\
\>", "Text"],

Cell[BoxData[
    \(spherevec[x_, y_, z_, 
        r_]\  := \ {2\ x, 2\ y, 2\ z, \(-1\) - r\^2 + x\^2 + y\^2 + z\^2, \ 
          1 - r\^2 + x\^2 + y\^2 + z\^2}/\((2*r)\)\)], "Input",
  CellLabel->"In[15]:=",
  Evaluatable->False],

Cell[BoxData[
    \(spherevec[x, y, z, r]\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(Simplify[
      pssp[spherevec[x, y, z, r], \ spherevec[x, y, z, r]]]\)], "Input",
  CellLabel->"In[22]:="],

Cell["Example: the sphere with centre (0,0,10), and radius 2:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[spherevec[0, 0, 10, 2]]\)], "Input",
  CellLabel->"In[9]:="],

Cell["Here one gets error messages:", "Text"],

Cell[BoxData[
    \(spherevec[0, 0, 1, 0]\)], "Input",
  CellLabel->"In[24]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Inversion of spherevec, and an euclidean definition of the sphere \
corresponding to a spacelike vector\
\>", "Subsubsection"],

Cell["From the formula", "Text"],

Cell[BoxData[
    \(vn\  = spherevec[x, y, z, r]\)], "Input",
  CellLabel->"In[33]:="],

Cell["we conclude", "Text"],

Cell[BoxData[
    \(Simplify[Together[vn[\([5]\)] - \ vn[\([4]\)]]]\)], "Input",
  CellLabel->"In[34]:="],

Cell["\<\
LEMMA. The sphere corresponding to the spacelike vector vn is a plane if and \
only if one has vn[[4]] = vn[[5]].
Proof: The relation between spheres (including planes) and one-dimensional \
euclidean subspaces of the 5-dimensional pseudo-euclidean space is bijective. \
Since the north pole of the 3-sphere corresponds to the isotropic vector \
stb[4]+stb[5], \
\>", "Text"],

Cell[BoxData[
    \(\(?stepro\)\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(stepro[stb[4] + stb[5]]\)], "Input",
  CellLabel->"In[39]:="],

Cell["our condition is equivalent to", "Text"],

Cell[BoxData[
    \(pssp[stb[4]\  + \ stb[5], \ vec[v]] \[Equal] \ 0\)], "Input",
  CellLabel->"In[40]:="],

Cell["\<\
COROLLARY. The euclidean sphere which corresponds to the spacelike unit  \
vector \
\>", "Text"],

Cell[BoxData[
    \(vec[v]\)], "Input",
  CellLabel->"In[41]:="],

Cell["\<\
with v[4] \[NotEqual] v[5]  is the sphere with center {x, y, z}, where \
\>", "Text"],

Cell[BoxData[
    \(x\  = \ v[1]/\((v[5] - v[4])\); y\  = \ v[2]/\((v[5] - v[4])\); 
    z\  = \ v[3]/\((v[5] - v[4])\);\)], "Input",
  CellLabel->"In[42]:="],

Cell["and radius", "Text"],

Cell[BoxData[
    \(\(r\  = \ 1/\((v[5] - v[4])\);\)\)], "Input",
  CellLabel->"In[43]:="],

Cell["\<\
Remember that vn is normed: pssp[vn,vn] ==1. Thus we conclude for radius and \
center of the sphere corresponding to the spacelike unit vector v:\
\>", "Text"],

Cell[BoxData[
    \(vradius[wx_List]\  := \ 
      Module[{s, q, \ vx}, \[IndentingNewLine]q\  = \ 
            pssp[wx, wx]; \[IndentingNewLine]If[q \[LessEqual] \ 0, 
            Print[wx, \ "\< is not spacelike!\>"]; 
            Return[]]; \[IndentingNewLine]vx\  = \ 
            wx/Sqrt[q]; \[IndentingNewLine]s = 
            vx[\([5]\)] - \ vx[\([4]\)]; \[IndentingNewLine]If[
            s \[Equal] 0, \ Return[Infinity], Return[1/s], Return[1/s]]] /; 
        Length[wx]\  \[Equal] \ 5\)], "Input",
  CellLabel->"In[44]:=",
  Evaluatable->False],

Cell[BoxData[
    \(vcenter[vx_List]\  := \ 
      Module[{s}, \[IndentingNewLine]If[pssp[vx, vx] \[LessEqual] \ 0, 
            Print[vx, \ "\< is not spacelike!\>"]; 
            Return[]]; \[IndentingNewLine]s = 
            vx[\([5]\)] - \ vx[\([4]\)]; \[IndentingNewLine]If[
            s \[Equal] 0, \ Return[{Infinity, Infinity, Infinity}]]; 
          Return[{vx[\([1]\)]/s, vx[\([2]\)]/s, vx[\([3]\)]/s}]] /; 
        Length[vx] \[Equal] 5\)], "Input",
  CellLabel->"In[28]:=",
  Evaluatable->False],

Cell["\<\
WARNINGS!
1. These definitions make sense for spacelike vectors only!\
\>", "Text"],

Cell[BoxData[
    \(vcenter[{1, 0, 0, 1, 3}]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(vradius[null[]]\)], "Input",
  CellLabel->"In[45]:="],

Cell["\<\
2. If the corresponding sphere is a plane  center and radius will become \
infinite,  e.g.\
\>", "Text"],

Cell[BoxData[
    \(vcenter[stb[1]]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(vradius[{1, 0, 0, 1, 1}]\)], "Input",
  CellLabel->"In[48]:="],

Cell["This case is treated in the next subsection. ", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Orientation", "Subsubsection"],

Cell["A negative radius yields the negatively oriented sphere.", "Text"],

Cell[BoxData[
    \(Clear[x, y, z, r]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(spherevec[x, y, z, r]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(vradius[%]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(spherevec[\(-x\), \(-y\), \(-z\), \(-r\)]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(FullSimplify[vradius[%]]\)], "Input",
  CellLabel->"In[63]:="],

Cell["\<\
For v[[4]] > v[[5]] the radius of the sphere becomes negative. Changing the \
sign of v one may always reach r > 0; the center is independent of the sign: \
\
\>", "Text"],

Cell[BoxData[
    \(FullSimplify[vcenter[spherevec[x, y, z, \(-r\)]]]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(FullSimplify[vcenter[vec[a]]]\)], "Input",
  CellLabel->"In[61]:="],

Cell[TextData[{
  " The sign of the radius can be interpreted as the orientation of the \
sphere. If one considers the sphere corresponding to v as subsphere of ",
  Cell[BoxData[
      \(TraditionalForm\`S\^3\)]],
  " (that means: not carrying out the stereographic projection), the sphere \
divides the 3-sphere into two disks: the inner and the outer disk. Let us \
define the inner disks as the set of all points (= isotropic 1-spaces) w of \
the 3-sphere  ",
  Cell[BoxData[
      \(TraditionalForm\`S\^3\)]],
  " with pssp[v,w] < 0. Then changing the sign of v means permuting inner and \
outer disk. It follows that the spacelike unit vectors correspond bijectively \
to the oriented subspheres of  ",
  Cell[BoxData[
      \(TraditionalForm\`S\^3\)]],
  ". "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Parameter representation of the sphere corresponding to a spacelike unit \
vector\
\>", "Subsubsection"],

Cell["\<\
Applying the standard euclidean parameter representation of a sphere ( see \
the notebook eusphere.nb) we get immediately the parameter representation of \
the sphere corresponding to the spacelike unit vector  v:\
\>", "Text"],

Cell[BoxData[
    \(\(?sphere\)\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(Simplify[\(sphere[vcenter[vn], vradius[vn]]\)[u, v]]\)], "Input",
  CellLabel->"In[67]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Some examples", "Subsubsection"],

Cell[BoxData[
    \(vradius[{1, 0, 0, 2, 1}]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(vradius[stb[4]*5]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(vcenter[stb[4]*5]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(\(?sphereplot3D\)\)], "Input",
  CellLabel->"In[72]:="],

Cell["This is the standard unit sphere with center in the origin:", "Text"],

Cell[BoxData[
    \(sphereplot3D[vcenter[stb[4]], \ vradius[stb[4]]]\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(Table[
      sphereplot3D[vcenter[{0, 0, 0, Sqrt[1 + j^2], \ j}], \ 
        vradius[{0, 0, 0, Sqrt[1 + j^2], \ j}], \ Pi, \ 2*Pi, \(-Pi\)/2, 
        Pi/2], {j, 0, 4}]\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[75]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2 Planes", "Subsection"],

Cell["\<\
Before constructing  modules which yield the sphere or plane corresponding to \
a spacelike vector v we find the spacelike vector corresponding to a plane of \
the euclidean 3-space.\
\>", "Text"],

Cell[CellGroupData[{

Cell["The definition planevec", "Subsubsection"],

Cell[BoxData[
    \(\(?planevec\)\)], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
The following Module defined in mspher.m yields an unnormed spacelike vector \
which defines the plane, fulfilling the equation w.x==p:\
\>", "Text"],

Cell[BoxData[
    \(planev[w_List, \ p_]\  := \ 
      Module[{v1, v2, v3, u4\  = stb[4] + stb[5], \n\t\tu1, u2, u3}, \n\t\tIf[
          Length[w] != 3 || \ w\  === null[3], \n\t\t\tPrint[
            w, \ "\< is not a normal vector!\>"]; Return[]]; \n\t\tv1 = 
          w*p/w . w; \n\t\tIf[w[\([1]\)] === 0, 
          v2\  = v1 + stb[1, 3]; \n\t\t\tIf[w[\([2]\)] === \ 0, \ 
            v3\  = \ v1\  + \ stb[2, 3], 
            v3\  = {0, \ p/w[\([2]\)], 
                0}], \n\t\t\tv2\  = \ {p/w[\([1]\)]\  - \ 
                w[\([2]\)]/w[\([1]\)], 1, 
              0}; \n\t\t\tv3\  = \ {p/w[\([1]\)]\  - \ w[\([3]\)]/w[\([1]\)], 
              0, 1}]; \n\t\tu1 = \ invstepro[v1]; \n\t\tu2 = \ 
          invstepro[v2]; \n\t\tu3 = \ invstepro[v3]; \n
        pscross[{u1, u2, u3, u4}]]\)], "Input",
  CellLabel->"In[7]:="],

Cell["The general evaluation with succeeding simplification", "Text"],

Cell[BoxData[
    \(Simplify[planev[{x, y, z}, h]]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(%*\((\((h^2\  + \ 2*x^2\  - \ 2*h*y\  + \ y^2)\)*\((h^2\  + \ x^2\  + \ 
              y^2\  + \ z^2)\)*\n\ \ \ \ \ \ \ \((h^2\  + \ 2*x^2\  - \ 
              2*h*z\  + \ z^2)\))\)\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(%/\((\((8*x^3)\)*\((\(-x^2\) - y^2 - z^2 + 
              h*\((y + z)\))\))\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
finally leads to the following definition, contained in the package mspher.m:\
\
\>", "Text"],

Cell[BoxData[
    \(planevec[a_, b_, c_, \ p_]\  := \ 
      If[Not[a^2 + b^2 + c^2 === 0], \n\tReturn[{a, \ b, \ c, \ p, \ p}], 
        Print["\<Normal vector null is not admissible!\>"]; 
        Return[]]\)], "Input",
  CellLabel->"In[84]:=",
  Evaluatable->False],

Cell[BoxData[
    \(planevec[a, b, c, p]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(planevec[0, 0, 0, p]\)], "Input",
  CellLabel->"In[13]:="],

Cell["Clearly, if we norm planevec[a,b,c,p] by ", "Text"],

Cell[BoxData[
    \(dotnorme[{a, b, c}]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({a, b, c} . {a, b, c} \[Equal] \ 1\)], "Input",
  CellLabel->"In[15]:="],

Cell["or, what means the same,", "Text"],

Cell[BoxData[
    \(normalize[{a, b, c, p, p}]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(pssp[{a, b, c, p, p}, {a, b, c, p, p}]\  \[Equal] 1\)], "Input",
  CellLabel->"In[17]:="],

Cell["\<\
we have a bijection between the manifold of all oriented planes of the \
euclidean 3-space and the manifold of all spacelike unit vectors v with the \
property v[[4]]==v[[5]]. Usually one names an equation n.x == p with normed \
3-vector n the Hesse normal form of the plane equation. The following module \
yields a parameter representation of the plane with this normal form, which \
we translate into the 5-vector vc = {a,b,c,p,p}:\
\>", "Text"],

Cell[BoxData[
    \(Clear[plane]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(\(plane[vc_List]\)[u_, v_]\  := \ 
      Module[{q, p, w, ob}, \[IndentingNewLine]q = 
          pssp[vc, vc]; \[IndentingNewLine]If[
          q \[LessEqual] 0 || \ vc[\([4]\)] \[NotEqual] \ vc[\([5]\)], 
          Print[vc, \ "\< incorrect argument!\>"]; 
          Return[]]; \ \[IndentingNewLine]w = 
          vc/Sqrt[q]; \[IndentingNewLine]p\  = \ 
          w[\([5]\)]; \[IndentingNewLine]w\  = \ 
          Take[w, 3]; \[IndentingNewLine]ob\  = \ 
          orthocomplement[{w}]; \[IndentingNewLine]\ \ \ \ \ AppendTo[ob, \ 
          w]; \[IndentingNewLine]Return[
          ob[\([3]\)]*p\  + \ ob[\([1]\)]*u\  + \ ob[\([2]\)]*v]]\)], "Input",\

  CellLabel->"In[6]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection"],

Cell[BoxData[
    \(\(\(\ \)\(nx = planevec[1, 1, 1, 1]\)\)\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(pssp[nx, nx]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(\(plane[nx]\)[u, v]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(ParametricPlot3D[%, \ {u, \ \(-3\), 3}, \ {v, \ \(-3\), 3}]\)], "Input",\

  CellLabel->"In[55]:="],

Cell[BoxData[
    \(nx\  = planevec[0, 0, 1, 0]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(\(plane[%]\)[u, v]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(ParametricPlot3D[%, \ {u, \ \(-3\), 3}, \ {v, \ \(-3\), 3}]\)], "Input",\

  CellLabel->"In[58]:="],

Cell["Next we construct random planes:", "Text"],

Cell[BoxData[
    \(nx\  = \ randomv[4]\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \(AppendTo[nx, nx[\([4]\)]]\)], "Input",
  CellLabel->"In[89]:="],

Cell["Clearly, this vector must be spacelike with probability 1.", "Text"],

Cell[BoxData[
    \(\(plane[%]\)[u, v]\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \(ParametricPlot3D[%, \ {u, \ \(-3\), 3}, \ {v, \ \(-3\), 3}]\)], "Input",\

  CellLabel->"In[91]:="],

Cell[BoxData[
    \(Clear[nx]\)], "Input",
  CellLabel->"In[92]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The plane through three points", "Subsubsection"],

Cell["\<\
Through three points in general position there exists exactly one plan in the \
euclidean 3-space. The following Module gives a spacelike 5-vector \
corresponding to this plane:\
\>", "Text"],

Cell[BoxData[
    \(spvplane3pts[p1_List, p2_List, p3_List] := \ 
      Module[{q1, q2, q3, vq, \ wrong}, \[IndentingNewLine]If[
          Not[Length[p1] \[Equal] 3 && Length[p2] \[Equal] 3 && 
              Length[p3] \[Equal] 3], \ 
          Goto[wrong]]; \[IndentingNewLine]q1\  = \ invstepro[p1]; 
        q2 = \ invstepro[p2]; 
        q3\  = \ invstepro[p3]; \[IndentingNewLine]vq\  = \ 
          pscross[{q1, q2, q3, stb[4] + stb[5]}]; \[IndentingNewLine]If[
          vq\  \[Equal] \ null[5], \ Goto[wrong], Return[vq], 
          Return[vq]]; \[IndentingNewLine]Label[
          wrong]; \[IndentingNewLine]Print["\<Incorrect arguments, or points \
not in general position!.\>"]; \[IndentingNewLine]Return[]]\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(spvplane3pts[null[3], \ stb[1, 3], \ \(-stb[1, 3]\)]\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(spvplane3pts[null[3], \ stb[1, 3], \ stb[2, 3]]\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(\(plane[%]\)[u, v]\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \(ParametricPlot3D[%, \ {u, \ \(-3\), 3}, \ {v, \ \(-3\), 3}]\)], "Input",\

  CellLabel->"In[97]:="],

Cell[BoxData[
    \(spvplane3pts[stb[3, 3], \ stb[1, 3], \ stb[2, 3]]\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(\(plane[%]\)[u, v]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(ParametricPlot3D[%, \ {u, \ \(-3\), 3}, \ {v, \ \(-3\), 3}]\)], "Input",\

  CellLabel->"In[100]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Planes through three random points", "Subsubsection"],

Cell["\<\
This is a random point in the unit cube of the euclidean 3-space:\
\>", "Text"],

Cell[BoxData[
    \(randomv[3]\)], "Input",
  CellLabel->"In[305]:="],

Cell["\<\
A random plane as the plane through three random points of the unit cube:\
\>", "Text"],

Cell[BoxData[
    \(pts\  = \ {randomv[3], randomv[3], randomv[3]}\)], "Input",
  CellLabel->"In[306]:="],

Cell[BoxData[
    \(spvplane3pts[pts[\([1]\)], \ pts[\([2]\)], \ pts[\([3]\)]]\)], "Input",
  CellLabel->"In[307]:="],

Cell[BoxData[
    \(\(plane[%]\)[u, v]\)], "Input",
  CellLabel->"In[308]:="],

Cell[BoxData[
    \(ParametricPlot3D[%, \ {u, \ \(-3\), 3}, \ {v, \ \(-3\), 3}]\)], "Input",\

  CellLabel->"In[309]:="],

Cell[BoxData[
    \(gpl\  = \ %\)], "Input",
  CellLabel->"In[310]:="],

Cell[BoxData[
    \(Map[Point, pts]\)], "Input",
  CellLabel->"In[311]:="],

Cell[BoxData[
    \(Show[Graphics3D[{PointSize[0.05], %}]]\)], "Input",
  CellLabel->"In[312]:="],

Cell[BoxData[
    \(gpts\  = \ %\)], "Input",
  CellLabel->"In[313]:="],

Cell[BoxData[
    \(Show[{gpts, gpl}]\)], "Input",
  CellLabel->"In[314]:="],

Cell[BoxData[
    \(Remove[pts, gpl, gpts]\)], "Input",
  CellLabel->"In[316]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3 The sphere or plane corresponding to a spacelike vector", \
"Subsection"],

Cell["\<\
In this section we join the results of the two foregoing sections: We \
construct a procedure, which gives the parameter representation of the sphere \
or plane corresponding to a spacelike vector, and apply it in a plot command.\
\
\>", "Text"],

Cell[CellGroupData[{

Cell["The definition of the parameter representation euklidsphere", \
"Subsubsection"],

Cell[BoxData[
    \(\(?euklidsphere\)\)], "Input",
  CellLabel->"In[322]:="],

Cell[BoxData[
    \(\(euklidsphere[va_List]\)[u_, v_] := 
      Module[{q}, 
          q = pssp[va, va]; \[IndentingNewLine]If[q \[LessEqual] 0, 
            Print[va, "\< is not spacelike!\>"]; 
            Return[]]; \[IndentingNewLine]w = 
            va/Sqrt[q]; \[IndentingNewLine]If[w[\([4]\)] \[Equal] w[\([5]\)], 
            Goto[pla]]; \[IndentingNewLine]Return[\(sphere[vcenter[w], 
                vradius[w]]\)[u*Pi, v*Pi/2]]; \[IndentingNewLine]Label[
            pla]; \[IndentingNewLine]p = w[\([5]\)]; \[IndentingNewLine]w = 
            Take[w, 3]; \[IndentingNewLine]ob = 
            orthocomplement[{w}]; \[IndentingNewLine]AppendTo[ob, 
            w]; \[IndentingNewLine]Return[
            ob[\([3]\)]*p + ob[\([1]\)]*u + ob[\([2]\)]*v]] /; 
        Length[va] \[Equal] 5\)], "Input",
  CellLabel->"In[57]:=",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection"],

Cell[BoxData[
    \(\(euklidsphere[stb[5]]\)[u, v]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(\(euklidsphere[stb[4]]\)[u, v]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(\(euklidsphere[stb[1]]\)[u, v]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(euklidsphere[stb[2]]\)[u, v]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(\(euklidsphere[stb[3]]\)[u, v]\)], "Input",
  CellLabel->"In[12]:="],

Cell["\<\
Evaluate repeated the following cell; \"almost surely\" you will get a random \
halfsphere.\
\>", "Text"],

Cell[BoxData[
    \(vrand\  = \ randomv[5]; 
    ParametricPlot3D[\(euklidsphere[vrand]\)[u, v], \ {u, \(-1\), 1}, {v, \ 
        0, \ 1}]\)], "Input",
  CellLabel->"In[13]:="],

Cell["\<\
Clearly, the probability for vrand[4] = vrand[5] is zero, therefore planes do \
happen with probability zero. Furthermore remember, that the probability for \
a random vector in the 5-dimensional unit cube to be not spacelike, is small; \
therefore the probability of error messages is small. Indeed, as already \
shown in the notebook pseuklid.nb, we have for the empirical probability \
nearly 6 %.\
\>", "Text"],

Cell[BoxData[
    \(\((\ nr\  = \ 0; \ 
      For[i\  = \ 1, \ i \[LessEqual] \ 10000, \(i++\), 
        If[ch[randomv[5]] < \ 1, \ nr\  = \ nr + 1]]; \ 
      nr/10000)\)\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(Remove[nr, vrand]\)], "Input",
  CellLabel->"In[16]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[" euklidsphereplot3D and plotsphere", "Subsubsection"],

Cell["\<\
Now it is easy to build the plot command for euklidsphere, contained in \
mspher.m:\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[vn_List, u0_: - 1, u1_:  1, \ v0_: - 1, v1_:  1, 
        opts___] := 
      ParametricPlot3D[
        Evaluate[\(euklidsphere[vn]\)[u, v]], {u, u0, u1}, \ {v, v0, v1}, 
        opts]\)], "Input",
  CellLabel->"In[69]:=",
  Evaluatable->False],

Cell["\<\
The package mspher.m contains a similar procedure plotsphere:\
\>", "Text"],

Cell[BoxData[
    \(\(?plotsphere\)\)], "Input",
  CellLabel->"In[17]:="],

Cell["\<\
Now we test euklidsphereplot3D  and compare it with plotsphere.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4 Examples, comparision", "Subsection"],

Cell[CellGroupData[{

Cell["Example: equidistant unit spheres", "Subsubsection"],

Cell[BoxData[
    \(Timing[
      Table[plotsphere[spherevec[x, 0, 0, 1]], \ {x, \ 0, \ 12, \ 
          3}]]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(Timing[
      Table[euklidsphereplot3D[spherevec[x, 0, 0, 1]], \ {x, \ 0, \ 12, \ 
          3}]]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(grser\  = %\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(ThreeScript["\<spherser.ts\>", grser]\)], "Input",
  CellLabel->"In[115]:=",
  PageWidth->Infinity],

Cell["\<\
With plotsphere 3.32 s, and with euklidsphereplot3D 0.36 s have been needed. \
There is yet another difference: with euklidsphereplot3D the geographical \
coordinates are defined with respect to the fixed orthonormed standard frame, \
and with plotsphere the coordinates depend on the considered sphere. \
Furthermore, since in the definition of plotsphere we used the \
stereographical projection, and in euklidsphereplot3D not, the coordinates \
and the representations generated by plotsphere are often distorted.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: The spacelike frame vectors", "Subsubsection"],

Cell[BoxData[
    \(Timing[Table[plotsphere[stb[i]], \ {i, 4}]]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(Timing[Table[euklidsphereplot3D[stb[i]], \ {i, 4}]]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(\(?sphv\)\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(Timing[
      Table[plotsphere[sphv[2  t, t/2]], \ {t, \ 0.5, \ 9.5, \ 
          3}]]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(Show[%[\([2]\)], \ PlotRange\  -> \ All]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(grser2 = %\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(ThreeScript["\<spherse2.ts\>", grser2]\)], "Input",
  CellLabel->"In[80]:=",
  PageWidth->Infinity],

Cell[BoxData[
    \(Timing[
      Table[euklidsphereplot3D[sphv[2  t, t/2]], \ {t, \ 0.5, \ 9.5, \ 
          3}]]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[21]:="],

Cell["\<\
We define a function which constructs a certain monotone sequence from a \
given sequence of positive numbers:\
\>", "Text"],

Cell[BoxData[
    \(ms[rs_List]\  := \ 
      Table[2*Sum[rs[\([j]\)], {j, 1, \ i - 1}] + \ rs[\([i]\)], \ {i, 1, 
          Length[rs]}]\)], "Input",
  CellLabel->"In[22]:="],

Cell["Here is a random  sequence of positive real numbers:", "Text"],

Cell[BoxData[
    \(rd\  = \ randomv[]\)], "Input",
  CellLabel->"In[23]:="],

Cell["\<\
Now we obtain a sequence of spheres with random radii rd less than 1 and \
centers on the x-axis in such a way that to consecutive spheres are tangent \
to each other; the sequence ms[rd] defines the centers of the spheres.\
\>", "Text"],

Cell[BoxData[
    \(ms[rd]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(Timing[
      Table[plotsphere[sphv[\(ms[rd]\)[\([i]\)], rd[\([i]\)]]], \ {i, 1, 
          5}]]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(Timing[
      Table[euklidsphereplot3D[sphv[\(ms[rd]\)[\([i]\)], rd[\([i]\)]]], \ {i, 
          1, 5}]]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(Timing[plotsphere[stb[1]*Cos[Pi/5]\  + \ stb[4]*Sin[Pi/5]]]\)], "Input",\

  CellLabel->"In[29]:="],

Cell[BoxData[
    \(Timing[
      euklidsphereplot3D[stb[1]*Cos[Pi/5]\  + \ stb[4]*Sin[Pi/5]]]\)], "Input",\

  CellLabel->"In[30]:="],

Cell[BoxData[
    \(Timing[
      Table[plotsphere[
          stb[1]*Cos[i*Pi/5]\  + \ stb[4]*Sin[i*Pi/5]], \n\t{i, \ 1, \ 
          5}]]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(Timing[
      Table[euklidsphereplot3D[
          stb[1]*Cos[i*Pi/5]\  + \ stb[4]*Sin[i*Pi/5]], \n\t{i, \ 1, \ 
          5}]]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[34]:="],

Cell["\<\
Here we obtain some exemplars of the bundle of planes containing the \
y-axis:\
\>", "Text"],

Cell[BoxData[
    \(Timing[
      Table[plotsphere[
          stb[1]*Cos[i*Pi/5]\  + \ stb[3]*Sin[i*Pi/5]], \n\t{i, \ 1, \ 
          5}]]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(Timing[
      Table[euklidsphereplot3D[
          stb[1]*Cos[i*Pi/5]\  + \ stb[3]*Sin[i*Pi/5]], \n\t{i, \ 1, \ 
          5}]]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(Show[%[\([2]\)]]\)], "Input",
  CellLabel->"In[38]:="],

Cell["\<\
euklidsphereplot3D is essentially faster than plotsphere, and gives nicer \
pictures!\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Evaluation problems: Floating point numbers", "Subsubsection"],

Cell["\<\
WARNING!
By numerical reasons, the results may be distorted, or completely false. E.g. \
we met the following situation\
\>", "Text"],

Cell[BoxData[
    \(vd[t_]\  := \ stb[1]*Cosh[t]\  + stb[5]*Sinh[t]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(\(euklidsphere[vd[t]]\)[u, v]\)], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \(Timing[
      Table[euklidsphereplot3D[vd[t*\((2*Pi)\)]], \ {t, 0.1, 4.1, 
          0.5}]]\)], "Input",
  CellLabel->"In[102]:="],

Cell["\<\
The reason is that  the vectors seem to be isotropic; they are very near to \
the asymptotic (isotropic) cone. \
\>", "Text"],

Cell[TextData[{
  "Besides of this, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not know the simplest trigonometric rules:"
}], "Text"],

Cell["Cosh[6*Pi]^2 - Sinh[6*Pi]^2", "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[47]:="],

Cell["TrueQ[Cosh[6*Pi]^2 - Sinh[6*Pi]^2 == 1]", "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \($MaxExtraPrecision\  = \ 500\)], "Input",
  CellLabel->"In[89]:="],

Cell["TrueQ[Cosh[6*Pi]^2 - Sinh[6*Pi]^2 == 1]", "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \(Cosh[6*Pi]^2 - Sinh[6*Pi]^2 \[Equal] 1\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(Cosh[6. *Pi]^2 - Sinh[6. *Pi]^2 \[Equal] 1\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(TrueQ[Cosh[x]\^2 - Sinh[x]\^2 \[Equal] 1]\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(Cosh[x]\^2 - Sinh[x]\^2 \[Equal] 1\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(TrueQ[Cos[x]\^2 + \ Sin[x]\^2 \[Equal] 1]\)], "Input",
  CellLabel->"In[95]:="],

Cell["Using Simplify the equations become True:", "Text"],

Cell[BoxData[
    \(TrueQ[Simplify[Cosh[x]\^2 - Sinh[x]\^2] \[Equal] 1]\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \(TrueQ[Simplify[Cos[x]\^2 + \ Sin[x]\^2] \[Equal] 1]\)], "Input",
  CellLabel->"In[97]:="],

Cell["\<\
Conclusion: It is often better introducing more Simplify's in the procedures.
But then it may happen that the evaluation needs much more time. In our case \
it doesn't help, since simplifying a plot makes no sense:\
\>", "Text"],

Cell[BoxData[
    \(Timing[
      Table[Simplify[euklidsphereplot3D[vd[t*\((2*Pi)\)]]], \ {t, 0, 4, 
          0.5}]]\)], "Input",
  CellLabel->"In[54]:="],

Cell["\<\
Simplifying the function, and then applying ParametrcPlot3D helps: \
\>", "Text"],

Cell[BoxData[
    \(\(euklidsphere[vd[t]]\)[u, v]\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(Simplify[%, \ t > 0]\)], "Input",
  CellLabel->"In[108]:="],

Cell[BoxData[
    \(Timing[
      Table[ParametricPlot3D[%, {u, 0, 2}, \ {v, \(-1\), 1}], \ {t, 0.1, 4.1, 
          0.5}]]\)], "Input",
  CellLabel->"In[109]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[" 3.5 The manifold of all spheres, random spheres", "Subsection"],

Cell[CellGroupData[{

Cell["The sphere manifold", "Subsubsection"],

Cell["\<\
Any (non oriented) sphere is represented by a pseudo-euclidean subspace of \
dimension 4; the manifold of all spheres is the open orbit of \
pseudo-euclidean 4-spaces under the action of the M\[ODoubleDot]bius group.  \
Going to the orthogonal complements one finds that the spacelike \
unit-hypersphere, the hyper-hyperboloid\
\>", "Text"],

Cell[TextData[{
  "pssp[x,x]=",
  Cell[BoxData[
      \(x[1]\^2 + x[2]\^2 + x[3]\^2 + x[4]\^2 - x[5]\^2\)]],
  "= 1\t\t(H)"
}], "Text",
  TextAlignment->Center],

Cell["\<\
is a twofold covering of the manifold of all non-oriented spheres. We \
immediately can write down a parameter representation of this hypersurface \
calculating\
\>", "Text"],

Cell[BoxData[
    \(Append[\(unit[3]\)[{s, \ t, \ u}], \ 0]*Cosh[v]\  + \ 
      stb[5]*Sinh[v]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(?unit\)\)], "Input",
  CellLabel->"In[11]:="],

Cell["This prameter representation is defined in mspher.m:", "Text"],

Cell[BoxData[
    \(spunit[s, t, u, v]\)], "Input",
  CellLabel->"In[12]:="],

Cell["\<\
Here we used unit[3][{s,t,u}], the parameter representation of the unit \
3-sphere in the 4-dimensional euclidean subspace orthogonal to stb[5], see \
euvec.m, or eusphere.nb. Obviously, spunit can be generalized easily to \
arbitrary dimension.\
\>", "Text"],

Cell[BoxData[
    \(% \[Equal] \ \(spunit[4]\)[{s, t, u, v}]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(\(?spunit\)\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(\(spunit[2]\)[{s, t}]\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(\(spunit[5]\)[{s, t, u, v, w}]\)], "Input",
  CellLabel->"In[16]:="],

Cell["\<\
Now we may apply  the euklidsphere functions of  section 3.3 to  \
spunit[s,t,u,v], and obtain a parameter representation or plot of the \
corresponding sphere. In an old version of this notebook we started with the \
now deleted function psphere:\
\>", "Text"],

Cell[BoxData[
    \(\(?psphere\)\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(\(\(\t\)\(Timing[\(psphere[spunit[s, t, u, v]]\)[x, y]]\)\)\)], "Input",\

  CellLabel->"In[14]:=",
  Evaluatable->False],

Cell["The needed time was 1483.02 s (on a very fast PC). ", "Text"],

Cell["\<\
Mathematica were working a long time calculating an odd looking formula.  \
Also Simplify did not help very much. FullSimplify I aborted after more than \
one hour.  With psphere replaced by euklidsphere  we get in less than 5 s a \
very nice formula:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\t\)\(Timing[
      Simplify[\(euklidsphere[spunit[s, t, u, v]]\)[x, 
          y], \[IndentingNewLine]s \[Element] Reals && t \[Element] Reals && 
          u \[Element] Reals && v \[Element] Reals && x \[Element] Reals && 
          y \[Element] Reals]]\)\)\)], "Input",
  CellLabel->"In[19]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["A bad definition", "Subsubsection"],

Cell["\<\
Therefore, and by certain evaluation advantages, we would prefer the direct \
definition\
\>", "Text"],

Cell[BoxData[
    \(\(euklidspherefct[s_, t_, u_, v_]\)[x_, 
        y_] := \n{\(Cos[\[Pi]\ x]\ Cos[\(\[Pi]\ y\)\/2] + Cos[s]\ Cos[t]\ \
Cos[u]\ Cosh[v]\)\/\(\(-Cosh[v]\)\ Sin[u] + Sinh[v]\), \(Cos[t]\ Cos[u]\ \
Cosh[v]\ Sin[s] + Cos[\(\[Pi]\ y\)\/2]\ Sin[\[Pi]\ x]\)\/\(\(-Cosh[v]\)\ \
Sin[u] + Sinh[v]\), \(Cos[u]\ Cosh[v]\ Sin[t] + Sin[\(\[Pi]\ \
y\)\/2]\)\/\(\(-Cosh[v]\)\ Sin[u] + Sinh[v]\)}\)], "Input",
  CellLabel->"In[20]:="],

Cell["Obviously, we then get infinite vectors for u==v==0:", "Text"],

Cell[BoxData[
    \(\(euklidspherefct[s, 0, 0, 0]\)[x, y]\)], "Input",
  CellLabel->"In[21]:="],

Cell["On the other hand, we get the correct result", "Text"],

Cell[BoxData[
    \(\(euklidsphere[spunit[s, 0, 0, 0]]\)[x, y]\)], "Input",
  CellLabel->"In[22]:="],

Cell["Something must be wrong!", "Text"],

Cell[BoxData[
    \(\(euklidsphere[spunit[s, t, u, v]]\)[x, y]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \(% /. u \[Rule] 0\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(% /. v \[Rule] 0\)], "Input",
  CellLabel->"In[25]:="],

Cell["\<\
The reason must be that under the general calculation of \
euklidsphere[spunit[s,t,u,v]][x,y] an error appears.
Indeed, looking at the definition of  euklidsphere in mspher.m one sees that \
for \
\>", "Text"],

Cell[BoxData[
    \(spunit[s, t, u, v]\)], "Input",
  CellLabel->"In[26]:="],

Cell["\<\
the function euklidspherefct, of course, en general must refuse the case\
\>", "Text"],

Cell[BoxData[
    \(%[\([4]\)]\  \[Equal] %[\([5]\)]\)], "Input",
  CellLabel->"In[27]:="],

Cell["Therefore vectors as ", "Text"],

Cell[BoxData[
    \(spunit[s, t, 0, 0]\)], "Input",
  CellLabel->"In[28]:="],

Cell["\<\
are not recognized as those which  generate planes. The attempt to evaluate \
the command line Return[xtest] \
\>", "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\(va\  = spunit[s, t, 0, 0]\),
        FontSize->14], 
      StyleBox[";",
        FontSize->14], 
      StyleBox["  ",
        FontSize->14], 
      StyleBox[\(xtest\  = \ \(sphere[vcenter[va], vradius[va]]\)[u*Pi, 
            v*Pi/2]\),
        FontFamily->"Courier Neu",
        FontSize->14]}]], "Input",
  CellLabel->"In[29]:="],

Cell["\<\
leads to infinite vectors what is reflected in the calculation of the general \
formula. Thus, it does not make sense to evaluate for values with u = v = 0, \
which correspond to planes, the function\
\>", "Text"],

Cell[BoxData[
    \(\(euklidspherefct[s, t, u, v]\)[x, y]\)], "Input",
  CellLabel->"In[30]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["A better definition", "Subsubsection"],

Cell["Since the derived formula is not general enough, we set", "Text"],

Cell[BoxData[
    \(Clear[euklidspherefct]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(\(euklidspherefct[s_, t_, u_, v_]\)[x_, 
        y_] := \ \(euklidsphere[spunit[s, t, u, v]]\)[x, y]\)], "Input",
  CellLabel->"In[32]:="],

Cell["and obtain the correct result:", "Text"],

Cell[BoxData[
    \(\(euklidspherefct[s, 0, 0, 0]\)[x, y]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(\(euklidsphere[spunit[s, 0, 0, 0]]\)[x, y]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(Timing[\(euklidspherefct[s, 0, 0, 0]\)[x, y]]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(spunit[Pi/4, Pi, \ Pi/4, 0]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(euklidsphereplot3D[spunit[Pi/4, Pi, \ Pi/4, 0]]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(\(euklidspherefct[Pi/4, Pi, \ Pi/4, 0]\)[x, y]\)], "Input",
  CellLabel->"In[38]:="],

Cell["Since", "Text"],

Cell[BoxData[
    \(stepro[stb[4] - stb[5]]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(stepro[stb[4] + stb[5]]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(spunit[2*Pi*Random[], \ Pi*Random[]/2, \ 0, 0]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(pssp[spunit[2*Pi*Random[], \ Pi*Random[]/2, \ 0, 0], 
        stb[4] - stb[5]] \[Equal] \ 0\)], "Input",
  CellLabel->"In[46]:="],

Cell["\<\
commands like the following always create a set of planes through the origin:\
\
\>", "Text"],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[
        spunit[2*Pi*Random[], \ Pi*Random[]/2, \ 0, 0]], {10}]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[43]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["A random spacelike unit vector", "Subsubsection"],

Cell[BoxData[
    \(sprandomv\  := \ 
      Module[{re, \ rs, \ rt, rv, \ i}, \[IndentingNewLine]re[i_]\  := \ 
          Sign[0.5\  - \ Random[]]; \[IndentingNewLine]rs[]\  := \ 
          Random[]*2*Pi; \[IndentingNewLine]rt[i_]\  := \ 
          Random[]*Pi/2; \[IndentingNewLine]rs[]\  := \ 
          re[3]*Random[]*10; \[IndentingNewLine]spunit[rs[], re[1]*rt[1], \ 
          re[2]*rt[2], \ rs[]]\ ]\)], "Input",
  CellLabel->"In[181]:="],

Cell["\<\
WARNING: The distribution of the random spacelike unit vector and the \
corresponding random sphere is not invariant under the action of the M\
\[ODoubleDot]bius group! The corresponding random sphere is:\
\>", "Text"],

Cell[BoxData[
    \(vte\  = \ sprandomv\)], "Input",
  CellLabel->"In[182]:="],

Cell[BoxData[
    \(pssp[vte, vte]\)], "Input",
  CellLabel->"In[183]:="],

Cell[BoxData[
    \(Timing[\(euklidsphere[vte]\)[x, \ y]]\)], "Input",
  CellLabel->"In[184]:="],

Cell[BoxData[
    \(Timing[euklidsphereplot3D[vte]]\)], "Input",
  CellLabel->"In[185]:="],

Cell[BoxData[
    \(vte\  = \ Table[sprandomv, {j, 10}]\)], "Input",
  CellLabel->"In[186]:="],

Cell[BoxData[
    \(Table[pssp[%[\([j]\)], %[\([j]\)]], \ {j, 10}]\)], "Input",
  CellLabel->"In[187]:="],

Cell[BoxData[
    \(Timing[
      Table[\(euklidsphere[vte[\([j]\)]]\)[x, \ y], {j, 10}]]\)], "Input",
  CellLabel->"In[188]:="],

Cell[BoxData[
    \(vte\  = \ Table[sprandomv, {j, 8}]\)], "Input",
  CellLabel->"In[189]:="],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[vte[\([j]\)], \ 0, 1, \ \(-1\), 1], {j, 
        8}]\)], "Input",
  CellLabel->"In[190]:="],

Cell[BoxData[
    \(Show[%, \ PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[191]:="],

Cell["\<\
Since the random radii and centers are wide spread, the union of the \
halfspheres in general does not give nice pictures, test it evaluating this \
subsection repeatingly.\
\>", "Text"],

Cell[BoxData[
    \(Table[{vradius[vte[\([j]\)]], \ vcenter[vte[\([j]\)]]}, {j, 
        8}]\)], "Input",
  CellLabel->"In[192]:="],

Cell[BoxData[
    \(Clear[vte]\)], "Input",
  CellLabel->"In[193]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Oriented spheres", "Subsubsection"],

Cell["\<\
Already in section 3.1 we mentioned oriented spheres. Let v be a spacelike \
vector. The sphere S(v) defined by v corresponds to the isotropic vectors x \
solving pssp[v,x] == 0. This defines a linear pseudo-euclidean 4-space \
dividing  the isotropic cone into two parts. On the 3-sphere these parts are \
the \"inner ball\", defined by pssp[v, y] < 0, and the outer ball, defined by \
pssp[v,y] > 0. Clearly, if we replace v by -v, the corresponding sphere does \
not change, but inner and outer ball exchange there roles. Therefore the \
hyper-hyperboloid (H) represents the manifold of all oriented spheres \
contained in  the 3-sphere bijectively.\
\>", "Text"],

Cell[BoxData[
    \(vte\  = \ sprandomv\)], "Input",
  CellLabel->"In[194]:="],

Cell[BoxData[
    \(pssp[vte, vte]\)], "Input",
  CellLabel->"In[195]:="],

Cell[BoxData[
    \(Timing[\(euklidsphere[vte]\)[x, \ y]]\)], "Input",
  CellLabel->"In[196]:="],

Cell[BoxData[
    \(Timing[euklidsphereplot3D[vte]]\)], "Input",
  CellLabel->"In[197]:="],

Cell[BoxData[
    \(Timing[\(euklidsphere[\(-vte\)]\)[x, \ y]]\)], "Input",
  CellLabel->"In[198]:="],

Cell[BoxData[
    \(Timing[euklidsphereplot3D[\(-vte\)]]\)], "Input",
  CellLabel->"In[199]:="],

Cell[BoxData[
    \(vte\)], "Input",
  CellLabel->"In[200]:="],

Cell[BoxData[
    \(vradius[vte] \[Equal] \(-vradius[\(-vte\)]\)\)], "Input",
  CellLabel->"In[201]:="],

Cell[BoxData[
    \(vcenter[vte]\  \[Equal] \ vcenter[\(-vte\)]\)], "Input",
  CellLabel->"In[202]:="],

Cell[BoxData[
    \(vec[n]\)], "Input",
  CellLabel->"In[203]:="],

Cell[BoxData[
    \(\(euklidsphere[vec[n]]\)[x, y] + \(euklidsphere[\(-vec[n]\)]\)[x, 
        y]\)], "Input",
  CellLabel->"In[204]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[205]:="],

Cell["\<\
It follows that the spheres are identical as sets; the radius vectors with \
the same parameter values with respect to the centers are opposite: The sum \
of the radius vectors is twice the center.\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["4 The generalized angle", "Section"],

Cell[CellGroupData[{

Cell["4.1 Definition. Cases", "Subsection"],

Cell["\<\
The consideration of this section are valid for hyperspheres in any dimension \
(with exception of plotting commands, of course). We consider two spheres, \
represented by the spacelike vectors v, w. Since the map v -> sphere[v] is \
equivariant, the generalized cosinus gencos of these vectors already yields a \
complete invariant system  in the space of oriented sphere pairs, as can be \
proved easily.\
\>", "Text"],

Cell[BoxData[
    \(\(?gencos\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(gencos[v_List, \ w_List]\  := \ 
      Simplify[pssp[v, \ w]/Sqrt[pssp[v, v]\ pssp[w, w]]]\)], "Input",
  CellLabel->"In[17]:=",
  Evaluatable->False],

Cell["\<\
We have to distinguish three cases: The linear hull of {v, w} can be 1) \
euclidean, 2) pseudo-euclidean, 3) isotropic. Here and in the following we \
assume that the spheres are distinct, i.e. the vectors v, w are linearely \
independent.\
\>", "Text"],

Cell[BoxData[
    \(\(?spherevec\)\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(spherevec[x, y, z, r]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(pssp[spherevec[x, y, z, r], spherevec[X, Y, Z, R]]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(Together[%]\)], "Input",
  CellLabel->"In[12]:="],

Cell["\<\
Since the distance square of the centers of the spheres in the euclidean \
space is\
\>", "Text"],

Cell[BoxData[
    \(d^2 = {\ X - x, Y - y, Z - z} . {\ X - x, Y - y, Z - z}\)], "Input",
  CellLabel->"In[13]:="],

Cell["\<\
we obtain the conformal invariant gencos of two spheres in terms of their \
euclidean invariants:\
\>", "Text"],

Cell[BoxData[
    \(coxeterinv[r1_, \ r2_, \ 
        d_]\  := \ \((r1^2\  + \ r2^2\  - d^2)\)/\((2\ r1\ r2)\)\)], "Input",
  CellLabel->"In[7]:=",
  Evaluatable->False],

Cell[BoxData[
    \(coxeterinv[r, R, d]\)], "Input",
  CellLabel->"In[43]:="],

Cell["\<\
If the spheres intersect this invariant is the cosinus of the intersection \
angle; If they do not intersect the invariant\
\>", "Text"],

Cell[BoxData[
    \(ArcCosh[coxeterinv[r, R, d]]\)], "Input",
  CellLabel->"In[17]:="],

Cell[TextData[{
  "has been considered by H. S. M. Coxeter in",
  ButtonBox[" [1]",
    ButtonData:>"Cox",
    ButtonStyle->"Hyperlink"],
  "; he called it the ",
  StyleBox["inversive distance ",
    FontColor->RGBColor[1, 0, 0]],
  "of the spheres. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.2 Intersecting spheres",
  FontSize->16,
  FontVariations->{"CompatibilityType"->0}]], "Subsection",
  FontFamily->"Times New Roman"],

Cell["\<\
The spheres intersect in a circle (resp. (n-2)-sphere) iff v, w span an \
euclidean subspace. Then gencos[v,w] obviously is the cosinus of the  usual \
angle between the vectors v, w, and this is valid iff -1 < gencos[v,w] < 1:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(phi[v_, \ w_]\  := \ ArcCos[gencos[v, w]]\)\)\)], "Input",
  CellLabel->"In[26]:="],

Cell["\<\
is the angle between the normal vectors (= radii vectors) of the spheres \
along the intersection. This follows easily from the cos-theorem. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Example", "Subsubsection"],

Cell["Abbreviating we define", "Text"],

Cell[BoxData[
    \(sphv[x_, r_]\  := \ spherevec[x, 0, 0, r]\)], "Input",
  CellLabel->"In[8]:=",
  InitializationCell->True],

Cell[BoxData[
    \(vx\  = \ sphv[0, \ 1]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(euklidsphereplot3D[vx]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(sph1\  = \ %\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(euklidsphereplot3D[sphv[Sqrt[2], \ 1. ]]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(sph2\  = \ %\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(Show[{sph1, sph2}]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(gencos[vx, \ sphv[Sqrt[2], \ 1. ]]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(phi[vx, \ sphv[Sqrt[2], \ 1. ]]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(%*180/Pi\)], "Input",
  CellLabel->"In[51]:="],

Cell["Test it with other arguments of sphv!", "Text"],

Cell[BoxData[
    \(wx = \ sphv[x, \ r]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(pssp[%, \ %]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(gencos[vx, \ wx]\)], "Input",
  CellLabel->"In[33]:="],

Cell["\<\
The absolute value of this invariant equals 1 in the cases x = \
\[PlusMinus](1-r) or x = \[PlusMinus](1+r), and this means that the spheres \
are tangent to each other, see also section 4.4 .\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Intersecting planes", "Subsubsection"],

Cell["\<\
A simple example of symbolic calculations: let us take two general planes:\
\>", "Text"],

Cell[BoxData[
    \(na = \ planevec[x, y, z, h]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(pssp[na, na]\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(nb = \ planevec[X, Y, Z, H]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(Simplify[\((pssp[na, nb])\)^2/\((pssp[na, na]*
            pssp[nb, nb])\)]\)], "Input",
  CellLabel->"In[55]:="],

Cell["\<\
And this is the cos^2 of the intersection angle, if the planes are not \
parallel, and 1 else, as expected!If the planes are parallel we have\
\>", "Text"],

Cell[BoxData[
    \(nc\  = \ \ planevec[x, y, z, k]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(Simplify[\((pssp[na, nc])\)^2/\((pssp[na, na]*
            pssp[nc, nc])\)]\)], "Input",
  CellLabel->"In[57]:="],

Cell["Parallel planes are tangent to each other at infinity. ", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["4.3 Non-intersecting spheres ",
  FontFamily->"Times New Roman",
  FontVariations->{"CompatibilityType"->0}]], "Subsection",
  FontSize->16],

Cell["\<\
In the pseudo-euclidean case the othogonal complement of the linear hull[v, \
w] is euclidean, thus, it does not contain isotropic vectors, and the \
intersection of the spheres is empty, and vice versa. We have \
\>", "Text"],

Cell[BoxData[
    \(fct[x1_, \ r1_, x2_, \ r2_]\  := \ 
      gencos[sphv[x1, \ r1], \ sphv[x2, \ r2]]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(fct[x1, r1, x2, r2]\)], "Input",
  CellLabel->"In[59]:="],

Cell["\<\
Since d = x1 - x2 is the euclidean distance between the centers of the \
spheres, we obtain the conformal invariant of two spheres with radii r1, r2 \
and distance d of its centers as \
\>", "Text"],

Cell[BoxData[
    \(\(?coxeterinv\)\)], "Input",
  CellLabel->"In[60]:="],

Cell["More generally we derived this expression already in 4.1.", "Text"],

Cell["\<\
In the non-intersecting case one has Abs[coxeterinv[r1, r2, d]]>1, and vice \
versa.\
\>", "Text"],

Cell[BoxData[
    \(coxeterinv[r1, \ r2, \ d]\)], "Input",
  CellLabel->"In[61]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["4.4",
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontSize->16],
  StyleBox["Tangential spheres",
    FontFamily->"Times New Roman",
    FontSize->16,
    FontVariations->{"CompatibilityType"->0}]
}], "Subsection"],

Cell["\<\
The spheres are tangent to each other at the common point, which correspond \
to the isotropic vector of the linear hull[v,w], iff one has \
Abs[coxeterinv[r1, r2, d]]=1.
We have two subcases:\
\>", "Text"],

Cell[CellGroupData[{

Cell["a)  d = |r1 + r2|", "Subsubsection"],

Cell[BoxData[
    \(coxeterinv[r1, \ r2, \ r1\  + \ r2]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[63]:="],

Cell["\<\
The invariant coxeterinv equals  -1; clearly the spheres are tangent to each \
other lying in different halfspaces, as we shall demonstrate. This property \
is independent of the orientation of the spheres.\
\>", "Text"],

Cell[BoxData[
    \(sphv[1 + r, \ r]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(Simplify[2\ r\ %]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[sphv[1 + r, \ r]], \ {r, \ 0.2, \ 1, \ 
        0.2}]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(tangser\  = \ %\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(euklidsphereplot3D[stb[4]]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(spst = %\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(Append[tangser, spst]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(taser\  = \ %\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(Show[taser]\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(tanser\  = %\)], "Input",
  CellLabel->"In[74]:="],

Cell[TextData[{
  "To see the tangent property, first load ",
  ButtonBox["MathGL",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"],
  ", and use the option appearance/wire frame, toggle the background color."
}], "Text"],

Cell[BoxData[
    \(MVShow3D[tanser]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(ThreeScript["\<tangsph.ts\>", tanser]\)], "Input",
  CellLabel->"In[117]:="],

Cell["The common point of all these spheres is", "Text"],

Cell[BoxData[
    \(stepro[{1, 0, 0, 0, 1}]\)], "Input",
  CellLabel->"In[88]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["b)  d = |r1  - r2|", "Subsubsection"],

Cell[BoxData[
    \(coxeterinv[r1, \ r2, \ r1\  - \ r2]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[62]:="],

Cell["\<\
Now the invariant coxeterinv equals  1; clearly the spheres are tangent to \
each other lying in the same halfspace, as we shall demonstrate. This \
property is independent of the orientation of the spheres.\
\>", "Text"],

Cell[BoxData[
    \(sphv[1 - r, \ r]\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(Simplify[2\ r\ %]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[sphv[1 - r, \ r]], \ {r, \ 0.2, \ 1, \ 
        0.2}]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(tangser2\  = \ %\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(Show[tangser2]\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(tanser2\  = %\)], "Input",
  CellLabel->"In[84]:="],

Cell[TextData[{
  "To see the tangent property, first load ",
  ButtonBox["MathGL",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"],
  ", and use the option appearance/wire frame, toggle the background color."
}], "Text"],

Cell[BoxData[
    \(MVShow3D[tanser2]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(ThreeScript["\<tangsph2.ts\>", tanser2]\)], "Input",
  CellLabel->"In[97]:="],

Cell["The common point of all these spheres is again ", "Text"],

Cell[BoxData[
    \(stepro[{1, 0, 0, 0, \ 1}]\)], "Input",
  CellLabel->"In[86]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.5 Intersection of a sphere and a plane", "Subsection"],

Cell["\<\
Now we consider the intersection of a plane with a sphere. For the conformal \
invariant of a sphere and a plane we calculate\
\>", "Text"],

Cell[BoxData[
    \(pssp[spherevec[x, y, z, r], \ planevec[X, Y, Z, p]]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \(Together[%]\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \(%^2/\((pssp[spherevec[x, y, z, r], 
            spherevec[x, y, z, r]]*\n\t\t\tpssp[\ planevec[X, Y, Z, p], \ 
            planevec[X, Y, Z, p]])\)\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[91]:="],

Cell["\<\
If plane and sphere really intersect, this is the cosinus square of the \
intersection angle. In the general case it corresponds to the conformal \
invariant coxeterinv of two spheres. The plane is tangent to the sphere iff \
this expression equals one.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Example", "Subsubsection"],

Cell["\<\
For the intersection of a unit sphere with center {x,0,0} and the y,z-plane \
through the origin we obtain\
\>", "Text"],

Cell[BoxData[
    \(sph[x_]\  := \ sphv[x, \ 1]\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(sph[x]\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(pl\  = \ planevec[1, 0, 0, 0]\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(gencos[pl, \ sph[x]]\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(pssp[sph[x], \ sph[x]]\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    \({euklidsphereplot3D[stb[1]], 
      euklidsphereplot3D[{1, 0, 0, \(-1\)/2, 1/2}]}\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(MVShow3D[%]\)], "Input",
  CellLabel->"In[100]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5 Geodesics of the sphere space", "Section"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.1 Introduction",
  FontSize->16]], "Subsection"],

Cell["\<\
In subsection 3.5 we identified the space of oriented spheres with the \
hypersurface  H: pssp[x,x] = 1 of spacelike unit vectors in the \
pseudo-euclidean vector space: a \"pseudo-hypersphere\".  It is a \
pseudo-Riemannian symmetric space of constant curvature. As in Riemannian \
sphere geometry, the geodesics of  H are the intersections of the \
pseudo-hypersphere H with 2-planes through the center o. But now we  have \
three kinds of such planes, and the corresponding geodesics. We take the \
equatorial sphere stb[4] as starting point of  the geodesics. To find the \
types of geodesic we may restrict to the linear hull[stb[5],stb[1]], as a \
subspace of the tangent space of this hyper-hyperboloid at stb[4]: look at \
the isotropy action, the action of the subgroup of the M\[ODoubleDot]bius \
group preserving stb[4] on the tangential space of H at stb[4]. Obviously, \
this is the usual standard action of the pseudo-orthogonal group O(3,1) on \
the 4-dimensional pseudo-euclidean vector space of index 1. 
We remember the following situation:\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(se1 = euklidsphereplot3D[stb[3]]\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \(se2\  = euklidsphereplot3D[stb[4]]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(Show[{se1, se2}, PlotRange\ \  -> {\(-1\), 1}]\)], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
The intersection of the spheres defined by stb[4] and stb[3] is the unit \
circle in the x,y-plane around o. The spheres containing this circle are \
exactly represented by the unit vectors of the linear hull[stb[4], stb[3]]. \
All the spheres corresponding to spacelike vectors of the linear hull[stb[1], \
stb[2], stb[5]] intersect all the spheres of this family orthogonally.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.2 Timelike geodesics",
  FontSize->16]], "Subsection",
  Evaluatable->False],

Cell["\<\
A timelike geodesics is the intersection of H with a pseudo-Euclidean plane, \
say, spanned by stb[4], stb[5]. This 2-plane contains two isotropic \
directions, i.e. points of the 3-sphere. The geodesic consists of all spheres \
which intersect all the spheres through these two points  in an angle Pi/2. \
If we take one of this point as the north pole (corresponding to stb[4,4]) \
and the other as the origin o , and the \"spheres\" through these points are \
the planes through the origin (under stereographical projection).Therefore  \
the geodesic is the set of all spheres with center o. The tangential vector \
of this geodesic at t=0 is stb[5]. Therefore the geodesic is timelike.\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Five spheres on this timelike geodesic (for better visibility we only plot \
the halfspheres):\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Table[euklidsphereplot3D[{0, 0, 0, Cosh[t], Sinh[t]},-1,1,0,1],
{t, -1, 1, 1/2}]\
\>", "Input",
  CellLabel->"In[12]:=",
  PageWidth->Infinity],

Cell[BoxData[
    \(grr\  = %\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(Show[grr]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(grr1\  = %\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(MVShow3D[grr1]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(ThreeScript["\<spheres1.ts\>", grr1]\)], "Input",
  CellLabel->"In[133]:=",
  PageWidth->Infinity],

Cell["\<\
Replacing stb[4] by stb[1] gives a M\[ODoubleDot]bius equivalent, also again \
timelike geodesic. In the euclidean picture, this geodesic starts at the \
\"sphere\" defined by stb[1], that is the y,z-plane. It is defined as the \
one-parameter sphere family corresponding to the spacelike vectors {Cosh[t], \
0, 0, 0, Sinh[t]}:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[{Cosh[t], 0, 0, 0, Sinh[t]}, \(-1\), 0, \(-1\), 
        1], {t, \(-5\), 5}]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(Show[%, \ PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[19]:="],

Cell[BoxData[
    \(tgr\  = \ %\)], "Input",
  CellLabel->"In[20]:="],

Cell["\<\
One sees that we obtained a one parameter family of pairwise non intersecting \
spheres,  containing the y,z-plane and contracting to two points, which \
correspond to the origin and the infinite point in our first example.These \
points are\
\>", "Text"],

Cell[BoxData[
    \({stepro[stb[1]\  + stb[5]], stepro[stb[1]\  - stb[5]]}\)], "Input",
  CellLabel->"In[21]:="],

Cell["\<\
The points are not arbitrary; they are in involution with respect to the \
starting sphere (here: the y,z-plane) of the geodesic. Consider all circles \
through the two points: they cut the y,z-plane orthogonally. Since the \
geodesic is generated moving the starting sphere by a 1-parameter group of M\
\[ODoubleDot]bius transformations  preserving these two points (the \
pseudo-orthogonal group of the subspace spanned by stb[1], stb[5]):\
\>", "Text"],

Cell[BoxData[
    \({{Cosh[t], 0, \ 0, \ 0, \ Sinh[t]}, \[IndentingNewLine]{0, \ 1, \ 0, \ 
          0, \ 0}, \[IndentingNewLine]{0, \ 0, \ 1, \ 0, \ 
          0}, \[IndentingNewLine]{0, \ 0, \ 0, \ 1, \ 
          0}, \[IndentingNewLine]{Sinh[t], 0, \ 0, \ 0, \ Cosh[t]}} . {1, 0, 
        0, 0, 0}\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({{Cosh[t], 0, \ 0, \ 0, \ Sinh[t]}, \[IndentingNewLine]{0, \ 1, \ 0, \ 
          0, \ 0}, \[IndentingNewLine]{0, \ 0, \ 1, \ 0, \ 
          0}, \[IndentingNewLine]{0, \ 0, \ 0, \ 1, \ 
          0}, \[IndentingNewLine]{Sinh[t], 0, \ 0, \ 0, \ Cosh[t]}} . {1, 0, 
        0, 0, 1}\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \({{Cosh[t], 0, \ 0, \ 0, \ Sinh[t]}, \[IndentingNewLine]{0, \ 1, \ 0, \ 
          0, \ 0}, \[IndentingNewLine]{0, \ 0, \ 1, \ 0, \ 
          0}, \[IndentingNewLine]{0, \ 0, \ 0, \ 1, \ 
          0}, \[IndentingNewLine]{Sinh[t], 0, \ 0, \ 0, \ Cosh[t]}} . {1, 0, 
        0, 0, \(-1\)}\)], "Input",
  CellLabel->"In[24]:="],

Cell["\<\
all the spheres of the geodesic intersect the circle bundle through the two \
points orthogonally, and therefore the geodesic is the family of orthogonal \
trajectories of the bundle. Thus, the recipe to conctruct a timelike geodesic \
through a given sphere is the following: Take a point outside the sphere, \
reflect it at the sphere, consider the bundle of all circles through the \
point pair in involution obtained this way: The geodesic is the family of \
orthogonal trajectories of this bundle, which are spheres. All these \
geodesics are M\[ODoubleDot]bius equivalent. The set of these geodesics is a \
six-dimensional homogeneous space under the action of the M\[ODoubleDot]bius \
group.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.3 Spacelike geodesics", "Subsection",
  Evaluatable->False,
  FontSize->16],

Cell["\<\
The spacelike geodesic corresponding to the intersection with the linear \
hull[stb[1], stb[4]] is the \"circle\"
{Sin[t], 0, 0, Cos[t],0}.
Five spheres on this spacelike geodesic (again we plot halfspheres only):\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[\[IndentingNewLine]{Sin[t], 0, 0, Cos[t], 
          0}, \(-1\), 0, \(-1\), 1], \[IndentingNewLine]{t, \(-1\)/3, 1/3, 
        1/6}]\)], "Input",
  CellLabel->"In[25]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[26]:=",
  PageWidth->Infinity],

Cell[BoxData[
    \(spacege\  = \ %\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(MVShow3D[spacege]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(ThreeScript["\<spacege4.ts\>", spacege]\)], "Input",
  CellLabel->"In[132]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell["\<\
These spheres intersect in the unit circle centered in o in the y,z-plane :\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(ParametricPlot3D[{0, Cos[t], \ Sin[t]}, {t, 0, 2\ \[Pi]}]\)], "Input",
  CellLabel->"In[29]:=",
  PageWidth->Infinity],

Cell[BoxData[
    \(circ1yz = %\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(Show[{spacege, circ1yz}]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(spacegec\  = %\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(MVShow3D[spacegec, \ MVLineTubeSize\  \[Rule]  .01]\)], "Input",
  CellLabel->"In[33]:="],

Cell["\<\
The whole geodesic consists of all the spheres through the fixed circle \
defined by the orthogonal complement of
linearhull{{Cos[t], 0, 0, Sin[t], 0}, { Cos[t + Pi/2], 0, 0, Sin[t + \
Pi/2],0}} = linearhull{stb[1], stb[4]}. 
As a special case of a spacelike geodesic we get the bundle of planes through \
a line. Since the space of all circles is six-dimensional, we can state: The \
space of all spacelike geodesics in the sphere space is a six-dimensional \
homogeneous space under the action of the M\[ODoubleDot]bius group, \
equivariant isomorphic to the space of all circles. \
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[\[IndentingNewLine]{Sin[t], 0, 0, Cos[t], 
          0}, \(-1\), 0, \(-1\), 1], \[IndentingNewLine]{t, 0, Pi, 
        Pi/8}]\)], "Input",
  CellLabel->"In[34]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(spacegeo1\  = \ %\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(MVShow3D[spacegeo1]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(Show[{spacegeo1, circ1yz}]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(spacegeo2\  = \ %\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(MVShow3D[spacegeo2, \ MVLineTubeSize\  \[Rule]  .05]\)], "Input",
  CellLabel->"In[40]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["5.4 Isotropic geodesics", "Subsection",
  Evaluatable->False,
  FontSize->16],

Cell["\<\
An isotropic geodesic through stb[4] is the intersection of H with the \
isotropic plane through the origin, spanned by the vectors stb[4] and stb[1] \
+ stb[5]. This is a generating line contained in the hyperboloid H, with \
parameter representation
 {t,0,0,1, t}.
The starting point: stb[4], the unit sphere with centre o, and any other \
sphere of this geodesic have the isotropic span:
linearhull[{1,0,0,0,1}, {0,0,0,1,0}], and therefore they intersect in the \
point\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[{
    \(\(cpt\  = {1, 0, 0, 0, 1};\)\), "\n", 
    \(stepro[cpt]\)}], "Input",
  CellLabel->"In[9]:="],

Cell["\<\
Because spheres which intersect in exactly one point must have a common \
tangential plane at this point,  the isotropic geodesic under consideration \
is the 1-parameter family of spheres through the point {1,0,0} having there \
the same tangent plane as the unitsphere with centre o, and this is the plane \
cutting the x-axis orthogonally. This tangent plane corresponds to the \
spacelike vector\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(planevec[1, 0, 0, 1]\)], "Input",
  CellLabel->"In[11]:="],

Cell["\<\
and belongs to the geodesic. If vec[x] is a spacelike unit vector the \
corresponding sphere of which is tangent to the unit sphere at the point \
{1,0,0}, it must be a solution of the following system\
\>", "Text"],

Cell[BoxData[
    \(Solve[{pssp[cpt, vec[x]] == 0, \n\t\tpssp[stb[4], vec[x]] == 1}, \n\t
      vec[x]]\)], "Input",
  CellLabel->"In[12]:=",
  PageWidth->Infinity],

Cell["The general solution is", "Text"],

Cell[BoxData[
    \(vs = \ {t, a, b, 1, t}\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(pssp[vs, vs]\)], "Input",
  CellLabel->"In[15]:="],

Cell["\<\
Since vs should be a spacelike unit vector it follows a=b=0: The isotropic \
geodesic consists exactly of all spheres tangent to the unit sphere at the \
point {1,0,0}.\
\>", "Text"],

Cell["Here are 7 spheres on this isotropic geodesic:", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[{t, 0, 0, 1, t}, 0, 1, \ \(-1\), 
        1, \[IndentingNewLine]PlotPoints -> \ 20], {t, \(-3\), 3}]\)], "Input",\

  CellLabel->"In[16]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[17]:=",
  PageWidth->Infinity],

Cell[BoxData[
    \(isogeod1 = %\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(MVShow3D[isogeod1]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    \(ThreeScript["\<isoge1.ts\>", isogeod1]\)], "Input",
  CellLabel->"In[12]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell["\<\
Another isotropic geodesic through the unit sphere in the linear hull under \
consideration is given by the spacelike vectors\
\>", "Text"],

Cell[BoxData[
    \({t, 0, 0, 1, \(-t\)}\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[{t, 0, 0, 1, \(-t\)}, \(-1\), 0, \ \(-1\), 
        1, \[IndentingNewLine]PlotPoints -> \ 20], {t, \(-3\), 3}]\)], "Input",\

  CellLabel->"In[19]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[20]:="],

Cell["\<\
The geodesic consists of all spheres having at the common point \
\>", "Text"],

Cell[BoxData[
    \(stepro[{1, 0, \ 0, \ 0, \ \(-1\)}]\)], "Input",
  CellLabel->"In[21]:="],

Cell["\<\
 the plane parallel to the y,z-plane as its common tangential plane. \
Obviously, there exists a 2-parameter family of isotropic geodesics through \
stb[4], corresponding to the points of the sphere, i.e. to the generators of \
the isotropic cone in the 4-dimensional tangential hyperplane of the \
hyper-hyperboloid of spacelike unit vectors at stb[4]. The set of all \
isotropic geodesics is a five-dimensional homogeneous manifold under the \
action of the M\[ODoubleDot]bius group.\
\>", "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["6 ThreeScript, MathGL3d", "Section",
  CellTags->"MathGL"],

Cell[TextData[{
  "If you want to generate *.ts files for animations outside of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", activate the next section. To use the animation program MathGL3d in this \
notebook, activate section 6.2."
}], "Text"],

Cell[CellGroupData[{

Cell["6.1 Threescript ", "Subsection"],

Cell["\<\
 The ThreeScript commands generate *.ts files appropriate  for certain \
animation programs, e.g. the  freeware program  MathGL3d  created by \
Jens-Peer Kuska [2] (for Windows95, Linux and other platforms).\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Under Windows the commercial 3D-Animation programs MathLive and \
DynamicVisualizer are available. To produce .ts-files one \
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(Needs["\<Graphics`ThreeScript`\>"]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(\(?ThreeScript\)\)], "Input",
  CellLabel->"In[32]:="],

Cell["\<\
The standard extension of these files is ts: \"filename.ts\" or \
\"Path/filename.ts\", e.g.\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(ThreeScript["\<tangr.ts\>", \ tangr3]\)], "Input",
  CellLabel->"In[18]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["6.2 MathGL3d", "Subsection"],

Cell[TextData[{
  "The free animation program MathGL3d by Jens-Peer Kuska [2] can be used \
from a command line and within a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. A new version of this program is in preparation. Jens-Peer Kuska \
has sent me a new startup file OpenGLViewer.m, and friendly permitted to add \
it to the item \"Spheres\". Replace the old file OpenGLViewer.m by this new \
OpenGLViewer.m. If you did this, changes of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ParametricPlot3D, especially the sometimes disturbing generating of \
MeshGraphics3D objects, will not take place.\nEstablish the link to the \
current ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session with the command:"
}], "Text"],

Cell[BoxData[
    \(Get["\<MathGL3d`OpenGLViewer`\>"]\)], "Input",
  CellLabel->"In[16]:="],

Cell["If you want to close the link, enter", "Text"],

Cell["MVClose[]", "Text",
  CellLabel->"In[44]:="],

Cell["\<\
The following command clears the Viewer window; this and other MathGL3d \
commands you may enter also with  palettes.\
\>", "Text"],

Cell[BoxData[{
    \(\(MVClear[];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(MVShow3D[\[Placeholder], MVPolygonShading \[Rule] MVSmooth, 
      MVGrayBackground \[Rule] False, MVTexture \[Rule] None, 
      MVTextureMapType \[Rule] MVMeshUVMapping, 
      MVScaleTexture \[Rule] {1, 1}, 
      MVTranslateTextureTarget \[Rule] Automatic, 
      MVRotateTextureTarget \[Rule] Automatic, 
      MVScaleTextureTarget \[Rule] Automatic]\)}], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(MVShow3D[gre1\[IndentingNewLine], MVPointSphereSize \[Rule] 0.8, \ 
      MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(MVShow3D[tgr3, \ MVPointSphereSize\  \[Rule] \ 1.8]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(MVShow3D[ex123, MVPointSphereSize \[Rule] 1.8]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(MVShow3D[isogeod1]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(Options[MVShow3D]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(MVClose[]\)], "Input",
  CellLabel->"In[41]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Appendix", "Section"],

Cell[CellGroupData[{

Cell["Moving frame on the sphere manifold: pstg5frame", "Subsection"],

Cell[BoxData[
    \(\(?tg4frame\)\)], "Input",
  CellLabel->"In[22]:="],

Cell["\<\
We construct a pseudo-orthogonal moving 5-frame of the hypersurface (H), \
using its parameter representation spunit. We follow the procedure which us \
led to the definition of tg4frame, see the notebook euspher.nb:\
\>", "Text"],

Cell[BoxData[
    \(pstg1[s_, t_, u_, v_]\  := \ 
      normalize[D[spunit[x, \ t, u, v], x] /. x\  -> \ s]\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    \(\(\(pstg1[s, t, u, v]\)\(\ \)\)\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(pstg2[s_, t_, u_, v_]\  := \ 
      normalize[D[spunit[s, \ x, u, v], x] /. x\  -> \ t]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(\(\(pstg2[s, t, u, v]\)\(\ \)\)\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(pstg3[s_, t_, u_, v_]\  := \ 
      normalize[D[spunit[s, \ t, x, v], x] /. x\  -> \ u]\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\(\(pstg3[s, t, u, v]\)\(\ \)\)\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(pstg4[s_, t_, u_, v_]\  := \ 
      normalize[D[spunit[s, \ t, u, x], x] /. x\  -> \ v]\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(\(\(pstg4[s, t, u, v]\)\(\ \)\)\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(spunit[s, t, u, v]\)], "Input",
  CellLabel->"In[31]:="],

Cell["\<\
Simplifying these vectors we defined in mspher.m the moving orthonormal \
tangentially adapted  5-frame of the spacelike unitsphere in the \
pseudo-euclidean 5-space,  analogous to tg4frame:\
\>", "Text"],

Cell[BoxData[
    \(\(?pstg5frame\)\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(pstg5frame[s_, \ t_, \ u_, \ 
        v_]\  := \n\t{{\(-\ Sin[s]\), Cos[s], 0, 0, 
          0}, \n\t\t{\(-Cos[s]\)\ Sin[t], \(-\ Sin[s]\)\ Sin[t], Cos[t], 0, 
          0}, \n\t\t{\(-Cos[s]\)\ Cos[t]\ \ Sin[u], \(-Cos[t]\)\ \ Sin[
              s]\ Sin[u], \(-\ Sin[t]\)\ Sin[u], Cos[u], 
          0}, \n\t\t{Cos[s]\ Cos[t]\ Cos[u]\ Sinh[v], 
          Cos[t]\ Cos[u]\ Sin[s]\ Sinh[v], Cos[u]\ Sin[t]\ Sinh[v], 
          Sin[u]\ Sinh[v], Cosh[v]}, \n\t\t{Cos[s]\ Cos[t]\ Cos[u]\ Cosh[v], 
          Cos[t]\ Cos[u]\ Cosh[v]\ Sin[s], Cos[u]\ Cosh[v]\ Sin[t], 
          Cosh[v]\ Sin[u], Sinh[v]}}\)], "Input",
  CellLabel->"In[43]:=",
  Evaluatable->False],

Cell[BoxData[
    \(\(pst5\  = pstg5frame[s, \ t, \ u, \ v];\)\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(Table[
      Simplify[pssp[pst5[\([i]\)], \ pst5[\([j]\)]]], \ {i, 5}, {j, 
        5}]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(Simplify[Det[pst5]]\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(spunit[s, t, u, v]\  + \ 
      spunit[s + Pi, \(-t\), \(-u\), \(-v\)]\)], "Input",
  CellLabel->"In[36]:="],

Cell["\<\
We conclude that changing the sign of  spunit[s,t,u,v] changes the \
orientation of the orthogonal pseudo-euclidean subspace, if we consider the \
pseudo-euclidean 5-space as oriented. \
\>", "Text"],

Cell["\<\
The isotropic vectors in the tangential space spanned by (pstg5frame[[i]], i \
= 1,...,4) are:\
\>", "Text"],

Cell[BoxData[
    \(\(isotr[s_, t_, u_, v_]\)[x_, 
        y_]\  := \n\(\(\(pstg5frame[s, \ t, \ u, \ v]\)[\([1]\)] 
          Cos[x]\ Cos[
            y]\  + \ \n\(pstg5frame[s, \ t, \ u, \ v]\)[\([2]\)]\ Sin[x]\ Cos[
            y]\  + \n\(pstg5frame[s, \ t, \ u, \ v]\)[\([3]\)]\ Sin[
            y]\  + \n\(pstg5frame[s, \ t, \ u, \ v]\)[\([4]\)]\)\(\n\)
      \(\t\)\)\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(iso\  = \ Simplify[\(isotr[s, t, u, v]\)[x, y]]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(Simplify[pssp[iso, iso]]\)], "Input",
  CellLabel->"In[39]:="]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
[1] Coxeter, H. S. M.  Inversive distance. Ann. Mat. Pura Apli. 4, 71 (1966), \
73 - 83. \
\>", "Text",
  CellTags->"Cox"],

Cell["\<\
[2] Gray, Alfred. Modern Differential Geometry of Curves and Surfaces. CRC \
PRESS, 1993 (German translation: Spektrum Akademischer Verlag 1994)\
\>", "Text",
  CellTags->"G1"],

Cell["\<\
[3] Kuska, Jens-Peer. http://phong.informatik.uni-leipzig.de/ \
~kuska/mview3d.html.\
\>", "Text",
  CellTags->"K2"],

Cell[TextData[{
  "[4] A. L. Oniscik, R. Sulanke. Projektive und Cayley-Kleinsche Geometrien. \
 2003.  May be downloaded from my ",
  ButtonBox["homepage",
    ButtonData:>"HP",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"O-S"],

Cell["\<\
[5] Sulanke, Rolf. Spheres.  1999.  \
http://mathsource.com/Content/Enhancements/Geometry/0210-092\
\>", "Text",
  CellTags->"S1"],

Cell[TextData[{
  "[6] Sulanke,  R.  M\[ODoubleDot]bius invariants for pairs of spheres (",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\%m\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\_2\%l\)]],
  ") in the M\[ODoubleDot]bius space ",
  Cell[BoxData[
      \(TraditionalForm\`S\^n\)]],
  ", Beitr\[ADoubleDot]ge zur Algebra und Geometrie, 41 (2000), No.1, \
233-246. Preprint No. 373, SFB 288, Berlin 1999.  \
http://xxx.lanl.gov/abs/math.MG/9902131. "
}], "Text",
  Evaluatable->False,
  CellTags->"S2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Author's address", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
Homepage:
http://www-irm.mathematik.hu-berlin.de/~sulanke
e-Mail:\
\>", "Text",
  CellTags->"HP"],

Cell["sulanke@mathematik.hu-berlin.de", "Text"],

Cell["\<\
The author will be very thankful for hints, corrections, comments.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
WindowSize->{834, 668},
WindowMargins->{{50, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "rolf", "mymath", \
"spheres.v3"}, "msphere.nb.ps", CharacterEncoding -> "WindowsANSI"],
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "MathGL"->{
    Cell[95865, 3435, 64, 1, 106, "Section",
      CellTags->"MathGL"]},
  "Cox"->{
    Cell[103387, 3694, 132, 4, 40, "Text",
      CellTags->"Cox"]},
  "G1"->{
    Cell[103522, 3700, 186, 4, 59, "Text",
      CellTags->"G1"]},
  "K2"->{
    Cell[103711, 3706, 126, 4, 40, "Text",
      CellTags->"K2"]},
  "O-S"->{
    Cell[103840, 3712, 246, 8, 40, "Text",
      CellTags->"O-S"]},
  "S1"->{
    Cell[104089, 3722, 140, 4, 40, "Text",
      CellTags->"S1"]},
  "S2"->{
    Cell[104232, 3728, 517, 15, 59, "Text",
      Evaluatable->False,
      CellTags->"S2"]},
  "HP"->{
    Cell[104851, 3751, 107, 5, 102, "Text",
      CellTags->"HP"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"MathGL", 106410, 3799},
  {"Cox", 106494, 3802},
  {"G1", 106572, 3805},
  {"K2", 106649, 3808},
  {"O-S", 106727, 3811},
  {"S1", 106805, 3814},
  {"S2", 106882, 3817},
  {"HP", 106986, 3821}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 136, 3, 73, "Title",
  Evaluatable->False],
Cell[1915, 58, 225, 8, 29, "Text",
  Evaluatable->False],
Cell[2143, 68, 125, 4, 39, "Text",
  Evaluatable->False],
Cell[2271, 74, 165, 4, 28, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2461, 82, 32, 0, 37, "Subsubsection"],
Cell[2496, 84, 1992, 42, 264, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4525, 131, 33, 0, 37, "Subsubsection"],
Cell[4561, 133, 513, 8, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5111, 146, 32, 0, 31, "Subsubsection"],
Cell[5146, 148, 600, 14, 88, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5783, 167, 34, 0, 37, "Subsubsection"],
Cell[5820, 169, 552, 8, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6409, 182, 59, 1, 37, "Subsection"],
Cell[6471, 185, 313, 5, 68, "Text"],
Cell[6787, 192, 141, 4, 32, "Input",
  InitializationCell->True],
Cell[6931, 198, 156, 3, 32, "Text"],
Cell[7090, 203, 128, 4, 32, "Input",
  InitializationCell->True],
Cell[7221, 209, 140, 3, 28, "Text"],
Cell[7364, 214, 56, 0, 28, "Text"],
Cell[7423, 216, 231, 6, 28, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7691, 227, 42, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[7758, 231, 116, 2, 43, "Subsection"],
Cell[7877, 235, 240, 4, 46, "Text"],
Cell[8120, 241, 153, 4, 55, "Text"],
Cell[8276, 247, 1259, 20, 160, "Text"],
Cell[9538, 269, 112, 3, 32, "Input",
  InitializationCell->True],
Cell[9653, 274, 329, 7, 46, "Text",
  Evaluatable->False],
Cell[9985, 283, 102, 3, 27, "Text"],
Cell[10090, 288, 66, 2, 32, "Input"],
Cell[10159, 292, 133, 3, 27, "Text"],
Cell[10295, 297, 143, 3, 32, "Input",
  InitializationCell->True],
Cell[10441, 302, 380, 7, 65, "Text",
  Evaluatable->False],
Cell[10824, 311, 109, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[10970, 319, 36, 0, 38, "Subsection"],
Cell[11009, 321, 186, 5, 27, "Text",
  Evaluatable->False],
Cell[11198, 328, 72, 2, 32, "Input"],
Cell[11273, 332, 85, 2, 27, "Text"],
Cell[11361, 336, 64, 2, 32, "Input"],
Cell[11428, 340, 312, 7, 46, "Text",
  Evaluatable->False],
Cell[11743, 349, 690, 17, 46, "Text"],
Cell[12436, 368, 66, 2, 32, "Input"],
Cell[12505, 372, 69, 2, 32, "Input"],
Cell[12577, 376, 72, 2, 32, "Input"],
Cell[12652, 380, 73, 2, 32, "Input"],
Cell[12728, 384, 83, 2, 32, "Input"],
Cell[12814, 388, 69, 2, 32, "Input"],
Cell[12886, 392, 75, 2, 32, "Input"],
Cell[12964, 396, 81, 2, 32, "Input"],
Cell[13048, 400, 69, 2, 32, "Input"],
Cell[13120, 404, 73, 2, 32, "Input"],
Cell[13196, 408, 70, 2, 32, "Input"],
Cell[13269, 412, 70, 2, 32, "Input"],
Cell[13342, 416, 72, 2, 32, "Input"],
Cell[13417, 420, 73, 2, 32, "Input"],
Cell[13493, 424, 71, 2, 32, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13613, 432, 72, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[13710, 436, 73, 0, 44, "Subsection"],
Cell[13786, 438, 126, 3, 27, "Text"],
Cell[13915, 443, 157, 6, 27, "Text"],
Cell[14075, 451, 363, 6, 65, "Text"],
Cell[14441, 459, 83, 1, 27, "Text"],
Cell[14527, 462, 90, 2, 27, "Text"],
Cell[14620, 466, 66, 2, 32, "Input"],
Cell[14689, 470, 318, 8, 80, "Input",
  Evaluatable->False],
Cell[15010, 480, 233, 4, 46, "Text"],
Cell[15246, 486, 71, 2, 32, "Input"],
Cell[15320, 490, 40, 0, 27, "Text"],
Cell[15363, 492, 69, 2, 32, "Input"],
Cell[15435, 496, 93, 2, 32, "Input",
  Evaluatable->False],
Cell[15531, 500, 54, 0, 27, "Text"],
Cell[15588, 502, 105, 2, 32, "Input",
  Evaluatable->False],
Cell[15696, 506, 72, 2, 32, "Input"],
Cell[15771, 510, 74, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[15882, 517, 34, 0, 38, "Subsection"],
Cell[15919, 519, 90, 2, 32, "Input"],
Cell[16012, 523, 76, 2, 36, "Input",
  InitializationCell->True],
Cell[16091, 527, 53, 1, 36, "Input"],
Cell[16147, 530, 60, 1, 36, "Input"],
Cell[16210, 533, 53, 1, 36, "Input"],
Cell[16266, 536, 101, 2, 32, "Input"],
Cell[16370, 540, 104, 2, 32, "Input"],
Cell[16477, 544, 70, 2, 32, "Input"],
Cell[16550, 548, 69, 2, 32, "Input"],
Cell[16622, 552, 228, 4, 46, "Text"],
Cell[16853, 558, 159, 4, 56, "Input"],
Cell[17015, 564, 66, 2, 32, "Input"],
Cell[17084, 568, 70, 2, 32, "Input"],
Cell[17157, 572, 48, 0, 27, "Text"],
Cell[17208, 574, 82, 2, 32, "Input"],
Cell[17293, 578, 83, 2, 32, "Input"],
Cell[17379, 582, 103, 3, 27, "Text"],
Cell[17485, 587, 71, 2, 32, "Input"],
Cell[17559, 591, 74, 2, 32, "Input"],
Cell[17636, 595, 155, 3, 27, "Text"],
Cell[17794, 600, 89, 2, 32, "Input"],
Cell[17886, 604, 73, 2, 32, "Input"],
Cell[17962, 608, 81, 2, 32, "Input"],
Cell[18046, 612, 87, 2, 32, "Input"],
Cell[18136, 616, 69, 2, 32, "Input"],
Cell[18208, 620, 69, 2, 32, "Input"],
Cell[18280, 624, 86, 2, 32, "Input"],
Cell[18369, 628, 70, 2, 32, "Input"],
Cell[18442, 632, 53, 1, 36, "Input"],
Cell[18498, 635, 76, 2, 32, "Input"],
Cell[18577, 639, 82, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[18696, 646, 59, 0, 38, "Subsection"],
Cell[18758, 648, 267, 5, 46, "Text"],
Cell[19028, 655, 97, 2, 32, "Input"],
Cell[19128, 659, 80, 2, 32, "Input"],
Cell[19211, 663, 56, 0, 27, "Text"],
Cell[19270, 665, 90, 2, 32, "Input"],
Cell[19363, 669, 45, 0, 27, "Text"],
Cell[19411, 671, 106, 2, 32, "Input"],
Cell[19520, 675, 56, 0, 27, "Text"],
Cell[19579, 677, 94, 2, 32, "Input"],
Cell[19676, 681, 79, 2, 32, "Input"],
Cell[19758, 685, 172, 3, 33, "Input"],
Cell[19933, 690, 57, 0, 27, "Text"],
Cell[19993, 692, 246, 7, 56, "Input"],
Cell[20242, 701, 97, 2, 27, "Text"],
Cell[20342, 705, 305, 6, 56, "Input",
  Evaluatable->False],
Cell[20650, 713, 112, 4, 27, "Text"],
Cell[20765, 719, 81, 2, 32, "Input"],
Cell[20849, 723, 68, 0, 27, "Text"],
Cell[20920, 725, 89, 2, 32, "Input"],
Cell[21012, 729, 40, 0, 27, "Text"],
Cell[21055, 731, 115, 2, 32, "Input"],
Cell[21173, 735, 209, 4, 46, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[21431, 745, 28, 0, 92, "Section"],
Cell[21462, 747, 839, 17, 108, "Text"],

Cell[CellGroupData[{
Cell[22326, 768, 131, 3, 44, "Subsection"],

Cell[CellGroupData[{
Cell[22482, 775, 104, 2, 36, "Subsubsection"],
Cell[22589, 779, 534, 10, 84, "Text"],
Cell[23126, 791, 90, 2, 32, "Input"],
Cell[23219, 795, 91, 2, 32, "Input"],
Cell[23313, 799, 137, 3, 27, "Text"],
Cell[23453, 804, 105, 3, 27, "Text"],
Cell[23561, 809, 73, 2, 32, "Input"],
Cell[23637, 813, 664, 13, 248, "Input",
  Evaluatable->False],
Cell[24304, 828, 274, 6, 46, "Text"],
Cell[24581, 836, 72, 2, 32, "Input"],
Cell[24656, 840, 86, 2, 32, "Input"],
Cell[24745, 844, 80, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[24862, 851, 47, 0, 30, "Subsubsection"],
Cell[24912, 853, 81, 2, 32, "Input"],
Cell[24996, 857, 179, 4, 58, "Text"],
Cell[25178, 863, 129, 3, 32, "Input"],
Cell[25310, 868, 65, 0, 27, "Text"],
Cell[25378, 870, 78, 2, 32, "Input"],
Cell[25459, 874, 162, 3, 27, "Text"],
Cell[25624, 879, 128, 3, 32, "Input"],
Cell[25755, 884, 58, 0, 27, "Text"],
Cell[25816, 886, 79, 2, 32, "Input"],
Cell[25898, 890, 137, 3, 32, "Input"],
Cell[26038, 895, 92, 2, 27, "Text"],
Cell[26133, 899, 135, 3, 32, "Input"],
Cell[26271, 904, 169, 3, 56, "Input"],
Cell[26443, 909, 68, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[26548, 916, 115, 3, 30, "Subsubsection"],
Cell[26666, 921, 191, 4, 46, "Text"],
Cell[26860, 927, 194, 4, 56, "Input"],
Cell[27057, 933, 279, 5, 57, "Input"],
Cell[27339, 940, 73, 2, 32, "Input"],
Cell[27415, 944, 294, 6, 57, "Input"],
Cell[27712, 952, 87, 2, 27, "Text"],
Cell[27802, 956, 230, 5, 57, "Input",
  Evaluatable->False],
Cell[28035, 963, 79, 2, 32, "Input"],
Cell[28117, 967, 127, 3, 32, "Input"],
Cell[28247, 972, 71, 0, 27, "Text"],
Cell[28321, 974, 99, 2, 32, "Input"],
Cell[28423, 978, 45, 0, 27, "Text"],
Cell[28471, 980, 79, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[28587, 987, 136, 3, 30, "Subsubsection"],
Cell[28726, 992, 32, 0, 27, "Text"],
Cell[28761, 994, 86, 2, 32, "Input"],
Cell[28850, 998, 27, 0, 27, "Text"],
Cell[28880, 1000, 105, 2, 32, "Input"],
Cell[28988, 1004, 385, 7, 77, "Text"],
Cell[29376, 1013, 69, 2, 32, "Input"],
Cell[29448, 1017, 81, 2, 32, "Input"],
Cell[29532, 1021, 46, 0, 27, "Text"],
Cell[29581, 1023, 106, 2, 32, "Input"],
Cell[29690, 1027, 106, 3, 27, "Text"],
Cell[29799, 1032, 64, 2, 32, "Input"],
Cell[29866, 1036, 95, 2, 27, "Text"],
Cell[29964, 1040, 158, 3, 56, "Input"],
Cell[30125, 1045, 26, 0, 27, "Text"],
Cell[30154, 1047, 90, 2, 32, "Input"],
Cell[30247, 1051, 169, 3, 46, "Text"],
Cell[30419, 1056, 555, 11, 176, "Input",
  Evaluatable->False],
Cell[30977, 1069, 508, 10, 128, "Input",
  Evaluatable->False],
Cell[31488, 1081, 93, 3, 58, "Text"],
Cell[31584, 1086, 82, 2, 32, "Input"],
Cell[31669, 1090, 73, 2, 32, "Input"],
Cell[31745, 1094, 114, 3, 27, "Text"],
Cell[31862, 1099, 73, 2, 32, "Input"],
Cell[31938, 1103, 82, 2, 32, "Input"],
Cell[32023, 1107, 61, 0, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[32121, 1112, 36, 0, 36, "Subsubsection"],
Cell[32160, 1114, 72, 0, 27, "Text"],
Cell[32235, 1116, 75, 2, 32, "Input"],
Cell[32313, 1120, 79, 2, 32, "Input"],
Cell[32395, 1124, 68, 2, 32, "Input"],
Cell[32466, 1128, 73, 2, 32, "Input"],
Cell[32542, 1132, 99, 2, 32, "Input"],
Cell[32644, 1136, 82, 2, 32, "Input"],
Cell[32729, 1140, 181, 4, 46, "Text"],
Cell[32913, 1146, 107, 2, 32, "Input"],
Cell[33023, 1150, 87, 2, 32, "Input"],
Cell[33113, 1154, 778, 17, 103, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[33928, 1176, 114, 3, 36, "Subsubsection"],
Cell[34045, 1181, 237, 4, 46, "Text"],
Cell[34285, 1187, 69, 2, 32, "Input"],
Cell[34357, 1191, 110, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[34504, 1198, 38, 0, 30, "Subsubsection"],
Cell[34545, 1200, 82, 2, 32, "Input"],
Cell[34630, 1204, 75, 2, 32, "Input"],
Cell[34708, 1208, 75, 2, 32, "Input"],
Cell[34786, 1212, 75, 2, 32, "Input"],
Cell[34864, 1216, 75, 0, 27, "Text"],
Cell[34942, 1218, 106, 2, 32, "Input"],
Cell[35051, 1222, 226, 5, 80, "Input"],
Cell[35280, 1229, 65, 2, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[35394, 1237, 32, 0, 38, "Subsection"],
Cell[35429, 1239, 206, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[35660, 1247, 48, 0, 36, "Subsubsection"],
Cell[35711, 1249, 70, 2, 32, "Input"],
Cell[35784, 1253, 159, 3, 46, "Text"],
Cell[35946, 1258, 833, 15, 344, "Input"],
Cell[36782, 1275, 69, 0, 27, "Text"],
Cell[36854, 1277, 87, 2, 32, "Input"],
Cell[36944, 1281, 238, 4, 56, "Input"],
Cell[37185, 1287, 135, 3, 32, "Input"],
Cell[37323, 1292, 69, 2, 32, "Input"],
Cell[37395, 1296, 103, 3, 27, "Text"],
Cell[37501, 1301, 268, 6, 80, "Input",
  Evaluatable->False],
Cell[37772, 1309, 78, 2, 32, "Input"],
Cell[37853, 1313, 78, 2, 32, "Input"],
Cell[37934, 1317, 57, 0, 27, "Text"],
Cell[37994, 1319, 77, 2, 32, "Input"],
Cell[38074, 1323, 92, 2, 32, "Input"],
Cell[38169, 1327, 40, 0, 27, "Text"],
Cell[38212, 1329, 84, 2, 32, "Input"],
Cell[38299, 1333, 109, 2, 32, "Input"],
Cell[38411, 1337, 458, 7, 84, "Text"],
Cell[38872, 1346, 70, 2, 32, "Input"],
Cell[38945, 1350, 726, 15, 248, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[39708, 1370, 33, 0, 30, "Subsubsection"],
Cell[39744, 1372, 97, 2, 32, "Input"],
Cell[39844, 1376, 70, 2, 32, "Input"],
Cell[39917, 1380, 77, 2, 32, "Input"],
Cell[39997, 1384, 119, 3, 32, "Input"],
Cell[40119, 1389, 85, 2, 32, "Input"],
Cell[40207, 1393, 76, 2, 32, "Input"],
Cell[40286, 1397, 119, 3, 32, "Input"],
Cell[40408, 1402, 48, 0, 27, "Text"],
Cell[40459, 1404, 77, 2, 32, "Input"],
Cell[40539, 1408, 83, 2, 32, "Input"],
Cell[40625, 1412, 74, 0, 27, "Text"],
Cell[40702, 1414, 76, 2, 32, "Input"],
Cell[40781, 1418, 119, 3, 32, "Input"],
Cell[40903, 1423, 67, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[41007, 1430, 55, 0, 30, "Subsubsection"],
Cell[41065, 1432, 201, 4, 46, "Text"],
Cell[41269, 1438, 756, 13, 272, "Input"],
Cell[42028, 1453, 110, 2, 32, "Input"],
Cell[42141, 1457, 105, 2, 32, "Input"],
Cell[42249, 1461, 76, 2, 32, "Input"],
Cell[42328, 1465, 119, 3, 32, "Input"],
Cell[42450, 1470, 107, 2, 32, "Input"],
Cell[42560, 1474, 76, 2, 32, "Input"],
Cell[42639, 1478, 120, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42796, 1486, 59, 0, 30, "Subsubsection"],
Cell[42858, 1488, 89, 2, 27, "Text"],
Cell[42950, 1492, 69, 2, 32, "Input"],
Cell[43022, 1496, 97, 2, 27, "Text"],
Cell[43122, 1500, 105, 2, 32, "Input"],
Cell[43230, 1504, 117, 2, 32, "Input"],
Cell[43350, 1508, 77, 2, 32, "Input"],
Cell[43430, 1512, 120, 3, 32, "Input"],
Cell[43553, 1517, 70, 2, 32, "Input"],
Cell[43626, 1521, 74, 2, 32, "Input"],
Cell[43703, 1525, 97, 2, 32, "Input"],
Cell[43803, 1529, 71, 2, 32, "Input"],
Cell[43877, 1533, 76, 2, 32, "Input"],
Cell[43956, 1537, 81, 2, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[44086, 1545, 83, 1, 38, "Subsection"],
Cell[44172, 1548, 255, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[44452, 1557, 86, 1, 36, "Subsubsection"],
Cell[44541, 1560, 76, 2, 32, "Input"],
Cell[44620, 1564, 855, 16, 296, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[45512, 1585, 33, 0, 30, "Subsubsection"],
Cell[45548, 1587, 87, 2, 32, "Input"],
Cell[45638, 1591, 87, 2, 32, "Input"],
Cell[45728, 1595, 88, 2, 32, "Input"],
Cell[45819, 1599, 88, 2, 32, "Input"],
Cell[45910, 1603, 88, 2, 32, "Input"],
Cell[46001, 1607, 115, 3, 27, "Text"],
Cell[46119, 1612, 176, 4, 56, "Input"],
Cell[46298, 1618, 424, 7, 65, "Text"],
Cell[46725, 1627, 209, 5, 56, "Input"],
Cell[46937, 1634, 62, 2, 32, "Input"],
Cell[47002, 1638, 75, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[47114, 1645, 59, 0, 30, "Subsubsection"],
Cell[47176, 1647, 107, 3, 27, "Text"],
Cell[47286, 1652, 282, 7, 80, "Input",
  Evaluatable->False],
Cell[47571, 1661, 85, 2, 27, "Text"],
Cell[47659, 1665, 73, 2, 32, "Input"],
Cell[47735, 1669, 87, 2, 27, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[47871, 1677, 47, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[47943, 1681, 58, 0, 36, "Subsubsection"],
Cell[48004, 1683, 146, 4, 32, "Input"],
Cell[48153, 1689, 73, 2, 32, "Input"],
Cell[48229, 1693, 154, 4, 32, "Input"],
Cell[48386, 1699, 74, 2, 32, "Input"],
Cell[48463, 1703, 69, 2, 32, "Input"],
Cell[48535, 1707, 119, 3, 32, "Input"],
Cell[48657, 1712, 540, 8, 103, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[49234, 1725, 61, 0, 36, "Subsubsection"],
Cell[49298, 1727, 101, 2, 32, "Input"],
Cell[49402, 1731, 74, 2, 32, "Input"],
Cell[49479, 1735, 109, 2, 32, "Input"],
Cell[49591, 1739, 74, 2, 32, "Input"],
Cell[49668, 1743, 67, 2, 32, "Input"],
Cell[49738, 1747, 144, 4, 32, "Input"],
Cell[49885, 1753, 98, 2, 32, "Input"],
Cell[49986, 1757, 68, 2, 32, "Input"],
Cell[50057, 1761, 119, 3, 32, "Input"],
Cell[50179, 1766, 152, 4, 32, "Input"],
Cell[50334, 1772, 74, 2, 32, "Input"],
Cell[50411, 1776, 134, 3, 27, "Text"],
Cell[50548, 1781, 175, 4, 56, "Input"],
Cell[50726, 1787, 68, 0, 27, "Text"],
Cell[50797, 1789, 76, 2, 32, "Input"],
Cell[50876, 1793, 247, 4, 46, "Text"],
Cell[51126, 1799, 64, 2, 32, "Input"],
Cell[51193, 1803, 154, 4, 32, "Input"],
Cell[51350, 1809, 74, 2, 32, "Input"],
Cell[51427, 1813, 162, 4, 56, "Input"],
Cell[51592, 1819, 74, 2, 32, "Input"],
Cell[51669, 1823, 119, 3, 32, "Input"],
Cell[51791, 1828, 134, 4, 32, "Input"],
Cell[51928, 1834, 176, 5, 56, "Input"],
Cell[52107, 1841, 74, 2, 32, "Input"],
Cell[52184, 1845, 184, 5, 104, "Input"],
Cell[52371, 1852, 74, 2, 32, "Input"],
Cell[52448, 1856, 102, 3, 27, "Text"],
Cell[52553, 1861, 176, 5, 56, "Input"],
Cell[52732, 1868, 74, 2, 32, "Input"],
Cell[52809, 1872, 184, 5, 104, "Input"],
Cell[52996, 1879, 74, 2, 32, "Input"],
Cell[53073, 1883, 109, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[53219, 1891, 68, 0, 30, "Subsubsection"],
Cell[53290, 1893, 143, 4, 58, "Text"],
Cell[53436, 1899, 105, 2, 32, "Input"],
Cell[53544, 1903, 87, 2, 32, "Input"],
Cell[53634, 1907, 150, 4, 32, "Input"],
Cell[53787, 1913, 135, 3, 27, "Text"],
Cell[53925, 1918, 155, 5, 27, "Text"],
Cell[54083, 1925, 69, 1, 36, "Input"],
Cell[54155, 1928, 62, 2, 32, "Input"],
Cell[54220, 1932, 81, 1, 36, "Input"],
Cell[54304, 1935, 86, 2, 32, "Input"],
Cell[54393, 1939, 81, 1, 36, "Input"],
Cell[54477, 1942, 96, 2, 32, "Input"],
Cell[54576, 1946, 100, 2, 32, "Input"],
Cell[54679, 1950, 99, 2, 33, "Input"],
Cell[54781, 1954, 92, 2, 33, "Input"],
Cell[54876, 1958, 99, 2, 33, "Input"],
Cell[54978, 1962, 57, 0, 27, "Text"],
Cell[55038, 1964, 109, 2, 33, "Input"],
Cell[55150, 1968, 109, 2, 33, "Input"],
Cell[55262, 1972, 238, 4, 58, "Text"],
Cell[55503, 1978, 155, 4, 56, "Input"],
Cell[55661, 1984, 91, 2, 27, "Text"],
Cell[55755, 1988, 88, 2, 32, "Input"],
Cell[55846, 1992, 79, 2, 32, "Input"],
Cell[55928, 1996, 162, 4, 56, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[56139, 2006, 70, 0, 38, "Subsection"],

Cell[CellGroupData[{
Cell[56234, 2010, 44, 0, 36, "Subsubsection"],
Cell[56281, 2012, 350, 6, 65, "Text"],
Cell[56634, 2020, 160, 6, 27, "Text"],
Cell[56797, 2028, 184, 4, 46, "Text"],
Cell[56984, 2034, 133, 3, 32, "Input"],
Cell[57120, 2039, 67, 2, 32, "Input"],
Cell[57190, 2043, 68, 0, 27, "Text"],
Cell[57261, 2045, 76, 2, 32, "Input"],
Cell[57340, 2049, 269, 5, 46, "Text"],
Cell[57612, 2056, 98, 2, 32, "Input"],
Cell[57713, 2060, 69, 2, 32, "Input"],
Cell[57785, 2064, 79, 2, 32, "Input"],
Cell[57867, 2068, 88, 2, 32, "Input"],
Cell[57958, 2072, 271, 5, 46, "Text"],
Cell[58232, 2079, 70, 2, 32, "Input"],
Cell[58305, 2083, 141, 4, 32, "Input",
  Evaluatable->False],
Cell[58449, 2089, 67, 0, 27, "Text"],
Cell[58519, 2091, 275, 5, 46, "Text"],
Cell[58797, 2098, 321, 6, 56, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[59155, 2109, 41, 0, 30, "Subsubsection"],
Cell[59199, 2111, 112, 3, 27, "Text"],
Cell[59314, 2116, 434, 7, 223, "Input"],
Cell[59751, 2125, 68, 0, 27, "Text"],
Cell[59822, 2127, 95, 2, 32, "Input"],
Cell[59920, 2131, 60, 0, 27, "Text"],
Cell[59983, 2133, 100, 2, 32, "Input"],
Cell[60086, 2137, 40, 0, 27, "Text"],
Cell[60129, 2139, 100, 2, 32, "Input"],
Cell[60232, 2143, 74, 2, 32, "Input"],
Cell[60309, 2147, 74, 2, 32, "Input"],
Cell[60386, 2151, 219, 5, 58, "Text"],
Cell[60608, 2158, 76, 2, 32, "Input"],
Cell[60687, 2162, 96, 2, 27, "Text"],
Cell[60786, 2166, 90, 2, 32, "Input"],
Cell[60879, 2170, 37, 0, 27, "Text"],
Cell[60919, 2172, 76, 2, 32, "Input"],
Cell[60998, 2176, 133, 3, 27, "Text"],
Cell[61134, 2181, 376, 12, 56, "Input"],
Cell[61513, 2195, 223, 4, 46, "Text"],
Cell[61739, 2201, 95, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[61871, 2208, 44, 0, 30, "Subsubsection"],
Cell[61918, 2210, 71, 0, 27, "Text"],
Cell[61992, 2212, 80, 2, 32, "Input"],
Cell[62075, 2216, 158, 3, 56, "Input"],
Cell[62236, 2221, 46, 0, 27, "Text"],
Cell[62285, 2223, 95, 2, 32, "Input"],
Cell[62383, 2227, 100, 2, 32, "Input"],
Cell[62486, 2231, 103, 2, 32, "Input"],
Cell[62592, 2235, 85, 2, 32, "Input"],
Cell[62680, 2239, 105, 2, 32, "Input"],
Cell[62788, 2243, 104, 2, 32, "Input"],
Cell[62895, 2247, 21, 0, 27, "Text"],
Cell[62919, 2249, 81, 2, 32, "Input"],
Cell[63003, 2253, 81, 2, 32, "Input"],
Cell[63087, 2257, 104, 2, 32, "Input"],
Cell[63194, 2261, 149, 3, 56, "Input"],
Cell[63346, 2266, 103, 3, 27, "Text"],
Cell[63452, 2271, 153, 4, 56, "Input"],
Cell[63608, 2277, 65, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[63710, 2284, 55, 0, 30, "Subsubsection"],
Cell[63768, 2286, 445, 8, 152, "Input"],
Cell[64216, 2296, 228, 4, 46, "Text"],
Cell[64447, 2302, 78, 2, 32, "Input"],
Cell[64528, 2306, 73, 2, 32, "Input"],
Cell[64604, 2310, 96, 2, 32, "Input"],
Cell[64703, 2314, 90, 2, 32, "Input"],
Cell[64796, 2318, 94, 2, 32, "Input"],
Cell[64893, 2322, 105, 2, 32, "Input"],
Cell[65001, 2326, 128, 3, 32, "Input"],
Cell[65132, 2331, 93, 2, 32, "Input"],
Cell[65228, 2335, 143, 4, 32, "Input"],
Cell[65374, 2341, 95, 2, 32, "Input"],
Cell[65472, 2345, 196, 4, 46, "Text"],
Cell[65671, 2351, 131, 3, 32, "Input"],
Cell[65805, 2356, 69, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[65911, 2363, 41, 0, 30, "Subsubsection"],
Cell[65955, 2365, 676, 10, 103, "Text"],
Cell[66634, 2377, 78, 2, 32, "Input"],
Cell[66715, 2381, 73, 2, 32, "Input"],
Cell[66791, 2385, 96, 2, 32, "Input"],
Cell[66890, 2389, 90, 2, 32, "Input"],
Cell[66983, 2393, 101, 2, 32, "Input"],
Cell[67087, 2397, 95, 2, 32, "Input"],
Cell[67185, 2401, 62, 2, 32, "Input"],
Cell[67250, 2405, 103, 2, 32, "Input"],
Cell[67356, 2409, 102, 2, 32, "Input"],
Cell[67461, 2413, 65, 2, 32, "Input"],
Cell[67529, 2417, 136, 3, 32, "Input"],
Cell[67668, 2422, 80, 2, 32, "Input"],
Cell[67751, 2426, 221, 4, 46, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[68033, 2437, 42, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[68100, 2441, 43, 0, 44, "Subsection"],
Cell[68146, 2443, 430, 7, 68, "Text"],
Cell[68579, 2452, 68, 2, 31, "Input"],
Cell[68650, 2456, 170, 4, 54, "Input",
  Evaluatable->False],
Cell[68823, 2462, 263, 5, 48, "Text"],
Cell[69089, 2469, 71, 2, 31, "Input"],
Cell[69163, 2473, 79, 2, 31, "Input"],
Cell[69245, 2477, 108, 2, 31, "Input"],
Cell[69356, 2481, 69, 2, 31, "Input"],
Cell[69428, 2485, 107, 3, 28, "Text"],
Cell[69538, 2490, 113, 2, 31, "Input"],
Cell[69654, 2494, 121, 3, 28, "Text"],
Cell[69778, 2499, 169, 4, 31, "Input",
  Evaluatable->False],
Cell[69950, 2505, 77, 2, 31, "Input"],
Cell[70030, 2509, 146, 3, 28, "Text"],
Cell[70179, 2514, 86, 2, 31, "Input"],
Cell[70268, 2518, 264, 9, 28, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[70569, 2532, 159, 3, 39, "Subsection"],
Cell[70731, 2537, 251, 4, 48, "Text"],
Cell[70985, 2543, 113, 2, 31, "Input"],
Cell[71101, 2547, 165, 3, 48, "Text"],

Cell[CellGroupData[{
Cell[71291, 2554, 32, 0, 37, "Subsubsection"],
Cell[71326, 2556, 38, 0, 27, "Text"],
Cell[71367, 2558, 126, 3, 32, "Input",
  InitializationCell->True],
Cell[71496, 2563, 79, 2, 32, "Input"],
Cell[71578, 2567, 80, 2, 32, "Input"],
Cell[71661, 2571, 70, 2, 32, "Input"],
Cell[71734, 2575, 98, 2, 32, "Input"],
Cell[71835, 2579, 70, 2, 32, "Input"],
Cell[71908, 2583, 76, 2, 32, "Input"],
Cell[71987, 2587, 92, 2, 32, "Input"],
Cell[72082, 2591, 89, 2, 32, "Input"],
Cell[72174, 2595, 66, 2, 32, "Input"],
Cell[72243, 2599, 53, 0, 27, "Text"],
Cell[72299, 2601, 77, 2, 32, "Input"],
Cell[72379, 2605, 70, 2, 32, "Input"],
Cell[72452, 2609, 69, 2, 32, "Input"],
Cell[72524, 2613, 74, 2, 32, "Input"],
Cell[72601, 2617, 216, 4, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[72854, 2626, 44, 0, 31, "Subsubsection"],
Cell[72901, 2628, 98, 2, 27, "Text"],
Cell[73002, 2632, 85, 2, 32, "Input"],
Cell[73090, 2636, 70, 2, 32, "Input"],
Cell[73163, 2640, 85, 2, 32, "Input"],
Cell[73251, 2644, 133, 3, 32, "Input"],
Cell[73387, 2649, 165, 3, 27, "Text"],
Cell[73555, 2654, 89, 2, 32, "Input"],
Cell[73647, 2658, 133, 3, 32, "Input"],
Cell[73783, 2663, 71, 0, 27, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[73903, 2669, 164, 3, 39, "Subsection"],
Cell[74070, 2674, 236, 4, 46, "Text"],
Cell[74309, 2680, 140, 3, 32, "Input"],
Cell[74452, 2685, 77, 2, 32, "Input"],
Cell[74532, 2689, 208, 4, 46, "Text"],
Cell[74743, 2695, 73, 2, 32, "Input"],
Cell[74819, 2699, 73, 0, 27, "Text"],
Cell[74895, 2701, 108, 3, 27, "Text"],
Cell[75006, 2706, 83, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[75126, 2713, 289, 10, 39, "Subsection"],
Cell[75418, 2725, 216, 5, 77, "Text"],

Cell[CellGroupData[{
Cell[75659, 2734, 42, 0, 36, "Subsubsection"],
Cell[75704, 2736, 93, 2, 32, "Input"],
Cell[75800, 2740, 69, 2, 32, "Input"],
Cell[75872, 2744, 230, 4, 46, "Text"],
Cell[76105, 2750, 74, 2, 32, "Input"],
Cell[76182, 2754, 75, 2, 32, "Input"],
Cell[76260, 2758, 143, 4, 32, "Input"],
Cell[76406, 2764, 73, 2, 32, "Input"],
Cell[76482, 2768, 65, 2, 32, "Input"],
Cell[76550, 2772, 84, 2, 32, "Input"],
Cell[76637, 2776, 66, 2, 32, "Input"],
Cell[76706, 2780, 79, 2, 32, "Input"],
Cell[76788, 2784, 71, 2, 32, "Input"],
Cell[76862, 2788, 69, 2, 32, "Input"],
Cell[76934, 2792, 70, 2, 32, "Input"],
Cell[77007, 2796, 229, 6, 27, "Text"],
Cell[77239, 2804, 74, 2, 32, "Input"],
Cell[77316, 2808, 96, 2, 32, "Input"],
Cell[77415, 2812, 56, 0, 27, "Text"],
Cell[77474, 2814, 81, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[77592, 2821, 43, 0, 36, "Subsubsection"],
Cell[77638, 2823, 93, 2, 32, "Input"],
Cell[77734, 2827, 69, 2, 32, "Input"],
Cell[77806, 2831, 231, 4, 46, "Text"],
Cell[78040, 2837, 74, 2, 32, "Input"],
Cell[78117, 2841, 75, 2, 32, "Input"],
Cell[78195, 2845, 143, 4, 32, "Input"],
Cell[78341, 2851, 74, 2, 32, "Input"],
Cell[78418, 2855, 72, 2, 32, "Input"],
Cell[78493, 2859, 71, 2, 32, "Input"],
Cell[78567, 2863, 229, 6, 27, "Text"],
Cell[78799, 2871, 75, 2, 32, "Input"],
Cell[78877, 2875, 97, 2, 32, "Input"],
Cell[78977, 2879, 63, 0, 27, "Text"],
Cell[79043, 2881, 83, 2, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[79175, 2889, 62, 0, 38, "Subsection"],
Cell[79240, 2891, 149, 3, 27, "Text"],
Cell[79392, 2896, 109, 2, 32, "Input"],
Cell[79504, 2900, 69, 2, 32, "Input"],
Cell[79576, 2904, 205, 4, 56, "Input"],
Cell[79784, 2910, 69, 2, 32, "Input"],
Cell[79856, 2914, 277, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[80158, 2923, 32, 0, 36, "Subsubsection"],
Cell[80193, 2925, 130, 3, 27, "Text"],
Cell[80326, 2930, 85, 2, 32, "Input"],
Cell[80414, 2934, 64, 2, 32, "Input"],
Cell[80481, 2938, 87, 2, 32, "Input"],
Cell[80571, 2942, 78, 2, 32, "Input"],
Cell[80652, 2946, 80, 2, 32, "Input"],
Cell[80735, 2950, 69, 2, 32, "Input"],
Cell[80807, 2954, 139, 3, 32, "Input"],
Cell[80949, 2959, 65, 2, 32, "Input"],
Cell[81017, 2963, 70, 2, 32, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[81148, 2972, 50, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[81223, 2976, 74, 1, 45, "Subsection"],
Cell[81300, 2979, 1104, 17, 191, "Text",
  Evaluatable->False],
Cell[82407, 2998, 89, 2, 32, "Input"],
Cell[82499, 3002, 92, 2, 32, "Input"],
Cell[82594, 3006, 104, 2, 32, "Input"],
Cell[82701, 3010, 402, 6, 65, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[83140, 3021, 102, 2, 39, "Subsection",
  Evaluatable->False],
Cell[83245, 3025, 735, 11, 103, "Text",
  Evaluatable->False],
Cell[83983, 3038, 140, 4, 27, "Text",
  Evaluatable->False],
Cell[84126, 3044, 153, 5, 61, "Input"],
Cell[84282, 3051, 67, 2, 32, "Input"],
Cell[84352, 3055, 67, 2, 32, "Input"],
Cell[84422, 3059, 68, 2, 32, "Input"],
Cell[84493, 3063, 72, 2, 32, "Input"],
Cell[84568, 3067, 118, 3, 32, "Input"],
Cell[84689, 3072, 351, 6, 65, "Text"],
Cell[85043, 3080, 166, 4, 56, "Input"],
Cell[85212, 3086, 94, 2, 32, "Input"],
Cell[85309, 3090, 69, 2, 32, "Input"],
Cell[85381, 3094, 265, 5, 46, "Text"],
Cell[85649, 3101, 112, 2, 32, "Input"],
Cell[85764, 3105, 465, 7, 84, "Text"],
Cell[86232, 3114, 339, 6, 128, "Input"],
Cell[86574, 3122, 339, 6, 128, "Input"],
Cell[86916, 3130, 344, 6, 128, "Input"],
Cell[87263, 3138, 722, 11, 103, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[88022, 3154, 83, 2, 39, "Subsection",
  Evaluatable->False],
Cell[88108, 3158, 259, 6, 89, "Text",
  Evaluatable->False],
Cell[88370, 3166, 351, 10, 80, "Input"],
Cell[88724, 3178, 88, 3, 32, "Input"],
Cell[88815, 3183, 73, 2, 32, "Input"],
Cell[88891, 3187, 75, 2, 32, "Input"],
Cell[88969, 3191, 227, 7, 32, "Input"],
Cell[89199, 3200, 121, 3, 27, "Text",
  Evaluatable->False],
Cell[89323, 3205, 138, 3, 32, "Input"],
Cell[89464, 3210, 69, 2, 32, "Input"],
Cell[89536, 3214, 82, 2, 32, "Input"],
Cell[89621, 3218, 72, 2, 32, "Input"],
Cell[89696, 3222, 109, 2, 32, "Input"],
Cell[89808, 3226, 866, 20, 127, "Text",
  Evaluatable->False],
Cell[90677, 3248, 344, 10, 80, "Input"],
Cell[91024, 3260, 65, 2, 32, "Input"],
Cell[91092, 3264, 75, 2, 32, "Input"],
Cell[91170, 3268, 77, 2, 32, "Input"],
Cell[91250, 3272, 84, 2, 32, "Input"],
Cell[91337, 3276, 75, 2, 32, "Input"],
Cell[91415, 3280, 110, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[91562, 3287, 83, 2, 39, "Subsection",
  Evaluatable->False],
Cell[91648, 3291, 518, 11, 139, "Text",
  Evaluatable->False],
Cell[92169, 3304, 115, 3, 56, "Input"],
Cell[92287, 3309, 445, 8, 65, "Text",
  Evaluatable->False],
Cell[92735, 3319, 78, 2, 32, "Input"],
Cell[92816, 3323, 225, 4, 46, "Text"],
Cell[93044, 3329, 164, 4, 80, "Input"],
Cell[93211, 3335, 39, 0, 27, "Text"],
Cell[93253, 3337, 80, 2, 32, "Input"],
Cell[93336, 3341, 70, 2, 32, "Input"],
Cell[93409, 3345, 192, 4, 46, "Text"],
Cell[93604, 3351, 84, 1, 27, "Text",
  Evaluatable->False],
Cell[93691, 3354, 321, 10, 56, "Input"],
Cell[94015, 3366, 88, 3, 32, "Input"],
Cell[94106, 3371, 70, 2, 32, "Input"],
Cell[94179, 3375, 76, 2, 32, "Input"],
Cell[94258, 3379, 225, 7, 32, "Input"],
Cell[94486, 3388, 149, 3, 27, "Text"],
Cell[94638, 3393, 78, 2, 32, "Input"],
Cell[94719, 3397, 331, 10, 56, "Input"],
Cell[95053, 3409, 65, 2, 32, "Input"],
Cell[95121, 3413, 88, 2, 27, "Text"],
Cell[95212, 3417, 92, 2, 32, "Input"],
Cell[95307, 3421, 509, 8, 84, "Text"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[95865, 3435, 64, 1, 106, "Section",
  CellTags->"MathGL"],
Cell[95932, 3438, 259, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[96216, 3448, 38, 0, 44, "Subsection"],
Cell[96257, 3450, 253, 5, 46, "Text",
  Evaluatable->False],
Cell[96513, 3457, 170, 4, 46, "Text",
  Evaluatable->False],
Cell[96686, 3463, 92, 2, 32, "Input"],
Cell[96781, 3467, 74, 2, 32, "Input"],
Cell[96858, 3471, 138, 4, 27, "Text",
  Evaluatable->False],
Cell[96999, 3477, 95, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[97131, 3484, 34, 0, 38, "Subsection"],
Cell[97168, 3486, 771, 17, 134, "Text"],
Cell[97942, 3505, 91, 2, 32, "Input"],
Cell[98036, 3509, 52, 0, 27, "Text"],
Cell[98091, 3511, 50, 1, 27, "Text"],
Cell[98144, 3514, 141, 3, 27, "Text"],
Cell[98288, 3519, 482, 9, 152, "Input"],
Cell[98773, 3530, 159, 3, 56, "Input"],
Cell[98935, 3535, 109, 2, 32, "Input"],
Cell[99047, 3539, 104, 2, 32, "Input"],
Cell[99154, 3543, 76, 2, 32, "Input"],
Cell[99233, 3547, 75, 2, 32, "Input"],
Cell[99311, 3551, 67, 2, 32, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[99427, 3559, 27, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[99479, 3563, 69, 0, 44, "Subsection"],
Cell[99551, 3565, 71, 2, 32, "Input"],
Cell[99625, 3569, 240, 4, 46, "Text"],
Cell[99868, 3575, 145, 3, 32, "Input"],
Cell[100016, 3580, 89, 2, 32, "Input"],
Cell[100108, 3584, 145, 3, 32, "Input"],
Cell[100256, 3589, 89, 2, 32, "Input"],
Cell[100348, 3593, 145, 3, 32, "Input"],
Cell[100496, 3598, 89, 2, 32, "Input"],
Cell[100588, 3602, 145, 3, 32, "Input"],
Cell[100736, 3607, 89, 2, 32, "Input"],
Cell[100828, 3611, 76, 2, 32, "Input"],
Cell[100907, 3615, 214, 4, 46, "Text"],
Cell[101124, 3621, 73, 2, 32, "Input"],
Cell[101200, 3625, 677, 12, 224, "Input",
  Evaluatable->False],
Cell[101880, 3639, 100, 2, 32, "Input"],
Cell[101983, 3643, 145, 4, 32, "Input"],
Cell[102131, 3649, 77, 2, 32, "Input"],
Cell[102211, 3653, 128, 3, 32, "Input"],
Cell[102342, 3658, 209, 4, 46, "Text"],
Cell[102554, 3664, 118, 3, 27, "Text"],
Cell[102675, 3669, 411, 8, 152, "Input"],
Cell[103089, 3679, 105, 2, 32, "Input"],
Cell[103197, 3683, 82, 2, 32, "Input"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[103328, 3691, 56, 1, 32, "Subsubtitle"],
Cell[103387, 3694, 132, 4, 40, "Text",
  CellTags->"Cox"],
Cell[103522, 3700, 186, 4, 59, "Text",
  CellTags->"G1"],
Cell[103711, 3706, 126, 4, 40, "Text",
  CellTags->"K2"],
Cell[103840, 3712, 246, 8, 40, "Text",
  CellTags->"O-S"],
Cell[104089, 3722, 140, 4, 40, "Text",
  CellTags->"S1"],
Cell[104232, 3728, 517, 15, 59, "Text",
  Evaluatable->False,
  CellTags->"S2"]
}, Closed]],

Cell[CellGroupData[{
Cell[104786, 3748, 62, 1, 24, "Subsubtitle"],
Cell[104851, 3751, 107, 5, 102, "Text",
  CellTags->"HP"],
Cell[104961, 3758, 47, 0, 27, "Text"],
Cell[105011, 3760, 90, 2, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

