(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    251530,       9142]*)
(*NotebookOutlinePosition[    254567,       9245]*)
(*  CellTagsIndexPosition[    254135,       9225]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  " Pairs of Subspheres in ",
  Cell[BoxData[
      \(TraditionalForm\`S\^3\)]]
}], "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center],

Cell["by", "Subsubtitle",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Times",
  FontSize->14,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1]],

Cell["Rolf Sulanke", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontSize->24],

Cell["April 14, 1999, last revision January 26, 2004", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center],

Cell["Last time used:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Date[]\)], "Input",
  CellLabel->"In[59]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \({2004, 2, 2, 10, 33, 8}\)], "Output",
  CellLabel->"Out[59]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection",
  TextAlignment->Left,
  FontFamily->"Times"],

Cell[TextData[{
  "This notebook describes the Moebius invariants for pairs of subspheres in \
",
  Cell[BoxData[
      \(TraditionalForm\`S\^3\)]],
  ", or, by stereographic projection, in the euclidean 3-space . The most \
important cases, pairs of spheres and pairs of circles, are treated in the \
notebooks mspheres.nb and mcircles.nb and the accompanying packages, some \
procedures of which are needed in the present notebook. In section 2 pairs \
consisting of a sphere and a circle are considered; they are characterized up \
to M\[ODoubleDot]bius equivalence by a single invariant moebsc. Certain \
expressions of moebsc in terms of euclidean invariants of the pairs are \
deduced. Section 3 treats pairs consisting of a sphere and a point pair; \
remember that point pairs are 0-spheres. Their mutual position is described \
again by a single invariant named moebspp. In section 4 pairs of 1-spheres \
and 0-spheres, i.e. circles and point pairs, are considered; their mutual \
position depends on two invariants: the eigenvalues of a double projection, \
see ",
  ButtonBox["[6]",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  ". Finally, section 5 treats point quadruples as pairs of  0-spheres, and \
in section 6 the geodesics in the space of  0-spheres (= point pairs) are \
considered. The last section imports  ThreeScript and MathGL3d, which can be \
applied for animations of the created 3D-graphics. \nFor differential \
geometry with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in the euclidean 3-space see Alfred Gray ",
  ButtonBox["[1]",
    ButtonData:>"G1",
    ButtonStyle->"Hyperlink"],
  ".\nFor the concepts of M\[ODoubleDot]bius geometry applied here see my  \
paper ",
  ButtonBox["[6]",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  Evaluatable->False],

Cell[TextData[{
  "A systematic description of the circle space is contained in the diploma \
paper of Uwe May ",
  ButtonBox["[3]",
    ButtonData:>"M3",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "Some tools for working in the pseudo-orthogonal Lie algebra we took from \
",
  ButtonBox["[8]",
    ButtonData:>"S8",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell["\<\
Since in the current notebook permanently concepts and functions developed in \
the other packages and notebooks of the item [5] are applied it is  \
recommended to study these notebooks, in particular \"mspheres.nb\" and \
\"mcircles.nb\", before starting with the present notebook.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Keywords: ", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
pseudo-euclidean geometry,  Moebius geometry, rank of a matrix, random \
matrix, 3D-circles, invariants of pairs of subspheres (arbitrary dimensions), \
double projection, stationary angles, eigenspheres, point pairs as 0-spheres, \
associated spheres,  point quadruples, throws, geodesics in the space of \
0-spheres,  Killing form, MathGL3d.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Version", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "This notebook is a new version of the notebook pairs.nb,  first published  \
in the item ",
  ButtonBox["[5]",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  " in MathSource. The same is true for the accompanying packages. Since \
these packages contain the most important procedures used in this and other \
notebooks, published first in the  item Spheres,and the contents as well as \
some names have been changed, the two versions should not be mixed.   The \
notebook is developed with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v. 4.200. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Copyright", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
This notebook, the linked notebooks, and the accompanying packages are  \
public. Authors who intend to publish a changed or completed version of them \
should do it under their own names with the condition that they cite the \
original notebook with the Internet address or other source where they got \
it. I am not responsible for errors or damages originated by the use of the \
procedures contained in my notebooks or packages; anybody who applies them \
should test carefully whether they are appropriate for his purposes.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  FontFamily->"Times"],

Cell[TextData[{
  "First, if not done already,  copy the ",
  StyleBox["needed packages",
    FontColor->RGBColor[0, 0, 1]],
  "  euvec.m, pseuvec.m, mspher.m, mcirc.m,  and this notebook mpairs.nb into \
your working directory, and  insert the path of your working directory, e.g. \
under Windows, \"C:\\\\Eigene Dateien\\\\mymath\\\\spheres.v4\", into the \
next command line:"
}], "Text"],

Cell[BoxData[
    \(SetDirectory["\<D:\\Dokumente und Einstellungen\\rolf\\Eigene \
Dateien\\mymath\\work\>"]\)], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[TextData[StyleBox["Now: Activite Kernel/Evaluation/Evaluate \
Initialization from the menu!",
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell["are contained in your working directory.", "Text"],

Cell[TextData[{
  "Before applying commands for graphics3D animations like ThreeScript or \
MVShow3D import first the needed tools, see section ",
  ButtonBox["7",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"],
  " .\nThe next initialization cell imports all the packages mentioned \
above:"
}], "Text"],

Cell[BoxData[
    \(Needs["\<mpairs`\>"]\)], "Input",
  CellLabel->"In[3]:=",
  InitializationCell->True,
  FontFamily->"Times"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1 Preliminaries", "Section",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["1.1 Pseudo-euclidean vector algebra and other prerequisites", \
"Subsection",
  FontFamily->"Times"],

Cell["\<\
The dimension dim of the underlying vector space and the index  ind of the \
(non-degenerate, symmetric) scalar product are now defined by\
\>", "Text"],

Cell[BoxData[
    \(dim\  = 5; \ ind\  = \ 1;\)], "Input",
  CellLabel->"In[4]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["\<\
because in this notebook the 3-dimensional sphere is treated as the \
elliptical hyperquadric in the four-dimensional projective  space, which \
belongs to the five-dimensional real vector space. You may change these \
constants any time you wants. But remember that these constants enter in many \
procedures defined in the packages or notebooks;  some of them may not work \
if dim or ind are changed.\
\>", "Text",
  Evaluatable->False],

Cell["\<\
The matrix of the scalar products of any orthonormal basis of the \
pseudo-euclidean vector space is\
\>", "Text"],

Cell[BoxData[
    \(MatrixForm[
      Table[pssp[stb[i], \ stb[j]], {i, dim}, {j, dim}]]\)], "Input",
  CellLabel->"In[5]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["\<\
Terminology: Spheres are usual 2-dimenional spheres if we consider the \
3-dimensional spherical geometry. We prefer the three-dimensional case since \
we can imagine this geometry and represent the configurations graphically. \
\>", "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["1.2 The usages", "Subsection",
  FontFamily->"Times"],

Cell["\<\
After a package has been loaded you can get information about the  listed \
concepts in the usual way, e.g.\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(\(?orthonorm\)\)], "Input",
  CellLabel->"In[18]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Context[orthonorm]\)], "Input",
  CellLabel->"In[19]:=",
  FontFamily->"Times"],

Cell["\<\
For getting the usage and the complete definition, enter e.g.\
\>", "Text"],

Cell[BoxData[
    \(?? spt\)], "Input",
  CellLabel->"In[20]:=",
  FontFamily->"Times"],

Cell["\<\
Since the names are prepended by the ContextNames the definition obtained in \
this way are hard to read. Therefore you will find some of them below in the \
original form in unevaluable cells.  It is recommended to look in the \
packages.\
\>", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["Symbols in euvec.m", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(TableForm[{"\<cross\>", "\<hyperplane\>", "\<invsterproj\>", \
"\<dotnorme\>", "\<esorthonorm\>", "\<innerprod\>", "\<normed\>", \
"\<print\>", "\<neglect\>", "\<null\>", "\<orthocomplement\>", "\<outzero\>", \
"\<randomv\>", "\<rank\>", "\<renorm\>", "\<smoothing\>", "\<sphere\>", \
"\<sphereplot3D\>", \ "\<subsphere\>", "\<subspheremf\>", \
"\<sphericalreflection\>", "\<stb\>", "\<sterproj\>", "\<tg4frame\>", "\<unit\
\>", "\<vec\>"}]\)], "Input",
  CellLabel->"In[44]:=",
  FontFamily->"Times"],

Cell["To get the usages activate the next cell!", "Text"],

Cell[BoxData[
    \(\({\(?"\<cross\>"\), \(?"\<hyperplane\>"\), \(?"\<invsterproj\>"\), \
\(?"\<dotnorme\>"\), \(?"\<esorthonorm\>"\), \(?"\<innerprod\>"\), \
\(?"\<normed\>"\), \(?"\<print\>"\), \(?"\<neglect\>"\), \(?"\<nulll\>"\), \
\(?"\<orthocomplement\>"\), \(?"\<outzero\>"\), \(?"\<randomv\>"\), \
\(?"\<rank\>"\), \(?"\<renorm\>"\), \(?"\<smoothing\>"\), \(?"\<sphere\>"\), \
\(?"\<subsphere\>"\), \(?"\<subspheremf\>"\), \(?"\<sphereplot3D\>"\), \
\(?"\<sphericalreflection\>"\), \(?"\<stb\>"\), \(?"\<sterproj\>"\), \
\(?"\<tg4frame\>"\), \(?"\<unit\>"\), \(?"\<vec\>"\)};\)\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? invsterproj\)], "Input",
  CellLabel->"In[21]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbols in pseuvec.m", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(TableForm[{"\<ch\>", "\<dual\>", "\<ide\>", "\<normalize\>", \
"\<orthonorm\>", "\<orthopair\>", "\<pr\>", "\<psCross\>", "\<pscross\>", \
"\<psfilter\>", "\<pssp\>"}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[25]:=",
  FontFamily->"Times"],

Cell["To get the usages activate the next cell!", "Text"],

Cell[BoxData[
    \(\({\(?"\<ch\>"\), \(?"\<dual\>"\), \(?"\<ide\>"\), \
\(?"\<normalize\>"\), \(?"\<orthonorm\>"\), \(?"\<orthopair\>"\), \(?"\<pr\>"\
\), \(?"\<psCross\>"\), \(?"\<pscross\>"\), \(?"\<psfilter\>"\), \
\(?"\<pssp\>"\)};\)\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?psfilter\)\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? pscross\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? psCross\)], "Input",
  CellLabel->"In[24]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbols in mspher.m", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(TableForm[{"\<coxeterinv\>", \ "\<gencos\>", \ "\<invstepro\>", \ "\
\<planevec\>", \ \n"\<euklidsphere\>", \ "\<pstg5frame\>", \ \
"\<euklidsphereplot3D\>", \ "\<vradius\>", \ "\<vcenter\>", \ \
"\<spherevec\>", \n\ "\<spt\>", "\<spunit\>", \ "\<stepro\>"}]\)\(\ \)\)\)], \
"Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell["To get the usages activate the next cell!", "Text"],

Cell[BoxData[
    \(\({\(?"\<coxeterinv\>"\), \ \(?"\<gencos\>"\), \ \(?"\<invstepro\>"\), \
\ \(?"\<planevec\>"\), \ \n\(?"\<euklidsphere\>"\), \ \(?"\<pstg5frame\>"\), \
\ \(?"\<euklidsphereplot3D\>"\), \ \(?"\<vradius\>"\), \ \(?"\<vcenter\>"\), \
\ \(?"\<spherevec\>"\), \n\ \(?"\<spt\>"\), \(?"\<spunit\>"\), \ \(?"\<stepro\
\>"\)};\)\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? spunit\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbols in mcirc.m", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Here you can get information about the commands which are defined in mcirc.m:\
\
\>", "Text"],

Cell[BoxData[
    \(TableForm[{"\<adaptsplframe\>", "\<center\>", "\<posvec\>", \
"\<radius\>", "\<center3pts\>", "\<circle2spv\>", "\<circle3D\>", \
"\<circle3pts\>", "\<circlefamily\>", "\<circleplane\>", \
"\<circlespacevectors\>", "\<control\>", "\<gencircle\>", \
"\<plotcircle2spv\>", "\<plotcircle3D\>", "\<plotcircle3pts\>", \
"\<plotgencircle\>", "\<posvec3pts\>", "\<pp\>", "\<ppdet\>", "\<pptr\>", \
"\<pscomplement\>", "\<radius3pts\>", "\<threepoints\>", "\<tube\>", \
"\<unitvec\>", "\<vspace\>"}]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell["To get the usages activate the next cell!", "Text"],

Cell[BoxData[
    \(\({\(?"\<adaptsplframe\>"\), \(?"\<center\>"\), \(?"\<posvec\>"\), \(?"\
\<radius\>"\), \(?"\<center3pts\>"\), \ \(?"\<circle2spv\>"\), \ \
\(?"\<circle3D\>"\), \(?"\<circle3pts\>"\), \(?"\<circlefamily\>"\), \
\(?"\<circleplane\>"\), \(?"\<circlespacevectors\>"\), \ \(?"\<control\>"\), \
\ \(?"\<gencircle\>"\), \ \ \ \(?"\<plotcircle2spv\>"\), \
\(?"\<plotcircle3D\>"\), \ \(?"\<plotgencircle\>"\), \
\(?"\<plotcircle3pts\>"\), \(?"\<posvec3pts\>"\), \ \(?"\<pp\>"\), \
\(?"\<ppdet\>"\), \ \(?"\<pptr\>"\), \(?"\<pscomplement\>"\), \
\(?"\<radius3pts\>"\), \(?"\<threepoints\>"\), \ \n\ \(?"\<tube\>"\), \ \
\(?"\<unitvec\>"\), \ \(?"\<vspace\>"\)};\)\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Symbols in mpairs.m", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Here you can get information about the commands which are defined in \
mpairs.m:\
\>", "Text"],

Cell[BoxData[
    \(TableForm[{"\<moebsc\>", "\<\>"}]\)], "Input",
  CellLabel->"In[42]:=",
  FontFamily->"Times"],

Cell["To get the usages activate the next cell!", "Text"],

Cell[BoxData[
    \(\({\(?"\<moebsc\>"\), \(?"\<center\>"\)};\)\)], "Input",
  CellLabel->"In[43]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2 Spheres and circles", "Section",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell["\<\
 A pair (S, C), consisting of a sphere S and a circle C of the 3-dimensional \
euclidean space or the 3-dimensional sphere,  is defined up to a M\
\[ODoubleDot]bius transform by exactly a single invariant, if C is not \
contained in S (\"general position\"); it is easy to show that all pairs (S, \
C) with C\[Subset]S are M\[ODoubleDot]bius equivalent. In the first \
subsection we calculate this invariant moebsc, then we give some examples, \
and finally we derive an expression of moebsc in terms of euclidean \
invariants of the pair (S,C). \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["2.1 The invariant moebsc", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Definition of moebsc", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
We consider the pair (S(vn), C(cn1,cn2)); here S(vn) denotes the sphere \
corresponding to the spacelike unit vector vn,  and C(cn1,cn2) the circle \
defined by the euclidean 2-space spanned by the orthonormal vectors cn1,cn2. \
Such a pair  is defined up to M\[ODoubleDot]bius equivalence by a single \
invariant:\
\>", "Text"],

Cell[BoxData[
    \(\(?moebsc\)\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(moebsc[vn, cn1, cn2]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(moebsc[vn_, cn1_, cn2_] := \ 
      pssp[vn, \ cn1]^2\  + \ \ pssp[vn, \ cn2]^2\)], "Input",
  CellLabel->"In[6]:=",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
Obviously, this invariant is independent of the choice of the generating \
vectors (vn normed, cn1,cn2 orthonormal):\
\>", "Text"],

Cell[BoxData[
    \(fct[t_]\  := \ 
      moebsc[vec[x], \ 
        stb[3]\ *Cos[t]\  + \ stb[4]*Sin[t], \(-\ stb[3]\)*Sin[t]\  + \ 
          stb[4]*Cos[t]]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fct[t]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(Simplify[fct[t]\  - fct[0]]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell["\<\
As circle we have chosen here the \"standard circle\" grc1 defined by stb[3], \
stb[4]:\
\>", "Text"],

Cell[BoxData[
    \(grc1\  = plotcircle2spv[stb[3], \ stb[4]]\)], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["Sometimes it is better to thicken the circle a bit:", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[{Cos[t], Sin[t], 0, Thickness[0.009]}, {t, 0, 
        2\ Pi}]\)], "Input",
  CellLabel->"In[7]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(grc2\  = \ %\)], "Input",
  CellLabel->"In[8]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[TextData[{
  "Choosing the standard circle is not a restriction of generality, since the \
M\[ODoubleDot]bius group acts transitively on the manifold of all circles. \
The formula for moebsc makes sense for arbitrary vectors vn = vec[x]; it \
defines an invariant of the pair of subspaces defined by vn, and cn1,cn2,  \
only if the vector vn is normalized (cn1,cn2 assumed to be orthonormal). If \
vn is timelike, it defines a hyperbolic 3-dimensional linear complex of \
spheres: This are all the spheres corressponding to spacelike unit vectors \
orthogonal to vn. In this case, moebsc[vn, cn1,cn2] = 0 if and only iff all \
spheres containing the circle C(cn1,cn2) belong to the linear sphere complex \
defined by vn. For isotropic vectors vn = vec[x] only the vanishing of moebsc \
is an invariant property. Let p denote the point of ",
  Cell[BoxData[
      \(S\^3\)]],
  " defined by the isotropic vector vn. Then we have\nmoebsc[vn, cn1,cn2] = 0 \
<==> p \[Element] C.\nOne easily proves that the M\[ODoubleDot]bius group \
acts transitively on each of the manifolds of pairs\n{(p, C) |  p \[Element] \
C},  {(p, C) |  p \[Element] ",
  Cell[BoxData[
      \(S\^3\)]],
  " \\  C}.\n(Exercise: Show this using pseudo-orthogonal linear algebra.)"
}], "Text"],

Cell[BoxData[
    \(Clear[fct]\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2 Examples", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Inclusion: rank 2", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Clearly, we always have rank[{vn,cn1,cn2}] \[GreaterEqual] 2.  Any two pairs \
(S, C) with C \[Subset] S are M\[ODoubleDot]bius equivalent, and this \
inclusion takes place iff  rank[{vn,cn1,cn2}] = 2, and then we have \
moebsc[vn,cn1,cn2] = 1. Indeed, we have rank[{vn,cn1,cn2}] = 2 iff vn is \
contained in the span of cn1, cn2. Then vn must be spacelike, and being   \
normed it follows moebsc[vn,cn1,cn2] = 1. The spheres corresponding to \
\>", "Text",
  TextAlignment->Left],

Cell["vn = cn1*Cos[t] + cn2*Sin[t]", "Text",
  TextAlignment->Center],

Cell[TextData[{
  "form the bundle of spheres through the circle; this is a spacelike \
geodesic in the space of all spheres, see the notebook ",
  ButtonBox["mspheres.nb",
    ButtonData:>{"mspheres.nb", None},
    ButtonStyle->"Hyperlink"],
  ", section 5.3."
}], "Text"],

Cell[BoxData[
    \(Simplify[
      moebsc[stb[3]*Cos[t]\  + \ stb[4]*Sin[t], \ stb[3], \ 
        stb[4]]]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[N[{0, 0, Cos[k*Pi/10], \ Sin[k*Pi/10], 0}], \(-1\), 
        0, \(-1\), 1], \ {k, 3, 7}]\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%, grc2}]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pict1\  = %\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "Before using commands starting with MV ",
  ButtonBox["MathGL",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"],
  " must be loaded!"
}], "Text"],

Cell[BoxData[
    \(MVShow3D[pict1]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Tangent pairs", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "The condition  ",
  "moebsc",
  "[vn,cn1,cn2] = 1 does not be sufficient for the inclusion of the circle \
into the sphere. From  the results in ",
  ButtonBox["[6]",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  " it follows: If "
}], "Text",
  TextAlignment->Left],

Cell["rank[{vn,cn1,cn2}] =3,   and    moebsc[vn,cn1,cn2] = 1", "Text",
  TextAlignment->Center],

Cell["the circle is tangent to, but not contained in the sphere. ", "Text"],

Cell["1. Example", "Text"],

Cell[BoxData[
    \(vmm = { .5, 0, 1, 0,  .5}\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[vmm, vmm]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[vmm, \ 0, 1, \(-1\), 1]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%, grc2}]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(testgr = %\)], "Input",
  CellLabel->"In[80]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vcenter[vmm]\)], "Input",
  CellLabel->"In[81]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vradius[vmm]\)], "Input",
  CellLabel->"In[82]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(moebsc[vmm, stb[3], stb[4]]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[testgr]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times"],

Cell["2. Example", "Text"],

Cell[BoxData[
    \(spherevec[2*Cos[t], \ 2*Sin[t], 0, 1]\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[85]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(moebsc[{2\ Cos[t], 2\ Sin[t], 0, 1, 2}, stb[3], stb[4]]\)], "Input",
  CellLabel->"In[86]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(rank[{{2\ Cos[t], 2\ Sin[t], 0, 1, 2}, stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[87]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[N[{2*Cos[k*Pi/5], 2*Sin[k*Pi/5], 0, 1, 2}]], \ {k, 
        10}]\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[89]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%, grc2}]\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tangex = \ %\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[tangex]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times"],

Cell["3. Example", "Text"],

Cell["\<\
Let CC be the circle of radius 1 and center {1,0,0} in the x,z-plane:\
\>", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[{1 + Cos[t], 0, \ Sin[t]}, \ {t, 0, 2*Pi}]\)], "Input",\

  CellLabel->"In[93]:="],

Cell[BoxData[
    \(\(?plotcircle3D\)\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(testcircle[t_] := \ 
      plotcircle3D[1 + Cos[t], 0, \ Sin[t], Pi/2, 0, 1]\)], "Input",
  CellLabel->"In[95]:="],

Cell["\<\
The unitcircles in this plane with centers at CC give a nice rosette\
\>", "Text"],

Cell[BoxData[
    \(Table[testcircle[k*2*Pi/10], {k, 10}]\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[97]:="],

Cell["\<\
All the unitspheres with center at CC are tangent to the standard unit circle \
grc1 at the point {1,0,0}:\
\>", "Text"],

Cell[BoxData[
    \(spherevec[1 + Cos[t], 0, \ Sin[t], 1]\)], "Input",
  CellLabel->"In[98]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[99]:=",
  FontFamily->"Times"],

Cell["\<\
This is a family of spacelike vectors defining  spheres tangent to the \
standard unit circle at the point {1,0,0}:\
\>", "Text"],

Cell[BoxData[
    \(sphv[t_]\  := \ {1 + Cos[t], 0, Sin[t], Cos[t], 1 + Cos[t]}\)], "Input",\

  CellLabel->"In[101]:="],

Cell[BoxData[
    \(Simplify[pssp[sphv[t], sphv[t]]]\)], "Input",
  CellLabel->"In[103]:="],

Cell["The invariant of the pair is, as expected:", "Text"],

Cell[BoxData[
    \(Simplify[moebsc[sphv[t], stb[3], stb[4]]]\)], "Input",
  CellLabel->"In[104]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(rank[{sphv[t], stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times"],

Cell["\<\
rank treats the \"general\" case,  there may exist singular points in which \
the statement fails, in our example:\
\>", "Text"],

Cell[BoxData[
    \(rank[{sphv[Pi], stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times"],

Cell["\<\
In this case the standard unit circle is contained in the sphere:\
\>", "Text"],

Cell[BoxData[
    \(Show[{euklidsphereplot3D[N[sphv[Pi]]], \ grc2}]\)], "Input",
  CellLabel->"In[107]:="],

Cell["\<\
For t \[NotEqual] (2k+1)Pi this is not the case, we have a general tangent \
sphere:\
\>", "Text"],

Cell[BoxData[
    \(Show[{euklidsphereplot3D[N[sphv[2*Random[]*Pi]]], \ grc2}]\)], "Input",
  CellLabel->"In[108]:="],

Cell["Here is a family of  spheres, including the singular case", "Text"],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[N[sphv[k*Pi/4]], \ 0, 1], \ {k, \(-4\), 
        4}]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%, grc2}]\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tangex3 = \ %\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[tangex3]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times"],

Cell["Spin this picture around the z-axis.", "Text"],

Cell["Test", "Text"],

Cell["\<\
We consider two special pairs (S0, C), (S1,C) with C = grc1,  corresponding \
to the spacelike vectors\
\>", "Text"],

Cell[BoxData[
    \(msph0\  = \ sphv[0]\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(msph1\  = \ sphv[Pi/2]\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(Show[{euklidsphereplot3D[msph0, \ 0, 1], grc2}]\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(Show[{euklidsphereplot3D[msph1, \ 0, 1], grc2}]\)], "Input",
  CellLabel->"In[118]:="],

Cell["\<\
At first glance it seems to be doubtful that these pairs, having the same M\
\[ODoubleDot]bius invariants,  are M\[ODoubleDot]bius equivalent, as follows \
from the general theory:  In the first pair, the plane of the circle  is \
orthogonal to the tangent plane of the sphere at the common point, and in the \
second pair the circle belongs to this plane. But really, they are \
equivalent; \"plane\" is not a concept of M\[ODoubleDot]bius geometry, \
neither \"plane of a circle\", nor \"tangent plane\". We ask for a M\
\[ODoubleDot]bius transformation g with g(msph0,C) = (msph1,C). Such a \
transformation is given by the matrix\
\>", "Text"],

Cell[BoxData[
    \(mat\  = {{5/4, 0, 0, 0, \(-3\)/4}, stb[2], 
        stb[4], \(-stb[3]\), {\(-3\)/4, 0, 0, 0, 5/4}}\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(Table[pssp[mat[\([i]\)], mat[\([j]\)]], {i, 5}, {j, 5}]\)], "Input",
  CellLabel->"In[121]:="],

Cell[BoxData[
    \(Det[mat]\)], "Input",
  CellLabel->"In[122]:="],

Cell["\<\
Indeed, mat is pseudo-orthogonal, orientation preserving, and maps msph0 into \
msph1; \
\>", "Text"],

Cell[BoxData[
    \(mat . msph0\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \(% \[Equal] \ msph1\)], "Input",
  CellLabel->"In[124]:="],

Cell["\<\
Obviously, it preserves the standard unitcircle. The corresponding map in \
orthonormal coordinates of the euclidean 3-space is given by\
\>", "Text"],

Cell[BoxData[
    \(stepro[mat . invstepro[vec[x, 3]]]\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(fmat = \ {\(-\(3\/5\)\) + \(8\ \((4\ x[1] + 3\ x[3])\)\)\/\(5\ \((5 + \
x[1]\ \((\(-6\) + 5\ x[1])\) + 5\ x[2]\^2 + x[3]\ \((8 + 5\ x[3])\))\)\), \(8\
\ x[2]\)\/\(5 + x[1]\ \((\(-6\) + 5\ x[1])\) + 5\ x[2]\^2 + x[3]\ \((8 + 5\ \
x[3])\)\), \(4\ \((\(-1\) + x[1]\^2 + x[2]\^2 + x[3]\^2)\)\)\/\(5 + x[1]\ \((\
\(-6\) + 5\ x[1])\) + 5\ x[2]\^2 + x[3]\ \((8 + 5\ x[3])\)\)}\)], "Input",
  CellLabel->"In[127]:="],

Cell[BoxData[
    \(fmat /. {x[1] \[Rule] x, x[2] \[Rule] y, x[3] \[Rule] z}\)], "Input",
  CellLabel->"In[128]:="],

Cell[BoxData[
    \(fg[x_, y_, 
        z_]\  := \ {\(-\(3\/5\)\) + \(8\ \((4\ x + 3\ z)\)\)\/\(5\ \((5 + x\ \
\((\(-6\) + 5\ x)\) + 5\ y\^2 + z\ \((8 + 5\ z)\))\)\), \(8\ y\)\/\(5 + x\ \
\((\(-6\) + 5\ x)\) + 5\ y\^2 + z\ \((8 + 5\ z)\)\), \(4\ \((\(-1\) + x\^2 + \
y\^2 + z\^2)\)\)\/\(5 + x\ \((\(-6\) + 5\ x)\) + 5\ y\^2 + z\ \((8 + 5\ \
z)\)\)}\)], "Input",
  CellLabel->"In[129]:="],

Cell["Clearly, this map must have a pole; we try to find it", "Text"],

Cell[BoxData[
    \(Solve[
      5 + x[1]\ \((\(-6\) + 5\ x[1])\) + 5\ x[2]\^2 + 
          x[3]\ \((8 + 5\ x[3])\) \[Equal] \ 0, vec[x, 3]]\)], "Input",
  CellLabel->"In[130]:="],

Cell[BoxData[
    \(Plot3D[\(-5\) + 6\ x[1] - 5\ x[1]\^2 - 8\ x[3] - 
        5\ x[3]\^2, {x[1], \ \(-10\), 10}, {x[3], \ \(-10\), 10}]\)], "Input",\

  CellLabel->"In[131]:="],

Cell[BoxData[
    \(Solve[\(-5\) + 6\ x[1] - 5\ x[1]\^2 - 8\ x[3] - 5\ x[3]\^2 \[Equal] \ 
        0, \ {x[1], x[3]}]\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(Plot[\(-16\) - 40\ x[3] - 
        25\ x[3]\^2, \ {x[3], \ \(-2\), \(- .5\)}]\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \(Solve[\(-16\) - 40\ x[3] - 25\ x[3]\^2 \[Equal] \ 0, \ x[3]]\)], "Input",\

  CellLabel->"In[134]:="],

Cell[BoxData[
    \(fmat /. {x[1] -> 3/5, x[2] -> 0, x[3] -> \(-4\)/5}\)], "Input",
  CellLabel->"In[135]:="],

Cell["\<\
Now we verify that the map fg is conformal for all points {x,y,z} \
\[NotEqual]{3/5, 0, -4/5}. We calculate the partial derivatives\
\>", "Text"],

Cell[BoxData[
    \(D[fg[x, y, z], x]\)], "Input",
  CellLabel->"In[136]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    \(fgx[x_, y_, 
        z_]\  := \ {\(-\(\(16\ \((2\ x\^2 - 2\ y\^2 + 
                    3\ x\ z - \((2 + z)\)\ \((1 + 
                          2\ z)\))\)\)\/\((5 + x\ \((\(-6\) + 5\ x)\) + 5\ \
y\^2 + z\ \((8 + 5\ z)\))\)\^2\)\), \(-\(\(8\ \((\(-6\) + 
                    10\ x)\)\ y\)\/\((5 + x\ \((\(-6\) + 5\ x)\) + 5\ y\^2 + \
z\ \((8 + 5\ z)\))\)\^2\)\), \(-\(\(8\ \((3\ x\^2 - 2\ x\ \((5 + 4\ z)\) - 
                    3\ \((\(-1\) + y\^2 + 
                          z\^2)\))\)\)\/\((5 + x\ \((\(-6\) + 5\ x)\) + 5\ \
y\^2 + z\ \((8 + 5\ z)\))\)\^2\)\)}\)], "Input",
  CellLabel->"In[138]:="],

Cell[BoxData[
    \(D[fg[x, y, z], y]\)], "Input",
  CellLabel->"In[139]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[140]:="],

Cell[BoxData[
    \(fgy[x_, y_, 
        z_]\  := {\(-\(\(16\ y\ \((4\ x + 
                    3\ z)\)\)\/\((5 + x\ \((\(-6\) + 5\ x)\) + 5\ y\^2 + z\ \
\((8 + 5\ z)\))\)\^2\)\), \(8\ \((5 + x\ \((\(-6\) + 5\ x)\) - 5\ y\^2 + z\ \
\((8 + 5\ z)\))\)\)\/\((5 + x\ \((\(-6\) + 5\ x)\) + 5\ y\^2 + z\ \((8 + 5\ \
z)\))\)\^2, \(16\ y\ \((5 - 3\ x + 4\ z)\)\)\/\((5 + x\ \((\(-6\) + 5\ x)\) + \
5\ y\^2 + z\ \((8 + 5\ z)\))\)\^2}\)], "Input",
  CellLabel->"In[141]:="],

Cell[BoxData[
    \(D[fg[x, y, z], z]\)], "Input",
  CellLabel->"In[142]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[143]:="],

Cell[BoxData[
    \(fgz[x_, y_, 
        z_] := {\(8\ \((3\ x\^2 - 2\ x\ \((5 + 4\ z)\) + 3\ \((1 + y\^2 - \
z\^2)\))\)\)\/\((5 + x\ \((\(-6\) + 5\ x)\) + 5\ y\^2 + z\ \((8 + 5\ \
z)\))\)\^2, \(-\(\(8\ y\ \((8 + 
                    10\ z)\)\)\/\((5 + x\ \((\(-6\) + 5\ x)\) + 5\ y\^2 + z\ \
\((8 + 5\ z)\))\)\^2\)\), \(-\(\(16\ \((2\ x\^2 + 2\ y\^2 + 
                    3\ x\ z - \((2 + z)\)\ \((1 + 
                          2\ z)\))\)\)\/\((5 + x\ \((\(-6\) + 5\ x)\) + 5\ \
y\^2 + z\ \((8 + 5\ z)\))\)\^2\)\)}\)], "Input",
  CellLabel->"In[144]:="],

Cell["\<\
Here is the matrix describing the differential of fg at the point {x, y, \
z}:\
\>", "Text"],

Cell[BoxData[
    \(derfg[x_, y_, z_]\  := \ {fgx[x, y, z], fgy[x, y, z], 
        fgz[x, y, z]}\)], "Input",
  CellLabel->"In[145]:="],

Cell[BoxData[
    \(mmfg\  = derfg[x, y, z]\)], "Input",
  CellLabel->"In[146]:="],

Cell["\<\
The euclidean scalar products of the partial derivatives form the matrix \
\>", "Text"],

Cell[BoxData[
    \(Table[mmfg[\([i]\)] . mmfg[\([j]\)], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[147]:="],

Cell[BoxData[
    \(FullSimplify[%]\)], "Input",
  CellLabel->"In[148]:="],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[149]:="],

Cell[BoxData[
    \(\((5 + x\ \((\(-6\) + 5\ x)\) + 5\ y\^2 + z\ \((8 + 5\ z)\))\)\^2 /. {x \
\[Rule] 3/5, \ y \[Rule] 0, \ z\  \[Rule] \ \(-4\)/5}\)], "Input",
  CellLabel->"In[150]:="],

Cell["\<\
Easily one proves that the pole is the only zero of the nominator; the shape \
of the matrix shows that the map fg  is conformal at all other points. We \
check  that fg transforms the pairs as stated. First we see that the standard \
unit circle is transformed onto itself:\
\>", "Text"],

Cell[BoxData[
    \(Simplify[fg[Cos[u], Sin[u], 0]]\)], "Input",
  CellLabel->"In[151]:="],

Cell[BoxData[
    \(ParametricPlot3D[%, {u, 0, 2*Pi}, PlotPoints\  \[Rule] \ 60, \ 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[152]:="],

Cell["Of course, the common point of the pairs remaines fixed:", "Text"],

Cell[BoxData[
    \(fg[1, 0, 0]\)], "Input",
  CellLabel->"In[153]:="],

Cell["Finally, the image of the sphere corresponding to sph0:", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[{2 + Cos[u]*Cos[v], Sin[u]*Cos[v], Sin[v]}, {u, 0, 
        2*Pi}, {v, \ \(-Pi\)/2, Pi/2}]\)], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \(Show[{%, grc2}]\)], "Input",
  CellLabel->"In[155]:="],

Cell["is the sphere corresponding to sph1:", "Text"],

Cell[BoxData[
    \(ParametricPlot3D[
      fg[2 + Cos[u]*Cos[v], Sin[u]*Cos[v], Sin[v]], {u, 0, 
        2*Pi}, {v, \ \(-Pi\)/2, Pi/2}, PlotPoints\  \[Rule] \ 60, \ 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[156]:="],

Cell[BoxData[
    \(Show[{%, grc2}, PlotRange\  \[Rule] All]\)], "Input",
  CellLabel->"In[157]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Intersecting pairs", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
We assume now rank[vn,cn1, cn2] = 3. The sphere S and the circle C are \
intersecting in a 0-sphere (two points) iff the orthogonal complement of \
span[vn,cn1, cn2] is pseudo-euclidean, and this is the case iff \
\>", "Text",
  TextAlignment->Left],

Cell["moebsc[vn, cn1, cn2] < 1. ", "Text",
  TextAlignment->Center],

Cell["In the next section we shall see that in this case one has ", "Text",
  TextAlignment->Left],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Cos[\[Alpha]]\^2\)]],
  " =  ",
  "moebsc",
  "[vn, cn1, cn2],"
}], "Text",
  TextAlignment->Center],

Cell["\<\
where \[Alpha] denotes the intersection angle. Consider the standard unit \
circle and the halfspheres \
\>", "Text"],

Cell[BoxData[
    \(Table[
      moebsc[stb[2]*Cos[k*Pi/20] + stb[4]*Sin[k*Pi/20], stb[3], 
        stb[4]], \ {k, 3, 8}]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[
        N[stb[2]*Cos[k*Pi/20] + stb[4]*Sin[k*Pi/20]], \(-1\), 0, \(-1\), 
        1], \ {k, 3, 8}]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc2, \ %}, \ PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tgr1\  = \ %\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[tgr1, MVLineTubeSize\  \[Rule] \ \ 0.02]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell["\<\
We try another example: We fix the unit sphere and vary the circle:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      moebsc[stb[4], stb[3]*Sin[k*Pi/20]\  + \ stb[4]*Cos[k*Pi/20], \ 
        stb[2]*Sqrt[2] + stb[5]], \ {k, 1, 10}]\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[
      plotcircle2spv[stb[3]*N[Sin[k*Pi/20]] + \ stb[4]*N[Cos[k*Pi/20]], \ 
        stb[2]*N[Sqrt[2]] + stb[5]], \ {k, 1, 10}]\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tgrc10\  = \ %\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[4], \ \(-1\), 0]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(grs1\  = \ %\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grs1, tgrc10}]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tgrscc\  = \ %\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[tgrscc, \ MVLineTubeSize\  -> \ 0.01]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Orthogonal intersections", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
The standard unit circle intersects the \"sphere\" x = 0 orthogonally:\
\>", "Text"],

Cell[BoxData[
    \(moebsc[stb[1], stb[3], stb[4]]\)], "Input",
  CellLabel->"In[43]:=",
  FontFamily->"Times"],

Cell["\<\
Generally, any sphere corresponding to a spacelike unit vector of the \
orthogonal complement to [cn1, cn2], here the space spanned by stb[1], \
stb[2], stb[5], intersects the circle grc1 orthogonally. 
We consider the  spheres S(stb[1]Cosh[t] + stb[5]*Sinh[t]): \
\>", "Text"],

Cell[BoxData[
    \(moebsc[stb[1] Cosh[t]\  + \ stb[5]*Sinh[t], stb[3], stb[4]]\)], "Input",\

  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[stb[1] Cosh[t]\  + \ stb[5]*Sinh[t]], {t, \ 0, \ 
        2, \ 0.5}]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(extab\  = \ %\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[Show[{extab[\([i]\)], \ grc2}], \ {i, 1, 5}]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{extab[\([5]\)], grc2}]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gs2\  = \ %\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(sphex\  = \ euklidsphereplot3D[{1, 1, 0, 0, 1}]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grc2, \ sphex}]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[%]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell["\<\
The set of all the spheres intersecting  a given circle orthogonally is a \
2-dimensional sphere family, corresponding to the hyperboloid of spacelike \
unit vectors of the orthogonal complement of cn1,cn2: a linear sphere \
congruence. \
\>", "Text"],

Cell[BoxData[
    \(ur\  = \ Random[]; tr = Random[]; 
    vsph = {Cos[ur*2*Pi]*Cosh[tr], \ Sin[ur*2*Pi]*Cosh[tr], 0, 0, 
        Sinh[tr]}\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(moebsc[vsph, stb[3], stb[4]]\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(euklidsphereplot3D[vsph]\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \(Show[{%, \ grc2}]\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(MVShow3D[%, MVLineTubeSize\  \[Rule] \ 0.02]\)], "Input",
  CellLabel->"In[92]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Disjoint pairs", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
We consider the spheres S(stb[3]Cosh[t] + stb[5]*Sinh[t]). Obviously, for t = \
0 the standard circle grc1 is contained in the corresponding \"sphere\", the \
x,y-plane:\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[3]]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%, grc2}]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times"],

Cell["\<\
Since moebsc > 1 for t \[NotEqual] 0, any sphere S(stb[3]Cosh[t] + \
stb[5]*Sinh[t]) is disjoint to the unit circle:\
\>", "Text"],

Cell[BoxData[
    \(moebsc[stb[3] Cosh[t]\  + \ stb[5]*Sinh[t], stb[3], stb[4]]\)], "Input",\

  CellLabel->"In[95]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[3] Cosh[2. ]\  + \ stb[5]*Sinh[2. ]]\)], "Input",\

  CellLabel->"In[97]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%, grc2}, PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[98]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gs2\  = \ %\)], "Input",
  CellLabel->"In[99]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tr = Random[]; vsph = {0, \ 0, Cosh[2*tr], 0, Sinh[2*tr]}\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(moebsc[vsph, stb[3], stb[4]]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(euklidsphereplot3D[vsph]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(Show[{%, \ grc2}, PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(MVShow3D[%, MVLineTubeSize\  \[Rule] \ 0.02]\)], "Input",
  CellLabel->"In[71]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["All cases (of rank 3) in one example", \
"Subsubsection"]], "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
With the next example we can reach all possible values of the invariant\
\>", "Text"],

Cell[BoxData[
    \(moebsc[stb[1]*Cosh[t]\  + \ stb[5]*Sinh[t], \ 
      stb[2]*Cosh[s]\  + \ stb[5]*Sinh[s], \ stb[4]]\)], "Input",
  CellLabel->"In[144]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(rank[{stb[1]*Cosh[t]\  + \ stb[5]*Sinh[t], \ 
        stb[2]*Cosh[s]\  + \ stb[5]*Sinh[s], \ stb[4]}]\)], "Input",
  CellLabel->"In[145]:=",
  FontFamily->"Times"],

Cell["We construct an intersecting pair:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[1] Cosh[1/2]\  + \ stb[5]*Sinh[1/2]]\)], "Input",\

  CellLabel->"In[146]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gs1\  = \ %\)], "Input",
  CellLabel->"In[147]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[stb[2]*Cosh[1/2]\  + \ stb[5]*Sinh[1/2], \ 
      stb[4]]\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gc1\  = \ %\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{gc1, gs1}]\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(moebsc[stb[1]*Cosh[1/2]\  + \ stb[5]*Sinh[1/2], \ 
      stb[2]*Cosh[1/2]\  + \ stb[5]*Sinh[1/2], \ stb[4]]\)], "Input",
  CellLabel->"In[151]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[152]:=",
  FontFamily->"Times"],

Cell["Now a disjoint pair:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[1] Cosh[3/2]\  + \ stb[5]*Sinh[3/2]]\)], "Input",\

  CellLabel->"In[153]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gs4\  = \ %\)], "Input",
  CellLabel->"In[154]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[stb[2]*Cosh[3/2]\  + \ stb[5]*Sinh[3/2], \ 
      stb[4]]\)], "Input",
  CellLabel->"In[155]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gs3\  = \ %\)], "Input",
  CellLabel->"In[156]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{gs3, gs4}]\)], "Input",
  CellLabel->"In[157]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gs2\  = \ %\)], "Input",
  CellLabel->"In[158]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(moebsc[stb[1]*Cosh[3/2]\  + \ stb[5]*Sinh[3/2], \ 
      stb[2]*Cosh[3/2]\  + \ stb[5]*Sinh[3/2], \ stb[4]]\)], "Input",
  CellLabel->"In[159]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[%]\)], "Input",
  CellLabel->"In[160]:=",
  FontFamily->"Times"],

Cell["\<\
Now we construct a tangent pair; all tangent pairs are M\[ODoubleDot]bius \
equivalent: Give a direct proof!\
\>", "Text"],

Cell[BoxData[
    \(ct\  = \ ArcSinh[1]\)], "Input",
  CellLabel->"In[161]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[ct]\)], "Input",
  CellLabel->"In[162]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Sinh[ct]\)], "Input",
  CellLabel->"In[163]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(moebsc[stb[1]*Cosh[ct]\  + \ stb[5]*Sinh[ct], 
      stb[2]*Cosh[ct]\  + \ stb[5]*Sinh[ct], \ stb[4]]\)], "Input",
  CellLabel->"In[164]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(rank[{stb[1]*Cosh[ct]\  + \ stb[5]*Sinh[ct], 
        stb[2]*Cosh[ct]\  + \ stb[5]*Sinh[ct], \ stb[4]}]\)], "Input",
  CellLabel->"In[165]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[1]*Cosh[ct]\  + \ stb[5]*Sinh[ct]]\)], "Input",
  CellLabel->"In[166]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gt1\  = \ %\)], "Input",
  CellLabel->"In[167]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[stb[2]*Cosh[ct]\  + \ stb[5]*Sinh[ct], \ 
      stb[4]]\)], "Input",
  CellLabel->"In[168]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gt2\  = \ %\)], "Input",
  CellLabel->"In[169]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{gt1, gt2}]\)], "Input",
  CellLabel->"In[170]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gt3 = \ %\)], "Input",
  CellLabel->"In[172]:=",
  FontFamily->"Times"],

Cell["\<\
Apply MathGL3d (see the end of the notebook) or a similar animation program \
for visualizing the situations.\
\>", "Text"],

Cell[BoxData[
    \(MVShow3D[gt3, \ MVLineTubeSize\  \[Rule] \ 0.01]\)], "Input",
  CellLabel->"In[174]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(moebsc[stb[1]*Cosh[t]\  + \ stb[5]*Sinh[t], \ 
      stb[2]*Cosh[s]\  + \ stb[5]*Sinh[s], \ stb[4]]\)], "Input",
  CellLabel->"In[140]:=",
  FontFamily->"Times"],

Cell["For s =0 or t = 0 we have orthogonal intersections:", "Text"],

Cell["t= 0:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[1]]\)], "Input",
  CellLabel->"In[175]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gi0\  = \ %\)], "Input",
  CellLabel->"In[176]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[1]*Cosh[3/2]\  + \ stb[5]*Sinh[3/2]]\)], "Input",\

  CellLabel->"In[177]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gi1\  = \ %\)], "Input",
  CellLabel->"In[178]:=",
  FontFamily->"Times"],

Cell["s= 0:", "Text"],

Cell[BoxData[
    \(plotcircle2spv[stb[2], stb[4]]\)], "Input",
  CellLabel->"In[179]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gi2\  = \ %\)], "Input",
  CellLabel->"In[180]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{gi1, gi2}]\)], "Input",
  CellLabel->"In[181]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gt2\  = \ %\)], "Input",
  CellLabel->"In[182]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{gi0, gi2}]\)], "Input",
  CellLabel->"In[183]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[1]*Cosh[1/2]\  + \ stb[5]*Sinh[1/2]]\)], "Input",\

  CellLabel->"In[184]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gi1\  = \ %\)], "Input",
  CellLabel->"In[185]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{gi1, gi2}]\)], "Input",
  CellLabel->"In[186]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gt2\  = \ %\)], "Input",
  CellLabel->"In[187]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[gt2, \ MVLineTubeSize\  \[Rule] \ 0.03]\)], "Input",
  CellLabel->"In[188]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3 Euclidean interpretation of moebsc", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["A general formula", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
The spacelike vector defining a sphere with given center and radius is\
\>", "Text"],

Cell[BoxData[
    \(\(?spherevec\)\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(sv\  = spherevec[x, y, z, r]\)], "Input",
  CellLabel->"In[43]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[44]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(invstepro[{x + r, y, z}]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(FullSimplify[Together[%]]\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[sv, invstepro[{x, y - r, z}]]\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(FullSimplify[Together[%]]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell["The adapted frame of the arbitrary circle is", "Text"],

Cell[BoxData[
    \(\(?circlespacevectors\)\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cv\  = \ circlespacevectors[X, Y, Z, U, V, R]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell["We  calculate", "Text"],

Cell[BoxData[
    \(Simplify[moebsc[sv, \ cv[\([1]\)], \ cv[\([2]\)]]]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell["The vector ", "Text"],

Cell[BoxData[
    \(vd\  = {x, y, z}\  - \ {X, Y, Z}\)], "Input",
  CellLabel->"In[38]:=",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["is the radius vector of the centers, and ", "Text"],

Cell[BoxData[
    \(vn = \(unit[2]\)[{U, V}]\)], "Input",
  CellLabel->"In[39]:=",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
is the position vector: a unit normal vector of the plane of the circle. \
Therefore we can express the conformal invariant moebsc as a function of the \
euclidean positioning entities vd,vn, r, R:\
\>", "Text"],

Cell[BoxData[
    \(moebscfct[vd_List, \ vn_List, \ r_, 
        R_]\  := \[IndentingNewLine]\((\((vd . vd\  - r^2\  - R^2)\)/\((2*r*
                  R)\))\)^2\  + \((\((vd . vn)\)/r)\)^2\)], "Input",
  CellLabel->"In[9]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["\<\
In euclidean terms, the radii r, R, the distance of the centers d = \
Sqrt[vd.vd], and the angle\
\>", "Text"],

Cell[BoxData[
    \(phi, d\ *Cos[phi] = vd . vn, 0 \[LessEqual] phi < Pi, \)], "Input",
  Evaluatable->False],

Cell["\<\
between the postion vector vn and the radiusvector of the centers vd are a \
complete invariant system of the pair of non-oriented circle with a \
non-oriented sphere. In these terms the conformal invariant moebsc can be \
expressed as\
\>", "Text"],

Cell[BoxData[
    \(euklidmoebsc[d_, r_, R_, 
        phi_]\  := \ \((\((d^2\  - r^2\  - R^2)\)/\((2*r*
                  R)\))\)^2\  + \ \((\((d*Cos[phi])\)/r)\)^2\)], "Input",
  CellLabel->"In[10]:=",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidmoebsc[d, r, R, phi]\)], "Input",
  CellLabel->"In[41]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "As far as I know,  this expression of the conformal invariant of a sphere \
and a circle is new; at least I have not found it in the literature. The \
result is a good example of a symbolic calculation in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " with the tools developed in the item \"Spheres\". The first term is the \
square of the conformal Coxeter invariant of the given sphere with the sphere \
through the circle, having the same center and radius as the circle, see \
section 4.1 in the notebook mspheres.nb (H. S. M. Coxeter's \"inversive \
distance\"):"
}], "Text"],

Cell[BoxData[
    \(coxeterinv[r, R, d]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell["\<\
The second term measures the influence of the angle between the position \
vector and the radius vector of the centers; d*Cos[phi] is the length of the \
projection of this radius vector onto the normal of the circle plane through \
the circle's center. From our expression euklidmoebsc one recognizes \
immediately that moebsc vanishes if and only iff the circle intersects the \
sphere orthogonally: The tangents of the circle at the intersection points \
are the radial lines from the center of the sphere to these points. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Evaluation", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Since any circle is M\[ODoubleDot]bius equivalent to the standard circle \
grc1, given by stb[3], stb[4],  we reach all possible values of the invariant \
by\
\>", "Text"],

Cell[BoxData[
    \(moebsc[spherevec[x, y, z, r], stb[3], \ stb[4]]\)], "Input",
  CellLabel->"In[42]:=",
  FontFamily->"Times"],

Cell["what coincides with", "Text"],

Cell[BoxData[
    \(moebscfct[{x, y, z}, {0, 0, 1}, \ r, \ 1]\)], "Input",
  CellLabel->"In[43]:=",
  FontFamily->"Times"],

Cell["\<\
Since m = {x,y,z} is the center of the sphere, and d = Sqrt[m.m] the distance \
of the centers, we may simplify this formula as follows:\
\>", "Text"],

Cell[BoxData[
    \(fctinv[d_, \ r_, 
        z_]\  := \ \ \((\((1\  + \ r^2\  - d^2)\)^2\  + \ 4*z^2)\)/\((4*
            r^2)\)\)], "Input",
  CellLabel->"In[44]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "Obviously, only the values for  ",
  Cell[BoxData[
      \(TraditionalForm\`z\^2\)]],
  "\[LessEqual]  ",
  Cell[BoxData[
      \(TraditionalForm\`d\^2\)]],
  "are to consider."
}], "Text"],

Cell[BoxData[
    \(fctinv[d, r, z]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell["\<\
Clearly, this is not a M\[ODoubleDot]bius invariant of the arbitrary sphere \
with an arbitrary circle: alle the spheres are compared with the standard \
circle grc1. Therefore it is not invariant e.g. against dilatations, which \
are M\[ODoubleDot]bius transformations. In spite of this the function may be \
applied to study how the invariant moebsc depends of the euclidean \
invariants. Here the sphere has radius 1, its center is on the z-axis at d = \
z:\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctinv[d, 1, d], \ {d, \ 0, 10}]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[fctinv[d, 1, d], \ {d, \ 0, 3}]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell["\<\
Here the circle is contained in the unit sphere (as equator, what is not \
essential):\
\>", "Text"],

Cell[BoxData[
    \(fctinv[0, 1, 0]\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell["\<\
Now the unit sphere has the center in distance d from the origin (the \
circle's center); the center lies in the plane of the circle:\
\>", "Text"],

Cell[BoxData[
    \(Plot[fctinv[d, 1, 0], \ {d, \ 0, 3}]\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell["\<\
For d = Sqrt[2] we have orthogonal intersection of circle and sphere:\
\>", "Text"],

Cell[BoxData[
    \(fctinv[Sqrt[2], 1, 0]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?sphereplot3D\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(sphereplot3D[{Sqrt[2], \ 0, 0}, 1]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(Show[{%, grc2}]\)], "Input",
  CellLabel->"In[53]:="],

Cell["\<\
In the following picture only the values Abs[z] \[LessEqual] d are to \
consider:\
\>", "Text"],

Cell[BoxData[
    \(Plot3D[fctinv[d, 1, z], {d, 0, 2}, {z, 0, 1}]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The invariant moebsc and the mutual position", "Subsubsection",
  FontFamily->"Times"],

Cell["The standard unit sphere:", "Text"],

Cell[BoxData[
    \(spherevec[0, 0, 0, 1]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(euklidsphereplot3D[stb[4]]\)], "Input",
  CellLabel->"In[10]:=",
  InitializationCell->True],

Cell[BoxData[
    \(sph1\  = \ %\)], "Input",
  CellLabel->"In[11]:=",
  InitializationCell->True],

Cell["\<\
The circle with Radius R, center at X on the x-axis and position vector\
\>", "Text"],

Cell[BoxData[
    \(\(unit[2]\)[{u, v}]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell["corresponds to the euclidean 2-space  spanned by", "Text"],

Cell[BoxData[
    \(csvs[X_, R_, u_, v_] := circlespacevectors[X, 0, 0, u, v, R]\)], "Input",\

  CellLabel->"In[101]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(csvs[X, R, u, v]\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(\(vspuv\  = \ %;\)\)], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times"],

Cell["\<\
Some pairs: the sphere sph1 and circles with X = R = 2, and random u,v:\
\>", "Text"],

Cell[BoxData[
    \(bspv[u_, 
        v_]\  := \ \ {{Cos[u]\ Cos[v], Cos[v]\ Sin[u], Sin[v], 
          2\ Cos[u]\ Cos[v], 2\ Cos[u]\ Cos[v]}, {1, 0, 
          0, \(\(-1\) - 2\^2 + 2\^2\)\/\(2\ *2\), \(1 - 2\^2 + \
2\^2\)\/\(\(2\)\(*\)\(2\)\(\ \)\)}}\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(Table[\((a\  = \ Random[]*2*Pi; b\  = \ Random[]*Pi; 
        Print["\<u = \>"\ , \ a, "\< v = \>", b]; 
        Print["\<moebsc = \>", 
          moebsc[stb[
              4], \(bspv[a, b]\)[\([1]\)], \(bspv[a, b]\)[\([2]\)]]]\ ; 
        Show[{plotcircle2spv[\(bspv[a, b]\)[\([1]\)], \(bspv[a, 
                  b]\)[\([2]\)]], sph1}, 
          PlotRange\  \[Rule] \ All])\), {4}]\)], "Input",
  CellLabel->"In[96]:="],

Cell["\<\
For studying the properties of moebsc[(S,C)], without restriction of \
generality we may assume that S is the standard unit sphere and that the line \
connecting the centers of S and C is the x-axis.\
\>", "Text"],

Cell[BoxData[
    \(moebsc[spherevec[0, 0, 0, 1], vspuv[\([1]\)], \ 
      vspuv[\([2]\)]]\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times"],

Cell["We consider", "Text"],

Cell[BoxData[
    \(fctmoebscuv[X_, R_, u_, v_]\  = %\)], "Input",
  CellLabel->"In[98]:=",
  FontFamily->"Times"],

Cell["\<\
Since all the unit circle with center at the origin are contained in the \
standard unit sphere we obtain the constant 1 for\
\>", "Text"],

Cell[BoxData[
    \(Plot3D[
      fctmoebscuv[0, 1, u, v], \ {u, 0, 2*Pi}, \ {v, \(-Pi\)/2, 
        Pi/2}]\)], "Input",
  CellLabel->"In[99]:=",
  FontFamily->"Times"],

Cell["\<\
Next we consider the standard unit sphere and circles with radius 1, center \
{3/2,0,0}, and arbitrary position vector:\
\>", "Text"],

Cell[BoxData[
    \(Plot3D[
      fctmoebscuv[3/2, 1, u, v], \ {u, 0, 2*Pi}, \ {v, \(-Pi\)/2, 
        Pi/2}]\)], "Input",
  CellLabel->"In[100]:=",
  FontFamily->"Times"],

Cell["\<\
Now we turn the unit circle with center {3/2, 0, 0} around the parallel to \
the z-axis through the center:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      Print["\<moebsc = \>", \ 
        N[moebsc[
            stb[4], \(csvs[3/2, 1, k*Pi/5, 0]\)[\([1]\)], \(csvs[3/2, 1, 
                k*2*Pi/5, 0]\)[\([2]\)]]]]; 
      Show[{plotcircle2spv[\(csvs[3/2, 1, k*Pi/5, 0]\)[\([1]\)], \(csvs[3/2, 
                1, k*Pi/5, 0]\)[\([2]\)]], sph1}, 
        PlotRange\  \[Rule] \ All], \ {k, 5}]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[110]:="],

Cell[BoxData[
    \(fctmoebscuv[3/2, 1, u, 0]\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(Plot[fctmoebscuv[3/2, 1, u, 0], {u, 0, 2*Pi}]\)], "Input",
  CellLabel->"In[111]:="],

Cell[BoxData[
    \(N[fctmoebscuv[3/2, 1, 0, 0]]\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(N[fctmoebscuv[3/2, 1, Pi/2, 0]]\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(fctmoebscuv[3/2, 1, u, 0]\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times"],

Cell["Here are the tangent cases:", "Text"],

Cell[BoxData[
    \(Solve[1\/4\ \((1\/16 + 9\ Cos[u]\^2)\) \[Equal] 1, u]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[ArcCos[\@7\/4]]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(N[ArcCos[\(-\@7\)\/4]]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[\(csvs[3/2, 1, 0.848062078981481`, 0]\)[\([1]\)], \(csvs[
          3/2, 1, 0.848062078981481`, 0]\)[\([2]\)]]\)], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \(tc1\  = \ %\)], "Input",
  CellLabel->"In[123]:="],

Cell[BoxData[
    \(plotcircle2spv[\(csvs[3/2, 1, 2.293530574608312`, 0]\)[\([1]\)], \(csvs[
          3/2, 1, 2.293530574608312`, 0]\)[\([2]\)]]\)], "Input",
  CellLabel->"In[124]:="],

Cell[BoxData[
    \(tc2\  = \ %\)], "Input",
  CellLabel->"In[125]:="],

Cell[BoxData[
    \(Show[{tc1, tc2}]\)], "Input",
  CellLabel->"In[126]:="],

Cell[BoxData[
    \(Show[{%, sph1}]\)], "Input",
  CellLabel->"In[127]:="],

Cell["The minimum is ", "Text"],

Cell[BoxData[
    \(fctmoebscuv[3/2, 1, Pi/2, 0]\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times"],

Cell["\<\
The intersection angle in this position (circle is contained in the \
x,z-plane) is\
\>", "Text"],

Cell[BoxData[
    \(N[ArcCos[1/8]]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell["In degrees:", "Text"],

Cell[BoxData[
    \(%*180/Pi\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(plotcircle2spv[\(csvs[3/2, 1, Pi/2, 0]\)[\([1]\)], \(csvs[3/2, 1, Pi/2, 
          0]\)[\([2]\)]]\)], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \(Show[{%, sph1}]\)], "Input",
  CellLabel->"In[132]:="],

Cell["The position for the maximum:", "Text"],

Cell[BoxData[
    \(plotcircle3D[1.5, 0, 0, 0, \ 0, \ 1]\)], "Input",
  CellLabel->"In[133]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{%, sph1}]\)], "Input",
  CellLabel->"In[134]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Plane and circle", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
If the sphere S of the pair (S,C) appears as an euclidean plane with an \
equation in Hesse's normal form\
\>", "Text"],

Cell[BoxData[
    \({vec[x, 3] . {a, b, c}\  \[Equal] \ 
        p, \ {a, b, c} . {a, b, c}\  \[Equal] \ 1}\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"],

Cell["its characterizing spacelike vector in the 5-space is", "Text"],

Cell[BoxData[
    \(\(?planevec\)\)], "Input",
  CellLabel->"In[28]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pn\  = planevec[a, b, c, p]\)], "Input",
  CellLabel->"In[29]:=",
  FontFamily->"Times"],

Cell["We consider again", "Text"],

Cell[BoxData[
    \(cv\  = \ circlespacevectors[X, Y, Z, U, V, R]\)], "Input",
  CellLabel->"In[30]:=",
  FontFamily->"Times"],

Cell["and  calculate", "Text"],

Cell[BoxData[
    \(Simplify[moebsc[pn, \ cv[\([1]\)], \ cv[\([2]\)]]]\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell["\<\
The term d = -p+a X+b Y+c Z is the distance of the center of the circle to \
the plane, and the expression\
\>", "Text",
  TextAlignment->Left],

Cell["\<\
Cos[\[Alpha]] = a Cos[U] Cos[V]+b Cos[V] Sin[U]+c Sin[V]\
\>", "Text",
  TextAlignment->Center],

Cell["\<\
defines the angle \[Alpha] between the given plane and the plane of the \
circle. Therefore we get for the M\[ODoubleDot]bius invariant of the pair \
(P,C) of the plane P and the circle C the expression moebsc in euclidean \
terms:\
\>", "Text"],

Cell[BoxData[
    \(planecirclemoebsc[d_, R_, 
        alpha_]\  := \ \((d/R)\)^2\  + \((Cos[alpha])\)^2\)], "Input",
  CellLabel->"In[12]:=",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
It is easy to transfer the geometric consideration we did in the case \
(sphere, circle) to the pairing (plane, circle).\
\>", "Text"],

Cell[BoxData[
    \(Clear[cv, pn, x]\)], "Input",
  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell["\<\
The combinations (plane,  line), (sphere, line) we leave to the interested \
reader...\
\>", "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3 Spheres and point pairs", "Section",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["3.1 Point pairs as 0-spheres", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["An adapted frame", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "A point pair can be represented by a pair of isotropic vectors, which \
define a pseudo-euclidean 2-space, or its orthogonal complement, an euclidean \
3-space in the 5-dimensional pseudo-euclidean vector space. We shall \
construct for any pair (a,b) of distinct points in the 3-space, i.e. a  \
0-sphere, an pseudo-orthonormal frame (c[[i]]) in the pseudo-euclidean \
5-space such that\na = stepro[c[[4]] + c[[5]]],   b  = stepro[c[[4]] - \
c[[5]]].\nSuch a frame we call ",
  StyleBox["adapted",
    FontColor->RGBColor[1, 0, 0]],
  " to the 0-sphere; of course, it is not uniquely defined.  To this aim we \
first construct a pseudo-orthonormal basis of the pseudo-euklidean 2-space \
spanned by the preimages invstepro[a], invstepro[b], and then an orthonormal \
basis of its orthogonal complement; joining these bases we obtain the wanted \
adapted frame.\nHere is a variable point in the euclidean 3-space:"
}], "Text"],

Cell[BoxData[
    \(point[a_]\  := \ Table[a[i], \ {i, 1, 3}]\)], "Input",
  CellLabel->"In[12]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["A corresponding isotropic vector is", "Text"],

Cell[BoxData[
    \(invstepro[point[a]]\)], "Input",
  CellLabel->"In[26]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[pssp[%, %]]\)], "Input",
  CellLabel->"In[27]:=",
  FontFamily->"Times"],

Cell["\<\
The following scalar product is not M\[ODoubleDot]bius invariant, since the \
point defines the  isotropic vector only up to a non zero factor; the \
expression is zero iff point[a] = point[b]. Any two pairs of distinct points \
are M\[ODoubleDot]bius equivalent. \
\>", "Text"],

Cell[BoxData[
    \(pssp[invstepro[point[a]], invstepro[point[b]]]\)], "Input",
  CellLabel->"In[28]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[29]:=",
  FontFamily->"Times"],

Cell["\<\
We shall show that his expression equals the following euclidean invariant of \
the radius vector pair\
\>", "Text"],

Cell[BoxData[
    \(euinv[a_List, 
        b_List]\  := \ \(-2\) \((a - b)\) . \((a - 
                  b)\)/\((\((1\  + \ a . a)\)*\((1\  + \ b . b)\))\) /; 
        Length[a] == \ Length[b]\)], "Input",
  CellLabel->"In[13]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(euinv[point[a], point[b]]\)], "Input",
  CellLabel->"In[30]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euinv[stb[1, 3], stb[2, 3]]\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pointt[a_]\  := \ invstepro[point[a]]\)], "Input",
  CellLabel->"In[14]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[pointt[a]\  + \ pointt[b], \ pointt[a]\  - \ pointt[b]]\)], "Input",\

  CellLabel->"In[32]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[33]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[pointt[a]\  + \ pointt[b], \ pointt[a]\  + \ pointt[b]]\)], "Input",\

  CellLabel->"In[34]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[35]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(%\  - \ 2*euinv[point[a], point[b]]\)], "Input",
  CellLabel->"In[36]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[37]:=",
  FontFamily->"Times"],

Cell["This proves the statement, since", "Text"],

Cell[BoxData[
    \(pssp[pointt[a]\  + \ pointt[b], \ pointt[a]\  + \ pointt[b]] \[Equal] \ 
      2*pssp[pointt[a], pointt[b]]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[72]:="],

Cell["Analogously we have", "Text"],

Cell[BoxData[
    \(pssp[pointt[a]\  - \ pointt[b], \ pointt[a]\  - \ pointt[b]]\)], "Input",\

  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(%\  + \ 2*euinv[point[a], point[b]]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell["\<\
These formulae lead to the following procedure, which defines an adapted \
pseudo-orthogonal frame of the pseudo-euclidean 2-space, spanned by the \
representing isotropic vectors pointt[a],  pointt[b] of the 5-space:\
\>", "Text"],

Cell[BoxData[{
    \(pp2space[a_List, b_List]\  := \ 
      Module[{eu, d\  = \ Length[a], 
          m}, \n\t\tIf[\((Length[b]\  != \ d)\) || \((a == \ 
                b)\), \ \n\t\t\t\tPrint["\<Incorrect arguments!\>"]; 
          Return[]]; \[IndentingNewLine]m\  = \ 
          Table[null[d + 2]\ , {2}]; \n\t\teu\  = 
          4 \((a - b)\) . \((a - 
                    b)\)/\((\((1\  + \ a . a)\)*\((1\  + \ b . b)\))\); \n\t
        m[\([1]\)]\  = \ \((invstepro[a]\  - \ invstepro[b])\)/Sqrt[eu]; \n
        m[\([2]\)] = \ \((invstepro[a]\  + \ invstepro[b])\)/Sqrt[eu]; \ 
        Return[m]]\n\), "\[IndentingNewLine]", 
    \(pp2space[a_List]\  := \ 
      pp2space[a[\([1]\)], \ a[\([2]\)]]\), "\[IndentingNewLine]", 
    \(\)}], "Input",
  CellLabel->"In[15]:=",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?pp2space\)\)], "Input",
  CellLabel->"In[38]:="],

Cell["for control purpose we set", "Text"],

Cell[BoxData[
    \(pts = pp2space[point[a], \ point[b]]\)], "Input",
  CellLabel->"In[35]:="],

Cell["and verify ", "Text"],

Cell[BoxData[
    \(FullSimplify[pssp[pts[\([1]\)], pts[\([2]\)]]]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(FullSimplify[pssp[pts[\([2]\)], pts[\([2]\)]]]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(FullSimplify[pssp[pts[\([1]\)], pts[\([1]\)]]]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(stepro[pts[\([1]\)] + pts[\([2]\)]]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(stepro[pts[\([1]\)] - pts[\([2]\)]]\)], "Input",
  CellLabel->"In[50]:="],

Cell["\<\
An orthonormal basis of the orthogonal complement is obtained by\
\>", "Text"],

Cell[BoxData[
    \(\(?vspacepp\)\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[{
    \(vspacepp[a_List, \ b_List]\  := \ 
      Module[{m, m1, d = Length[a]}, \[IndentingNewLine]m\  = \ 
          pp2space[a, b]; \[IndentingNewLine]If[m\  \[Equal] Null, \ 
          Return[Null]]; \[IndentingNewLine]m1\  = \ 
          orthonorm[
            NullSpace[{dual[m[\([1]\)], d + 2], 
                dual[m[\([2]\)], d + 2]}]]; \[IndentingNewLine]Return[
          m1]]\), "\n", 
    \(vspacepp[a_List]\  := \ 
      vspacepp[a[\([1]\)], \ a[\([2]\)]]\), "\[IndentingNewLine]", 
    \(\)}], "Input",
  CellLabel->"In[15]:=",
  Evaluatable->False],

Cell["\<\
Joining these bases we obtain the wanted adapted frame of the \
pseudo-euclidean 5-space:\
\>", "Text"],

Cell[BoxData[
    \(\(?psframepp\)\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(psframepp[a_List, 
        b_List]\  := \ \ Module[{m, m1, \ 
          d\  = \ Length[a]}, \[IndentingNewLine]m\  = \ 
          pp2space[a, b]; \[IndentingNewLine]If[m\  \[Equal] Null, \ 
          Return[Null]]; \[IndentingNewLine]m1\  = \ 
          orthonorm[
            NullSpace[{dual[m[\([1]\)], d + 2], 
                dual[m[\([2]\)], d + 2]}]]; \[IndentingNewLine]Return[
          Join[m1, m]]]\)], "Input",
  CellLabel->"In[15]:=",
  Evaluatable->False,
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Another version of vspacepp", "Subsubsection"],

Cell["\<\
 The orthogonal complement of the subspace spanned by the isotropic vectors \
{invstepro[a],invstepro[b]}, a,b two points of the M\[ODoubleDot]bius space, \
is always an euclidean subspace. Therefore one may apply Erhard Schmidt's \
orthogonalization \
\>", "Text"],

Cell[BoxData[
    \(\(?esorthonorm\)\)], "Input",
  CellLabel->"In[40]:="],

Cell["\<\
for getting an orthonormal basis of this subspace. This is done by the \
following module, valid for dim = 5 only:\
\>", "Text"],

Cell[BoxData[
    \(v3spacepp[a_List, \ b_List]\  := \ 
      Module[{m, m1}, \[IndentingNewLine]m\  = \ 
          pp2space[a, b]; \[IndentingNewLine]If[
          m\  \[Equal] Null || Length[a]\  \[NotEqual] \ 3, 
          Print["\<incorrect arguments\>"]; \ 
          Return[Null]]; \[IndentingNewLine]m1\  = {psCross[m[\([1]\)], 
              m[\([2]\)], stb[1], stb[2]], 
            psCross[m[\([1]\)], m[\([2]\)], stb[1], stb[3]], 
            psCross[m[\([1]\)], m[\([2]\)], stb[1], stb[4]], 
            psCross[m[\([1]\)], m[\([2]\)], stb[1], stb[5]], 
            psCross[m[\([1]\)], m[\([2]\)], stb[2], stb[3]], 
            psCross[m[\([1]\)], m[\([2]\)], stb[2], stb[4]], 
            psCross[m[\([1]\)], m[\([2]\)], stb[2], stb[5]], 
            psCross[m[\([1]\)], m[\([2]\)], stb[3], stb[4]], 
            psCross[m[\([1]\)], m[\([2]\)], stb[3], stb[5]], 
            psCross[m[\([1]\)], m[\([2]\)], stb[4], 
              stb[5]]}; \[IndentingNewLine]Return[
          esorthonorm[m1, \ innerprod\  \[Rule] pssp]]]\)], "Input",
  CellLabel->"In[15]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Test of vspacepp", "Subsubsection"],

Cell[BoxData[
    \(vspacepp[null[3], \ stb[1, 3]]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(vspacepp[null[3], \ {x, y, z}]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(FullSimplify[%, \ {x, y, z} \[Element] Reals]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], \ {i, 3}, {j, 3}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[63]:="],

Cell["The simplification result is false for x= 0:", "Text"],

Cell[BoxData[
    \({1\/Sign[x], 0, 0, \(-\(Abs[x]\/\(x\^2 + y\^2 + z\^2\)\)\), 
        Abs[x]\/\(x\^2 + y\^2 + z\^2\)} /. x \[Rule] 0\)], "Input",
  CellLabel->"In[64]:="],

Cell["\<\
Also inserting x =0 in the unsimplified expression causes an error: \
\>", "Text"],

Cell[BoxData[
    \({\(x\^2 + y\^2 + z\^2\)\/\(x\ \@Abs[\((x\^2 + y\^2 + \
z\^2)\)\^2\/x\^2]\), 0, 
        0, \(-\(1\/\@Abs[\((x\^2 + y\^2 + z\^2)\)\^2\/x\^2]\)\), 
        1\/\@Abs[\((x\^2 + y\^2 + z\^2)\)\^2\/x\^2]} /. 
      x \[Rule] 0\)], "Input",
  CellLabel->"In[65]:="],

Cell["The correct value one may find by the limit:", "Text"],

Cell[BoxData[
    \(Limit[{\(x\^2 + y\^2 + z\^2\)\/\(x\ \@Abs[\((x\^2 + y\^2 + \
z\^2)\)\^2\/x\^2]\), 0, 
        0, \(-\(1\/\@Abs[\((x\^2 + y\^2 + z\^2)\)\^2\/x\^2]\)\), 
        1\/\@Abs[\((x\^2 + y\^2 + z\^2)\)\^2\/x\^2]}, \ 
      x\  \[Rule] \ 0]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(Simplify[%, \ {y, z} \[Element] Reals]\)], "Input",
  CellLabel->"In[67]:="],

Cell["what could have been realized at a glance immediately. ", "Text"],

Cell[BoxData[
    \(pssp[
      invstepro[{x, y, z}], {0, 0, \(-1\), 
        z\/\(x\^2 + y\^2 + z\^2\), \(-\(z\/\(x\^2 + y\^2 + 
                z\^2\)\)\)}]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(Timing[vspacepp[\(-{x, y, z}\), \ {x, y, z}]]\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(Simplify[%[\([2]\)], {x, y, z} \[Element] Reals]\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], \ {i, 3}, {j, 3}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(Simplify[Together[%], {x, y, z} \[Element] Reals]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(atest\  = {{0, 0, 
          0, \(1 + x\^2 + y\^2 + z\^2\)\/\(2\ \@\(x\^2 + y\^2 + z\^2\)\), \
\(\(-1\) + x\^2 + y\^2 + z\^2\)\/\(2\ \@\(x\^2 + y\^2 + z\^2\)\)}, \
{\(-\(\(\(z\)\(\ \)\)\/\@\(x\^2 + z\^2\)\)\), 0, x\/\@\(x\^2 + z\^2\), 0, 
          0}, {\(-\(\(x\ y\)\/\@\(\((x\^2 + z\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\
\)\)\), 1\/\@\(\(x\^2 + y\^2 + z\^2\)\/\(x\^2 + z\^2\)\), \(-\(\(y\ z\)\/\@\(\
\((x\^2 + z\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\)\)\), 0, 0}}\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(Table[
      pssp[atest[\([i]\)], \ invstepro[\(-{x, y, z}\)]], {i, 3}]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \(FullSimplify[Together[%], {x, y, z} \[Element] Reals]\)], "Input",
  CellLabel->"In[88]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Test of v3spacepp", "Subsubsection"],

Cell[BoxData[
    \(v3spacepp[null[3], \ stb[1, 3]]\)], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \(v3spacepp[null[3], \ {x, y, z}]\)], "Input",
  CellLabel->"In[132]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], \ {i, 3}, {j, 3}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \(pssp[
      invstepro[{x, y, z}], {0, 0, \(-1\), 
        z\/\(x\^2 + y\^2 + z\^2\), \(-\(z\/\(x\^2 + y\^2 + 
                z\^2\)\)\)}]\)], "Input",
  CellLabel->"In[134]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[135]:="],

Cell[BoxData[
    \(Timing[v3spacepp[\(-{x, y, z}\), \ {x, y, z}]]\)], "Input",
  CellLabel->"In[138]:="],

Cell["vspacepp needed 0.11 s only.", "Text"],

Cell[BoxData[
    \(Simplify[%[\([2]\)], {x, y, z} \[Element] Reals]\)], "Input",
  CellLabel->"In[139]:="],

Cell[BoxData[
    \(Simplify[%, z > 0]\)], "Input",
  CellLabel->"In[140]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], \ {i, 3}, {j, 3}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[141]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[142]:="],

Cell[BoxData[
    \(a3test\  = {{0, 0, 
          0, \(1 + x\^2 + y\^2 + z\^2\)\/\(2\ \@\(x\^2 + y\^2 + z\^2\)\), \
\(\(-1\) + x\^2 + y\^2 + z\^2\)\/\(2\ \@\(x\^2 + y\^2 + z\^2\)\)}, {0, \(-\(z\
\/\@\(y\^2 + z\^2\)\)\), y\/\@\(y\^2 + z\^2\), 0, 
          0}, {\@\(\(y\^2 + z\^2\)\/\(x\^2 + y\^2 + z\^2\)\), \(-\(\(x\ y\)\/\
\@\(\((y\^2 + z\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\)\)\), \(-\(\(x\ \
z\)\/\@\(\((y\^2 + z\^2)\)\ \((x\^2 + y\^2 + z\^2)\)\)\)\), 0, 0}}\)], "Input",\

  CellLabel->"In[143]:="],

Cell[BoxData[
    \(Table[
      pssp[a3test[\([i]\)], \ invstepro[\(-{x, y, z}\)]], {i, 3}]\)], "Input",\

  CellLabel->"In[144]:="],

Cell[BoxData[
    \(Simplify[Together[%], {x, y, z} \[Element] Reals]\)], "Input",
  CellLabel->"In[145]:="],

Cell["\<\
Resuming we see that vspacepp is faster than v3spcepp, but v3spcepp seems to \
give simpler results. We carry out  yet a random test:\
\>", "Text"],

Cell[BoxData[{
    \(aa = \ randomv[3]; \ bb = \ randomv[3];\), "\[IndentingNewLine]", 
    \(Timing[v3spacepp[aa, bb]]\)}], "Input",
  CellLabel->"In[173]:="],

Cell[BoxData[
    \(Timing[vspacepp[aa, bb]]\)], "Input",
  CellLabel->"In[175]:="],

Cell[BoxData[
    \(Remove[aa, bb, \ atest, \ a3test]\)], "Input",
  CellLabel->"In[176]:="],

Cell["\<\
Booth modules have nearly the same speed doing these numerical calculations; \
thus, sometimes it may be useful to replace vspacepp by v3spacepp e.g. \
setting\
\>", "Text"],

Cell[BoxData[
    \(Clear[psframepp3]\)], "Input",
  CellLabel->"In[182]:="],

Cell[BoxData[
    \(psframepp3[a_List, 
        b_List]\  := \ \ Module[{m, m1}, \[IndentingNewLine]m1\  = \ 
          v3spacepp[a, b]; \[IndentingNewLine]m\  = \ 
          pp2space[a, b]; \[IndentingNewLine]If[
          m\  \[Equal] Null || \ m1\  \[Equal] \ Null, \ 
          Return[Null]]; \[IndentingNewLine]Return[Join[m1, m]]]\)], "Input",
  CellLabel->"In[183]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[" Examples", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(psframepp[{1, 1, 1}, {0, 0, 0}]\)], "Input",
  CellLabel->"In[179]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 1, 5}, {j, 1, 5}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[180]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(psframepp3[{1, 1, 1}, {0, 0, 0}]\)], "Input",
  CellLabel->"In[184]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 1, 5}, {j, 1, 5}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[185]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[psframepp[randomv[3], randomv[3]]]\)], "Input",
  CellLabel->"In[186]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(atpp\  = \ %[\([2]\)];\)\)], "Input",
  CellLabel->"In[187]:="],

Cell[BoxData[
    \(Table[Chop[pssp[%[\([i]\)], %[\([j]\)]]], {i, 1, 5}, {j, 1, 5}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[188]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Timing[psframepp3[randomv[3], randomv[3]]]\)], "Input",
  CellLabel->"In[189]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(atpp\  = \ %[\([2]\)];\)\)], "Input",
  CellLabel->"In[190]:="],

Cell[BoxData[
    \(Table[Chop[pssp[%[\([i]\)], %[\([j]\)]]], {i, 1, 5}, {j, 1, 5}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[191]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(psframepp[{1, 1, 1}, {1, 1, 1}]\)], "Input",
  CellLabel->"In[192]:=",
  FontFamily->"Times"],

Cell["Remember: null[] = null[dim]:", "Text"],

Cell[BoxData[
    \(psframepp[{1, 1, 1}, null[]]\)], "Input",
  CellLabel->"In[193]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(psframepp3[{1, 1, 1}, {1, 1, 1}]\)], "Input",
  CellLabel->"In[194]:=",
  FontFamily->"Times"],

Cell["Remember: null[] = null[dim]:", "Text"],

Cell[BoxData[
    \(psframepp3[{1, 1, 1}, null[]]\)], "Input",
  CellLabel->"In[195]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(psframepp3[{\(-t\), 0, 0}, {t, 0, 0}]\)], "Input",
  CellLabel->"In[200]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ t > 0]\)], "Input",
  CellLabel->"In[201]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], \ %[\([j]\)]], {i, 5}, \ {j, 5}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[202]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ t > 0]\)], "Input",
  CellLabel->"In[203]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(psframepp[{\(-t\), 0, 0}, {t, 0, 0}]\)], "Input",
  CellLabel->"In[196]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ t > 0]\)], "Input",
  CellLabel->"In[197]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], \ %[\([j]\)]], {i, 5}, \ {j, 5}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[198]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ t > 0]\)], "Input",
  CellLabel->"In[199]:=",
  FontFamily->"Times"],

Cell["\<\
The procedure works correctly also in symbolical calculations (we suppress \
the long and clumsy output)\
\>", "Text"],

Cell[BoxData[
    \(\(Simplify[psframepp[{a, b, c}, {x, y, z}]];\)\)], "Input",
  CellLabel->"In[204]:=",
  FontFamily->"Times"],

Cell["\<\
The next two cells show that the calculated frame is adapted:\
\>", "Text"],

Cell[BoxData[
    \(stepro[%[\([4]\)] + %[\([5]\)]]\)], "Input",
  CellLabel->"In[206]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(stepro[%%[\([4]\)] - %%[\([5]\)]]\)], "Input",
  CellLabel->"In[207]:=",
  FontFamily->"Times"],

Cell["psframepp3 runned a comparatively long time without result:", "Text"],

Cell[BoxData[
    \(psframepp3[{a, b, c}, {x, y, z}]\)], "Input",
  CellLabel->"In[208]:=",
  FontFamily->"Times"],

Cell["\<\
Therefore, and since psframepp3 works only within 3-dimensional \
M\[ODoubleDot]bius geometry, we shall use psframepp, and vspacepp, in future \
calculations.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Random test", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
The procedures pp2space,vspacepp, psframepp work in arbitrary dimension. We \
consider random points in the 4space and put\
\>", "Text"],

Cell[BoxData[
    \(\(dim\  = \ 6;\)\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(psid\  = dual[IdentityMatrix[6], 6]\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell["\<\
We take two random points of the eucliden 4-space (recommendation: try it \
with different factors), and control the pseudo-orthonormality of the \
resulted adapted frame: \
\>", "Text"],

Cell[BoxData[
    \(\((a\  = \(-5\)*\ randomv[4]; b\  = 4*\ randomv[4]; \n\t
      Print[{a, b}]; \nmat\  = \ Timing[psframepp[a, b]]; \n
      Print[mat[\([1]\)], MatrixForm[mat[\([2]\)]]]; \n\t
      mbt\  = \ Table[
          pssp[mat[\([2, i]\)], mat[\([2, j]\)], 6, 1], {i, 6}, {j, 6}]; \n\t
      Chop[mbt\  - \ psid])\)\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell["\<\
The random points are reproduced:\
\>", "Text"],

Cell[BoxData[
    \({stepro[mat[\([2, dim - 1]\)]\  + \ mat[\([2, dim]\)]], \ 
      stepro[mat[\([2, dim - 1]\)]\  - \ mat[\([2, dim]\)]]}\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell["Now we restore the dimension", "Text"],

Cell[BoxData[
    \(dim\  = \ 5\)], "Input",
  CellLabel->"In[53]:="],

Cell["\<\
The procedures work without changing the dimension explicitely, indeed:\
\>", "Text"],

Cell[BoxData[
    \(\((a\  = \(-5\)*\ randomv[4]; b\  = 4*\ randomv[4]; \n\t
      Print[{a, b}]; \nmat\  = \ Timing[psframepp[a, b]]; \n
      Print[mat[\([1]\)], MatrixForm[mat[\([2]\)]]]; \n\t
      mbt\  = \ Table[
          pssp[mat[\([2, i]\)], mat[\([2, j]\)], 6, 1], {i, 6}, {j, 6}]; \n\t
      Chop[mbt\  - \ psid])\)\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell["\<\
The random points are reproduced:\
\>", "Text"],

Cell[BoxData[
    \({stepro[mat[\([2, 5]\)]\  + \ mat[\([2, 6]\)]], \ 
      stepro[mat[\([2, 5]\)]\  - \ mat[\([2, 6]\)]]}\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Remove[a, b, mat, \ mbt, psid]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2 The invariant moebspp and the mutual position", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["The definition", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Let the 0-sphere (a, b) consisting of  two points of the 3-space be given. \
Then the corresponding euclidean 3-subspace of the pseudo-euclidean 5-space \
is the span of the orthonormal vectors vspacepp[point[a], point[b]] defined \
above.\
\>", "Text"],

Cell[TextData[{
  "Let the spacelike unit vector n define the sphere, and the orthonormal \
vectors b ={ b[[1]], b[[2]], b[[3]] }span the subspace vspacepp of the point \
pair. Then, see ",
  ButtonBox["[6]",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  " or [4],  the only invariant describing the mutual position is "
}], "Text"],

Cell[BoxData[
    \(\(?moebspp\)\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(moebspp[n_List, a_List, b_List]\  := \ 
      Module[{m, \ dn\  = \ Length[n], \ 
          da = Length[
              a]}, \[IndentingNewLine]If[\((da\  \[NotEqual] \ 
                Length[b])\) || \ \((da + 2\  \[NotEqual] \ dn)\), \ 
          Print["\<Incorrect arguments!\>"]; 
          Return[]]; \[IndentingNewLine]m\  = \ 
          vspacepp[a, b]; \[IndentingNewLine]Return[
          Sum[pssp[m[\([i]\)], \ n]^2, {i, dim\  - 2}]/
            pssp[n, n]]]\)], "Input",
  CellLabel->"In[15]:=",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["The point pair belongs to the sphere iff", "Text"],

Cell[BoxData[
    \(indicator[n_List, a_List, b_List]\  := \ 
      pscross[Join[\ vspacepp[a, b], {n}]]\)], "Input",
  CellLabel->"In[15]:=",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
 equals null[]; the pair (sphere, point pair) is not in general position.\
\>", "Text"],

Cell["\<\
Remark. The last two definitions and the last statement are valid in any \
dimension dim \[GreaterEqual] 3.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection",
  FontFamily->"Times",
  CellTags->"ex3.2_1"],

Cell["We consider the line as the euclidean 1-space; thus we put", "Text"],

Cell[BoxData[
    \(dim\  = \ 3\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(\(?indicator\)\)], "Input",
  CellLabel->"In[68]:="],

Cell["\<\
The vector indicator  of the arbitrary \"hypersphere\" defined by vec[n3], \
assumed to be spacelike, and the 0-sphere S0 = {{3},{5}} is\
\>", "Text"],

Cell[BoxData[
    \(indicator[vec[nn], {3}, {5}]\)], "Input",
  CellLabel->"In[45]:="],

Cell["The corresponding M\[ODoubleDot]bius invariant moebspp equals", "Text"],

Cell[BoxData[
    \(\(?moebspp\)\)], "Input",
  CellLabel->"In[69]:="],

Cell[BoxData[
    \(moebspp[vec[nn], {3}, {5}]\)], "Input",
  CellLabel->"In[46]:="],

Cell["\<\
For the 1-space a hypersphere is a 0-sphere; thus we change our point of view \
replacing vec[n3] by the only vector of\
\>", "Text"],

Cell[BoxData[
    \(vspacepp[{3}, {5}]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(vv\  = \ Flatten[%]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(pssp[vv, vv]\)], "Input",
  CellLabel->"In[49]:="],

Cell["vv defines the 0-sphere S={{3},{5}}:", "Text"],

Cell[BoxData[
    \(indicator[vv, {3}, {5}]\)], "Input",
  CellLabel->"In[50]:="],

Cell["\<\
If only one point a = 3 belongs to S,  indicator yields an isotropic vector (\
\"S is tangent to S0\")\
\>", "Text"],

Cell[BoxData[
    \(Simplify[indicator[vv, {3}, {b}], \ b \[Element] Reals]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(Simplify[pssp[%, %]]\)], "Input",
  CellLabel->"In[52]:="],

Cell["\<\
The only solution of indicator[vv,{3},{b}]\[Equal]null[] is b = 5, that means \
S=S0:\
\>", "Text"],

Cell[BoxData[
    \(Solve[%% \[Equal] null[], \ b]\)], "Input",
  CellLabel->"In[53]:="],

Cell["The tangency property is reflected by", "Text"],

Cell[BoxData[
    \(Simplify[moebspp[vv, {3}, {b}], \ b > 0]\)], "Input",
  CellLabel->"In[54]:="],

Cell["The point  a = b =3 is to be excluded, of course:", "Text"],

Cell[BoxData[
    \(indicator[vv, {3}, {3}]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(moebspp[vv, {3}, {3}]\)], "Input",
  CellLabel->"In[56]:="],

Cell["\<\
If the 0-spheres S,S0 are interlaced (i.e. separating each other), the \
indicator is timelike, and the M\[ODoubleDot]bius invariant is less than 1:\
\>", "Text"],

Cell[BoxData[
    \(indicator[vv, {1}, {4}]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(moebspp[vv, {1}, {4}]\)], "Input",
  CellLabel->"In[59]:="],

Cell["\<\
If they don't separate each other, we get a spacelike indicator, and the M\
\[ODoubleDot]bius invariant is greater than 1:\
\>", "Text"],

Cell[BoxData[
    \(indicator[vv, {1}, {6}]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(moebspp[vv, {1}, {6}]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(indicator[vv, {3.5}, {4}]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(moebspp[vv, {3.5}, {4}]\)], "Input",
  CellLabel->"In[65]:="],

Cell["We return to the euclidean 3-space, that means", "Text"],

Cell[BoxData[
    \(\(dim\  = \ 5;\)\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(Remove[nn, vv]\)], "Input",
  CellLabel->"In[67]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
We compare the point pair {{x,0,0}, {0,y,0}} with the unit sphere, defined by \
stb[4]; the invariant is\
\>", "Text"],

Cell[BoxData[
    \(invfctspp[x_, y_]\  := \ 
      moebspp[stb[4], \ {x, 0, 0}, {0, y, 0}]\)], "Input",
  CellLabel->"In[85]:=",
  FontFamily->"Times"],

Cell["We calculate  the function", "Text"],

Cell[BoxData[
    \(invfctspp[x, y]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell["\<\
This simple result leads to the direct definition of the function \
\>", "Text"],

Cell[BoxData[
    \(Clear[invfctspp]; \ 
    invfctspp[x_, 
        y_]\  := \ \((1 + \ x^2*y^2)\)/\((x^2\  + \ y^2)\)\)], "Input",
  CellLabel->"In[40]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot3D[invfctspp[x, y], {x, \(-0.3\), 0.3}, {y, 0.3, 1.5}, 
      PlotRange\  \[Rule] \ All, \ PlotPoints\  \[Rule] 40]\)], "Input",
  CellLabel->"In[41]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[invfctspp[x, 1.5], \ {x, \(-20\), 20}]\)], "Input",
  CellLabel->"In[42]:="],

Cell["For x=y=1 both points lie on the sphere:", "Text"],

Cell[BoxData[
    \(indicator[stb[4], \ stb[1, 3], stb[2, 3]]\)], "Input",
  CellLabel->"In[81]:=",
  FontFamily->"Times"],

Cell["\<\
For pairs not in general position the invariant moebspp always equals one:\
\>", "Text"],

Cell[BoxData[
    \(invfctspp[1, 1]\)], "Input",
  CellLabel->"In[44]:=",
  FontFamily->"Times"],

Cell["\<\
 More generally, we get for the x,y-plane and two of its points again \
\>", "Text"],

Cell[BoxData[
    \(moebspp[stb[3], \ {a, b, 0}, {c, d, 0}]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(indicator[stb[3], \ {a, b, 0}, {c, d, 0}]\)], "Input",
  CellLabel->"In[82]:="],

Cell["Now only the point stb[1,3] belongs to the sphere:", "Text"],

Cell[BoxData[
    \(indicator[stb[4], \ stb[1, 3], null[3]]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times"],

Cell["\<\
The vector product yields an isotropic vector, and the invariant equals 1:\
\>", "Text"],

Cell[BoxData[
    \(invfctspp[1, 0]\)], "Input",
  CellLabel->"In[86]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(invfctspp[x, 0]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[invfctspp[x, 0], \ {x, \(-2\), 2}]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell["\<\
Clearly,  for Abs[x] > 1 the sphere separates the points stb[1,3],null[3]], \
and the invariant is < 1; for Abs[x] < 1 vice versa.\
\>", "Text"],

Cell[BoxData[
    \(Plot[invfctspp[x, 0], \ {x, 1/2, 2}]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Limit[invfctspp[x, 1.5], x \[Rule] Infinity]\)], "Input",
  CellLabel->"In[147]:="],

Cell[BoxData[
    \(invfctspp[0, 1.5]\)], "Input",
  CellLabel->"In[148]:="],

Cell[BoxData[
    \(Plot[invfctspp[x, 1.5], \ {x, \(- .20\),  .20}]\)], "Input",
  CellLabel->"In[149]:="],

Cell[BoxData[
    \(Limit[invfctspp[x, 0], \ x \[Rule] Infinity]\)], "Input",
  CellLabel->"In[53]:="],

Cell["\<\
At the solutions of the following equations the property \"sphere separate \
the points\"/ \"sphere does not separate the points\" changes.\
\>", "Text"],

Cell[BoxData[
    \(Solve[x^2\  + y^2\  == 1\  + x^2*y^2, y]\)], "Input",
  CellLabel->"In[151]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Solve[x^2\  + y^2\  == 1\  + x^2*y^2, x]\)], "Input",
  CellLabel->"In[152]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[1\  + \ Chop[invfctspp[x, 1] - 1], {x, 0. , 1.5}]\)], "Input",
  CellLabel->"In[153]:=",
  FontFamily->"Times"],

Cell["Sphere separates the points:", "Text"],

Cell[BoxData[
    \(invfctspp[1/2, 1.5]\)], "Input",
  CellLabel->"In[154]:=",
  FontFamily->"Times"],

Cell["Sphere does not separate points:", "Text"],

Cell[BoxData[
    \(invfctspp[5, 1.5]\)], "Input",
  CellLabel->"In[155]:=",
  FontFamily->"Times"],

Cell["\<\
Exercise: Scetch the sets of all points in the x,y-plane for which the points \
(x,0,0), (0,y,0) are separated (not separated, resp.) by the sphere.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
3.3 An expression of the invariant moebspp in euclidean terms\
\>", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["The result", "Subsubsection"],

Cell["\<\
Now we consider the arbitrary sphere with the corresponding spacelike \
vector\
\>", "Text"],

Cell[BoxData[
    \(vs\  = \ spherevec[x, y, z, r]\)], "Input",
  CellLabel->"In[29]:=",
  FontFamily->"Times"],

Cell["\<\
and the point pair {{-t,0,0}, {t,0,0}}. We calculate the invariant\
\>", "Text"],

Cell[BoxData[
    \(\(?moebspp\)\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(moebspp[vs, {\(-t\), 0, 0}, \ {t, 0, 0}]\)], "Input",
  CellLabel->"In[30]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ t > 0]\)], "Input",
  CellLabel->"In[31]:=",
  FontFamily->"Times"],

Cell["This result leads to the following  function:", "Text"],

Cell["\<\
fctmoebspp[t_, x_, y_, z_, r_] :=(4*t^2*(y^2 + z^2) + 
(-r^2 - t^2 + x^2 + y^2 + z^2)^2)/(4*r^2*t^2)\
\>", "Input",
  CellLabel->"In[16]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["Test: The points belong to the sphere:", "Text"],

Cell[BoxData[
    \(fctmoebspp[t, 0, 0, 0, t]\)], "Input",
  CellLabel->"In[33]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[fctmoebspp[t, 0, 0, z, Sqrt[z^2\  + t^2]]]\)], "Input",
  CellLabel->"In[34]:=",
  FontFamily->"Times"],

Cell["The terms entering in the function", "Text"],

Cell[BoxData[
    \(fctmoebspp[t, x, y, z, r]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "have very simple euclidean interpretations: r and t are the radii of the \
spheres, d = ",
  Cell[BoxData[
      \(\@\(x\^2 + y\^2 + z\^2\)\)]],
  " is the distance of their centers, and   ",
  Cell[BoxData[
      \(t\^2\ \((y\^2 + z\^2)\)\)]],
  " is the square of the surface of the triangle formed by the point pair and \
the center of the sphere:"
}], "Text"],

Cell[BoxData[
    \(cross[{{x, y, z}, {2*t, 0, 0}}]/2\)], "Input",
  CellLabel->"In[36]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(% . %\)], "Input",
  CellLabel->"In[37]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "It follows:\n",
  StyleBox["PROPOSITION 1",
    FontColor->RGBColor[0, 0, 1]],
  ". In the euclidean 3-space let r >0 denote the radius of the 2-sphere S, t \
>0 the radius of the 0-sphere pp,  d the distance of their centers, and u, 0 \
\[LessEqual] u < Pi, the angle between the line containing the 0-sphere and \
the line containing the centers, u=0 in case d=0. Then the function"
}], "Text"],

Cell[BoxData[
    \(euklidmoebspp[r_, t_, d_, 
        u_]\  := \ \((d^2 - r^2 - t^2)\)^2/\((4*r^2*t^2)\)\  + \ \((d*
              Sin[u]/r)\)^2\)], "Input",
  CellLabel->"In[17]:=",
  Evaluatable->False],

Cell[BoxData[
    \(euklidmoebspp[r, t, d, u]\)], "Input",
  CellLabel->"In[17]:=",
  InitializationCell->True],

Cell["\<\
is conformally invariant; it is an expression of the M\[ODoubleDot]bius \
invariant moebspp[(S,pp)) of the pair (S,pp) in euclidean terms.\
\>", "Text"],

Cell[TextData[{
  StyleBox["COROLLARY. ",
    FontColor->RGBColor[0, 0, 1]],
  " The last formula is valid for hyperspheres and 0-spheres of the \
n-dimensional euclidean space."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Test", "Subsubsection"]], "Subsubsection"],

Cell["\<\
Let the 0-sphere be {{0,0,-t},{0,0,t}} and the center of the 2-sphere be \
\>", "Text"],

Cell[BoxData[
    \(ct2sph[d_, \ v_, u_]\  := \ d*\(unit[2]\)[{v, u}]\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(ct2sph[d, v, u]\)], "Input",
  CellLabel->"In[108]:="],

Cell["The spherevector is", "Text"],

Cell[BoxData[
    \(sph2v[d_, u_, v_, r_]\  := \ 
      spherevec[d\ Cos[u]\ Cos[v], d\ Cos[u]\ Sin[v], d\ Sin[u], 
        r]\)], "Input",
  CellLabel->"In[18]:=",
  InitializationCell->True],

Cell["\<\
Activate the next cell repeatedly; change the factor at the random varibles, \
if wanted, and use MathGL3D with  the option WireFrame.\
\>", "Text"],

Cell[BoxData[
    \(\((d = 1.1*Random[]; u = Random[]*Pi/2; \ v = Random[]*Pi*2; 
      r = Random[]*2; 
      t = Random[]*2; \ \[IndentingNewLine]Print["\<(d,u,v,r,t) = (\>", d, u, 
        v, r, t, "\<)\>"]; \[IndentingNewLine]res = \ 
        moebspp[sph2v[d, u, v, r], {0, 0, \(-t\)}, {0, 0, 
            t}]; \[IndentingNewLine]Print["\<res = \>", \ 
        res]; \[IndentingNewLine]eures\  = \ 
        euklidmoebspp[r, t, d, 
          Pi/2\  - u]; \[IndentingNewLine]Print["\<eures = \>", \ 
        eures]; \[IndentingNewLine]grandom\  = 
        Show[{euklidsphereplot3D[sph2v[d, u, v, r]], \ 
            Graphics3D[{PointSize[0.04], Point[{0, 0, \(-t\)}], 
                Point[{0, 0, t}]}]}, 
          PlotRange\  \[Rule] \ All]; \[IndentingNewLine]Chop[
        res\  - \ eures])\)\)], "Input",
  CellLabel->"In[114]:="],

Cell[BoxData[
    \(MVShow3D[grandom, \ MVPointSphereSize \[Rule] 1.8]\)], "Input",
  CellLabel->"In[262]:="]
}, Closed]],

Cell[CellGroupData[{

Cell[" Example", "Subsubsection"],

Cell["\<\
Now we consider  the point pair with t = 1 and the unit sphere S1 with center \
{1,0,0};their invariant is\
\>", "Text"],

Cell[BoxData[
    \(fctmoebspp[1, 1, 0, 0, 1]\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times"],

Cell["\<\
Point pair and sphere are \"interlaced\": any sphere through the point pair \
intersects the sphere S1. We shall calculate the intersection angle between \
the sphere S1 and any sphere through the point pair. The spacelike vectors of \
this sphere bundle  form the unit sphere in\
\>", "Text"],

Cell[BoxData[
    \(vspacepp[{\(-1\), 0, 0}, {1, 0, 0}]\)], "Input",
  CellLabel->"In[40]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vn[u_, v_]\  := \ 
      stb[2]*Cos[u]*Cos[v]\  + \ stb[3]*Cos[u]*Sin[v]\  + 
        stb[4]*Sin[u]\)], "Input",
  CellLabel->"In[41]:=",
  FontFamily->"Times"],

Cell["The sphere vector of S1 is", "Text"],

Cell[BoxData[
    \(spherevec[1, 0, 0, 1]\)], "Input",
  CellLabel->"In[42]:=",
  FontFamily->"Times"],

Cell["\<\
The following function gives the cosinus of the intersection angle:\
\>", "Text"],

Cell[BoxData[
    \(ftest[u_, v_]\  := 
      pssp[{1, 0, 0, \(-\(1\/2\)\), 1\/2}, vn[u, v]]\)], "Input",
  CellLabel->"In[43]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ftest[u, v]\)], "Input",
  CellLabel->"In[44]:=",
  FontFamily->"Times"],

Cell["\<\
Thus, the maximum of ftest[u,v] is 1/2, and this is the square root of the \
\"eigenvalue\", which is in this case simply the invariant moebspp. For the \
intersection angle we have\
\>", "Text"],

Cell[BoxData[
    \(angle[u_]\  := \ ArcCos[\(-Sin[u]\)/2]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[angle[u]*180/Pi, \ {u, \(-Pi\)/2, Pi/2}]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[angle[u]*180/Pi, \ {u, \(-Pi\), Pi}]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell["The minimal angle is ", "Text"],

Cell[BoxData[
    \(angle[\(-Pi\)/2]*180/Pi\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ArcCos[1/2]\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell["It will be reached for the  standard unit sphere", "Text"],

Cell[BoxData[
    \(vn[\(-Pi\)/2, \ v]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell["The maximal angle is", "Text"],

Cell[BoxData[
    \(angle[Pi/2]*180/Pi\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell["\<\
and this is again the standard unit sphere, only with the other \
orientation:\
\>", "Text"],

Cell[BoxData[
    \(vn[Pi/2, v]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell["\<\
which is the sphere of smallest (positive) radius containing the two \
points.\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[spherevec[1, 0, 0, 1]]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(sph1001\  = \ %\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(Show[{sph1, sph1001}]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(vn[u, v]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell["\<\
Of course, the centers of the spheres containing the point pair  belong to \
the y,z-plane:\
\>", "Text"],

Cell[BoxData[
    \(vcenter[vn[u, v]]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vradius[vn[u, v]]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vradius[vn[\(-Pi\)/2, v]]\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vradius[vn[Pi/2, v]]\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[vradius[vn[u, 1]], \ {u, \(-2\), \(- .2\)}]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(Table[N[vcenter[vn[k*Pi/8, Pi/2]]], {k, \ \(-4\), 4}]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[N[vradius[vn[k*Pi/8, Pi/2]]], {k, \ \(-4\), 4}]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[N[angle[k*Pi/8]*180/Pi], {k, \ \(-4\), 4}]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell["\<\
Remember: negative sphere radius and positive sphere radius correspond to \
opposite orientations of the sphere; let the radius be a vector pointing to \
or away of the center. Therefore appear the complementary angles under the \
negative orientation of the radius. \
\>", "Text"],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[vn[k*Pi/8, Pi/2], \ \(-1\), 0, \(-1\), 
        1], {k, \(-4\), 4}]\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tgr1\  = %\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[{1, 0, 0, \(-\(1\/2\)\), 1\/2}]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{tgr1, %}]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tgr2\  = \ %\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[
      Graphics3D[{PointSize[0.04], Point[{\(-1\), 0, 0}], 
          Point[{1, 0, 0}]}]]\)], "Input",
  CellLabel->"In[82]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ppts\  = \ %\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(Show[{tgr2, ppts}]\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tgr3\  = \ %\)], "Input",
  CellLabel->"In[85]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(Show[{ppts, \ sph1, sph1001}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(minsph\  = \ %\)], "Input",
  CellLabel->"In[87]:="],

Cell["\<\
Apply MathGL3d, Appearance Wire Frame, to look at these graphics.\
\>", "Text"],

Cell[BoxData[
    \(MVShow3D[tgr3, MVPointSphereSize \[Rule] 2.8]\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    \(MVShow3D[minsph, MVPointSphereSize \[Rule] 2.8]\)], "Input",
  CellLabel->"In[89]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Random Test in dimension 5, i.e. dim = 7, ind = 1", "Subsubsection"],

Cell["\<\
We shall not change the values  dim = 5, ind = 1globally, because we want \
checking wether the modules defined so far work indepedently of these basic \
constants. You may  also  choose, e. g. the plane replacing 7and 5 by  4 and \
2 in the commands defining the random vectors and prodd below.\
\>", "Text"],

Cell[BoxData[
    \(\(?moebspp\)\)], "Input",
  CellLabel->"In[129]:="],

Cell[BoxData[
    \(vn = randomv[7]\)], "Input",
  CellLabel->"In[148]:="],

Cell["This is the scalar product we are considering now:", "Text"],

Cell[BoxData[
    \(prodd[u_List, v_List]\  := pssp[u, v, 7]\)], "Input",
  CellLabel->"In[131]:="],

Cell[BoxData[
    \(Table[prodd[stb[i, 7], stb[j, 7]], {i, 7}, {j, 7}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[133]:="],

Cell[BoxData[
    \(prodd[vn, vn]\)], "Input",
  CellLabel->"In[149]:="],

Cell["\<\
Thus, vn is a spacelike vector. We take two random points of the euclidean \
5-space:\
\>", "Text"],

Cell[BoxData[
    \(vx\  = \ randomv[5]\)], "Input",
  CellLabel->"In[150]:="],

Cell[BoxData[
    \(vy\  = \ randomv[5]\)], "Input",
  CellLabel->"In[151]:="],

Cell["\<\
and calculate the M\[ODoubleDot]bius invariant of the hypersphere defined by \
vn, and the 0-sphere, defined by the two points:\
\>", "Text"],

Cell[BoxData[
    \(ti1\  = moebspp[vn, vx, vy]\)], "Input",
  CellLabel->"In[152]:="],

Cell["\<\
Now we calculate the euclidean invariants of the configuration and use \
euklidmoebspp calculating the M\[ODoubleDot]bius invariant by these euclidean \
entities. First the radius of the hypersphere:\
\>", "Text"],

Cell[BoxData[
    \(\(?vradius\)\)], "Input",
  CellLabel->"In[138]:="],

Cell[BoxData[
    \(vradius[vn]\)], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \(rr\  = \ %\)], "Input",
  CellLabel->"In[154]:="],

Cell["\<\
Next the radius of the 0-sphere (remember Dot = _._ is the euclidean scalar \
product in any dimension):\
\>", "Text"],

Cell[BoxData[
    \(tt\  = Sqrt[\((vx - vy)\) . \((vx - vy)\)]/2\)], "Input",
  CellLabel->"In[155]:="],

Cell["\<\
To calculate the distance of the centers we calculate the center of the \
hypersphere:\
\>", "Text"],

Cell[BoxData[
    \(vcenter[vn]\)], "Input",
  CellLabel->"In[156]:="],

Cell["nd subtract it from the center of the 0-sphere:", "Text"],

Cell[BoxData[
    \(vdiff\  = \((vx + vy)\)/2\  - %\)], "Input",
  CellLabel->"In[157]:="],

Cell["The length of this vector is the distance we asked for:", "Text"],

Cell[BoxData[
    \(dd\  = \ Sqrt[vdiff . vdiff]\)], "Input",
  CellLabel->"In[158]:="],

Cell["\<\
Finally we have to find the angle of the vector vdiff with the line through \
vx,vy:\
\>", "Text"],

Cell[BoxData[
    \(uu\  = \ 
      ArcSin[Sqrt[
          1 - \((vdiff . \((vx - vy)\)/\((dd*2*tt)\))\)^2]]\)], "Input",
  CellLabel->"In[159]:="],

Cell["Inserting these entities into euklidmoebspp we obtain", "Text"],

Cell[BoxData[
    \(ti2\  = euklidmoebspp[rr, tt, dd, uu]\)], "Input",
  CellLabel->"In[160]:="],

Cell["\<\
Indeed, this coincides, up to numerical disturbances, with ti1:\
\>", "Text"],

Cell[BoxData[
    \(Chop[ti1 - ti2]\)], "Input",
  CellLabel->"In[161]:="],

Cell["\<\
OK! Repeat the commands of this subsectionmay be,  in other dimensions, as \
often you need it to be sure that all is correct.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4 Orthogonality", "Subsection",
  FontFamily->"Times"],

Cell["\<\
We remark that the invariant in  the example in subsection 3.2  is always \
greater than zero; for y = 0 it tends to zero for x ->\[Proportional] . The \
point pair {null[3], \[Proportional]} has the property that all spheres \
through these points (i.e.all planes through the origin), and all circles \
through these points (i.e. all  lines through the origin) intersect the unit \
sphere orthogonally. Furthermore, the two points of the 0-sphere are in \
inversion with respect to the unit sphere.  Since both these properties are M\
\[ODoubleDot]bius invariant, and moebspp[(S,pp)] defines the pair (S,pp) up  \
to a M\[ODoubleDot]bius transform, we obtain\
\>", "Text"],

Cell[TextData[{
  StyleBox["PROPOSITION",
    FontColor->RGBColor[0, 0, 1]],
  " ",
  StyleBox["2",
    FontColor->RGBColor[0, 0, 1]],
  ". Let S be a sphere, and  pp = {p1,p2} a point pair in inversion with \
respect to this sphere. Then all the spheres through {p1, p2} intersect S \
orthogonally, and conversely, if all spheres containing the two points meet a \
sphere S orthogonally, then the points are in inversion with respect to S. \
The points {p1,p2} are in inversion with respect to S iff moebspp[(S,pp)] = \
0."
}], "Text",
  CellTags->"prop2"],

Cell["\<\
PROOF.  The remark formulated in the paragraph before proposition 2 is \
already proving the statement. Geometrically one may argue  that any circle  \
or sphere intersecting S orthogonally is mapped onto itself under the \
inversion at S, and vice versa, any circle or sphere not contained in S and \
mapped onto itself by the inversion must intersect S orthogonally.  Thus, if \
any circle of the bundle defined by p1,p2 is mapped onto itself, the circles \
through p1,p2 intersect S orthogonally and p1,p2 are in inversion with \
respect to S, and vice versa.   We shall give yet another proof using the \
formula  \
\>", "Text"],

Cell[BoxData[
    \(Clear[r, t, d, u, v, w]; euklidmoebspp[r, t, d, u]\)], "Input",
  CellLabel->"In[35]:="],

Cell[TextData[{
  "Obviously, this invariant vanishes iff  ",
  Cell[BoxData[
      \(d\^2 = r\^2 + t\^2\)]],
  " and u = k*Pi, k integer: We may set r=d*Cos[w], t =d*Sin[w] and obtain"
}], "Text"],

Cell[BoxData[
    \(Simplify[euklidmoebspp[d*Cos[w], d*Sin[w], d, Pi]\ ]\)], "Input",
  CellLabel->"In[36]:="],

Cell["\<\
On the other hand, u = 0, Pi means  that p1, p2, and the center m of S are \
kollinear. For the distances of p1,p2 to the center  m we have:\
\>", "Text"],

Cell[BoxData[
    \(a1\  = \ d\  - d*Sin[w]; \ a2\  = \ d + \ d*Sin[w];\)], "Input",
  CellLabel->"In[37]:="],

Cell["It follows", "Text"],

Cell[BoxData[
    \(Simplify[a1^2*a2^2 \[Equal] \ d^4*Cos[w]^4]\)], "Input",
  CellLabel->"In[38]:="],

Cell[TextData[{
  "This shows that p1,p2 are in inversion with respect to S.  If p1,p2 are in \
inversion with respect to S one has u = 0 or u = Pi; easily one calculates \
with the notations used above   ",
  Cell[BoxData[
      \(d\^2 = r\^2 + t\^2\)]],
  "."
}], "Text"],

Cell["\<\
Remark 1. The geometric arguments and the statements about moebspp are valid \
in any dimension n \[GreaterEqual] 2 of the euclidean space (dim = n+2). \
Thus, proposition 2 remains valid if \"sphere\" is replaced by \
\"hypersphere\".\
\>", "Text"],

Cell["\<\
Remark 2. Since moebspp is always non negativ, proposition 2 leads to the \
attempt of the following interpretation of moebspp:
moebspp(S, (p1,p2)) is a measure of the deviation of p2 from the point in \
inversion to p1 wth respect to the hypersphere S, or symmetrically, of the \
deviation of p1 from the point in inversion to p2 wth respect to the \
hypersphere S.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Example", "Subsubsection"],

Cell["\<\
We shall now construct a finite example for this situation. We consider the \
points S0 = {{0,0,0}, {2,0,0}}. The corresponding 3-dimensional euclidean \
subspace is\
\>", "Text"],

Cell[BoxData[
    \(nspx\  = vspacepp[null[3], \ stb[1, 3]*2]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell["\<\
Therefore, the spacelike unit vectors of all spheres containing S0 have the \
parameter representation as the standard unit sphere of this 3-space: \
\>", "Text"],

Cell[BoxData[
    \(orthospheres[u_, v_] := \ 
      stb[2]*Cos[u]*Cos[v] + stb[3]*Cos[u]*Sin[v]\  + 
        nspx[\([1]\)]*Sin[u]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell["\<\
One speaks about the \"bundle of spheres through S0. Now we shall find the \
spheres which  intersect all spheres of the bundle orthogonally. They \
correspond to the spacelike unit vectors of the orthogonal complement to the \
euclidean subspace spanned by nspx, i.e. the pseudo-euclidean 2-space spanned \
by the isotropic subspaces which represent the points of S0. We define an \
pseudo-orthonormal basis:\
\>", "Text"],

Cell[BoxData[
    \(dnspx = Table[dual[nspx[\([i]\)]], \ {i, 3}]\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(NullSpace[dnspx]\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(orthonorm[%]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ocase\  = \ %\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[
      Simplify[Together[pssp[ocase[\([i]\)], ocase[\([j]\)]]]], {i, 2}, {j, 
        2}]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell["\<\
Obviously, the spacelike unit vectors we asked for form the hyperbola\
\>", "Text"],

Cell[BoxData[
    \(ovec[t_]\  := \ 
      ocase[\([1]\)]*Sinh[t]\  + \ ocase[\([2]\)]*Cosh[t]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell["\<\
The M\[ODoubleDot]bius invariant of any sphere of this family paired with S0 \
is, as expected\
\>", "Text"],

Cell[BoxData[
    \(moebspp[ovec[t], \ null[3], \ stb[1, 3]*2]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell["\<\
Obviously, ovec[t], t \[GreaterEqual] 0, corresponds to all the spheres with \
the property, that all spheres orthospheres[u,v] through {0,0,0}, {2,0,0} \
intersect them orthogonally:\
\>", "Text"],

Cell[BoxData[
    \(pssp[orthospheres[u, v], \ ovec[t]]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell["\<\
We show that the point pair {0,0,0}, {2,0,0} is in inversion with respect to \
any of the spheres ovec[t]. First we calculate center and radius of the \
sphere defined by ovec[t]:\
\>", "Text"],

Cell[BoxData[
    \(vcenter[ovec[t]]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vradius[ovec[t]]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell["\<\
Sperical reflection at a hypersphere with center a and radius r has been \
defined in euvec.m:\
\>", "Text"],

Cell[BoxData[
    \(\(?sphericalreflection\)\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell["\<\
We show that the image of the origin under the inversion at any  of the \
spheres ovec[t] coincides with {2,0,0}:\
\>", "Text"],

Cell[BoxData[
    \(sphericalreflection[
      null[3], {\(Cosh[t] + Sinh[t]\)\/\(\(-Cosh[t]\) + 2\ Sinh[t]\), 0, 
        0}, \ \@3\/\(\(-Cosh[t]\) + 2\ Sinh[t]\)]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell["\<\
This shows the situation described in proposition 2; we construct a picture \
with the dates of our example.\
\>", "Text"],

Cell[BoxData[
    \(pts\  = \ {Point[null[3]], Point[{2, 0, 0}]}\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[Graphics3D[{RGBColor[1, 0, 0], PointSize[0.05], pts}]]\)], "Input",\

  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ex1\  = \ %\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[ovec[0]]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ex2\  = \ %\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{ex1, ex2}]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ex12\  = \ %\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell["In the next cell consider the case aa = 1, too.", "Text"],

Cell[BoxData[
    \(aa\  = \ Random[]; Print[aa]; 
    Table[euklidsphereplot3D[orthospheres[k*Pi/8, \ aa*Pi/2], 0, 1, \(-1\), 
        1], {k, 0, 4}]\)], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[104]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ex3\  = \ %\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{ex1, ex2, ex3}]\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ex123\  = \ %\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times"],

Cell["\<\
Apply MVShow3D with the option MVPointSphereSize -> 0.8, see the last \
section; use Appearance: wire frame.\
\>", "Text"],

Cell[BoxData[
    \(MVShow3D[ex123, \ MVPointSphereSize\  \[Rule] 1.8]\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times"],

Cell["\<\
 The three spheres through the points corresponding to the vectors of nspx \
are the x,y-plane, the x,z-plane and\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[nspx[\([1]\)], \(-1\), 1, \(-1\), 1, 
      PlotPoints\  -> \ 50]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ex4\  = \ %\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times"],

Cell["Two circles through the points are", "Text"],

Cell[BoxData[
    \({plotcircle2spv[nspx[\([1]\)], nspx[\([2]\)]], \ 
      plotcircle2spv[nspx[\([1]\)], nspx[\([3]\)]]}\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ex5\  = \ %\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{ex1, ex2, ex5}]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ex125\  = \ %\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell["\<\
Apply MVShow3D with the options MVPointSphereSize -> 1.4, MVLineTubeSize -> \
0.02, see the last section; use Appearance: wire frame.  \
\>", "Text"],

Cell[BoxData[
    \(MVShow3D[ex125, \ MVPointSphereSize\  \[Rule] 1.4, \ 
      MVLineTubeSize\  \[Rule] \ 0.02]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times"],

Cell["More circles:", "Text"],

Cell[BoxData[
    \(pssp[orthospheres[u, v], orthospheres[u + Pi/2, v]]\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(Table[
      plotcircle2spv[orthospheres[0, k*Pi/10], 
        orthospheres[Pi/2, k*Pi/10]], {k, \(-10\), 10, 
        2}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ex6\  = \ %\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{ex1, ex2, ex6}]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ex126\  = \ %\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[ex126, \ MVPointSphereSize\  \[Rule] 1.4, \ 
      MVLineTubeSize\  \[Rule] \ 0.02]\)], "Input",
  CellLabel->"In[122]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4 Circles and point pairs ", "Section",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell[TextData[{
  "In this section we consider pairs (C, pp) consisting of a Circle C = ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\%1\)]],
  " and a point pair pp = (a1,a2) = ",
  Cell[BoxData[
      \(TraditionalForm\`S\_2\%0\)]],
  " contained in the euclidean 3-space or the 3-sphere. Such a pair is said \
to be in general position, if the union C\[Union]pp is not contained in a \
2-sphere.  Then its mutual position is defined up to M\[ODoubleDot]bius \
equivalence by two invariants, which we are going to calculate. We study the \
relation between the values of these invariants and the geometry of the pair. \
In the last subsection we find formulas expressing the invariants in terms of \
the euclidean invariants of the pairs. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.1 The invariants", "Subsection",
  FontFamily->"Times"],

Cell["\<\
As it has been very detailed described in the notebook mcircles.nb, a circle \
in the 3-sphere or in the euclidean 3-space can be defined by a 2-dimensional \
euclidean subspace of the pseudo-euclidean 5-space. Let p1, p2, p3 be three \
pairwise distinct points in the euclidean 3-space. Their preimages under the \
stereographic projection define uniquely a circle in the 3-sphere containing \
them, and the corresponding isotropic vectors span a pseudo-euclidean \
3-space, the orthogonal complement of which is the euclidean subspace we ask \
for. An orthonormal base of this space is given by vspace[p1,p2,p3], \
\>", "Text"],

Cell[BoxData[
    \(\(?vspace\)\)], "Input",
  CellLabel->"In[43]:="],

Cell["Here is the standard unit circle:", "Text"],

Cell[BoxData[
    \(vspace[{1, 0, 0}, \ {\(-1\), 0, 0}, \ {0, 1, 0}]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell["\<\
plotcircle2spv[v1,v2] plots the circle corresponding to the orthonormal \
vectors v1,v2, in our cse grc1, defined already before:\
\>", "Text",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \(plotcircle2spv[%]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(Show[grc1]\)], "Input",
  CellLabel->"In[49]:="],

Cell["\<\
Let b ={b1,b2,b3} be an orthonormal basis corresponding to the point pair \
pp=(a1,a2), e.g.\
\>", "Text"],

Cell[BoxData[
    \(blist\  = \ vspacepp[{0, \(-1\), 0}, {1, 1, 0}/Sqrt[2]]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell["\<\
Then the condition that the circle containes both points is indicator[n1,b] = \
indicator[n2,b] = null[],what is trivial in our special case:\
\>", "Text"],

Cell[BoxData[
    \(\(?indicator\)\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(indicator[stb[3], {0, \(-1\), 0}, {1, 1, 0}/Sqrt[2]]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(indicator[stb[4], {0, \(-1\), 0}, {1, 1, 0}/Sqrt[2]]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell["\<\
The condition that at least one of the points a1,a2 belongs to the circle \
through the 3 points p1,p2,p3 implies that all the five points belong to a \
sphere; i. e. the points are not in general position\
\>", "Text"],

Cell[BoxData[
    \(incid[a1_, a2_, b1_, b2_, b3_]\  := \ 
      Det[{invstepro[a1], invstepro[a2], invstepro[b1], invstepro[b2], 
          invstepro[b3]}]\)], "Input",
  CellLabel->"In[19]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["vanishes, e.g.", "Text"],

Cell[BoxData[
    \(incid[{0, 3, 0}, {1, 1, 0}/Sqrt[2], {1, 0, 0}, \ {\(-1\), 0, 0}, \ {0, 
        1, 0}]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[a, b]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell["\<\
Let a = {a[[1]], a[[2]]} be an orthonormal basis of the euclidean 2-space \
defining the circle C, and b = {b[[1]], b[[2]], b[[3]]}  an orthonormal basis \
of the euclidean 3-space defining the point pair {p0, p1}.\
\>", "Text"],

Cell[TextData[{
  "The matrix of the double projection whose eigenvalues are the M\
\[ODoubleDot]bius invariants of the pair (see ",
  ButtonBox["[6]",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  ") is"
}], "Text"],

Cell[BoxData[
    \(ppcpp[a_List, b_List]\  := 
      Table[Simplify[
          Sum[pssp[b[\([k]\)], a[\([i]\)]]*pssp[b[\([k]\)], a[\([j]\)]], {k, 
              3}]], {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[20]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(p2p3\  = ppcpp[{a1, a2}, {b1, b2, b3}]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(p2p3[\([1, 1]\)]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(p2p3[\([1, 2]\)]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(p2p3[\([2, 2]\)]\)], "Input",
  CellLabel->"In[59]:="],

Cell[TextData[{
  "Its eigenvalues are the  generalized cosinus squares of the stationary \
angles, and the spheres corresponding to the  eigenvectors we call ",
  StyleBox["eigenspheres",
    FontColor->RGBColor[1, 0, 0]],
  ".  Instead of the eigenvalues one can take the determinant and the trace \
of the matrix ppcpp forming a complete system of M\[ODoubleDot]bius \
invariants for pairs (C, pp) in general position, too. "
}], "Text"],

Cell[BoxData[
    \(Simplify[Det[p2p3]]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(Tr[p2p3]\)], "Input",
  CellLabel->"In[61]:="],

Cell[BoxData[
    \(Remove[p2p3]\)], "Input",
  CellLabel->"In[42]:="],

Cell["\<\
The function ppcpp may be composed with other functions delivering the \
orthonormal bases appearing as its arguments, e.g.\
\>", "Text"],

Cell[BoxData[
    \(\(?vspace\)\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[{
    \(\(Clear[a1, a2, b1, b2, b3];\)\), "\[IndentingNewLine]", 
    \(\(ppcpp3pts2pts[a3_List]\)[b2_List]\  := \ 
      ppcpp[vspace[a3], vspacepp[b2]]\)}], "Input",
  CellLabel->"In[21]:=",
  InitializationCell->True],

Cell["\<\
If the circle is given by its euclidean parameters, one may find the \
invariant by the function\
\>", "Text"],

Cell[BoxData[
    \(\(ppcppcircle2pts[x_, y_, z_, u_, v_, r_]\)[p_List]\  := \ 
      ppcpp[circlespacevectors[x, y, z, u, v, r], \ vspacepp[p]]\)], "Input",
  CellLabel->"In[23]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(ppcppcircle2pts[0, 0, 0, u, Pi/3, 
        r]\)[{{0, 0, \(-1\)}, {1, 0, 1}}]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(Simplify[Det[%]]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(Simplify[Tr[%%]]\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \(\(ppcppcircle2pts[x, y, z, u, v, 
        r]\)[{{0, 0, \(-1\)}, {1, 0, 1}}]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(FullSimplify[%, {x, y, z, u, v} \[Element] Reals && r > 0]\)], "Input",
  CellLabel->"In[47]:="],

Cell["\<\
The result of the simplification is the following not very appealing \
expression:\
\>", "Text"],

Cell[BoxData[
    \(ppcircle2ptsfct[x_, y_, z_, u_, v_, 
        r_] := {{1\/25\ \((25\ Cos[v]\^2\ Sin[u]\^2 + \((Cos[v]\ \((\((\(-5\) \
+ 2\ x)\)\ Cos[u] + 2\ y\ Sin[u])\) + 2\ \((1 + z)\)\ Sin[v])\)\^2 + \((4\ \
Cos[v]\ \((x\ Cos[u] + y\ Sin[u])\) + \((\(-1\) + 4\ z)\)\ Sin[v])\)\^2)\), \
\(\(1\/\(5\ r\)\)\((\(-\((\((\(-1\) + 2\ x)\)\ \((\(-1\) + r\^2 + x - x\^2 - 
                            y\^2)\) + 2\ z + \((1 - 2\ x)\)\ z\^2)\)\)\ Cos[
                  u]\ Cos[v] + 
              y\ \((3 - 2\ r\^2 + 2\ \((\(-1\) + x)\)\ x + 2\ y\^2 + 
                    2\ z\^2)\)\ Cos[v]\ Sin[
                  u] + \((1 - 
                    2\ x + \((\(-1\) - 2\ r\^2 + 2\ \((\(-1\) + x)\)\ x + 
                          2\ y\^2)\)\ z + 2\ z\^3)\)\ Sin[
                  v])\)\)}, {\(\(1\/\(5\ r\)\)\((\(-\((\((\(-1\) + 
                            2\ x)\)\ \((\(-1\) + r\^2 + x - x\^2 - y\^2)\) + 
                      2\ z + \((1 - 2\ x)\)\ z\^2)\)\)\ Cos[u]\ Cos[v] + 
              y\ \((3 - 2\ r\^2 + 2\ \((\(-1\) + x)\)\ x + 2\ y\^2 + 
                    2\ z\^2)\)\ Cos[v]\ Sin[
                  u] + \((1 - 
                    2\ x + \((\(-1\) - 2\ r\^2 + 2\ \((\(-1\) + x)\)\ x + 
                          2\ y\^2)\)\ z + 2\ z\^3)\)\ Sin[
                  v])\)\), \(\(1\/\(5\ r\^2\)\)\((r\^4 - 
              2\ r\^2\ \((\(-1\) + \((\(-1\) + x)\)\ x + y\^2 + 
                    z\^2)\) + \((2 + \((\(-2\) + x)\)\ x + 
                    y\^2 + \((\(-2\) + z)\)\ z)\)\ \((x\^2 + 
                    y\^2 + \((1 + z)\)\^2)\))\)\)}}\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(Simplify[
      Det[ppcircle2ptsfct[x, y, z, u, v, r]], {x, y, z, u, v} \[Element] 
          Reals && r > 0]\)], "Input",
  CellLabel->"In[49]:="],

Cell["\<\
The result is clumsy, and not appropriate for geometrical conclusions. Of \
course, by the help of the defined modules one may calculate the M\
\[ODoubleDot]bius invariants for an explicitely given pair (C, pp) \
numerically.  It remains the task to express the M\[ODoubleDot]bius \
invariants of such a pair by geometrical parameters of such a configuration. \
This will be done in the last subsection 4.5 below.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["4.2 Examples", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Pairs not in general position", "Subsubsection"],

Cell["Here only one point lies on the circle:", "Text"],

Cell[BoxData[
    \(\(ppcpp3pts2pts[{{1, 0, 0}, \ {\(-1\), 0, 0}, \ {0, 1, 0}}]\)[{{0, 3, 
          0}, {1, 1, 0}/Sqrt[2]}]\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell["Here both points belong to the circle", "Text"],

Cell[BoxData[
    \(\(ppcpp3pts2pts[{{1, 0, 0}, \ {\(-1\), 0, 0}, \ {0, 1, 0}}]\)[{{0, 1, 
          0}, {1, 1, 0}/Sqrt[2]}]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell["The invariants are the same! But the following ranks differ", "Text"],

Cell[BoxData[
    \(\(\(rank[{invstepro[{1, 0, 0}], invstepro[{\(-1\), 0, 0}], 
        invstepro[{0, 1, 0}], invstepro[{0, 3, 0}], 
        invstepro[{1, 1, 0}/Sqrt[2]]}]\)\(\n\)
    \)\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(rank[{invstepro[{1, 0, 0}], invstepro[{\(-1\), 0, 0}], 
        invstepro[{0, 1, 0}], invstepro[{0, 1, 0}], 
        invstepro[{1, 1, 0}/Sqrt[2]]}]\)\(\n\)
    \)\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell["\<\
In both cases the pairs are not in general position. This examples shows that \
the eigenvalues of ppcpp do not suffice to distinguish the two cases; in \
addition the dimension rank -2 of the smallest sphere containing the pair \
must be considered.  We remark that in case of general position the \
eigenvalue 1 may have multiplicity 1 at most; thus an example of a pair \
(C,pp) in general position with twofold eigenvalues one may not exist.\
\>", "Text"],

Cell[TextData[{
  "In the following example the pair belongs to the plane  ( = sphere) z = 0, \
we again do not have general position; one has  the varying invariant ",
  Cell[BoxData[
      \(1\/Abs[x]\^2\)]],
  ", and the constant 1: "
}], "Text"],

Cell[BoxData[
    \(fctppcpp[x_] := \n
      ppcpp[vspace[{1, 0, 0}, \ {\(-1\), 0, 0}, \ {0, 1, 0}], 
        vspacepp[{0, 0, 0}, {x, 0, 0}]]\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctppcpp[x]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(rank[{invstepro[{1, 0, 0}], invstepro[{\(-1\), 0, 0}], 
        invstepro[{0, 1, 0}], invstepro[{0, 0, 0}], 
        invstepro[{x, 0, 0}]}]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(Abs[x]\^2\)]],
  " < 1 the circle in this sphere does not separate the points, for ",
  Cell[BoxData[
      \(Abs[x]\^2\)]],
  ">1 it does, and for ",
  Cell[BoxData[
      \(Abs[x]\^2\)]],
  "=1 the point belongs to the circle; separate has a meaning, of course , \
only within the sphere z=0. The situation here is the same as in subsection \
3.2, only one dimension less. The singularity  for x = 0 corresponds to the \
fact taht in this case the 0-sphere degenerates into a single point. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[" Pairs in general position", "Subsubsection"],

Cell["Here is an example of a pair in general position", "Text"],

Cell[BoxData[
    \(\(\(rank[{invstepro[{1, 0, 0}], invstepro[{\(-1\), 0, 0}], 
        invstepro[{0, 1, 0}], invstepro[{0, 3, 0}], 
        invstepro[{2, 1, 1}]}]\)\(\n\)
    \)\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(ppcpp3pts2pts[{{1, 0, 0}, \ {\(-1\), 0, 0}, \ {0, 1, 0}}]\)[{{0, 3, 
          0}, {2, 1, 1}}]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Det[%]\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    \(Tr[%%]\)], "Input",
  CellLabel->"In[69]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["The circle may be a line", "Subsubsection"],

Cell[BoxData[
    \(vspace[{{0, 0, 0}, {1, 1, 1}, {2, 2, 2}}]\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    \(\(ppcpp3pts2pts[{{0, 0, 0}, {1, 1, 1}, {2, 2, 2}}]\)[{{1, 0, 
          0}, \ {\(-1\), 0, 0}}]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(Det[\(ppcpp3pts2pts[{{0, 0, 0}, {1, 1, 1}, {2, 2, 2}}]\)[{{1, 0, 
            0}, \ {\(-1\), 0, 0}}]]\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(Tr[\(ppcpp3pts2pts[{{0, 0, 0}, {1, 1, 1}, {2, 2, 2}}]\)[{{1, 0, 
            0}, \ {\(-1\), 0, 0}}]]\)], "Input",
  CellLabel->"In[73]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["One eigenvalue 0", "Subsubsection"],

Cell[BoxData[
    \(\(\(rank[{invstepro[{1, 0, 0}], invstepro[{\(-1\), 0, 0}], 
        invstepro[{0, 1, 0}], invstepro[{0, 0, 0}], 
        invstepro[{0, 0, z}]}]\)\(\n\)
    \)\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctgenppcpp[
        z_] := \ \(ppcpp3pts2pts[{{1, 0, 0}, \ {\(-1\), 0, 0}, \ {0, 1, 
              0}}]\)[{{0, 0, 0}, {0, 0, z}}]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fctgenppcpp[z]\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ppz\  = \ %\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Det[ppz]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Tr[ppz]\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(Simplify[%, \ z > 0]\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    \(Eigenvalues[ppz]\)], "Input",
  CellLabel->"In[81]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvectors[ppz]\)], "Input",
  CellLabel->"In[82]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "The geometric interpretation is the following: There exists a sphere, \
containing the unit circle and being \"orthogonal to the 0-sphere\" (what \
means that?: see 3.2, ",
  ButtonBox["Orthogonality",
    ButtonData:>"prop2",
    ButtonStyle->"Hyperlink"],
  "); the other eigenvalue is the maximum of the M\[ODoubleDot]bius invariant \
of two spheres, one  containing the circle, the other the point pair, and \
these spheres are disjoint, since the invariant is > 1. Since the double \
projection is an endomorpism of the space spanned by"
}], "Text"],

Cell[BoxData[
    \(vspace[{1, 0, 0}, \ {\(-1\), 0, 0}, \ {0, 1, 0}]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times"],

Cell["we have the eigensphere to the eigenvalue 0", "Text"],

Cell[BoxData[
    \(ppz . {z, 1}\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ev1[z_]\  := \ \(-\((stb[3]\  + \ stb[4]*z)\)\)/
        Sqrt[1 + z^2]\)], "Input",
  CellLabel->"In[87]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vcenter[ev1[z]]\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vradius[ev1[z]]\)], "Input",
  CellLabel->"In[89]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ z > 0]\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times"],

Cell["The Point pair corresponding to z = 1 is", "Text"],

Cell[BoxData[
    \(pts\  = \ {Point[null[3]], Point[{0, 0, 1}]}\)], "Input",
  CellLabel->"In[24]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[Graphics3D[{RGBColor[1, 0, 0], PointSize[0.05], pts}]]\)], "Input",\

  CellLabel->"In[25]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(grpts\  = \ %\)], "Input",
  CellLabel->"In[26]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[ev1[1]]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gev1\  = \ %\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times"],

Cell["We calculate the projection of ev1[z] into ", "Text"],

Cell[BoxData[
    \(vspacepp[{0, 0, 0}, {0, 0, z}]\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vpp[
        z_]\  := \ {{0, 0, z\/Abs[z], \(-\(1\/Abs[z]\)\), 1\/Abs[z]}, {0, 1, 
          0, 0, 0}, {1, 0, 0, 0, 0}}\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[pssp[\(vpp[z]\)[\([i]\)], \ ev1[z]], \ {i, 3}]\)], "Input",
  CellLabel->"In[98]:=",
  FontFamily->"Times"],

Cell["\<\
Therefore, the projection is null[5], and the eigensphere gev1 intersects any \
sphere containing the point pair orthogonally. We return to the example \
z=1:\
\>", "Text"],

Cell[BoxData[
    \(fam1[t_] := \ \(vpp[1]\)[\([1]\)]*Cos[t]\  + \ stb[1]*Sin[t]\)], "Input",\

  CellLabel->"In[99]:="],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[fam1[k*Pi/5]*Sign[5 - 2*k], 0], {k, 1, 
        5}]\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(grfam1 = %\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(Show[{grfam1, gev1}]\)], "Input",
  CellLabel->"In[103]:="],

Cell["Joining the point pair and the circle we consider", "Text"],

Cell[BoxData[
    \(Show[{grfam1, gev1, grpts, grc1}]\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(pictfam1\  = \ %\)], "Input",
  CellLabel->"In[108]:="],

Cell[TextData[{
  "Use MathGL3d  (",
  ButtonBox["see last section",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"],
  ")  with the option MVPointSphereSize -> 0.8,MVLineTubeSize -> 0.03 using \
MathGl3d applying  wire frame"
}], "Text"],

Cell[BoxData[
    \(MVShow3D[pictfam1, MVPointSphereSize \[Rule] 0.8, \ 
      MVLineTubeSize\  -> \ 0.01]\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times"],

Cell["The other eigensphere is given by", "Text"],

Cell[BoxData[
    \(Simplify[Together[ppz . {\(-1\)/z, 1}]]\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(stb[4]*\((\(-\(1\/\(z\ Abs[z]\^2\)\)\) - z\/Abs[z]\^2)\) + \ 
      stb[3]*\((1\/Abs[z]\^2 + z\^2\/Abs[z]\^2)\)\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ev2[z_]\  := \ \((stb[3]\  - stb[4]/z)\)/Sqrt[1\  + \ 1/z^2]\)], "Input",\

  CellLabel->"In[113]:=",
  FontFamily->"Times"],

Cell["\<\
The projection of this eigenvector in vspacepp[{0,0,0},{0,0,z}] is\
\>", "Text"],

Cell[BoxData[
    \(prev2[z_]\  := \ 
      Sum[pssp[\(vpp[z]\)[\([i]\)], \ ev2[z]]*\(vpp[z]\)[\([i]\)], \ {i, 
          3}]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(prev2[z]\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ z > 0]\)], "Input",
  CellLabel->"In[116]:=",
  FontFamily->"Times"],

Cell["For z > 0 this coincides with", "Text"],

Cell[BoxData[
    \(prev2pos[
        z_] := \ {0, 0, Sqrt[1 + z^2]/z, \(-Sqrt[1 + z^2]\)/z^2, 
          Sqrt[1 + z^2]/z^2} /; z > 0\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times"],

Cell["and for z < 0 we obtain", "Text"],

Cell[BoxData[
    \(Simplify[prev2[z], \ z < 0]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(prev2pos[
        z_] := \ {0, 0, \(-Sqrt[1 + z^2]\)/z, 
          Sqrt[1 + z^2]/z^2, \(-Sqrt[1 + z^2]\)/z^2} /; z < 0\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(prev2pos[1]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(prev2pos[\(-1\)]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times"],

Cell["For  z = 1 we have the eigensphere", "Text"],

Cell[BoxData[
    \(ev2[1]\)], "Input",
  CellLabel->"In[122]:="],

Cell[BoxData[
    \(euklidsphereplot3D[ev2[1]]\)], "Input",
  CellLabel->"In[123]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gev2\  = \ %\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times"],

Cell["\<\
The normalized projection of ev2[1]  in vspacepp[{0,0,0},{0,0,z}] and the \
corresponding sphere are\
\>", "Text"],

Cell[BoxData[
    \(projev2\  = \ normalize[prev2[1]]\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(euklidsphereplot3D[projev2]\)], "Input",
  CellLabel->"In[126]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gev3\  = \ %\)], "Input",
  CellLabel->"In[127]:=",
  FontFamily->"Times"],

Cell["The generalized cosinus is the square root of the eigenvalue", "Text"],

Cell[BoxData[
    \(pssp[projev2, \ ev2[1]]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times"],

Cell["\<\
This is the maximal value of the generalized cosinus for any pair of spheres, \
one containing the standard unit circle and the other containing the point \
pair {null[3], {0,0,1}.\
\>", "Text"],

Cell[BoxData[
    \(Show[{grc1, gev2, gev3, grpts}]\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(grevmax\  = \ %\)], "Input",
  CellLabel->"In[130]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "With the option MVPointSphereSize -> 0.8,MVLineTubeSize -> 0.03 using \
MathGl3d with wire frame (",
  ButtonBox["see last section",
    ButtonData:>"MathGL",
    ButtonStyle->"Hyperlink"],
  ") one gets a nice visualization of the situation . "
}], "Text"],

Cell[BoxData[
    \(MVShow3D[grevmax\[IndentingNewLine], MVPointSphereSize \[Rule] 0.8, \ 
      MVLineTubeSize\  -> \ 0.01]\)], "Input",
  CellLabel->"In[131]:=",
  FontFamily->"Times"],

Cell["\<\
Joining the \"minimal\" eigensphere gev1 one obtains the complete picture\
\>", "Text"],

Cell[BoxData[
    \(Show[{gev1, grevmax}]\)], "Input",
  CellLabel->"In[132]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(grevmaxmin\  = \ %\)], "Input",
  CellLabel->"In[133]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[grevmaxmin\[IndentingNewLine], 
      MVPointSphereSize \[Rule] 0.8, \ MVLineTubeSize\  -> \ 0.01]\)], "Input",\

  CellLabel->"In[134]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Remove[ppz, pts, projev2, prev2pos, prev2, ev1, ev2, prev1, vpp, 
      fctgenppcpp, fctppcpp, fam1]\)], "Input",
  CellLabel->"In[135]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Standard unit circle and random point pairs", "Subsubsection"],

Cell[BoxData[
    \(a1\  = \ {0, 0, Random[]}; a2\  = \ \(-{0, Random[], Random[]}\); 
    Print["\<a1 = \>", \ a1, \ "\<, a2 = \>", \ a2]; \ 
    mpp = \(ppcpp3pts2pts[{{1, 0, 0}, \ {\(-1\), 0, 0}, \ {0, 1, 0}}]\)[{a1, 
          a2}]; Print["\<mpp = \>", mpp // MatrixForm]; 
    Eigenvalues[mpp]\)], "Input",
  CellLabel->"In[136]:="],

Cell[BoxData[
    \(a1\  = \ 10*randomv[3]; a2\  = \(-3\)*randomv[3]; 
    Print["\<a1 = \>", \ a1, \ "\<, a2 = \>", \ a2]; \ 
    mpp = \(ppcpp3pts2pts[{{1, 0, 1}, \ {1, 0, \(-1\)}, \ {1, 1, 0}}]\)[{a1, 
          a2}]; Print["\<mpp = \>", mpp // MatrixForm]; 
    Eigenvalues[mpp]\)], "Input",
  CellLabel->"In[137]:="],

Cell[BoxData[
    \(\(\(rank[{invstepro[{1, 0, 1}], invstepro[{1, 0, \(-1\)}], 
        invstepro[{1, 1, 0}], invstepro[a1], invstepro[a2]}]\)\(\n\)
    \)\)], "Input",
  CellLabel->"In[138]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.3 The separation property", "Subsection",
  FontFamily->"Times"],

Cell["\<\
In all the examples in subsection 4.2 we have at least one eigenvalue greater \
or equal 1. Indeed, one can show\
\>", "Text"],

Cell[TextData[{
  StyleBox["PROPOSITION 3",
    FontColor->RGBColor[0, 0, 1]],
  ". For any point pair pp = (a1,a2) and any circle C of the euclidean \
3-space or the 3-sphere being in general position there exist spheres S0, S1 \
separating pp and C. i.e. pp \[Subset]  S0, C \[Subset]  S1, and S0 \
\[Intersection] S1 = \[EmptySet]."
}], "Text",
  CellTags->"sepprop"],

Cell["\<\
Proof. For the dimensions of the pseudo-euclidean subspaces defining pp and \
C, respectively, we have \
\>", "Text"],

Cell["dim W0 = 2, dim W1 = 3.", "Text",
  TextAlignment->Center],

Cell["Their euclidean orthogonal complements have the dimensions", "Text"],

Cell["dim U0 = 3, dim U1 = 2.", "Text",
  TextAlignment->Center],

Cell["\<\
By our assumption, pp and C are in generaal position: there does not exist a \
sphere containing both. This is equivalent to\
\>", "Text"],

Cell["\<\
dim U0 \[Intersection] U1 = 0, or dim U0 + U1 = 5.\
\>", "Text",
  TextAlignment->Center],

Cell["\<\
Therefore the (direct) sum U0 + U1 is the whole pseudo-euclidean vector \
space; let v be a timelike vector and v = u0 +u1 its representation according \
to the decomposition V = U0 + U1. Then neither u0 nor u1, being spacelike \
vectors, may vanish. The subspace span(u0,u1) is pseudo-euclidean, and the \
spheres S0 = S(u0), S1 = S(u1) corresponding to these vectors  have the \
stated separation property. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "4.4 Two associated spheres belonging to a pair (",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\%1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\_2\%0\)]],
  ")"
}], "Subsection",
  FontFamily->"Times"],

Cell[TextData[{
  "Each pair (C, (p0, p1)) of a circle C and a 0-sphere (p0, p1) defines, in \
general,  two spheres, containing (C, p0) and (C, p1), respectively.  We call \
them the ",
  StyleBox["associated spheres",
    FontColor->RGBColor[1, 0, 0]],
  " of the pairing. If one of the points belong to the circle the \
corresponding sphere remains indetermined. Let us consider the general case, \
that none of the two points is contained in the circle. If (cn1, cn2) is a \
basis of the euclidean subspace defining the circle C, then the spacelike \
vector defining the sphere through C and a point p is given by the cross \
product as follows:"
}], "Text"],

Cell[BoxData[
    \(\(?pscomplement\)\)], "Input",
  CellLabel->"In[153]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Context[pscomplement]\)], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \(\(?normalize\)\)], "Input",
  CellLabel->"In[178]:="],

Cell[BoxData[
    \(\(\(circlepointsphere[cn1_, cn2_, 
        p_]\)\(:=\)\(Module[{vc}, \[IndentingNewLine]vc\  = 
          pscomplement[cn1, cn2]; \[IndentingNewLine]vc\  = \ 
          AppendTo[vc, invstepro[p]]; \[IndentingNewLine]Return[
          normalize[pscross[vc]]]]\)\(\ \)\)\)], "Input",
  CellLabel->"In[26]:=",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
Obviously, circlepointsphere yields the null vector null[5] iff p\[Element] \
C,  e.g.\
\>", "Text"],

Cell[BoxData[
    \(circlepointsphere[stb[3], \ stb[4], \ {0, 1, 0}]\)], "Input",
  CellLabel->"In[38]:=",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?circlepointsphere\)\)], "Input",
  CellLabel->"In[39]:="],

Cell["\<\
In an  example of section 4.2 we had cn1 = Stb[4], cn2 = stb[3], p1 = \
null[3], p2= {0,0,z}. We find\
\>", "Text",
  FontVariations->{"CompatibilityType"->0}],

Cell[BoxData[
    \(vn1\  = \ circlepointsphere[stb[4], stb[3], \ null[3]]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell["Clearly, this is the x,y-plane:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[3]]\)], "Input",
  CellLabel->"In[37]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(grvn1\  = \ %\)], "Input",
  CellLabel->"In[38]:=",
  FontFamily->"Times"],

Cell["The other sphere is", "Text"],

Cell[BoxData[
    \(vn2[z_]\  := \ circlepointsphere[stb[4], stb[3], {0, 0, z}]\)], "Input",\

  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vn2[z]\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[42]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vradius[vn2[z]]\)], "Input",
  CellLabel->"In[43]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[44]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vcenter[vn2[z]]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell["Specializing to the case z=1 :", "Text"],

Cell[BoxData[
    \(vn2[1]\)], "Input",
  CellLabel->"In[47]:=",
  FontFamily->"Times"],

Cell["This is the standard unit sphere:", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[stb[4]]\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(grvn2\  = \ %\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grvn1, grvn2, grpts}]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "Here the spheres intersect orthogonally. We remark that zero is the \
smaller eigenvalue of our pair {C, ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  "}. For the cosinus of the intersection angle for variable z we obtain \
(Remember: vn2[z] is a spacelike unit vector for all values of z):"
}], "Text"],

Cell[BoxData[
    \(pssp[vn1, vn2[z]]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Together[%]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Remove[vn1, vn2]\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[x, y, z]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell["\<\
We consider the pair consisting of the standard unit circle C:\
\>", "Text"],

Cell[BoxData[
    \(Show[grc1]\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[" and the point pair {null[3], {x,y,z}}.", "Text"],

Cell[BoxData[
    \(vpp[x_, y_, z_]\  := vspacepp[{0, 0, 0}, {x, y, z}]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vpp[x, y, z]\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ 
      x \[Element] \ Reals && y \[Element] \ Reals && 
        z \[Element] \ Reals]\)], "Input",
  CellLabel->"In[43]:=",
  FontFamily->"Times"],

Cell["Simplifying by hand gives for x > 0:", "Text"],

Cell[BoxData[
    \(vpp[x_, y_, 
        z_]\  := \ {{1, 0, 0, \(-\(x\/\(x\^2 + y\^2 + z\^2\)\)\), 
          x\/\(x\^2 + y\^2 + z\^2\)}, {0, 0, 
          1, \(-\(z\/\(x\^2 + y\^2 + z\^2\)\)\), 
          z\/\(x\^2 + y\^2 + z\^2\)}, {0, 1, 
          0, \(-\(y\/\(x\^2 + y\^2 + z\^2\)\)\), 
          y\/\(x\^2 + y\^2 + z\^2\)}}\)], "Input",
  CellLabel->"In[27]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(vpp[x, y, z]\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], \ %[\([j]\)]], {i, 3}, \ {j, 3}]\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell["\<\
The matrix defining the invariants of {C, {null[3], {x,y,z}} is\
\>", "Text"],

Cell[BoxData[
    \(pcfct[x_, y_, z_]\  := ppcpp[{stb[3], stb[4]}, vpp[x, y, z]]\)], "Input",\

  CellLabel->"In[28]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(pcfct[x, y, z]\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvalues[%]\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ {x, y, z} \[Element] \ Reals]\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Factor[
      x\^4 + y\^4 + 2\ y\^2\ \((\(-1\) + z\^2)\) + \((1 + z\^2)\)\^2 + 
        2\ x\^2\ \((\(-1\) + y\^2 + z\^2)\)]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(F[x_, y_, z_]\  = \ %;\)\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[F[x, y, z]\  - \ \((1 - x^2 - y^2 - z^2)\)^2]\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell[BoxData[{
    \(Since\), "\[IndentingNewLine]", 
    \(\ d\^2 = x\^2 + y\^2 + z\^2\), "\[IndentingNewLine]", 
    \(\ is\ the\ square\ of\ the\ distance\ of\ the\ two\ points\ we\ may\ \
write\ down\ the\ eigenvalues\ in\ the\ form\)}], "Text",
  FontFamily->"Times"],

Cell[BoxData[
    \(ev1[d_, 
        z_] := \ \((1\  + \ d^2\  - \ 
            Sqrt[\((1 - d^2)\)^2\  + \ 4*z^2])\)/\((2*d^2)\)\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ev2[d_, 
        z_] := \ \((1\  + \ d^2\  + \ 
            Sqrt[\((1 - d^2)\)^2\  + \ 4*z^2])\)/\((2*d^2)\)\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell["\<\
For the intersection angle of the two spheres {C, null[3]}, {C,{x,y,z}} we \
calculate the cosinus\
\>", "Text"],

Cell[BoxData[
    \(cosfct[x_, y_, z_] := 
      pssp[circlepointsphere[stb[3], \ stb[4], \ null[3]], 
        circlepointsphere[stb[3], \ stb[4], \ {x, y, z}]]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cosfct[x, y, z]\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(Simplify[%, {x, y, z} \[Element] \ Reals]\)\(\ \)\)\)], "Input",
  CellLabel->"In[58]:="],

Cell["Thus we better define", "Text"],

Cell["\<\
cosfct[x_, y_, z_] := (1 - x^2 - y^2 - z^2)/
   Sqrt[4*z^2 + (-1 + x^2 + y^2 + z^2)^2]\
\>", "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(cosfct[x, y, z]\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "This function gives correct values  for pairs not  in general position, \
too. If the pair is not in general position the associated spheres coincide \
and the intersection angle is a multiple of Pi, see the special cases ",
  ButtonBox["below",
    ButtonData:>"deg",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell["\<\
We want to epress this cosinus by the eigenvalues. For this purpose we \
calculate the trace and the determinant \
\>", "Text"],

Cell[BoxData[
    \(Simplify[ev1[d, z] + ev2[d, z]]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[ev1[d, z]*ev2[d, z]]\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell["The wanted expression is given by the solution of", "Text"],

Cell[BoxData[
    \(\(\(Solve[{e1\  + \ e2\  \[Equal] \ 1 + 1\/d\^2, 
        e1*e2\  \[Equal] \(d\^2 - z\^2\)\/d\^4}, {d, z}]\)\(\ \)\)\)], "Input",\

  CellLabel->"In[63]:="],

Cell[TextData[{
  "Only the squares ",
  Cell[BoxData[
      \(d\^2, z\^2\)]],
  " enter in cosfct; thus all four solutions give the same result. "
}], "Text"],

Cell[BoxData[
    \(Simplify[
      Together[1 - e2 - e2\/\(\(-1\) + e1 + e2\) + 
          e2\^2\/\(\(-1\) + e1 + e2\)]]\)], "Input",
  CellLabel->"In[64]:="],

Cell["We remember", "Text"],

Cell[BoxData[
    \(cosfct[x, y, z]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "Inserting ",
  Cell[BoxData[
      \(x\^2 + y\^2 + z\^2\)]],
  " = ",
  Cell[BoxData[
      \(d\^2\)]],
  " we consider"
}], "Text"],

Cell[BoxData[
    \(fct[d_, 
        z_] := \((1 - d^2)\)/\((Sqrt[4*z^2\  + \((1 - d^2)\)^2])\)\)], "Input",\

  CellLabel->"In[66]:="],

Cell["and simplify", "Text"],

Cell[BoxData[
    \(\(\(fct[d, 
        z]\)\(/.\)\({z^2\  \[Rule] \((e1 + e2 - e1*e2 - 
                1)\)/\((e1 + e2 - 1)\)^2, \ 
        d^2\  \[Rule] \ 1/\((e1 + e2 - 1)\)}\)\(\ \)\)\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(FullSimplify[%, \ e1\  + \ e2\  > \ 1]\)], "Input",
  CellLabel->"In[68]:="],

Cell["\<\
Therefore the  cosinus of the  intersection angle \[Alpha] of the associated \
spheres is\
\>", "Text"],

Cell[BoxData[
    \(Cos[\[Alpha]]\  = \ \(\(1 - d\^2\)\/\@\(\((1 - d\^2)\)\^2 + 4\ z\^2\)\  \
= \ \(e1 + e2\  - \ 2\)\/Abs[e1 - e2]\)\)], "Input",
  Evaluatable->False],

Cell[TextData[{
  "This is the expression we asked for. By a M\[ODoubleDot]bius transform any \
pairing of a circle and a point pair not contained in the circle can be \
brought in the position that the circle coincides with the standard unit \
circle C and one of the points coincides with the center null[3] of C.  Since \
under a M\[ODoubleDot]bius transform the eigenvalues and the intersection \
angle between the associated spheres remain invariant, we proved:\n",
  StyleBox["PROPOSITION 4",
    FontColor->RGBColor[0, 0, 1]],
  ". Let ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  " be an arbitrary circle (or a line) and ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  " = {p0, p1} a point pair disjoint to ",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  ". Then the cosinus of the intersection angle \[Alpha] of the associated \
spheres is expressed by the eigenvalues e1,e2 of the pairing {",
  Cell[BoxData[
      \(TraditionalForm\`S\^1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  "} by the formula"
}], "Text"],

Cell[BoxData[
    \(Cos[\[Alpha]]\  = \ \(e1 + e2\  - \ 2\)\/Abs[e1 - e2]\)], "Input",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["Degenerate case:", "Text",
  CellTags->"deg"],

Cell["\<\
If one of the points belong to the circle, the formula yields 0; moreover, \
the same is true for all points on the standard unit sphere  (d = 1):\
\>", "Text"],

Cell[BoxData[
    \(Off[Set::write]\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[cosfct[Cos[t], \ Sin[t], 0]]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[cosfct[Cos[t]*Cos[s], \ Sin[t]*Cos[s], Sin[s]]]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`S\^0\)]],
  " degenerates to a  single, \"double counting\" point, both spheres \
coincide; thus we obtain \[Alpha] = 0:"
}], "Text"],

Cell[BoxData[
    \(Simplify[cosfct[0, 0, 0]]\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell["For points belonging to the x,y-plane we get", "Text"],

Cell[BoxData[
    \(Simplify[cosfct[x, y, 0], \ {x, y} \[Element] \ Reals]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell["\<\
 This equals  \[PlusMinus]1, as expected, since both \"spheres\" coincide \
with the x,y plane; the pair (C,pp) is not in general position. \
\>", "Text"],

Cell[BoxData[
    \(Plot[\ cosfct[0, 0, z], \ {z, \ 0, \ 10}]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[\ ArcCos[cosfct[0, 0, z]]*180/Pi, \ {z, \ 0, \ 10}]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ArcCos[cosfct[0, 0, 1]]*180/Pi\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[\ cosfct[z, z, z], \ {z, \ \(-2\), \ 2}]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell["Clearly, one has", "Text"],

Cell[BoxData[
    \(cosfct[x, y, z] - cosfct[\(-x\), \(-y\), \(-z\)]\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(Plot[\ ArcCos[cosfct[z, z, z]], \ {z, 0, \ 2}]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(cosfct[z, z, z]\)], "Input",
  CellLabel->"In[80]:="],

Cell["\<\
The associated spheres intersect orthogonally iff (x,y,z) is a point of the \
standard unit sphere:\
\>", "Text"],

Cell[BoxData[
    \(cosfct[x, y, Sqrt[1 - x^2 - y^2]]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(Solve[cosfct[x, y, z] \[Equal] \ 0, z]\)], "Input",
  CellLabel->"In[82]:="],

Cell["\<\
Also in this case the associated spheres do not coincide with the \
eigenspheres.  To show this, we calculate the eigenspheres:\
\>", "Text"],

Cell[BoxData[
    \(Eigenvectors[pcfct[x, y, z]]\)], "Input",
  CellLabel->"In[83]:="],

Cell[BoxData[
    \(Simplify[%, \ {x, y, z} \[Element] \ Reals]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(\(evvs\  = \ %;\)\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(evvs /. {x \[Rule] \ 0, y \[Rule] 0, z \[Rule] 1}\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(evvs /. z \[Rule] Sqrt[1 - x^2 - y^2]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \(Simplify[%, {x, y} \[Element] \ Reals]\)], "Input",
  CellLabel->"In[88]:="],

Cell[TextData[{
  "In our example, the eigenspheres do not change if the associated spheres \
do not change. Is that a general rule? Indeed, this is true, see ",
  ButtonBox["below",
    ButtonData:>"asseigsph",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[{0, 0, 1, 1, 0}/Sqrt[2]]\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \(vradius[{0, 0, 1, 1, 0}/Sqrt[2]]\)], "Input",
  CellLabel->"In[90]:="],

Cell[BoxData[
    \(vcenter[{0, 0, 1, 1, 0}/Sqrt[2]]\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(euklidsphereplot3D[{0, 0, \(-1\), 1, 0}/Sqrt[2]]\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(vradius[{0, 0, \(-1\), 1, 0}/Sqrt[2]]\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(vcenter[{0, 0, \(-1\), 1, 0}/Sqrt[2]]\)], "Input",
  CellLabel->"In[94]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Eigenspheres and associated spheres", "Subsubsection",
  CellTags->"asseigsph"],

Cell["By random experiments we shall show the following ", "Text"],

Cell[TextData[{
  StyleBox["PROPOSITION 5",
    FontColor->RGBColor[0, 0, 1]],
  ". Let C be a circle, and let S1, S2 two spheres with intersection C. If \
the point pair (a1, a2) varies under the conditions a1\[Element] S1, a2\
\[Element] S2, a1,a2 \[NotSubset]C, then all pairs (C,(a1,a2)) have the same \
eigenspheres; the eigenvalues differ, in general."
}], "Text"],

Cell["\<\
Proof. Without loss of generality we may consider the configuration of the \
foregoing example: C the standard unit circle, a1 its center (0,0,0), and \
(x,y,z) an arbitrary point. The associated sphere through (x,y,z) is given by \
the spacelike vector\
\>", "Text"],

Cell[BoxData[
    \(Clear[x, y, z, u, v, d]\)], "Input",
  CellLabel->"In[60]:="],

Cell[BoxData[
    \(circlepointsphere[stb[3], \ stb[4], \ {x, y, z}]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, {x, y, z} \[Element] \ Reals]\)], "Input",
  CellLabel->"In[41]:="],

Cell["\<\
The associated sphere through (x,y,z) has the parameter representation\
\>", "Text"],

Cell[BoxData[
    \(\(assphere[x_, y_, z_]\)[u_, 
        v_]\  := \ \(euklidsphere[{0, 
            0, \(\(-1\) + x\^2 + y\^2 + z\^2\)\/\@\(4\ z\^2 + \((\(-1\) + \
x\^2 + y\^2 + z\^2)\)\^2\), \(-\(\(2\ z\)\/\@\(4\ z\^2 + \((\(-1\) + x\^2 + y\
\^2 + z\^2)\)\^2\)\)\), 0}]\)[u, v]\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \(\(assphere[x, y, z]\)[u, v]\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(Clear[
      assphere]; \(assphere[x_, y_, z_]\)[u_, 
        v_] := {\(\@\(4\ z\^2 + \((\(-1\) + x\^2 + y\^2 + z\^2)\)\^2\)\ Cos[\
\[Pi]\ u]\ Cos[\(\[Pi]\ v\)\/2]\)\/\(2\ z\), \(\@\(4\ z\^2 + \((\(-1\) + x\^2 \
+ y\^2 + z\^2)\)\^2\)\ Cos[\(\[Pi]\ v\)\/2]\ Sin[\[Pi]\ u]\)\/\(2\ z\), \
\(\(-1\) + x\^2 + y\^2 + z\^2 + \@\(4\ z\^2 + \((\(-1\) + x\^2 + y\^2 + z\^2)\
\)\^2\)\ Sin[\(\[Pi]\ v\)\/2]\)\/\(2\ z\)}\)], "Input",
  CellLabel->"In[64]:="],

Cell["\<\
Now we calculate ihe matrix of the double projection corresponding to the \
pair 
(grc1, ({0,0,0}, assphere[x,y,z][u,v]})
grc1 the standard  unit circle. With the functions introduced in the \
foregoing example we get\
\>", "Text"],

Cell[BoxData[
    \(asspp\  = \(assphere[x, y, z]\)[u, v]; 
    pcfct[asspp[\([1]\)], asspp[\([2]\)], asspp[\([3]\)]]\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(% //. x\^2 + y\^2 + z\^2 \[Rule] \ d^2\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(FullSimplify[%, {d, z, x, y, u, v} \[Element] Reals]\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(% //. x\^2 + y\^2 \[Rule] \ d^2 - \(\(z^2\)\(\ \)\)\)], "Input",
  CellLabel->"In[104]:="],

Cell[BoxData[
    \(FullSimplify[%, {d, z, v} \[Element] Reals]\)], "Input",
  CellLabel->"In[105]:="],

Cell["This matrix depends on z,d,v only. We put", "Text"],

Cell["\<\
testmatrix[d_, z_, v_] := 
  {{1, -((z*(-1 + d^2 + Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2]))/
      ((-1 + d^2)^2 + 2*z^2 + (-1 + d^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*
        Sin[(Pi*v)/2]))}, 
   {-((z*(-1 + d^2 + Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2]))/
      ((-1 + d^2)^2 + 2*z^2 + (-1 + d^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*
        Sin[(Pi*v)/2])), (2*z^2)/((-1 + d^2)^2 + 2*z^2 + 
      (-1 + d^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2])}}\
\>", "Input",
  CellLabel->"In[65]:="],

Cell["\<\
and ask wether the eigenvalues and eigenvectors depend on v. First we \
calculate the determinaant of testmatrix\
\>", "Text"],

Cell[BoxData[
    \(Det[testmatrix[d, z, v]]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(FullSimplify[%, {d, z, v} \[Element] Reals]\)], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \(dettestmat[d_, z_, 
        v_] := \ \(z\^2\ \((\((\(-1\) + d\^2)\)\^2 + 4\ z\^2)\)\ Cos[\(\[Pi]\ \
v\)\/2]\^2\)\/\((\((\(-1\) + d\^2)\)\^2 + 2\ z\^2 + \((\(-1\) + d\^2)\)\ \@\(\
\((\(-1\) + d\^2)\)\^2 + 4\ z\^2\)\ Sin[\(\[Pi]\ v\)\/2])\)\^2\)], "Input",
  CellLabel->"In[68]:="],

Cell["For the trace we get the simpler expression", "Text"],

Cell[BoxData[
    \(Tr[testmatrix[d, z, v]]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(trtematr[d_, z_, v_]\  = %\)], "Input",
  CellLabel->"In[72]:="],

Cell["\<\
This is an eigenvalue calculated using the determinant and the trace of \
testmatrix[d,z,v]\
\>", "Text"],

Cell[BoxData[
    \(Simplify[\((trtematr[d, z, v] + 
            Sqrt[\(-4\)*dettestmat[d, z, v] + trtematr[d, z, v]^2])\)/
        2, {d, z, v} \[Element] Reals]\)], "Input",
  CellLabel->"In[63]:="],

Cell["\<\
Clear[ev1]; ev1[d_, z_, v_] := 
   (1/2)*(1 + (2*z^2)/((-1 + d^2)^2 + 2*z^2 + 
       (-1 + d^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*
        Sin[(Pi*v)/2]) + 
     Sqrt[-((4*z^2*((-1 + d^2)^2 + 4*z^2)*Cos[(Pi*v)/2]^2)/
         ((-1 + d^2)^2 + 2*z^2 + (-1 + d^2)*
            Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2])^2) + 
       (1 + (2*z^2)/((-1 + d^2)^2 + 2*z^2 + (-1 + d^2)*
            Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2]))^2])\
\>", "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(Plot[ev1[1,  .7, v], \ {v, \(-2\), 2}]\)], "Input",
  CellLabel->"In[119]:="],

Cell["\<\
This example shows that the eigenvalues depend on v, in general. Now we \
consider the eigenvectors:\
\>", "Text"],

Cell[BoxData[
    \(Eigenvectors[testmatrix[d, z, v]]\)], "Input",
  CellLabel->"In[74]:="],

Cell["\<\
The next simplification needs  much time and is not very effective:\
\>", "Text"],

Cell[BoxData[
    \(Simplify[%, \ d > z && z > 0 && v > 0 && 1 > v]\)], "Input",
  CellLabel->"In[121]:="],

Cell["\<\
We use the result as definition of the following function, which yield the \
eigenvectors as a function of d,z,v:\
\>", "Text"],

Cell["\<\
evectors[d_, z_, v_] := 
  {{(((-1 + d^2)^2 + 2*z^2 + (-1 + d^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*
        Sin[(Pi*v)/2])*((2*z^2)/((-1 + d^2)^2 + 2*z^2 + 
         (-1 + d^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2]) + 
       (-3 + 12*d^2 - 18*d^4 + 12*d^6 - 3*d^8 - 16*z^2 + 32*d^2*z^2 - 
         16*d^4*z^2 - 16*z^4 + Cos[Pi*v] - 4*d^2*Cos[Pi*v] + 
         6*d^4*Cos[Pi*v] - 4*d^6*Cos[Pi*v] + d^8*Cos[Pi*v] + 
         4*z^2*Cos[Pi*v] - 8*d^2*z^2*Cos[Pi*v] + 4*d^4*z^2*Cos[Pi*v] + 
         4*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] - 
         12*d^2*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] + 
         12*d^4*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] - 
         4*d^6*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] + 
         12*z^2*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] - 
         12*d^2*z^2*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] + 
         2*Sqrt[2*z^2*(1 - 2*d^2 + d^4 + 4*z^2)*Cos[(Pi*v)/2]^2*
             (-3 + 12*d^2 - 18*d^4 + 12*d^6 - 3*d^8 - 12*z^2 + 
              24*d^2*z^2 - 12*d^4*z^2 - 8*z^4 + (-1 + d^2)^2*(1 - 
                2*d^2 + d^4 + 4*z^2)*Cos[Pi*v] - 4*(-1 + d^2)*(1 - 
                2*d^2 + d^4 + 2*z^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[
                (Pi*v)/2]) + (3/2 - 6*d^2 + 9*d^4 - 6*d^6 + 
              (3*d^8)/2 + 8*z^2 - 16*d^2*z^2 + 8*d^4*z^2 + 8*z^4 - 
              (1/2)*(-1 + d^2)^2*(1 - 2*d^2 + d^4 + 4*z^2)*Cos[Pi*v] + 
              2*(-1 + d^2)*(1 - 2*d^2 + d^4 + 3*z^2)*Sqrt[
                (-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2])^2])/
        (2*(3 - 12*d^2 + 18*d^4 - 12*d^6 + 3*d^8 + 12*z^2 - 
          24*d^2*z^2 + 12*d^4*z^2 + 8*z^4 - (-1 + d^2)^2*
           (1 - 2*d^2 + d^4 + 4*z^2)*Cos[Pi*v] + 4*(-1 + d^2)*
           (1 - 2*d^2 + d^4 + 2*z^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*
           Sin[(Pi*v)/2]))))/(z*(-1 + d^2 + Sqrt[(-1 + d^2)^2 + 4*z^2]*
        Sin[(Pi*v)/2])), 1}, 
   {(((-1 + d^2)^2 + 2*z^2 + (-1 + d^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*
        Sin[(Pi*v)/2])*((2*z^2)/((-1 + d^2)^2 + 2*z^2 + 
         (-1 + d^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2]) + 
       (-3 + 12*d^2 - 18*d^4 + 12*d^6 - 3*d^8 - 16*z^2 + 32*d^2*z^2 - 
         16*d^4*z^2 - 16*z^4 + Cos[Pi*v] - 4*d^2*Cos[Pi*v] + 
         6*d^4*Cos[Pi*v] - 4*d^6*Cos[Pi*v] + d^8*Cos[Pi*v] + 
         4*z^2*Cos[Pi*v] - 8*d^2*z^2*Cos[Pi*v] + 4*d^4*z^2*Cos[Pi*v] + 
         4*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] - 
         12*d^2*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] + 
         12*d^4*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] - 
         4*d^6*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] + 
         12*z^2*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] - 
         12*d^2*z^2*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2] - 
         2*Sqrt[2*z^2*(1 - 2*d^2 + d^4 + 4*z^2)*Cos[(Pi*v)/2]^2*
             (-3 + 12*d^2 - 18*d^4 + 12*d^6 - 3*d^8 - 12*z^2 + 
              24*d^2*z^2 - 12*d^4*z^2 - 8*z^4 + (-1 + d^2)^2*(1 - 
                2*d^2 + d^4 + 4*z^2)*Cos[Pi*v] - 4*(-1 + d^2)*(1 - 
                2*d^2 + d^4 + 2*z^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*Sin[
                (Pi*v)/2]) + (3/2 - 6*d^2 + 9*d^4 - 6*d^6 + 
              (3*d^8)/2 + 8*z^2 - 16*d^2*z^2 + 8*d^4*z^2 + 8*z^4 - 
              (1/2)*(-1 + d^2)^2*(1 - 2*d^2 + d^4 + 4*z^2)*Cos[Pi*v] + 
              2*(-1 + d^2)*(1 - 2*d^2 + d^4 + 3*z^2)*Sqrt[
                (-1 + d^2)^2 + 4*z^2]*Sin[(Pi*v)/2])^2])/
        (2*(3 - 12*d^2 + 18*d^4 - 12*d^6 + 3*d^8 + 12*z^2 - 
          24*d^2*z^2 + 12*d^4*z^2 + 8*z^4 - (-1 + d^2)^2*
           (1 - 2*d^2 + d^4 + 4*z^2)*Cos[Pi*v] + 4*(-1 + d^2)*
           (1 - 2*d^2 + d^4 + 2*z^2)*Sqrt[(-1 + d^2)^2 + 4*z^2]*
           Sin[(Pi*v)/2]))))/(z*(-1 + d^2 + Sqrt[(-1 + d^2)^2 + 4*z^2]*
        Sin[(Pi*v)/2])), 1}}\
\>", "Input",
  CellLabel->"In[76]:="],

Cell["\<\
For proving the proposition we show, that the derivative of the eigenvectors \
with respect to v vanish:\
\>", "Text"],

Cell[BoxData[
    \(D[\(evectors[d, z, v]\)[\([1]\)], v]\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(\(evector1dv[d_, z_, v_]\  = \ %;\)\)], "Input",
  CellLabel->"In[78]:="],

Cell["\<\
This vector should be the zero vector null[2]; by the long numerical \
computation we get disturbances of its first component:\
\>", "Text"],

Cell[BoxData[
    \(evector1dv[2 + Random[], 2*Random[], \ Random[]]\)], "Input",
  CellLabel->"In[84]:="],

Cell["Using Chop they are anullated:", "Text"],

Cell[BoxData[
    \(Chop[evector1dv[2 + Random[], 2*Random[], \ Random[]]]\)], "Input",
  CellLabel->"In[85]:="],

Cell["\<\
We make experiments with 1000 random arguments; it gives the number of cases \
with 
Chop[evector1dv[2+Random[],2*Random[], Random[]]],{1000}] \[NotEqual] {0,0},
which shhould and will be zero:\
\>", "Text"],

Cell[BoxData[
    \(etable1\  = 
      Table[Chop[evector1dv[2 + Random[], 2*Random[], \ Random[]]], {1000}]; 
    jj\  = \ 0; 
    For[i = 1, \ i \[LessEqual] \ Length[etable1], \(i++\), 
      If[Not[etable1[\([i]\)] \[Equal] \ {0, 0}], \ jj\  = \ jj + 1]]; \ 
    jj\)], "Input",
  CellLabel->"In[86]:="],

Cell["\<\
One may change this experiment with other facors or constants within the \
random arguments. Be sure, that for the arguments always d > 0, Abs[z] \
\[LessEqual] d, and -1 \[LessEqual] v \[LessEqual] 1 is valid. Sometimes the \
disturbances are too high to be anullated by Chop, as in the next example:\
\>", "Text"],

Cell[BoxData[
    \(etable1\  = 
      Table[Chop[
          evector1dv[1 + Random[], Random[], \ \(-Random[]\)]], {1000}]; 
    jj\  = \ 0; 
    For[i = 1, \ i \[LessEqual] \ Length[etable1], \(i++\), 
      If[Not[etable1[\([i]\)] \[Equal] \ {0, 0}], 
        Print[i, etable1[\([i]\)]]; \ \ jj\  = \ jj + 1]]; \ jj\)], "Input",
  CellLabel->"In[89]:="],

Cell[BoxData[
    \(etable1\  = 
      Table[Chop[
          evector1dv[1 + Random[], \(-Random[]\), \ \(-Random[]\)]], {1000}]; 
    jj\  = \ 0; 
    For[i = 1, \ i \[LessEqual] \ Length[etable1], \(i++\), 
      If[Not[etable1[\([i]\)] \[Equal] \ {0, 0}], 
        Print[i, etable1[\([i]\)]]; \ \ jj\  = \ jj + 1]]; \ jj\)], "Input",
  CellLabel->"In[90]:="],

Cell["We check the derivation of the second eigenvector:", "Text"],

Cell[BoxData[
    \(D[\(evectors[d, z, v]\)[\([2]\)], v]\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(\(evector2dv[d_, z_, v_]\  = \ %;\)\)], "Input",
  CellLabel->"In[92]:="],

Cell[BoxData[
    \(etable2\  = 
      Table[Chop[evector2dv[2 + Random[], 2*Random[], \ Random[]]], {1000}]; 
    jj\  = \ 0; 
    For[i = 1, \ i \[LessEqual] \ Length[etable2], \(i++\), 
      If[Not[etable1[\([i]\)] \[Equal] \ {0, 0}], \ jj\  = \ jj + 1]]; \ 
    jj\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(etable2\  = 
      Table[evector2dv[2 + Random[], Random[], \ Random[]], {10}]\)], "Input",\

  CellLabel->"In[100]:="],

Cell[BoxData[
    \(etable2\  = 
      Table[Chop[
          evector2dv[1 + Random[], \(-Random[]\), \ \(-Random[]\)]], {1000}]; 
    jj\  = \ 0; 
    For[i = 1, \ i \[LessEqual] \ Length[etable2], \(i++\), 
      If[Not[etable2[\([i]\)] \[Equal] \ {0, 0}], 
        Print[i, etable2[\([i]\)]]; \ \ jj\  = \ jj + 1]]; \ jj\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(etable2\  = 
      Table[Chop[
          evector2dv[2 + Random[], \(-Random[]\), \ Random[]]], {1000}]; 
    jj\  = \ 0; 
    For[i = 1, \ i \[LessEqual] \ Length[etable2], \(i++\), 
      If[Not[etable2[\([i]\)] \[Equal] \ {0, 0}], 
        Print[i, etable2[\([i]\)]]; \ \ jj\  = \ jj + 1]]; \ jj\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(etable2\  = 
      Table[Chop[evector2dv[10 + Random[], Random[], \ Random[]]], {1000}]; 
    jj\  = \ 0; 
    For[i = 1, \ i \[LessEqual] \ Length[etable2], \(i++\), 
      If[Not[etable2[\([i]\)] \[Equal] \ {0, 0}], 
        Print[i, etable2[\([i]\)]]; \ \ jj\  = \ jj + 1]]; \ jj\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(etable2\  = 
      Table[Chop[evector2dv[10 + Random[], 5*Random[], \ Random[]]], {1000}]; 
    jj\  = \ 0; 
    For[i = 1, \ i \[LessEqual] \ Length[etable2], \(i++\), 
      If[Not[etable2[\([i]\)] \[Equal] \ {0, 0}], 
        Print[i, etable2[\([i]\)]]; \ \ jj\  = \ jj + 1]]; \ jj\)], "Input",
  CellLabel->"In[103]:="],

Cell["\<\
The experiments are so convincing that we may state: Proposition 5 is true \
with probability 1.  It would be nice to find a direct, geometric proof.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["4.5 M\[ODoubleDot]bius invariants expressed by euclidean invariants", \
"Subsection",
  FontFamily->"Times"],

Cell[TextData[{
  "In this subsection we shall express the determinant and the trace of \
ppcpp[(C,pp)] by euclidean invariants of the configuration obtaining formulas \
similar, but more complicated, to the Coxeter distance of two spheres. The \
calculations show very well the excellent performance of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " in doing symbolical transformations. "
}], "Text"],

Cell[CellGroupData[{

Cell["Adaption of the euclidean coordinates to the point pair", \
"Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "First we adapt the coordinate system to",
  StyleBox[" the 0-sphere of radius: ",
    FontColor->RGBColor[1, 0, 0]],
  "let the center be the origin and the point pair belong to the z-axis :"
}], "Text"],

Cell[BoxData[
    \(Remove[p1, p2]; Clear[R]\)], "Input",
  CellLabel->"In[41]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(p1[R_]\  := \ {0, 0, R}; \ p2[R_] := \ {0, 0, \(-R\)};\)], "Input",
  CellLabel->"In[29]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?pp2space\)\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(Context[pp2space]\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(pp2space[p1[R], \ p2[R]]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(FullSimplify[%, \ R > 0]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(psvpp[R_] = %\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], \ {i, 2}, {j, 2}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(FullSimplify[%, \ R > 0]\)], "Input",
  CellLabel->"In[80]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(repp1\  = \ 
      stepro[\(psvpp[R]\)[\([1]\)] + \(psvpp[R]\)[\([2]\)]]\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    \(repp1\  = \ 
      stepro[\(psvpp[R]\)[\([1]\)] - \(psvpp[R]\)[\([2]\)]]\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(\(?vspacepp\)\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(\(\(\ \)\(vspacepp[p1[R], \ p2[R]]\)\)\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(FullSimplify[%, \ R > 0]\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell["For R = 1 this formula is false; correct is the limit", "Text"],

Cell[BoxData[
    \(Limit[%%, \ R \[Rule] \ 1]\)], "Input",
  CellLabel->"In[66]:="],

Cell["while the foregoing result gives", "Text"],

Cell[BoxData[
    \(%% /. \ R \[Rule] \ 1\)], "Input",
  CellLabel->"In[69]:="],

Cell[TextData[{
  "Remember: Simplifying symbolic expression ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " concentrates on the general case; singularities appear as exceptions of \
the general expressions. \nSince the factor -1 at the spacelike vector does \
not change the corresponding sphere, we define finally"
}], "Text"],

Cell["\<\
appspace[R_] := {{0, 0, 0, (1 + R^2)/(2*R), (-1 + R^2)/(2*R)}, 
 {0, 1, 0, 0, 0},{1,0,0,0,0}}\
\>", "Input",
  CellLabel->"In[30]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(appspace[R]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Table[
        pssp[\(appspace[R]\)[\([i]\)], \(appspace[R]\)[\([j]\)]], \ {i, 
          3}, {j, 3}] // MatrixForm\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \(Simplify[%] // MatrixForm\)], "Input",
  CellLabel->"In[89]:="],

Cell["\<\
The 0-sphere appears as the intersection of the z-axis with the sphere of \
radius R with center at the origin. The orthogonality of appspace and psvpp \
can easely be checked:\
\>", "Text"],

Cell[BoxData[
    \(Table[
        pssp[\(psvpp[R]\)[\([i]\)], \(appspace[R]\)[\([j]\)]], \ {i, 2}, {j, 
          3}] // MatrixForm\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(Simplify[%] // MatrixForm\)], "Input",
  CellLabel->"In[87]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Further adaption of the euclidean coordinates to the circle", \
"Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "Next we turn the coordinate system around the z-axis in such a way that \
the center m of the considered ",
  StyleBox["circle with radius r ",
    FontColor->RGBColor[1, 0, 0]],
  "belongs to the x,z-plane. Explaining it otherwise, we choose the \
coordinates in such a way that the plane defined by p1,p2, and m is the x, \
z-plane. Then we get for the "
}], "Text"],

Cell[BoxData[
    \(\(?circlespacevectors\)\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Context[circlespacevectors]\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    \(bcspace[x_, z_, u_, v_, r_] := \ 
      circlespacevectors[x, 0, z, u, v, r]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(bcspace[x, z, u, v, r]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "We introduce",
  StyleBox[" the distance d-> dist[x,z] of the centers of the pointpair and \
the circle ",
    FontColor->RGBColor[1, 0, 0]]
}], "Text"],

Cell[BoxData[
    \(dist[x_, z_]\  := \ Sqrt[x^2 + z^2]\)], "Input",
  CellLabel->"In[97]:="],

Cell[TextData[{
  "Introducing furthermore",
  StyleBox[" the angle b between the line containing the 0-sphere (p1, p2), \
i.e. the z-axis, and the radius vector of the centers {x,0,z}",
    FontColor->RGBColor[1, 0, 0]],
  ", we have with"
}], "Text"],

Cell[BoxData[
    \(subst\  = {d -> \ dist[x, z], b\  -> \ ArcCos[z/d]}\)], "Input",
  CellLabel->"In[95]:="],

Cell["that bcspace[x,z,u,v,r] coincides with the function", "Text"],

Cell["\<\
 eubcspace[d_, b_, u_, v_, r_] := 
   {{Cos[u]*Cos[v], Cos[v]*Sin[u], Sin[v], d*Sin[b]*Cos[u]*Cos[v] + \
d*Cos[b]*Sin[v],
d*Sin[b]*Cos[u]*Cos[v] + d*Cos[b]*Sin[v]}, 
    {(d*Sin[b])/r, 0, (d*Cos[b])/r, (-1 - r^2 + d^2)/(2*r), 
     (1 - r^2 + d^2)/(2*r)}}\
\>", "Input",
  CellLabel->"In[31]:=",
  InitializationCell->True],

Cell["We check this:", "Text"],

Cell[BoxData[
    \(eubcspace[d, b, u, v, r] //. subst\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(Simplify[%, x > 0 && z > 0]\)], "Input",
  CellLabel->"In[99]:="],

Cell[BoxData[
    \(% \[Equal] \ bcspace[x, z, u, v, r]\)], "Input",
  CellLabel->"In[100]:="],

Cell["\<\
Defining w we silently assumed d>0. Let us shortly consider the case d = 0, \
i.e. x=z=0:\
\>", "Text"],

Cell[BoxData[
    \(bcspace[0, 0, u, v, r]\)], "Input",
  CellLabel->"In[108]:="],

Cell["In this case the function eubcspace does not depend on b:", "Text"],

Cell[BoxData[
    \(eubcspace[0, b, u, v, r]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \({{Cos[u]\ Cos[v], Cos[v]\ Sin[u], Sin[v], 0, 0}, {0, 0, 
        0, \(\(-1\) - r\^2\)\/\(2\ r\), \(1 - r\^2\)\/\(2\ r\)}}\)], "Input",
  CellLabel->"Out[109]="],

Cell["Thus we agree to set b=0 in case of d=0.", "Text"],

Cell["\<\
Remark: the parameters u,v are the geographic coordinates of the position \
vector of the circle; they will be replaced by angles defined of the pair (C, \
pp) later..\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Calculation of the invarints", "Subsubsection"],

Cell["\<\
The matrix of the double projection corresponding to the pair (C, (p1,p2)) is \
\
\>", "Text"],

Cell[BoxData[
    \(\(?ppcpp\)\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ppcppmatrix[d_, b_, u_, v_, r_, R_\ ] := \ 
      ppcpp[eubcspace[d, b, u, v, r], appspace[R]]\)], "Input",
  CellLabel->"In[32]:=",
  InitializationCell->True],

Cell[BoxData[
    \(ppcppmatrix[d, b, u, v, r, R]\)], "Input",
  CellLabel->"In[102]:="],

Cell[BoxData[
    \(Det[%]\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(FullSimplify[Together[%], r > 0 && R > 0 && \ d > 0]\)], "Input",
  CellLabel->"In[104]:="],

Cell["We take this result as the definition of the function", "Text"],

Cell["\<\
detppcppmatrix[d_, b_, u_, v_, r_, R_] := (1/(4*r^2*R^2))*
   ((r^2 + R^2 - d^2*Cos[2*b])^2*Cos[u]^2*Cos[v]^2 + 
    (d^4 - 2*d^2*r^2 + (r^2 + R^2)^2 - 2*d^2*R^2*Cos[2*b])*Cos[v]^2*
     Sin[u]^2 + 4*d^4*Cos[b]^2*Sin[b]^2*Sin[v]^2 - 
    d^2*(-r^2 - R^2 + d^2*Cos[2*b])*Cos[u]*Sin[2*b]*Sin[2*v])\
\>", "Input",
  CellLabel->"In[33]:=",
  InitializationCell->True],

Cell["Now we calculate the trace", "Text"],

Cell[BoxData[
    \(Tr[ppcppmatrix[d, b, u, v, r, R]]\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \(FullSimplify[Together[%], r > 0 && R > 0 && \ d > 0]\)], "Input",
  CellLabel->"In[106]:="],

Cell["Again we take this result as the definition of the function", "Text"],

Cell["\<\
trppcppmatrix[d_, b_, u_, v_, r_, R_] := 
  (1/(4*r^2*R^2))*(d^4 - 2*d^2*r^2 + (r^2 + R^2)^2 - 
    2*d^2*Cos[2*b]*(R^2 + r^2*Cos[u]^2*Cos[v]^2) + 
    r^2*((d^2 + 4*R^2 + d^2*Cos[2*u])*Cos[v]^2 + 
      2*d^2*(2*Cos[b]^2*Sin[v]^2 + Cos[u]*Sin[2*b]*Sin[2*v])))\
\>", "Input",
  CellLabel->"In[34]:=",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell["Invariant angles", "Subsubsection"],

Cell["\<\
The parameters u,v of the position vector posv of the circle are defined with \
respect to the adapted frame. First we replace  the angle v of  the posv with \
the x,y-plane by the angle w of posv and the line through ppi.e. the z-axis, \
v+w = Pi/2\
\>", "Text"],

Cell[BoxData[
    \(v\  \[Rule] \ Pi/2\  - \ w\)], "Input",
  Evaluatable->False],

Cell[TextData[{
  "The parameter u is the angle between the orthogonal projection of the \
position vector posv and the orthogonal projection ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"of", " ", "the", " ", "radius", " ", "vector", 
          FormBox[\(\(o\ m\)\&\[LongRightArrow]\),
            "TraditionalForm"], "joining", " ", "the", " ", "centers", " ", 
          "of", " ", "pp", " ", "and", " ", "C", " ", "onto", " ", "the", " ",
           "plane", " ", "through", " ", "o"}], ",", 
        " ", \(orthogonal\ to\ the\ line\ containing\ pp\), 
        ",", \(u = \(0\ if\ d = 0. \)\)}]],
    FontFamily->"Times New Roman"],
  " "
}], "Text"],

Cell["\<\
Let a denote the angle between the position vector of the circle and the line \
connecting the centers, (d>0). We replace the angle u by a, using the \
equation\
\>", "Text"],

Cell[BoxData[
    \(Cos[u]*Sin[b]*Sin[w]\  + \ Cos[b]*Cos[w] \[Equal] \ \ Cos[a]\)], "Input",\

  Evaluatable->False],

Cell["The first substitution yields", "Text"],

Cell[BoxData[
    \(detppcppmatrix[d, b, u, v, r, R] //. \ 
      v \[Rule] Pi/2\  - \ w\)], "Input",
  CellLabel->"In[146]:="],

Cell[BoxData[
    \(% //. {\ Sin[2\ \((\[Pi]\/2 - w)\)] \[Rule] \ 2*\ Sin[w]*Cos[w], 
        Sin[u]^2\  \[Rule] \ 1\  - \ Cos[u]^2}\)], "Input",
  CellLabel->"In[147]:="],

Cell[BoxData[
    \(% //. Cos[
          u] \[Rule] \ \((Cos[a] - Cos[b]*Cos[w])\)/\((Sin[b]*
              Sin[w])\)\)], "Input",
  CellLabel->"In[148]:="],

Cell[BoxData[
    \(FullSimplify[\ %, {d, r, R, a, b, \ w} \[Element] Reals]\)], "Input",
  CellLabel->"In[117]:="],

Cell["This result motivates the explicit definition ", "Text"],

Cell["\<\
detppcpp[a_, b_, w_, d_, r_, R_] := (1/(4*r^2*R^2))*
   (2*d^2*((-Cos[a]^2)*(d^2 - 2*r^2 + d^2*Cos[2*b]) + 2*(d^2 - r^2 + \
R^2)*Cos[a]*Cos[b]*Cos[w] - 
      2*R^2*Cos[b]^2*Cos[w]^2) + (d^4 - 2*d^2*r^2 + (r^2 + R^2)^2 - \
2*d^2*R^2*Cos[2*b])*Sin[w]^2)\
\>", "Input",
  CellLabel->"In[35]:=",
  InitializationCell->True],

Cell[BoxData[
    \(detppcpp[a, b, w, d, r, R]\)], "Input",
  CellLabel->"In[150]:="],

Cell["\<\
In case of d = 0 the angles a,b are not defined. We calculate \
\>", "Text"],

Cell[BoxData[
    \(detppcpp[a, b, w, 0, r, R]\)], "Input",
  CellLabel->"In[161]:="],

Cell["\<\
This expression does not depend on a,b; thus the settings a = 0, b= 0 in case \
d = 0 are justified.\
\>", "Text"],

Cell["We treat the trace in the same way:", "Text"],

Cell[BoxData[
    \(trppcppmatrix[d, b, u, v, r, R] //. \ v \[Rule] Pi/2\  - \ w\)], "Input",\

  CellLabel->"In[151]:="],

Cell[BoxData[
    \(FullSimplify[%, \ {u, w, b} \[Element] Reals]\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(% /. Cos[2*u]\  \[Rule] \ 2*Cos[u]^2 - 1\)], "Input",
  CellLabel->"In[153]:="],

Cell[BoxData[
    \(% //. Cos[
          u]\  \[Rule] \ \((Cos[a] - Cos[b]*Cos[w])\)/\((Sin[b]*
              Sin[w])\)\)], "Input",
  CellLabel->"In[154]:="],

Cell[BoxData[
    \(FullSimplify[\ %, {d, r, R, a, b, \ w} \[Element] Reals]\)], "Input",
  CellLabel->"In[155]:="],

Cell["Using this formula we finally define", "Text"],

Cell["\<\
trppcpp[a_, b_, w_, d_, r_, R_] := (d^4 + r^4 + 4*r^2*R^2 + R^4 + \
2*d^2*r^2*Cos[2*a] - 2*R^2*(d^2*Cos[2*b] + r^2*Cos[2*w]))/(4*r^2*R^2)\
\>", "Input",
  CellLabel->"In[36]:=",
  InitializationCell->True],

Cell["The case d = 0", "Text"],

Cell[BoxData[
    \(trppcpp[a, b, w, 0, r, R]\)], "Input",
  CellLabel->"In[160]:="],

Cell["\<\
This expression does not depend on a,b; thus the settings a = 0, b= 0 in case \
d = 0 are justified.\
\>", "Text"],

Cell[TextData[StyleBox["Notations:",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell["\<\
C is a circle with center m, radius r, and position vector posv in the \
euclidean 3-space.\
\>", "Text"],

Cell["\<\
pp = (p1, p2) is a 0-sphere of radius R with center m0 in the euclidean \
3-space. \
\>", "Text"],

Cell["d denotes the distance of the centers m, m0,", "Text"],

Cell["\<\
a  denotes the angle between the position vector of the circle and the line \
connecting the centers, a = 0 if d = 0,\
\>", "Text"],

Cell["\<\
b denotes the angle between the line joining the centers and the line \
containing pp, b = 0 if d = 0.\
\>", "Text"],

Cell["\<\
w denotes the angle between the position vector posv and the line containing \
pp.\
\>", "Text"],

Cell[TextData[{
  StyleBox["PROPOSITION  6. ",
    FontColor->RGBColor[0, 0, 1]],
  "With the notations just explained  the expression"
}], "Text"],

Cell[BoxData[
    \(detppcpp[a, b, w, d, r, R]\)], "Input",
  CellLabel->"In[37]:=",
  InitializationCell->True],

Cell["is the determinant, and ", "Text"],

Cell[BoxData[
    \(trppcpp[a, b, w, d, r, R]\)], "Input",
  CellLabel->"In[38]:=",
  InitializationCell->True],

Cell["\<\
the trace of the matrix of the double projection ppspp[(C,pp)]. As such, they \
form a complete invariant system for the M\[ODoubleDot]bius geometry of the \
pairs (C,pp) of circles C with point pairs pp.\
\>", "Text"],

Cell[TextData[{
  "Since all calculations are done already, the ",
  StyleBox["proof",
    FontColor->RGBColor[0, 0, 1]],
  " is an easy consequence of the general ",
  ButtonBox["theory",
    ButtonData:>"S4",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Control: OK! :", "Subsubsection"],

Cell["\<\
We use the assumptions and notations explained in propostition 6:\
\>", "Text"],

Cell["Thus we have for the angle a", "Text"],

Cell[BoxData[
    \(\(unit[2]\)[{u, v}] . {x, y, z}/Sqrt[x^2 + y^2\  + \ z^2]\  \[Equal] \ 
      Cos[a]\)], "Input",
  CellLabel->"In[69]:="],

Cell["This leads to the definition", "Text"],

Cell["\<\
anglea[x_, y_, z_, u_, v_] := Module[{ds=x^2+y^2+z^2, angle},
If[(N[ds] \[Equal]  0.)|| ds \[Equal] 0,angle = 0,
angle = ArcCos[(x*Cos[u]*Cos[v] + y*Cos[v]*Sin[u] + z*Sin[v])/Sqrt[x^2 + y^2 \
+ z^2]],angle = ArcCos[(x*Cos[u]*Cos[v] + y*Cos[v]*Sin[u] + \
z*Sin[v])/Sqrt[x^2 + y^2 + z^2]]];
Return[angle]]\
\>", "Input",
  CellLabel->"In[43]:="],

Cell["\<\
For testing the result we take the 0-sphere {p1[R], p2[R]} with random R>0:\
\>", "Text"],

Cell[BoxData[
    \({p1[R], p2[R]}\)], "Input",
  CellLabel->"In[51]:="],

Cell["\<\
and a circle with random center {x,y,z}, random Radius r>0, and a random \
position vector unit[2][u,v].  First we calculate the determinant and the \
trace of the matrix ppcpp of this configuration directly, by the help of \
\>", "Text"],

Cell[BoxData[
    \(\(?circlespacevectors\)\)], "Input",
  CellLabel->"In[60]:="],

Cell["\<\
and appspace inserted into ppcpp,  and then we compare the results with the \
functions detppcpp, trppcpp appearing in proposition 6.\
\>", "Text"],

Cell[BoxData[{
    \(xx = \ 1*Random[]; yy = 1*\ Random[]; zz = \ 1*Random[]; 
    rr = \ 1*Random[]; RR = \ 1*Random[]; vv = \ Random[]*Pi/2; 
    uu\  = \ Random[]*Pi*2;\), "\[IndentingNewLine]", 
    \(aamatrix\  = \ 
      ppcpp[circlespacevectors[xx, yy, zz, uu, vv, rr], \ 
        appspace[RR]]\), "\[IndentingNewLine]", 
    \(\)}], "Input",
  CellLabel->"In[44]:="],

Cell["\<\
Now we calculate the euclidean invariants of the configuration, insert them \
into the functions newdetppcpp, newtrppcpp, and substract the determinant or \
the trace, respectively, of aamatrix. In both cases the test should give \
zero, upto numerical disturbances:\
\>", "Text"],

Cell[BoxData[{
    \(\(aa\  = \ anglea[xx, yy, zz, uu, vv];\)\), "\[IndentingNewLine]", 
    \(\(ww = \ Pi/2\  - \ vv;\)\ \), "\[IndentingNewLine]", 
    \(\(dd\  = \ Sqrt[xx^2 + yy^2 + zz^2];\)\), "\n", 
    \(\(If[dd \[Equal] 0 || dd \[Equal] \ 0. , 
        bb = \ 0, \[IndentingNewLine]bb\  = \ ArcCos[zz/dd], 
        bb\  = \ ArcCos[zz/dd]];\)\), "\n", 
    \(\(dettest\  = \ 
        detppcpp[aa, bb, ww, dd, rr, RR] - Det[aamatrix];\)\), "\n", 
    \(\(trtest\  = \ 
        trppcpp[aa, bb, ww, dd, rr, RR] - 
          Tr[aamatrix];\)\), "\[IndentingNewLine]", 
    \({dettest, trtest}\)}], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(Clear[xx, yy, zz, uu, vv, aa, bb, ww, dd, rr, RR]\)], "Input",
  CellLabel->"In[53]:="],

Cell["\<\
OK! All seems to be correct.  The next cell contains a test program with an \
error counter err giving the number of cases in which the Chop of the value \
of at least one of the test functions is not zero; in any such cases the \
values of the test functions are printed.  \
\>", "Text"],

Cell[BoxData[
    \(err\  = \ 0; 
    For[i = 0, \ 
      i \[LessEqual] 1000, \ \(i++\), \[IndentingNewLine]xx = \ 1*Random[]; 
      yy = 2*\ Random[]; zz = \ \(-1\)*Random[]; rr = 1*Random[]; 
      RR =  .1 + \ 1*Random[]; vv = \ 1*Random[]*Pi/2; 
      uu\  = \ Random[]*Pi*2; \n
      aamatrix\  = \ 
        ppcpp[circlespacevectors[xx, yy, zz, uu, vv, rr], \ appspace[RR]]; \n
      aa\  = \ \ anglea[xx, yy, zz, uu, vv]; \nww = \ Pi/2\  - \ vv; \ \n
      dd\  = \ Sqrt[xx^2 + yy^2 + zz^2]; \n
      If[dd \[Equal] 0 || dd \[Equal] \ 0. , 
        bb = \ 0, \[IndentingNewLine]bb\  = \ ArcCos[zz/dd], 
        bb\  = \ ArcCos[zz/dd]]; \n
      dettest\  = \ detppcpp[aa, bb, ww, dd, rr, RR] - Det[aamatrix]; \n
      trtest\  = \ trppcpp[aa, bb, ww, dd, rr, RR] - Tr[aamatrix]; \n
      If[Chop[dettest] \[NotEqual] \ 0 || \ Chop[trtest] \[NotEqual] \ 0, 
        Print[{dettest, trtest}]; \[IndentingNewLine]Print[{xx, yy, zz, uu, 
            vv, rr, RR}]; err\  = \ err + 1]]; err\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(Clear[xx, yy, zz, uu, vv, aa, bb, ww, dd, rr, RR]\)], "Input",
  CellLabel->"In[354]:="],

Cell["\<\
The number err depends on the factors at the coordinates and the radii; iff \
these values are in \"critical regions\", e.g. differ strongly, the number \
err increases.  As you see, also in these cases the test functions have only \
small values. Make your experiments! A bit hesitating one may say that the \
tests confirm the statements of proposition 6.\
\>", "Text"],

Cell[BoxData[
    \(Clear[aa, bb, xx, yy, zz, rr, RR, uu, vv, ww, aamatrix, aa, bb, dd, 
      dettest, trtest, err]\)], "Input",
  CellLabel->"In[355]:="]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5 Point quadrupels", "Section",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["5.1 A complete invariant system", "Subsection",
  FontFamily->"Times"],

Cell[TextData[{
  "We consider pairs of  0-spheres, i.e. point quadrupels {{a1,a2},{b1,b2}}. \
For 0-spheres on the line see ",
  ButtonBox["example 1 ",
    ButtonData:>"ex3.2_1",
    ButtonStyle->"Hyperlink"],
  "in subsection 3.2. Since each point quadrupel belongs to a sphere, we \
could consider spherical M\[ODoubleDot]bius geometry: dim = 2, but for later \
applications we shall consider the case dim = 3 here. Since the \
M\[ODoubleDot]bius group of the sphere coincides with the broken linear \
transformations in one complex variable of the Riemannian sphere, and this is \
the projective complex line, an invariant of the quadrupel coincides with the \
complex cross ratio, the basic invariant of complex projective geometry. \
Historically, the M\[ODoubleDot]bius group has been found by \
M\[ODoubleDot]bius in this important context. We considered the original \
complex M\[ODoubleDot]bius group, and its relation to the 2-dimensional real \
case, in the notebook ",
  ButtonBox["[8]",
    ButtonData:>"S8",
    ButtonStyle->"Hyperlink"],
  ". Here we are interested more in the real situation, for later application \
in differential geometry. Therefore we shall apply the general method of M\
\[ODoubleDot]bius invariants for pairs of subspheres also in this lowest \
dimensional case. Since the cross ratio is a complex number we may expect to \
obtain two real invariants describing the mutual position of two point pairs \
in the M\[ODoubleDot]bius space. "
}], "Text"],

Cell[CellGroupData[{

Cell["A complete invariant system", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
Let {a_list, b_list} = {{a1,a2},{b1,b2}} be two point pairs in the  3-space. \
Then the corresponding double projection is defined as\
\>", "Text"],

Cell[BoxData[
    \(ppptspp[a_List, \ b_List]\  := \ 
      Module[{av, \ bv, \ i, \ j, k}, \n\t\tav\  = \ 
          vspacepp[a[\([1]\)], \ a[\([2]\)]]; \n\t
        bv\  = \ vspacepp[b[\([1]\)], \ b[\([2]\)]]; \[IndentingNewLine]If[
          av\  \[Equal] \ Null || bv \[Equal] Null, \ Return[]]; \n\t\tTable[
          Sum[pssp[av[\([j]\)], bv[\([k]\)]]*
              pssp[av[\([i]\)], bv[\([k]\)]], {k, 3}], \n\t\t\t{i, 3}, {j, 
            3}]]\)], "Input",
  CellLabel->"In[39]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["The eigenvalues of this matrix and the rank", "Text"],

Cell[BoxData[
    \(rk[a1_List, \ a2_List, \ b1_List, \ b2_List] := 
      rank[Join[vspacepp[a1, \ a2], vspacepp[b1, \ b2]]]\)], "Input",
  CellLabel->"In[40]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell["\<\
 are a complete invariant system for the m\[ODoubleDot]bius geometry of point \
pairs.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["First examples", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(ppptspp[{{\(-1\), 0, 0}, \ {1, 0, 0}}, {{0, \(-1\), 0}, \ {0, \ 1, 
          0}}]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(rk[{\(-1\), 0, 0}, \ {1, 0, 0}, {0, \(-1\), 0}, \ {0, \ 1, 
        0}]\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vspacepp[{0, \(-1\), 0}, \ {0, \ 1, 0}]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?psframepp\)\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    \(psframepp[{0, \(-1\), 0}, \ {0, \ 1, 0}]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(stepro[%[\([4]\)] + \ %[\([5]\)]]\)], "Input",
  CellLabel->"In[84]:="],

Cell[BoxData[
    \(stepro[%%[\([4]\)] - \ %%[\([5]\)]]\)], "Input",
  CellLabel->"In[85]:="],

Cell["If the two point pairs coincide, we get the identity matrix:", "Text"],

Cell[BoxData[
    \(ppptspp[{{\(-1\), 0, 0}, \ {1, 0, 0}}, {{\(-1\), 0, 0}, \ {1, 0, 
          0}}]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(rk[{\(-1\), 0, 0}, \ {1, 0, 0}, {\(-1\), 0, 0}, \ {1, 0, 0}]\)], "Input",\

  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vspacepp[{0, 1, 0}, \ {0, \ 1, 0}]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ppptspp[{{\(-1\), 0, 0}, \ {1, 0, 0}}, {{0, 1, 0}, \ {0, \ 1, 
          0}}]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2 Throws", "Subsection",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["Definition of a throw and the matrix pppts", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  "We say that a point quadrupel is  a",
  StyleBox[" throw",
    FontColor->RGBColor[1, 0, 0]],
  ", if at least three of the four points are different. In this case we show \
that at least  one of the three eigenvalues of the corresponding matrix \
equals 1. To this aim we assume without loss of generality that all four \
points belong to the x,y-plane; by a M\[ODoubleDot]bius transform we reach \
that three of the points are  unit points on the axes:"
}], "Text"],

Cell[BoxData[
    \(ppptspp[{{\(-1\), 0, 0}, \ {1, 0, 0}}, {{x, \ y, 0}, {0, 1, 
          0}}]\)], "Input",
  CellLabel->"In[86]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, x \[Element] \ Reals && y \[Element] \ Reals]\)], "Input",
  CellLabel->"In[87]:=",
  FontFamily->"Times"],

Cell["Therefore we may define", "Text"],

Cell[BoxData[
    \(pppts[x_, 
        y_]\  := {{1, 
          0, \(\(-1\) + x\^2 + y\^2\)\/\(x\^2 + \((\(-1\) + y)\)\^2\)}, {0, 
          1, 0}, {\(\(-1\) + x\^2 + y\^2\)\/\(x\^2 + \((\(-1\) + y)\)\^2\), 
          0, \(x\^2 + \((1 + y)\)\^2\)\/\(x\^2 + \((\(-1\) + y)\)\^2\)}}\)], \
"Input",
  CellLabel->"In[41]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(pppts[x, y] // MatrixForm\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times"],

Cell["Our first example corresponds to", "Text"],

Cell[BoxData[
    \(pppts[0, \ \(-1\)]\)], "Input",
  CellLabel->"In[89]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The eigenvalue 1", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(pppts[x, y]\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times"],

Cell["\<\
Thus, {0,1,0} is eigenvector with eigenvalue 1, for all values of x,y:\
\>", "Text"],

Cell[BoxData[
    \(% . {0, 1, 0}\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"],

Cell["\<\
The corresponding Sphere is obtained by going back to the pseudo-euclidean \
5-space and applying euklidsphereplot3D:\
\>", "Text"],

Cell[BoxData[
    \(tpm\  = \ Transpose[vspacepp[{\(-1\), 0, 0}, \ {1, 0, 0}]]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tpm // MatrixForm\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tpm . {0, 1, 0}\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times"],

Cell["\<\
Thus, the eigenvector to the eigenvalue 1 defines the sphere which contains \
the four points:\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[%]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The other eigenvalues", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Det[pppts[x, y]]]\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times"],

Cell["In the general case, the eigenvalues are", "Text"],

Cell[BoxData[
    \(Eigenvalues[pppts[x, y]]\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[98]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fev1[x_, 
        y_] := \((1 + x^2 + y^2 - 
            Sqrt[x^4 + 
                2*x^2*\((\(-1\) + y^2)\) + \((1 + 
                      y^2)\)^2])\)/\((x^2 + \((\(-1\) + y)\)^2)\)\)], "Input",\

  CellLabel->"In[99]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fev2[x_, 
        y_] := \((1 + x^2 + y^2 + 
            Sqrt[x^4 + 
                2*x^2*\((\(-1\) + y^2)\) + \((1 + 
                      y^2)\)^2])\)/\((x^2 + \((\(-1\) + y)\)^2)\)\)], "Input",\

  CellLabel->"In[100]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(Plot3D[fev1[x, y], \ {x, \(-2\), 2}, {y, \(-2\), 2}, 
      PlotPoints\  \[Rule] \ 80, 
      PlotRange\  \[Rule] \ All]\)\(\ \)\)\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(Plot3D[fev1[x, y], \ {x, \(- .2\),  .2}, {y,  .8, 1.2}, 
      PlotPoints\  \[Rule] \ 80, \ 
      PlotRange\  \[Rule] All]\)\(\ \)\)\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[\((1 + x^2 + y^2)\)^2 - \((x^4 + 
            2*x^2*\((\(-1\) + y^2)\) + \((1 + y^2)\)^2)\)]\)], "Input",
  CellLabel->"In[103]:=",
  FontFamily->"Times"],

Cell["\<\
The eigenvalue fev1[x,y] has a singularity at the point (0,1); at this point \
the second 0-sphere ((0,1), (x, y)) degenerates to a point, thus, the \
invariants are undefined. \
\>", "Text"],

Cell[BoxData[
    \(fev1[0, y]\)], "Input",
  CellLabel->"In[104]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[fev1[0, y], \ {y, \ \(-2\), 2}]\)], "Input",
  CellLabel->"In[105]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fev1[0, 1.0000001]\)], "Input",
  CellLabel->"In[106]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fev1[0, 1. ]\)], "Input",
  CellLabel->"In[107]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(fev1[0,  .999999]\)], "Input",
  CellLabel->"In[108]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(Plot3D[fev2[x, y], \ {x, \(-2\), 2}, {y, \(-2\), 2}, 
      PlotPoints\  \[Rule] \ 80, 
      PlotRange\  \[Rule] \ {0.5, 5}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[109]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(Plot3D[fev2[x, y] - fev1[x, y], \ {x, \(-2\), 2}, {y, \(-2\), 2}, 
      PlotPoints\  \[Rule] \ 80, 
      PlotRange\  \[Rule] \ {0, 3}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(\(Plot3D[fev2[x, y] + fev1[x, y], \ {x, \(-2\), 2}, {y, \(-2\), 2}, 
      PlotPoints\  \[Rule] \ 80, 
      PlotRange\  \[Rule] \ {0, 3}]\)\(\ \)\)\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigensystem[pppts[x, y]]\)], "Input",
  CellLabel->"In[112]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times"],

Cell["The matrix of the eigenvectors is", "Text"],

Cell[BoxData[
    \(evmatr[x_, y_]\  = \ %[\([2]\)]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[\(evmatr[x, y]\)[\([2]\)] . \(evmatr[x, 
            y]\)[\([3]\)]]\)], "Input",
  CellLabel->"In[115]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["The eigenspheres", "Subsubsection",
  FontFamily->"Times"],

Cell["Again we may define the corresponding eigenspheres:", "Text"],

Cell[BoxData[
    \(tpm // MatrixForm\)], "Input",
  CellLabel->"In[117]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(tpm . \(evmatr[x, y]\)[\([2]\)]\)], "Input",
  CellLabel->"In[118]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigensphere2[x_, y_] := \ tpm . \(evmatr[x, y]\)[\([2]\)]\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigensphere3[x_, y_] := \ tpm . \(evmatr[x, y]\)[\([3]\)]\)], "Input",
  CellLabel->"In[120]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[pssp[eigensphere2[x, y], eigensphere3[x, y]]]\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[pssp[eigensphere2[x, y], eigensphere2[x, y]]]\)], "Input",
  CellLabel->"In[122]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?euklidsphereplot3D\)\)], "Input",
  CellLabel->"In[123]:=",
  FontFamily->"Times"],

Cell["For any values of x, y we obtain two orthogonal spheres:", "Text"],

Cell[BoxData[{
    \(a1 = Random[]; \ a2 = Random[]; 
    rsph1\  = 
      euklidsphereplot3D[eigensphere2[a1, a2]];\), "\[IndentingNewLine]", 
    \(\(rsph2\  = 
        euklidsphereplot3D[
          eigensphere3[a1, a2]];\)\), "\[IndentingNewLine]", 
    \(Show[{rsph1, rsph2}]\)}], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[%]\)], "Input",
  CellLabel->"In[110]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[a1, a2]\)], "Input",
  CellLabel->"In[127]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.3 Four points on the standard unit circle", "Subsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[pppts[Cos[t], \ Sin[t]]]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times"],

Cell["Obviously, the eigenvalues are", "Text"],

Cell[BoxData[
    \(Eigenvalues[%]\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv1[t_]\  := \ {1, 1, \((1 + Sin[t])\)/\((1 - Sin[t])\)}\)], "Input",\

  CellLabel->"In[130]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[Log[\((1 + Sin[t])\)/\((1 - Sin[t])\)], {t, 0, Pi}, 
      PlotRange\  \[Rule] {0, 13}]\)], "Input",
  CellLabel->"In[131]:=",
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["WARNING!", "Subsubsection",
  FontFamily->"Times"],

Cell[TextData[{
  " Starting from the unsimplified matrix ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " may calculate wrong eigenvalues:"
}], "Text"],

Cell[BoxData[
    \(Eigenvalues[pppts[Cos[t], \ Sin[t]]]\)], "Input",
  CellLabel->"In[132]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[%, \ t \[Element] \ Reals]\)], "Input",
  CellLabel->"In[133]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv2[
        t_]\  := \ {1, \((\(-1\) + Abs[Sin[t]])\)/\((\(-1\) + 
              Sin[t])\), \((1 + Abs[Sin[t]])\)/\((1 - Sin[t])\)}\)], "Input",
  CellLabel->"In[134]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv2[\(-Pi\)/2]\)], "Input",
  CellLabel->"In[135]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv1[\(-Pi\)/2]\)], "Input",
  CellLabel->"In[136]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[\(eigenv2[t]\)[\([2]\)]\  - \(eigenv2[t]\)[\([3]\)], \ {t, 0, \ 
        Pi/3}]\)], "Input",
  CellLabel->"In[137]:=",
  FontFamily->"Times"],

Cell["\<\
Obviously, the calculation of the eigenvalues of the unsimplified matrix \
leads to an incorrect result: we  get three distinct eigenvalues for general \
t. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Continuation", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
For t = 0, Pi all the eigenvalues are 1 since the point pairs have a common \
point:\
\>", "Text"],

Cell[BoxData[
    \(eigenv1[Pi]\)], "Input",
  CellLabel->"In[138]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(eigenv1[0]\)], "Input",
  CellLabel->"In[139]:=",
  FontFamily->"Times"],

Cell["\<\
Since for t = Pi/2 the second point pair degenerates to one point, we here \
get a singularity:\
\>", "Text"],

Cell[BoxData[
    \(eigenv1[Pi/2]\)], "Input",
  CellLabel->"In[140]:=",
  FontFamily->"Times"],

Cell["For t = 3Pi/2 we have orthogonal 0-spheres:", "Text"],

Cell[BoxData[
    \(eigenv1[3  Pi/2]\)], "Input",
  CellLabel->"In[141]:=",
  FontFamily->"Times"],

Cell["\<\
It follows: for all values of t the multiplicity of the eigenvalue 1 is at \
least 2.  This is due to the fact that the points are not in generl position: \
they belong to a circle.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The orthogonal case", "Subsubsection",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigensystem[pppts[0, \(-1\)]]\)], "Input",
  CellLabel->"In[142]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Eigenvectors[pppts[0, \(-1\)]]\)], "Input",
  CellLabel->"In[143]:=",
  FontFamily->"Times"],

Cell["The corresponding eigenspheres are", "Text"],

Cell[BoxData[
    \(bvv\  = \ vspacepp[{\(-1\), 0, 0}, \ {1, 0, 0}]\)], "Input",
  CellLabel->"In[144]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[ev1, ev2, ev3]\)], "Input",
  CellLabel->"In[145]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ev1\  = \ Transpose[bvv] . {0, 0, 1}\)], "Input",
  CellLabel->"In[146]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ev2\  = \ Transpose[bvv] . {0, 1, 0}\)], "Input",
  CellLabel->"In[147]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ev3\  = \ Transpose[bvv] . {1, 0, 0}\)], "Input",
  CellLabel->"In[148]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pts1\  = \ {Point[{1, 0, 0}], Point[{\(-1\), 0, 0}]}\)], "Input",
  CellLabel->"In[149]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pts2\  = \ {Point[{0, \(-1\), 0}], Point[{0, 1, 0}]}\)], "Input",
  CellLabel->"In[150]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[
      Graphics3D[{{RGBColor[1, 0, 0], PointSize[0.03], 
            pts1}, {RGBColor[0, 1, 0], PointSize[0.06], pts2}}]]\)], "Input",
  CellLabel->"In[151]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(grepts\  = \ %\)], "Input",
  CellLabel->"In[152]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \({euklidsphereplot3D[ev1], euklidsphereplot3D[ev2], 
      euklidsphereplot3D[ev3]}\)], "Input",
  CellLabel->"In[153]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[%]\)], "Input",
  CellLabel->"In[154]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gresph\  = \ %\)], "Input",
  CellLabel->"In[155]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ParametricPlot3D[{Cos[t], \ Sin[t], 0}, {t, 0, 2  Pi}]\)], "Input",
  CellLabel->"In[156]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gcir\  = \ %\)], "Input",
  CellLabel->"In[157]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Show[{grepts, gresph, gcir}]\)], "Input",
  CellLabel->"In[158]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gre1\  = \ %\)], "Input",
  CellLabel->"In[159]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[gre1, MVPointSphereSize \[Rule] 1.2, 
      MVLineTubeSize\  -> \ 0.01]\)], "Input",
  CellLabel->"In[160]:=",
  FontFamily->"Times"],

Cell["\<\
Remark. The eigenvalue 1 has multiplicity 2. Therefore any vector pair\
\>", "Text"],

Cell[BoxData[
    \(evv2[t_] := \ ev2*Cos[t]\  + \ ev3*Sin[t]\)], "Input",
  CellLabel->"In[161]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(evv3[t_] := \ \(-ev2\)*Sin[t]\  + \ ev3*Cos[t]\)], "Input",
  CellLabel->"In[162]:=",
  FontFamily->"Times"],

Cell["\<\
is an orthonormal basis of the corresponding eigensphere plane. We obtain a \
bundle of the corresponding spheres:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      euklidsphereplot3D[evv2[Pi*\((0.5 + j/10)\)]], {j, \(-2\), 
        2}]\)], "Input",
  CellLabel->"In[163]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(bdl2\  = \ %\)], "Input",
  CellLabel->"In[164]:=",
  FontFamily->"Times"],

Cell["\<\
that is the bundle of the spheres through the circle containing the four \
points. The sphere belonging to the eigenvalue 0 is the x,z-plane:\
\>", "Text"],

Cell[BoxData[
    \(euklidsphereplot3D[ev1, \(-2\), 2, \(-2\), 2]\)], "Input",
  CellLabel->"In[165]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(sph1\  = \ %\)], "Input",
  CellLabel->"In[166]:=",
  FontFamily->"Times"],

Cell["it intersects orthogonally all the spheres of the bundle.", "Text"],

Cell[BoxData[
    \(Show[{grepts, gcir, bdl2, sph1}]\)], "Input",
  CellLabel->"In[167]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gre2\  = \ %\)], "Input",
  CellLabel->"In[168]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[gre2, MVPointSphereSize \[Rule] 1.5, 
      MVLineTubeSize\  -> \ 0.01]\)], "Input",
  CellLabel->"In[160]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "6 ",
  StyleBox["Geodesics in the space of 0-spheres",
    FontFamily->"Times New Roman"]
}], "Section",
  Evaluatable->False,
  FontFamily->"Times"],

Cell[CellGroupData[{

Cell["6.1 Introduction", "Subsection",
  FontFamily->"Times"],

Cell["\<\
A 2-point curve is a curve in the 6-dimensional space of all 0-spheres. This \
space is pseudo-Riemannian symmetric of rank two. The geodesics of the space \
are orbits of certain 1-parameter subgroups of the M\[ODoubleDot]bius group.  \
 As in all reductive spaces, the geodesics through an element C are the \
orbits of certain  one-parameter subgroups exp(At)pp, t \[Element] Reals,  of \
the M\[ODoubleDot]bius group, where in our case pp is defined to be the point \
pair    \
\>", "Text"],

Cell[BoxData[
    \({stepro[stb[4]\  - \ stb[5]], stepro[stb[4]\  + \ stb[5]]}\)], "Input",
  CellLabel->"In[45]:=",
  FontFamily->"Times"],

Cell["\<\
 A denotes an element of the orthogonal complement of the isotropy algebra of \
pp in the pseudo-orthogonal Lie algebra o(4,1); here orthogonality is defined \
by the Killing form  of the Lie algebra o(4,1). It would be interesting to \
investigate the relation between the pseudo-Riemannian geometry of the \
0-sphere space and the point submanifolds more basically. But this may be the \
subject of another notebook. We emphasize that we do not give here a \
classification of all the geodesics with respect to the M\[ODoubleDot]bius \
group. We only treat three simple cases of geodesics lying in a 2-sphere.\
\>", "Text"],

Cell["\<\
For the Killing form and some other constructs we import the package \
\>", "Text"],

Cell[BoxData[
    \(<< liealg.m\)], "Input",
  CellLabel->"In[46]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "This package is an shortened version of the package liealg.m contained in  \
",
  StyleBox["MathSource",
    FontSlant->"Italic"],
  ", \"Lie Algebras\" ",
  ButtonBox["[7]",
    ButtonData:>"S5",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell["The isotropy algebra and its orthogonal complement", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
A general square matrix of order n = dim  with coefficients a[i,j] is\
\>", "Text"],

Cell[BoxData[
    \(matrix[a_, \ n_:  dim]\  := \ 
      Table[a[i, j], {i, n}, \ {j, n}]\)], "Input",
  CellLabel->"In[16]:=",
  Evaluatable->False,
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(matrix[a] // MatrixForm\)], "Input",
  CellLabel->"In[48]:=",
  FontFamily->"Times"],

Cell["In particular, we have the nullmatrix", "Text"],

Cell[BoxData[
    \(nullmatrix[3] // MatrixForm\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell["\<\
The pseudo-orthogonal Lie algebra for dim = 5 and ind = 1 is the set of all \
matrices which fulfil the condition\
\>", "Text"],

Cell[BoxData[
    \(MatrixForm[matrix[a] + \ dual[Transpose[dual[matrix[a]]]]] == \ 
      MatrixForm[nullmatrix[5]]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell["\<\
From this equation one sees that the Lie algebra has dimension 10 and \
consists of all matrices with the shape\
\>", "Text"],

Cell[BoxData[
    \(a[i_, j_]\  := \ 0 /; i == j\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(a[j_, i_]\  := \ \(-a[i, j]\) /; \((i < j\  && \ j < dim)\)\)], "Input",\

  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(a[j_, i_]\  := \ a[i, j] /; \((i < j\  && \ j == dim)\)\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MatrixForm[matrix[a]]\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell["\<\
 The isotropy algebra of the point pair pp = {o, \[Proportional]) is the \
four-dimensional Lie subalgebra of all matrices matrix[b] leaving the \
subspace spanned by {stb[4], stb[5]} fixed:\
\>", "Text"],

Cell[BoxData[
    \(stepro[\((stb[4] + stb[5])\)]\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(stepro[\((stb[4] - stb[5])\)]\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(b[i_, j_]\  := \ 
      0 /; \((i == 
              j || \((i > 3 && j < 4)\) || \((i < 4 && j > 3)\))\)\)], "Input",\

  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(b[j_, 
        i_]\  := \ \(-b[i, j]\) /; \((i < j\  && \ j < dim - 1)\)\)], "Input",\

  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(b[j_, i_]\  := \ b[i, j] /; \((i == j\  - 1 && \ j == dim)\)\)], "Input",\

  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MatrixForm[matrix[b]]\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell["\<\
Its orthogonal complement wit respect to the Killing form is the \
6-dimensional subspace of all matrices matrix[c], where the complementary set \
of coefficients is free, and the coefficients appearing in matrix[b] \
vanish:\
\>", "Text"],

Cell[BoxData[
    \(c[i_, j_]\  := \ 
      0 /; \((\((i < 4 && j < 4)\) || \((i > 3 && j > 3)\))\)\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(c[j_, i_]\  := \ \(-c[i, j]\) /; \((i < j\  && \ j < dim)\)\)], "Input",\

  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(c[j_, i_]\  := \ c[i, j] /; \((i < j\  - 1 && \ j == dim)\)\)], "Input",\

  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MatrixForm[matrix[c]]\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell["\<\
The Killing form restricted to the subspace of these matrices is \
\>", "Text"],

Cell[BoxData[
    \(psokilling[matrix[c], matrix[c]]\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell["\<\
Thus it is a 6-dimensional pseudo-euclidean vector space of index three. That \
this space is the orthogonal complement of the isotropy algebra follows \
easely; indeed:\
\>", "Text"],

Cell[BoxData[
    \(psokilling[matrix[c], matrix[b]]\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell["\<\
Here is the Killing form of an arbitrary element of the pseudo-orthogonal Lie \
algebra o(4,1):\
\>", "Text"],

Cell[BoxData[
    \(psokilling[matrix[a], matrix[a]]\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["6.2 Spacelike geodesics", "Subsection",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
The following matrix function defines the 1-parameter subgroup exp[Uh*t], \
where Uh is an element of the Lie algebra o(4,1) orthogonal to the isotropy \
algebra of pp and spacelike with respect to the Killing form of o(4,1) :\
\>", "Text"],

Cell[BoxData[
    \(Uh\  = \ {{0, 0, 0, 0, 1}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 
          0, 0}, {1, 0, 0, 0, 0}}\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Uh // MatrixForm\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(psokilling[Uh, Uh]\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(psokilling[Uh, \ matrix[b]]\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gUh[t_]\ \  := \ MatrixExp[Uh\ t]\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MatrixForm[gUh[t]]\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(stepro[\((stb[4] - stb[5])\)]\)], "Input",
  CellLabel->"In[75]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vh1[t_] := \ Evaluate[gUh[t] . \((stb[4] - stb[5])\)]\)], "Input",
  CellLabel->"In[76]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vh1[t]\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[79]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(x1[t_]\  := \ stepro[vh1[t]]\)], "Input",
  CellLabel->"In[80]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(x1[t]\)], "Input",
  CellLabel->"In[81]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(stepro[\((stb[4] + stb[5])\)]\)], "Input",
  CellLabel->"In[82]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(vh2[t_] := \ Evaluate[gUh[t] . \((stb[4] + stb[5])\)]\)], "Input",
  CellLabel->"In[83]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(x2[t_]\  := \ stepro[vh2[t]]\)], "Input",
  CellLabel->"In[84]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(x2[t]\)], "Input",
  CellLabel->"In[85]:=",
  FontFamily->"Times"],

Cell["\<\
Both points remain on the x-axis; the coordinate difference is\
\>", "Text"],

Cell[BoxData[
    \(diffx[t_]\  := Together[\((x2[t]\  - \ x1[t])\)[\([1]\)]]\)], "Input",
  CellLabel->"In[86]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(diffx[t]\)], "Input",
  CellLabel->"In[87]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[\(x1[t]\)[\([1]\)], \ {t, 0, 10}, 
      PlotRange\  \[Rule] \ All]\)], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[\(x2[t]\)[\([1]\)], \ {t, 0, 10}]\)], "Input",
  CellLabel->"In[89]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[\(x2[t]\)[\([1]\)], \ {t, 1, 5}]\)], "Input",
  CellLabel->"In[90]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[diffx[t], \ {t,  .5, 5}]\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"],

Cell["\<\
Obviously, for t -> \[Infinity], both points have the limit (1,0,0).\
\>", "Text"],

Cell[BoxData[
    \(invstepro[{1, 0, 0}]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gUh[t] . %\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(stepro[%]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times"],

Cell["Thus, {1, 0, 0} is a fixed point of this transformation.", "Text"],

Cell[BoxData[
    \(Clear[x]\)], "Input",
  CellLabel->"In[95]:=",
  FontFamily->"Times"],

Cell["\<\
The only fixed points on the x-axis are {1,0,0}, {-1,0,0}; here are the \
isotropic vectors corresponding to points of the x-axis:\
\>", "Text"],

Cell[BoxData[
    \(invstepro[{x, 0, 0}]\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times"],

Cell["The fixed points are the solutions of", "Text"],

Cell[BoxData[
    \(Solve[
      Uh . {\(2\ x\)\/\(1 + x\^2\), 0, 0, \(\(-1\) + x\^2\)\/\(1 + x\^2\), 
            1} \[Equal] \ 
        k {\(2\ x\)\/\(1 + x\^2\), 0, 0, \(\(-1\) + x\^2\)\/\(1 + x\^2\), 
            1}, {x, k}]\)], "Input",
  CellLabel->"In[97]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Uh . {\(2\ x\)\/\(1 + x\^2\), 0, 0, \(\(-1\) + x\^2\)\/\(1 + x\^2\), 
        1}\)], "Input",
  CellLabel->"In[98]:=",
  FontFamily->"Times"],

Cell[TextData[{
  "Indeed, if we consider the action of the subgroup gUh[t] on the M\
\[ODoubleDot]bius space ",
  Cell[BoxData[
      \(TraditionalForm\`S\^3\)]],
  ", these are the only fixed points of the action:"
}], "Text"],

Cell[BoxData[
    \(invstepro[{x, y, z}]\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(Solve[
      Uh . {\(2\ x\)\/\(1 + x\^2 + y\^2 + z\^2\), \(2\ y\)\/\(1 + x\^2 + y\^2 \
+ z\^2\), \(2\ z\)\/\(1 + x\^2 + y\^2 + z\^2\), \(\(-1\) + x\^2 + y\^2 + z\^2\
\)\/\(1 + x\^2 + y\^2 + z\^2\), 1} \[Equal] \ 
        k*{\(2\ x\)\/\(1 + x\^2 + y\^2 + z\^2\), \(2\ y\)\/\(1 + x\^2 + y\^2 \
+ z\^2\), \(2\ z\)\/\(1 + x\^2 + y\^2 + z\^2\), \(\(-1\) + x\^2 + y\^2 + z\^2\
\)\/\(1 + x\^2 + y\^2 + z\^2\), 1}, {x, y, z, k}]\)], "Input",
  CellLabel->"In[116]:="],

Cell["We have the two solutions", "Text"],

Cell[BoxData[
    \(Uh . {1, 0, 0, 0, 1}\)], "Input",
  CellLabel->"In[99]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Uh . {\(-1\), 0, 0, 0, 1}\)], "Input",
  CellLabel->"In[100]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(stepro[{1, 0, 0, 0, 1}]\)], "Input",
  CellLabel->"In[101]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(stepro[{\(-1\), 0, 0, 0, 1}]\)], "Input",
  CellLabel->"In[102]:=",
  FontFamily->"Times"],

Cell["\<\
We are going now to calculate the M\[ODoubleDot]bius invariants of two point \
pairs belonging to the orbit:\
\>", "Text"],

Cell[BoxData[
    \(\(?ppptspp\)\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(\(?x1\)\)], "Input",
  CellLabel->"In[105]:="],

Cell[BoxData[
    \(x1[t]\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \(x2[s]\)], "Input",
  CellLabel->"In[107]:="],

Cell[BoxData[
    \(spacelike[s_, t_] := ppptspp[{x1[s], x2[s]}, {x1[t], x2[t]}]\)], "Input",\

  CellLabel->"In[108]:="],

Cell[BoxData[
    \(spacelike[s, t]\)], "Input",
  CellLabel->"In[109]:="],

Cell[BoxData[
    \(FullSimplify[%, \ s > 0 && t > 0]\)], "Input",
  CellLabel->"In[110]:="],

Cell[TextData[{
  "The maximal eigenvalue is grater than 1, therefore the point pairs do not \
separate each other, see ",
  ButtonBox["example 3.2.1",
    ButtonData:>"ex3.2_1",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[BoxData[
    \(rk[x1[s], x2[s], x1[t], x2[t]]\)], "Input",
  CellLabel->"In[117]:="],

Cell[BoxData[
    \(rk[x1[s], x2[s], x1[s], x2[s]]\)], "Input",
  CellLabel->"In[118]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["6.3 Timelike geodesics", "Subsection",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
The following matrix function defines the 1-parameter subgroup exp[Ue*t], \
where Ue is an element of the Lie algebra o(n,1) orthogonal to the isotropy \
algebra of pp and timelike with respect to the Killing form of o(n,1):\
\>", "Text"],

Cell[BoxData[
    \(Ue\  = \ {{0, 0, 0, 1, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {\(-1\), 
          0, 0, 0, 0}, {0, 0, 0, 0, 0}}\)], "Input",
  CellLabel->"In[111]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[112]:="],

Cell[BoxData[
    \(psokilling[Ue, Ue]\)], "Input",
  CellLabel->"In[113]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(psokilling[Ue, \ matrix[b]]\)], "Input",
  CellLabel->"In[114]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gUe[t_] := MatrixExp[Ue\ t]\)], "Input",
  CellLabel->"In[119]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gUe[t] // MatrixForm\)], "Input",
  CellLabel->"In[120]:="],

Cell[BoxData[
    \(ve1[t_]\  := \ gUe[t] . \((stb[4] - stb[5])\)\)], "Input",
  CellLabel->"In[121]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ve1[t]\)], "Input",
  CellLabel->"In[122]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[pssp[%, %]]\)], "Input",
  CellLabel->"In[123]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(y1[t_]\  := \ stepro[ve1[t]]\)], "Input",
  CellLabel->"In[124]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ve2[t_]\  := \ gUe[t] . \((stb[4] + stb[5])\)\)], "Input",
  CellLabel->"In[125]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(ve2[t]\)], "Input",
  CellLabel->"In[126]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(y2[t_] := \ stepro[ve2[t]]\)], "Input",
  CellLabel->"In[127]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(y1[t]\)], "Input",
  CellLabel->"In[128]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(y2[t]\)], "Input",
  CellLabel->"In[129]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[\(I\ \((\(-1\) + E\^\(I\ t\))\)\)\/\(1 + E\^\(I\ t\)\), {t, \ 0, 
        10}]\)], "Input",
  CellLabel->"In[130]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[\(I\ \((1 + E\^\(I\ t\))\)\)\/\(\(-1\) + E\^\(I\ t\)\), {t, \ 0, 
        10}]\)], "Input",
  CellLabel->"In[131]:=",
  FontFamily->"Times"],

Cell["\<\
Again we have two points running periodically over the x-axis (i.e. on the \
sphere: rotation on a meridian), with distance\
\>", "Text"],

Cell[BoxData[
    \(distx2[t_]\  := 
      Together[\(I\ \((\(-1\) + E\^\(I\ t\))\)\)\/\(1 + E\^\(I\ t\)\) - \(I\ \
\((1 + E\^\(I\ t\))\)\)\/\(\(-1\) + E\^\(I\ t\)\)]\)], "Input",
  CellLabel->"In[132]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[distx2[t], \ {t, 0, 10}]\)], "Input",
  CellLabel->"In[133]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Plot[distx2[t], \ {t, 4, 5}]\)], "Input",
  CellLabel->"In[134]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Clear[x]\)], "Input",
  CellLabel->"In[135]:=",
  FontFamily->"Times"],

Cell["Obviously, there do not exist fixed points on the x-axis:", "Text"],

Cell[BoxData[
    \(invstepro[{x, 0, 0}]\)], "Input",
  CellLabel->"In[136]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Solve[
      Ue . {\(2\ x\)\/\(1 + x\^2\), 0, 0, \(\(-1\) + x\^2\)\/\(1 + x\^2\), 
            1} \[Equal] \ 
        k {\(2\ x\)\/\(1 + x\^2\), 0, 0, \(\(-1\) + x\^2\)\/\(1 + x\^2\), 
            1}, {x, k}]\)], "Input",
  CellLabel->"In[137]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Ue . {\(2\ x\)\/\(1 + x\^2\), 0, 0, \(\(-1\) + x\^2\)\/\(1 + x\^2\), 
        1}\)], "Input",
  CellLabel->"In[138]:=",
  FontFamily->"Times"],

Cell["\<\
Considered as a transformation group of the M\[ODoubleDot]bius space,the \
fixed points are the points (x,y,z) with x=0 and y^2 + z^2 =1, i.e. the \
standard unit circle in the y,z-plane:\
\>", "Text"],

Cell[BoxData[
    \(Solve[
      Ue . {\(2\ x\)\/\(1 + x\^2 + y\^2 + z\^2\), \(2\ y\)\/\(1 + x\^2 + y\^2 \
+ z\^2\), \(2\ z\)\/\(1 + x\^2 + y\^2 + z\^2\), \(\(-1\) + x\^2 + y\^2 + z\^2\
\)\/\(1 + x\^2 + y\^2 + z\^2\), 1} \[Equal] \ 
        k*{\(2\ x\)\/\(1 + x\^2 + y\^2 + z\^2\), \(2\ y\)\/\(1 + x\^2 + y\^2 \
+ z\^2\), \(2\ z\)\/\(1 + x\^2 + y\^2 + z\^2\), \(\(-1\) + x\^2 + y\^2 + z\^2\
\)\/\(1 + x\^2 + y\^2 + z\^2\), 1}, {x, y, z, k}]\)], "Input",
  CellLabel->"In[139]:="],

Cell["\<\
We are going now to calculate the M\[ODoubleDot]bius invariants of two point \
pairs belonging to the orbit:\
\>", "Text"],

Cell[BoxData[
    \(\(?ppptspp\)\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(\(?y1\)\)], "Input",
  CellLabel->"In[143]:="],

Cell[BoxData[
    \(y1[t]\)], "Input",
  CellLabel->"In[144]:="],

Cell[BoxData[
    \(y2[s]\)], "Input",
  CellLabel->"In[145]:="],

Cell[BoxData[
    \(timelike[s_, t_] := ppptspp[{y1[s], y2[s]}, {y1[t], y2[t]}]\)], "Input",\

  CellLabel->"In[146]:="],

Cell[BoxData[
    \(timelike[s, t]\)], "Input",
  CellLabel->"In[147]:="],

Cell[BoxData[
    \(FullSimplify[%, \ s > 0 && t > 0]\)], "Input",
  CellLabel->"In[148]:="],

Cell[TextData[{
  "The maximal eigenvalue is less than 1, therefore the point pairs  separate \
each other, see ",
  ButtonBox["example 3.2.1",
    ButtonData:>"ex3.2_1",
    ButtonStyle->"Hyperlink"]
}], "Text"],

Cell[BoxData[
    \(rk[y1[s], y2[s], y1[t], y2[t]]\)], "Input",
  CellLabel->"In[149]:="],

Cell[BoxData[
    \(rk[y1[s], y2[s], y1[s], y2[s]]\)], "Input",
  CellLabel->"In[150]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["6.4 Isotropic geodesics", "Subsection",
  Evaluatable->False,
  FontFamily->"Times"],

Cell["\<\
The following matrix function defines the 1-parameter subgroup exp[U*t], \
where U is an element of the Lie algebra o(n,1) orthogonal to the isotropy \
algebra of pp and isotropic with respect to the Killing form of o(n,1) :\
\>", "Text"],

Cell[BoxData[
    \(U\  = {{0, 0, 0, 1, 1}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {\(-1\), 0, 
          0, 0, 0}, {1, 0, 0, 0, 0}}\)], "Input",
  CellLabel->"In[151]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(% // MatrixForm\)], "Input",
  CellLabel->"In[152]:="],

Cell[BoxData[
    \(psokilling[U, \ U]\)], "Input",
  CellLabel->"In[153]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(psokilling[U, matrix[b]]\)], "Input",
  CellLabel->"In[154]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isotropugr[t_] := \ MatrixExp[U*t]\)], "Input",
  CellLabel->"In[155]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isotropugr[t] // MatrixForm\)], "Input",
  CellLabel->"In[156]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(gh[t_] := \ isotropugr[t]\)], "Input",
  CellLabel->"In[157]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Simplify[
      Table[pssp[\(gh[t]\)[\([i]\)], \ \(gh[t]\)[\([j]\)]], {i, 5}, {j, 
          5}]]\)], "Input",
  CellLabel->"In[158]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v1c[t_]\  := \ gh[t] . \((stb[4] - stb[5])\)\)], "Input",
  CellLabel->"In[159]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v2c[t_]\  := \ gh[t] . \((stb[4]\  + \ stb[5])\)\)], "Input",
  CellLabel->"In[160]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v1c[t]\)], "Input",
  CellLabel->"In[161]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(v2c[t]\)], "Input",
  CellLabel->"In[162]:=",
  FontFamily->"Times"],

Cell["The origin is a fixed point:", "Text"],

Cell[BoxData[
    \(z1[t_]\  := stepro[v1c[t]]\)], "Input",
  CellLabel->"In[164]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(z1[t]\)], "Input",
  CellLabel->"In[165]:="],

Cell[BoxData[
    \(z2[t_] := \ stepro[v2c[t]]\)], "Input",
  CellLabel->"In[166]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(z2[t]\)], "Input",
  CellLabel->"In[167]:="],

Cell["\<\
For this geodesic, the origin null[3] remains fixed, and the infinite point \
moves with distance 1/t along the x-axis towards the origin. The origin is \
the only fixed point on the x-axis:\
\>", "Text"],

Cell[BoxData[
    \(Clear[x]\)], "Input",
  CellLabel->"In[168]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(invstepro[{x, 0, 0}]\)], "Input",
  CellLabel->"In[169]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Solve[
      U . {\(2\ x\)\/\(1 + x\^2\), 0, 0, \(\(-1\) + x\^2\)\/\(1 + x\^2\), 
            1} \[Equal] \ 
        k {\(2\ x\)\/\(1 + x\^2\), 0, 0, \(\(-1\) + x\^2\)\/\(1 + x\^2\), 
            1}, {x, k}]\)], "Input",
  CellLabel->"In[170]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(U . {\(2\ x\)\/\(1 + x\^2\), 0, 0, \(\(-1\) + x\^2\)\/\(1 + x\^2\), 
        1}\)], "Input",
  CellLabel->"In[171]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(% /. x \[Rule] \ 0\)], "Input",
  CellLabel->"In[172]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(isotrop[s_, t_] := ppptspp[{z1[s], z2[s]}, {z1[t], z2[t]}]\)], "Input",
  CellLabel->"In[173]:="],

Cell[BoxData[
    \(isotrop[s, t]\)], "Input",
  CellLabel->"In[174]:="],

Cell[BoxData[
    \(FullSimplify[%, \ s > 0 && t > 0]\)], "Input",
  CellLabel->"In[175]:="],

Cell["\<\
Two such pairs of the orbit are M\[ODoubleDot]bius equivalent, since the \
origin is their common point (s\[NotEqual]t):\
\>", "Text"],

Cell[BoxData[
    \({{z1[s], z2[s]}, {z1[t], z2[t]}}\)], "Input",
  CellLabel->"In[178]:="],

Cell[BoxData[
    \(rk[z1[s], z2[s], z1[t], z2[t]]\)], "Input",
  CellLabel->"In[176]:="],

Cell[BoxData[
    \(rk[z1[s], z2[s], z1[s], z2[s]]\)], "Input",
  CellLabel->"In[177]:="],

Cell["\<\
Considered as a transformation group of the M\[ODoubleDot]bius space, the \
only real fixed point is the origin:\
\>", "Text"],

Cell[BoxData[
    \(Solve[
      U . {\(2\ x\)\/\(1 + x\^2 + y\^2 + z\^2\), \(2\ y\)\/\(1 + x\^2 + y\^2 \
+ z\^2\), \(2\ z\)\/\(1 + x\^2 + y\^2 + z\^2\), \(\(-1\) + x\^2 + y\^2 + z\^2\
\)\/\(1 + x\^2 + y\^2 + z\^2\), 1} \[Equal] \ 
        k*{\(2\ x\)\/\(1 + x\^2 + y\^2 + z\^2\), \(2\ y\)\/\(1 + x\^2 + y\^2 \
+ z\^2\), \(2\ z\)\/\(1 + x\^2 + y\^2 + z\^2\), \(\(-1\) + x\^2 + y\^2 + z\^2\
\)\/\(1 + x\^2 + y\^2 + z\^2\), 1}, {x, y, z, k}]\)], "Input",
  CellLabel->"In[179]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7 ThreeScript, MathGL3d", "Section",
  FontFamily->"Times",
  CellTags->"MathGL"],

Cell[TextData[{
  "If you want to generate *.ts files for animations outside of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", activate the next section. To use the animation program MathGL3d in this \
notebook, read and  activate section 7.2."
}], "Text"],

Cell[CellGroupData[{

Cell["7.1 Threescript ", "Subsection",
  FontFamily->"Times"],

Cell["\<\
 The ThreeScript commands generate *.ts files appropriate  for certain \
animation programs. The freeware program  MathGL3d  created by Jens-Peer \
Kuska (for Windows95, Linux and other platforms) can be downloaded from \
[2].\
\>", "Text",
  Evaluatable->False],

Cell["\<\
Under Windows the commercial 3D-Animation programs MathLive and \
DynamicVisualizer are available. To produce .ts-files one \
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(Needs["\<Graphics`ThreeScript`\>"]\)], "Input",
  CellLabel->"In[42]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?ThreeScript\)\)], "Input",
  CellLabel->"In[40]:=",
  FontFamily->"Times"],

Cell["\<\
The standard extension of these files is ts: \"filename.ts\" or \
\"Path/filename.ts\", e.g.\
\>", "Text",
  Evaluatable->False],

Cell[BoxData[
    \(ThreeScript["\<isofam.ts\>", \ isofam]\)], "Input",
  CellLabel->"In[33]:=",
  Evaluatable->False,
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.2 MathGL3d", "Subsection",
  FontFamily->"Times"],

Cell[TextData[{
  "The free animation program MathGL3d by Jens-Peer Kuska [2] can be used \
from a command line and within a ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session. A new version of this program is in preparation. Jens-Peer Kuska \
has sent me a new startup file OpenGLViewer.m, and friendly permitted to add \
it to the item \"Spheres\". Replace the old file OpenGLViewer.m by this new \
OpenGLViewer.m. If you did this, changes of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ParametricPlot3D, especially the sometimes disturbing generating of \
MeshGraphics3D objects, will not take place.\nIf not yet done, establish now \
the link to the current ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " session with the command:"
}], "Text"],

Cell[BoxData[
    \(Get["\<MathGL3d`OpenGLViewer`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  FontFamily->"Times"],

Cell["\<\
If you called anything of MathGL3D in absence of the link you must remove the \
called functions from the global context before establishing the link \
correctly:\
\>", "Text"],

Cell[BoxData[
    \(Remove[MVShow3D, MVPointSphereSize, MVLineTubeSize]\)], "Input",
  CellLabel->"In[51]:=",
  FontFamily->"Times"],

Cell["If you want to close the link, enter", "Text"],

Cell["MVClose[]", "Text",
  CellLabel->"In[44]:="],

Cell["\<\
The following command clears the Viewer window; this and other MathGL3d \
commands you may enter also with  palettes.\
\>", "Text"],

Cell[BoxData[{
    \(\(\(MVClear[];\)\(\[IndentingNewLine]\)
    \)\), "\[IndentingNewLine]", 
    \(MVShow3D[\[Placeholder], MVPolygonShading \[Rule] MVSmooth, 
      MVGrayBackground \[Rule] False, MVTexture \[Rule] None, 
      MVTextureMapType \[Rule] MVMeshUVMapping, 
      MVScaleTexture \[Rule] {1, 1}, 
      MVTranslateTextureTarget \[Rule] Automatic, 
      MVRotateTextureTarget \[Rule] Automatic, 
      MVScaleTextureTarget \[Rule] Automatic]\)}], "Input",
  CellLabel->"In[88]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[gre1\[IndentingNewLine], MVPointSphereSize \[Rule] 0.8, \ 
      MVLineTubeSize\  -> \ 0.01]\)], "Input",
  CellLabel->"In[96]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[tgr1, \ MVLineTubeSize\  -> \ 0.03]\)], "Input",
  CellLabel->"In[91]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[tgr3, MVPointSphereSize \[Rule] 2.8]\)], "Input",
  CellLabel->"In[92]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVShow3D[spsf6]\)], "Input",
  CellLabel->"In[93]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(Options[MVShow3D]\)], "Input",
  CellLabel->"In[94]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(MVClose[]\)], "Input",
  CellLabel->"In[180]:=",
  FontFamily->"Times"],

Cell["\<\
Attention! MVClose[] closes the link to MathVGl3d and therefore the viewer \
window, too,  but the  MathVGl3d commands are preserved:\
\>", "Text"],

Cell[BoxData[
    \(?? MVShow3D\)], "Input",
  CellLabel->"In[77]:=",
  FontFamily->"Times"],

Cell["They may not be removed:", "Text"],

Cell[BoxData[
    \(Remove[MVShow3D, MVPointSphereSize, MVLineTubeSize]\)], "Input",
  CellLabel->"In[78]:=",
  FontFamily->"Times"],

Cell["\<\
Solution: Quit the kernel and start again with evaluating the initialization \
cells. In general that must not be done; you may establish the link again by \
the Get command above without trouble.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
[1] Alfred Gray. Modern Differential Geometry of Curves and Surfaces. CRC \
PRESS, 1993 (German translation: Spektrum Akademischer Verlag 1994)\
\>", "Text",
  Evaluatable->False,
  CellTags->"G1"],

Cell["\<\
[2] Jens-Peer Kuska. http://phong.informatik.uni-leipzig.de/ \
~kuska/mview3d.html.\
\>", "Text",
  Evaluatable->False,
  CellTags->"K2"],

Cell["\<\
[3] U. May. Der Raum der Kreise in der Sph\[ADoubleDot]re. Diplomarbeit, \
Humboldt-Universit\[ADoubleDot]t, Berlin, 1993.\
\>", "Text",
  Evaluatable->False,
  CellTags->"M3"],

Cell[TextData[{
  "[4] A. L. Oniscik, R. Sulanke. Projektive und Cayley-Kleinsche Geometrien. \
 2003.  May be downloaded from my ",
  ButtonBox["homepage",
    ButtonData:>"HP",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"O-S"],

Cell["\<\
[5] Sulanke, Rolf. Spheres.  1999.  \
http://mathsource.com/Content/Enhancements/Geometry/0210-092\
\>", "Text",
  CellTags->"S1"],

Cell[TextData[{
  "[6] R. Sulanke. M\[ODoubleDot]bius invariants for pairs (",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\%m\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`S\_2\%l\)]],
  ") of spheres in the M\[ODoubleDot]bius space ",
  Cell[BoxData[
      \(TraditionalForm\`S\^n\)]],
  ". Beitr\[ADoubleDot]ge zur Algebra und Geometrie.41 (2000), No.1, 233-246. \
 Preprint No. 373, SFB 288, Berlin 1999.  \
http://xxx.lanl.gov/abs/math.MG/9902131. "
}], "Text",
  Evaluatable->False,
  CellTags->"S4"],

Cell["\<\
[7] R. Sulanke. Lie Algebras. \
http://www.mathsource.com/cgi-bin/msitem?0210-845\
\>", "Text",
  Evaluatable->False,
  CellTags->"S5"],

Cell[TextData[{
  "[8] Sulanke, R. The Riemannian Sphere. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook riemsph.nb, on the authors ",
  ButtonBox["homepage",
    ButtonData:>"HP",
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->"S8"]
}, Closed]],

Cell[CellGroupData[{

Cell["Author's address", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
Homepage:
http://www-irm.mathematik.hu-berlin.de/~sulanke
e-Mail:\
\>", "Text",
  CellTags->"HP"],

Cell["sulanke@mathematik.hu-berlin.de", "Text"],

Cell["\<\
The author will be very thankful for hints, corrections, comments.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->Automatic,
WindowToolbars->{},
WindowSize->{1016, 668},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->True,
SpellingDictionaries->{"CorrectWords"->{
  "Erhard", "orthonormalization", "semisimple", "Activite", 
    "Orthonormalization", "Cartan", "spacelike", "timelike", "Lorentz", 
    "Inspiron", "symplectic", "nullmatrices", "conformality", "subalgebra", 
    "Jacoby", "subspheres", "mspheres", "mcircles", "invsc.", "invsc", 
    "invspp.", "pssp", "stb", "orthonorm", "spt", "mcirc"}},
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> "TutorialBook.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "ex3.2_1"->{
    Cell[90897, 3284, 80, 2, 45, "Subsubsection",
      CellTags->"ex3.2_1"]},
  "prop2"->{
    Cell[113992, 4195, 557, 13, 97, "Text",
      CellTags->"prop2"]},
  "sepprop"->{
    Cell[149769, 5472, 370, 8, 59, "Text",
      CellTags->"sepprop"]},
  "deg"->{
    Cell[163374, 5984, 51, 1, 40, "Text",
      CellTags->"deg"]},
  "asseigsph"->{
    Cell[167442, 6145, 85, 1, 43, "Subsubsection",
      CellTags->"asseigsph"]},
  "MathGL"->{
    Cell[244256, 8870, 87, 2, 73, "Section",
      CellTags->"MathGL"]},
  "G1"->{
    Cell[249282, 9049, 207, 5, 62, "Text",
      Evaluatable->False,
      CellTags->"G1"]},
  "K2"->{
    Cell[249492, 9056, 147, 5, 42, "Text",
      Evaluatable->False,
      CellTags->"K2"]},
  "M3"->{
    Cell[249642, 9063, 186, 5, 42, "Text",
      Evaluatable->False,
      CellTags->"M3"]},
  "O-S"->{
    Cell[249831, 9070, 246, 8, 42, "Text",
      CellTags->"O-S"]},
  "S1"->{
    Cell[250080, 9080, 140, 4, 42, "Text",
      CellTags->"S1"]},
  "S4"->{
    Cell[250223, 9086, 515, 15, 62, "Text",
      Evaluatable->False,
      CellTags->"S4"]},
  "S5"->{
    Cell[250741, 9103, 145, 5, 42, "Text",
      Evaluatable->False,
      CellTags->"S5"]},
  "S8"->{
    Cell[250889, 9110, 261, 9, 42, "Text",
      CellTags->"S8"]},
  "HP"->{
    Cell[251252, 9127, 107, 5, 106, "Text",
      CellTags->"HP"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"ex3.2_1", 252769, 9171},
  {"prop2", 252861, 9174},
  {"sepprop", 252947, 9177},
  {"deg", 253030, 9180},
  {"asseigsph", 253114, 9183},
  {"MathGL", 253210, 9186},
  {"G1", 253293, 9189},
  {"K2", 253396, 9193},
  {"M3", 253499, 9197},
  {"O-S", 253603, 9201},
  {"S1", 253681, 9204},
  {"S4", 253758, 9207},
  {"S5", 253862, 9211},
  {"S8", 253965, 9215},
  {"HP", 254042, 9218}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 189, 7, 73, "Title",
  Evaluatable->False],
Cell[1968, 62, 222, 8, 33, "Subsubtitle",
  Evaluatable->False],
Cell[2193, 72, 125, 4, 39, "Text",
  Evaluatable->False],
Cell[2321, 78, 143, 3, 28, "Text",
  Evaluatable->False],
Cell[2467, 83, 31, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[2523, 87, 115, 4, 32, "Input",
  InitializationCell->True],
Cell[2641, 93, 82, 2, 30, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2760, 100, 78, 2, 37, "Subsubsection"],
Cell[2841, 104, 1837, 39, 232, "Text",
  Evaluatable->False],
Cell[4681, 145, 203, 7, 28, "Text"],
Cell[4887, 154, 179, 6, 28, "Text"],
Cell[5069, 162, 307, 5, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5413, 172, 58, 1, 37, "Subsubsection"],
Cell[5474, 175, 367, 6, 68, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5878, 186, 55, 1, 31, "Subsubsection"],
Cell[5936, 189, 599, 14, 68, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6572, 208, 57, 1, 31, "Subsubsection"],
Cell[6632, 211, 552, 8, 88, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7221, 224, 59, 1, 37, "Subsection"],
Cell[7283, 227, 391, 8, 48, "Text"],
Cell[7677, 237, 197, 5, 32, "Input",
  InitializationCell->True],
Cell[7877, 244, 156, 3, 32, "Text"],
Cell[8036, 249, 56, 0, 28, "Text"],
Cell[8095, 251, 313, 8, 60, "Text"],
Cell[8411, 261, 128, 4, 32, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[8576, 270, 57, 1, 91, "Section"],

Cell[CellGroupData[{
Cell[8658, 275, 106, 2, 43, "Subsection"],
Cell[8767, 279, 162, 3, 28, "Text"],
Cell[8932, 284, 133, 4, 32, "Input",
  InitializationCell->True],
Cell[9068, 290, 449, 8, 68, "Text",
  Evaluatable->False],
Cell[9520, 300, 124, 3, 28, "Text"],
Cell[9647, 305, 176, 5, 32, "Input",
  InitializationCell->True],
Cell[9826, 312, 273, 5, 48, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[10136, 322, 59, 1, 43, "Subsection"],
Cell[10198, 325, 153, 4, 27, "Text",
  Evaluatable->False],
Cell[10354, 331, 95, 3, 32, "Input"],
Cell[10452, 336, 99, 3, 32, "Input"],
Cell[10554, 341, 85, 2, 27, "Text"],
Cell[10642, 345, 87, 3, 32, "Input"],
Cell[10732, 350, 285, 6, 46, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[11042, 360, 66, 1, 36, "Subsubsection"],
Cell[11111, 363, 521, 9, 128, "Input"],
Cell[11635, 374, 57, 0, 27, "Text"],
Cell[11695, 376, 646, 10, 128, "Input"],
Cell[12344, 388, 95, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12476, 396, 68, 1, 36, "Subsubsection"],
Cell[12547, 399, 262, 5, 56, "Input"],
Cell[12812, 406, 57, 0, 27, "Text"],
Cell[12872, 408, 299, 6, 56, "Input"],
Cell[13174, 416, 94, 3, 32, "Input"],
Cell[13271, 421, 91, 3, 32, "Input"],
Cell[13365, 426, 91, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13493, 434, 67, 1, 36, "Subsubsection"],
Cell[13563, 437, 355, 7, 80, "Input"],
Cell[13921, 446, 57, 0, 27, "Text"],
Cell[13981, 448, 400, 7, 104, "Input"],
Cell[14384, 457, 90, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14511, 465, 66, 1, 36, "Subsubsection"],
Cell[14580, 468, 103, 3, 27, "Text"],
Cell[14686, 473, 572, 10, 128, "Input"],
Cell[15261, 485, 57, 0, 27, "Text"],
Cell[15321, 487, 735, 12, 152, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[16093, 504, 67, 1, 36, "Subsubsection"],
Cell[16163, 507, 104, 3, 27, "Text"],
Cell[16270, 512, 114, 3, 32, "Input"],
Cell[16387, 517, 57, 0, 27, "Text"],
Cell[16447, 519, 124, 3, 32, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[16632, 529, 63, 1, 59, "Section"],

Cell[CellGroupData[{
Cell[16720, 534, 32, 0, 36, "Subsubsection"],
Cell[16755, 536, 570, 9, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[17362, 550, 69, 1, 38, "Subsection"],

Cell[CellGroupData[{
Cell[17456, 555, 68, 1, 36, "Subsubsection"],
Cell[17527, 558, 338, 6, 65, "Text"],
Cell[17868, 566, 69, 2, 32, "Input"],
Cell[17940, 570, 78, 2, 32, "Input"],
Cell[18021, 574, 181, 5, 32, "Input",
  Evaluatable->False],
Cell[18205, 581, 140, 3, 27, "Text"],
Cell[18348, 586, 218, 6, 56, "Input"],
Cell[18569, 594, 64, 2, 32, "Input"],
Cell[18636, 598, 108, 3, 32, "Input"],
Cell[18747, 603, 111, 3, 27, "Text"],
Cell[18861, 608, 149, 4, 32, "Input",
  InitializationCell->True],
Cell[19013, 614, 67, 0, 27, "Text"],
Cell[19083, 616, 187, 5, 32, "Input",
  InitializationCell->True],
Cell[19273, 623, 120, 4, 32, "Input",
  InitializationCell->True],
Cell[19396, 629, 1268, 21, 246, "Text"],
Cell[20667, 652, 91, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[20807, 661, 57, 1, 38, "Subsection"],

Cell[CellGroupData[{
Cell[20889, 666, 65, 1, 36, "Subsubsection"],
Cell[20957, 669, 490, 8, 65, "Text"],
Cell[21450, 679, 69, 1, 27, "Text"],
Cell[21522, 682, 273, 7, 27, "Text"],
Cell[21798, 691, 145, 4, 32, "Input"],
Cell[21946, 697, 201, 5, 56, "Input"],
Cell[22150, 704, 88, 3, 32, "Input"],
Cell[22241, 709, 96, 3, 32, "Input"],
Cell[22340, 714, 92, 3, 32, "Input"],
Cell[22435, 719, 172, 6, 27, "Text"],
Cell[22610, 727, 96, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[22743, 735, 61, 1, 30, "Subsubsection"],
Cell[22807, 738, 294, 10, 27, "Text"],
Cell[23104, 750, 95, 1, 27, "Text"],
Cell[23202, 753, 75, 0, 27, "Text"],
Cell[23280, 755, 26, 0, 27, "Text"],
Cell[23309, 757, 106, 3, 32, "Input"],
Cell[23418, 762, 95, 3, 32, "Input"],
Cell[23516, 767, 123, 3, 32, "Input"],
Cell[23642, 772, 96, 3, 32, "Input"],
Cell[23741, 777, 91, 3, 32, "Input"],
Cell[23835, 782, 93, 3, 32, "Input"],
Cell[23931, 787, 93, 3, 32, "Input"],
Cell[24027, 792, 108, 3, 32, "Input"],
Cell[24138, 797, 97, 3, 32, "Input"],
Cell[24238, 802, 26, 0, 27, "Text"],
Cell[24267, 804, 118, 3, 32, "Input"],
Cell[24388, 809, 92, 3, 32, "Input"],
Cell[24483, 814, 136, 3, 32, "Input"],
Cell[24622, 819, 136, 3, 32, "Input"],
Cell[24761, 824, 177, 5, 56, "Input"],
Cell[24941, 831, 88, 3, 32, "Input"],
Cell[25032, 836, 96, 3, 32, "Input"],
Cell[25131, 841, 93, 3, 32, "Input"],
Cell[25227, 846, 97, 3, 32, "Input"],
Cell[25327, 851, 26, 0, 27, "Text"],
Cell[25356, 853, 93, 2, 27, "Text"],
Cell[25452, 857, 119, 3, 32, "Input"],
Cell[25574, 862, 75, 2, 32, "Input"],
Cell[25652, 866, 134, 3, 56, "Input"],
Cell[25789, 871, 92, 2, 27, "Text"],
Cell[25884, 875, 95, 2, 32, "Input"],
Cell[25982, 879, 65, 2, 32, "Input"],
Cell[26050, 883, 130, 3, 27, "Text"],
Cell[26183, 888, 118, 3, 32, "Input"],
Cell[26304, 893, 92, 3, 32, "Input"],
Cell[26399, 898, 139, 3, 27, "Text"],
Cell[26541, 903, 120, 3, 32, "Input"],
Cell[26664, 908, 91, 2, 32, "Input"],
Cell[26758, 912, 58, 0, 27, "Text"],
Cell[26819, 914, 123, 3, 32, "Input"],
Cell[26945, 919, 113, 3, 32, "Input"],
Cell[27061, 924, 138, 3, 27, "Text"],
Cell[27202, 929, 114, 3, 32, "Input"],
Cell[27319, 934, 89, 2, 27, "Text"],
Cell[27411, 938, 106, 2, 32, "Input"],
Cell[27520, 942, 108, 3, 27, "Text"],
Cell[27631, 947, 117, 2, 32, "Input"],
Cell[27751, 951, 73, 0, 27, "Text"],
Cell[27827, 953, 166, 5, 32, "Input"],
Cell[27996, 960, 89, 3, 32, "Input"],
Cell[28088, 965, 97, 3, 32, "Input"],
Cell[28188, 970, 95, 3, 32, "Input"],
Cell[28286, 975, 99, 3, 32, "Input"],
Cell[28388, 980, 52, 0, 27, "Text"],
Cell[28443, 982, 20, 0, 27, "Text"],
Cell[28466, 984, 126, 3, 27, "Text"],
Cell[28595, 989, 78, 2, 32, "Input"],
Cell[28676, 993, 81, 2, 32, "Input"],
Cell[28760, 997, 106, 2, 32, "Input"],
Cell[28869, 1001, 106, 2, 32, "Input"],
Cell[28978, 1005, 657, 10, 103, "Text"],
Cell[29638, 1017, 157, 3, 56, "Input"],
Cell[29798, 1022, 74, 2, 32, "Input"],
Cell[29875, 1026, 114, 2, 32, "Input"],
Cell[29992, 1030, 67, 2, 32, "Input"],
Cell[30062, 1034, 111, 3, 27, "Text"],
Cell[30176, 1039, 70, 2, 32, "Input"],
Cell[30249, 1043, 77, 2, 32, "Input"],
Cell[30329, 1047, 160, 3, 46, "Text"],
Cell[30492, 1052, 93, 2, 32, "Input"],
Cell[30588, 1056, 74, 2, 32, "Input"],
Cell[30665, 1060, 428, 6, 166, "Input"],
Cell[31096, 1068, 115, 2, 32, "Input"],
Cell[31214, 1072, 387, 7, 111, "Input"],
Cell[31604, 1081, 69, 0, 27, "Text"],
Cell[31676, 1083, 179, 4, 33, "Input"],
Cell[31858, 1089, 176, 4, 33, "Input"],
Cell[32037, 1095, 156, 3, 33, "Input"],
Cell[32196, 1100, 136, 3, 33, "Input"],
Cell[32335, 1105, 121, 3, 33, "Input"],
Cell[32459, 1110, 109, 2, 32, "Input"],
Cell[32571, 1114, 155, 3, 27, "Text"],
Cell[32729, 1119, 76, 2, 32, "Input"],
Cell[32808, 1123, 74, 2, 32, "Input"],
Cell[32885, 1127, 624, 11, 122, "Input"],
Cell[33512, 1140, 76, 2, 32, "Input"],
Cell[33591, 1144, 74, 2, 32, "Input"],
Cell[33668, 1148, 463, 8, 117, "Input"],
Cell[34134, 1158, 76, 2, 32, "Input"],
Cell[34213, 1162, 74, 2, 32, "Input"],
Cell[34290, 1166, 555, 10, 122, "Input"],
Cell[34848, 1178, 102, 3, 27, "Text"],
Cell[34953, 1183, 135, 3, 32, "Input"],
Cell[35091, 1188, 82, 2, 32, "Input"],
Cell[35176, 1192, 97, 2, 27, "Text"],
Cell[35276, 1196, 111, 2, 32, "Input"],
Cell[35390, 1200, 74, 2, 32, "Input"],
Cell[35467, 1204, 74, 2, 32, "Input"],
Cell[35544, 1208, 186, 3, 35, "Input"],
Cell[35733, 1213, 298, 5, 46, "Text"],
Cell[36034, 1220, 90, 2, 32, "Input"],
Cell[36127, 1224, 155, 3, 32, "Input"],
Cell[36285, 1229, 72, 0, 27, "Text"],
Cell[36360, 1231, 70, 2, 32, "Input"],
Cell[36433, 1235, 71, 0, 27, "Text"],
Cell[36507, 1237, 166, 3, 56, "Input"],
Cell[36676, 1242, 74, 2, 32, "Input"],
Cell[36753, 1246, 52, 0, 27, "Text"],
Cell[36808, 1248, 238, 5, 56, "Input"],
Cell[37049, 1255, 99, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[37185, 1262, 66, 1, 30, "Subsubsection"],
Cell[37254, 1265, 259, 5, 46, "Text"],
Cell[37516, 1272, 67, 1, 27, "Text"],
Cell[37586, 1275, 98, 1, 27, "Text"],
Cell[37687, 1278, 157, 7, 27, "Text"],
Cell[37847, 1287, 127, 3, 27, "Text"],
Cell[37977, 1292, 182, 5, 56, "Input"],
Cell[38162, 1299, 85, 3, 32, "Input"],
Cell[38250, 1304, 212, 6, 56, "Input"],
Cell[38465, 1312, 88, 3, 32, "Input"],
Cell[38556, 1317, 127, 3, 32, "Input"],
Cell[38686, 1322, 93, 3, 32, "Input"],
Cell[38782, 1327, 130, 3, 32, "Input"],
Cell[38915, 1332, 91, 2, 27, "Text"],
Cell[39009, 1336, 206, 5, 56, "Input"],
Cell[39218, 1343, 85, 3, 32, "Input"],
Cell[39306, 1348, 213, 5, 56, "Input"],
Cell[39522, 1355, 88, 3, 32, "Input"],
Cell[39613, 1360, 95, 3, 32, "Input"],
Cell[39711, 1365, 120, 3, 32, "Input"],
Cell[39834, 1370, 93, 3, 32, "Input"],
Cell[39930, 1375, 101, 3, 32, "Input"],
Cell[40034, 1380, 95, 3, 32, "Input"],
Cell[40132, 1385, 127, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[40296, 1393, 72, 1, 36, "Subsubsection"],
Cell[40371, 1396, 94, 2, 27, "Text"],
Cell[40468, 1400, 111, 3, 32, "Input"],
Cell[40582, 1405, 287, 5, 77, "Text"],
Cell[40872, 1412, 142, 4, 32, "Input"],
Cell[41017, 1418, 181, 5, 56, "Input"],
Cell[41201, 1425, 94, 3, 32, "Input"],
Cell[41298, 1430, 131, 3, 32, "Input"],
Cell[41432, 1435, 88, 3, 32, "Input"],
Cell[41523, 1440, 109, 3, 32, "Input"],
Cell[41635, 1445, 92, 3, 32, "Input"],
Cell[41730, 1450, 128, 3, 32, "Input"],
Cell[41861, 1455, 102, 3, 32, "Input"],
Cell[41966, 1460, 92, 3, 32, "Input"],
Cell[42061, 1465, 261, 5, 46, "Text"],
Cell[42325, 1472, 177, 4, 80, "Input"],
Cell[42505, 1478, 86, 2, 32, "Input"],
Cell[42594, 1482, 82, 2, 32, "Input"],
Cell[42679, 1486, 75, 2, 32, "Input"],
Cell[42757, 1490, 102, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[42896, 1497, 62, 1, 30, "Subsubsection"],
Cell[42961, 1500, 193, 4, 46, "Text"],
Cell[43157, 1506, 107, 3, 32, "Input"],
Cell[43267, 1511, 96, 3, 32, "Input"],
Cell[43366, 1516, 140, 3, 27, "Text"],
Cell[43509, 1521, 142, 4, 32, "Input"],
Cell[43654, 1527, 142, 4, 32, "Input"],
Cell[43799, 1533, 123, 3, 32, "Input"],
Cell[43925, 1538, 92, 3, 32, "Input"],
Cell[44020, 1543, 115, 2, 32, "Input"],
Cell[44138, 1547, 86, 2, 32, "Input"],
Cell[44227, 1551, 82, 2, 32, "Input"],
Cell[44312, 1555, 102, 2, 32, "Input"],
Cell[44417, 1559, 102, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[44556, 1566, 123, 2, 36, "Subsubsection"],
Cell[44682, 1570, 95, 2, 27, "Text"],
Cell[44780, 1574, 181, 4, 32, "Input"],
Cell[44964, 1580, 183, 4, 32, "Input"],
Cell[45150, 1586, 50, 0, 27, "Text"],
Cell[45203, 1588, 143, 4, 32, "Input"],
Cell[45349, 1594, 93, 3, 32, "Input"],
Cell[45445, 1599, 154, 4, 32, "Input"],
Cell[45602, 1605, 93, 3, 32, "Input"],
Cell[45698, 1610, 98, 3, 32, "Input"],
Cell[45799, 1615, 189, 4, 56, "Input"],
Cell[45991, 1621, 86, 3, 32, "Input"],
Cell[46080, 1626, 36, 0, 27, "Text"],
Cell[46119, 1628, 143, 4, 32, "Input"],
Cell[46265, 1634, 93, 3, 32, "Input"],
Cell[46361, 1639, 154, 4, 32, "Input"],
Cell[46518, 1645, 93, 3, 32, "Input"],
Cell[46614, 1650, 98, 3, 32, "Input"],
Cell[46715, 1655, 93, 3, 32, "Input"],
Cell[46811, 1660, 189, 4, 56, "Input"],
Cell[47003, 1666, 86, 3, 32, "Input"],
Cell[47092, 1671, 132, 3, 27, "Text"],
Cell[47227, 1676, 101, 3, 32, "Input"],
Cell[47331, 1681, 87, 3, 32, "Input"],
Cell[47421, 1686, 90, 3, 32, "Input"],
Cell[47514, 1691, 183, 4, 32, "Input"],
Cell[47700, 1697, 185, 4, 32, "Input"],
Cell[47888, 1703, 139, 3, 32, "Input"],
Cell[48030, 1708, 93, 3, 32, "Input"],
Cell[48126, 1713, 152, 4, 32, "Input"],
Cell[48281, 1719, 93, 3, 32, "Input"],
Cell[48377, 1724, 98, 3, 32, "Input"],
Cell[48478, 1729, 91, 3, 32, "Input"],
Cell[48572, 1734, 133, 3, 27, "Text"],
Cell[48708, 1739, 130, 3, 32, "Input"],
Cell[48841, 1744, 181, 4, 32, "Input"],
Cell[49025, 1750, 67, 0, 27, "Text"],
Cell[49095, 1752, 21, 0, 27, "Text"],
Cell[49119, 1754, 108, 3, 32, "Input"],
Cell[49230, 1759, 93, 3, 32, "Input"],
Cell[49326, 1764, 143, 4, 32, "Input"],
Cell[49472, 1770, 93, 3, 32, "Input"],
Cell[49568, 1775, 21, 0, 27, "Text"],
Cell[49592, 1777, 112, 3, 32, "Input"],
Cell[49707, 1782, 93, 3, 32, "Input"],
Cell[49803, 1787, 98, 3, 32, "Input"],
Cell[49904, 1792, 93, 3, 32, "Input"],
Cell[50000, 1797, 98, 3, 32, "Input"],
Cell[50101, 1802, 143, 4, 32, "Input"],
Cell[50247, 1808, 93, 3, 32, "Input"],
Cell[50343, 1813, 98, 3, 32, "Input"],
Cell[50444, 1818, 93, 3, 32, "Input"],
Cell[50540, 1823, 130, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[50719, 1832, 83, 1, 44, "Subsection"],

Cell[CellGroupData[{
Cell[50827, 1837, 65, 1, 36, "Subsubsection"],
Cell[50895, 1840, 94, 2, 27, "Text"],
Cell[50992, 1844, 95, 3, 32, "Input"],
Cell[51090, 1849, 109, 3, 32, "Input"],
Cell[51202, 1854, 91, 3, 32, "Input"],
Cell[51296, 1859, 102, 3, 32, "Input"],
Cell[51401, 1864, 105, 3, 32, "Input"],
Cell[51509, 1869, 91, 3, 32, "Input"],
Cell[51603, 1874, 106, 3, 32, "Input"],
Cell[51712, 1879, 115, 3, 32, "Input"],
Cell[51830, 1884, 106, 3, 32, "Input"],
Cell[51939, 1889, 60, 0, 27, "Text"],
Cell[52002, 1891, 104, 3, 32, "Input"],
Cell[52109, 1896, 126, 3, 32, "Input"],
Cell[52238, 1901, 29, 0, 27, "Text"],
Cell[52270, 1903, 131, 3, 32, "Input"],
Cell[52404, 1908, 27, 0, 27, "Text"],
Cell[52434, 1910, 135, 4, 32, "Input",
  Evaluatable->False],
Cell[52572, 1916, 57, 0, 27, "Text"],
Cell[52632, 1918, 127, 4, 32, "Input",
  Evaluatable->False],
Cell[52762, 1924, 221, 4, 46, "Text"],
Cell[52986, 1930, 277, 6, 56, "Input",
  InitializationCell->True],
Cell[53266, 1938, 120, 3, 27, "Text"],
Cell[53389, 1943, 109, 2, 32, "Input",
  Evaluatable->False],
Cell[53501, 1947, 259, 5, 46, "Text"],
Cell[53763, 1954, 247, 6, 32, "Input",
  Evaluatable->False],
Cell[54013, 1962, 107, 3, 32, "Input"],
Cell[54123, 1967, 611, 11, 84, "Text"],
Cell[54737, 1980, 100, 3, 32, "Input"],
Cell[54840, 1985, 550, 8, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[55427, 1998, 58, 1, 30, "Subsubsection"],
Cell[55488, 2001, 181, 4, 46, "Text"],
Cell[55672, 2007, 128, 3, 32, "Input"],
Cell[55803, 2012, 35, 0, 27, "Text"],
Cell[55841, 2014, 122, 3, 32, "Input"],
Cell[55966, 2019, 160, 3, 46, "Text"],
Cell[56129, 2024, 190, 5, 32, "Input"],
Cell[56322, 2031, 208, 8, 27, "Text"],
Cell[56533, 2041, 96, 3, 32, "Input"],
Cell[56632, 2046, 484, 8, 84, "Text"],
Cell[57119, 2056, 118, 3, 32, "Input"],
Cell[57240, 2061, 117, 3, 32, "Input"],
Cell[57360, 2066, 110, 3, 27, "Text"],
Cell[57473, 2071, 96, 3, 32, "Input"],
Cell[57572, 2076, 157, 3, 46, "Text"],
Cell[57732, 2081, 117, 3, 32, "Input"],
Cell[57852, 2086, 93, 2, 27, "Text"],
Cell[57948, 2090, 102, 3, 32, "Input"],
Cell[58053, 2095, 75, 2, 32, "Input"],
Cell[58131, 2099, 92, 2, 32, "Input"],
Cell[58226, 2103, 73, 2, 32, "Input"],
Cell[58302, 2107, 105, 3, 27, "Text"],
Cell[58410, 2112, 126, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[58573, 2120, 92, 1, 36, "Subsubsection"],
Cell[58668, 2123, 41, 0, 27, "Text"],
Cell[58712, 2125, 79, 2, 32, "Input"],
Cell[58794, 2129, 112, 3, 32, "Input",
  InitializationCell->True],
Cell[58909, 2134, 98, 3, 32, "Input",
  InitializationCell->True],
Cell[59010, 2139, 95, 2, 27, "Text"],
Cell[59108, 2143, 100, 3, 32, "Input"],
Cell[59211, 2148, 64, 0, 27, "Text"],
Cell[59278, 2150, 144, 4, 32, "Input"],
Cell[59425, 2156, 75, 2, 32, "Input"],
Cell[59503, 2160, 100, 3, 32, "Input"],
Cell[59606, 2165, 95, 2, 27, "Text"],
Cell[59704, 2169, 289, 6, 108, "Input"],
Cell[59996, 2177, 442, 9, 104, "Input"],
Cell[60441, 2188, 223, 4, 46, "Text"],
Cell[60667, 2194, 151, 4, 32, "Input"],
Cell[60821, 2200, 27, 0, 27, "Text"],
Cell[60851, 2202, 114, 3, 32, "Input"],
Cell[60968, 2207, 148, 3, 27, "Text"],
Cell[61119, 2212, 168, 5, 32, "Input"],
Cell[61290, 2219, 143, 3, 27, "Text"],
Cell[61436, 2224, 171, 5, 32, "Input"],
Cell[61610, 2231, 131, 3, 27, "Text"],
Cell[61744, 2236, 409, 9, 128, "Input"],
Cell[62156, 2247, 66, 2, 32, "Input"],
Cell[62225, 2251, 84, 2, 32, "Input"],
Cell[62312, 2255, 104, 2, 32, "Input"],
Cell[62419, 2259, 87, 2, 32, "Input"],
Cell[62509, 2263, 90, 2, 32, "Input"],
Cell[62602, 2267, 107, 3, 32, "Input"],
Cell[62712, 2272, 43, 0, 27, "Text"],
Cell[62758, 2274, 135, 3, 56, "Input"],
Cell[62896, 2279, 99, 3, 64, "Input"],
Cell[62998, 2284, 104, 3, 64, "Input"],
Cell[63105, 2289, 184, 3, 56, "Input"],
Cell[63292, 2294, 70, 2, 32, "Input"],
Cell[63365, 2298, 184, 3, 56, "Input"],
Cell[63552, 2303, 70, 2, 32, "Input"],
Cell[63625, 2307, 75, 2, 32, "Input"],
Cell[63703, 2311, 74, 2, 32, "Input"],
Cell[63780, 2315, 31, 0, 27, "Text"],
Cell[63814, 2317, 110, 3, 32, "Input"],
Cell[63927, 2322, 107, 3, 27, "Text"],
Cell[64037, 2327, 95, 3, 32, "Input"],
Cell[64135, 2332, 27, 0, 27, "Text"],
Cell[64165, 2334, 89, 3, 32, "Input"],
Cell[64257, 2339, 156, 3, 32, "Input"],
Cell[64416, 2344, 74, 2, 32, "Input"],
Cell[64493, 2348, 45, 0, 27, "Text"],
Cell[64541, 2350, 118, 3, 32, "Input"],
Cell[64662, 2355, 74, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[64773, 2362, 64, 1, 30, "Subsubsection"],
Cell[64840, 2365, 129, 3, 27, "Text"],
Cell[64972, 2370, 168, 4, 32, "Input"],
Cell[65143, 2376, 69, 0, 27, "Text"],
Cell[65215, 2378, 94, 3, 32, "Input"],
Cell[65312, 2383, 108, 3, 32, "Input"],
Cell[65423, 2388, 33, 0, 27, "Text"],
Cell[65459, 2390, 126, 3, 32, "Input"],
Cell[65588, 2395, 30, 0, 27, "Text"],
Cell[65621, 2397, 131, 3, 32, "Input"],
Cell[65755, 2402, 153, 4, 27, "Text"],
Cell[65911, 2408, 105, 3, 27, "Text"],
Cell[66019, 2413, 255, 5, 46, "Text"],
Cell[66277, 2420, 187, 5, 32, "Input",
  Evaluatable->False],
Cell[66467, 2427, 144, 3, 27, "Text"],
Cell[66614, 2432, 97, 3, 32, "Input"],
Cell[66714, 2437, 110, 3, 27, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[66885, 2447, 67, 1, 59, "Section"],

Cell[CellGroupData[{
Cell[66977, 2452, 73, 1, 43, "Subsection"],

Cell[CellGroupData[{
Cell[67075, 2457, 64, 1, 37, "Subsubsection"],
Cell[67142, 2460, 945, 15, 204, "Text"],
Cell[68090, 2477, 150, 4, 32, "Input",
  InitializationCell->True],
Cell[68243, 2483, 51, 0, 28, "Text"],
Cell[68297, 2485, 100, 3, 32, "Input"],
Cell[68400, 2490, 101, 3, 32, "Input"],
Cell[68504, 2495, 288, 5, 48, "Text"],
Cell[68795, 2502, 127, 3, 32, "Input"],
Cell[68925, 2507, 102, 3, 32, "Input"],
Cell[69030, 2512, 126, 3, 28, "Text"],
Cell[69159, 2517, 281, 7, 32, "Input",
  InitializationCell->True],
Cell[69443, 2526, 106, 3, 32, "Input"],
Cell[69552, 2531, 108, 3, 32, "Input"],
Cell[69663, 2536, 146, 4, 32, "Input",
  InitializationCell->True],
Cell[69812, 2542, 143, 4, 32, "Input"],
Cell[69958, 2548, 102, 3, 32, "Input"],
Cell[70063, 2553, 143, 4, 32, "Input"],
Cell[70209, 2559, 102, 3, 32, "Input"],
Cell[70314, 2564, 116, 3, 32, "Input"],
Cell[70433, 2569, 102, 3, 32, "Input"],
Cell[70538, 2574, 48, 0, 28, "Text"],
Cell[70589, 2576, 165, 3, 31, "Input"],
Cell[70757, 2581, 79, 2, 31, "Input"],
Cell[70839, 2585, 35, 0, 28, "Text"],
Cell[70877, 2587, 143, 4, 32, "Input"],
Cell[71023, 2593, 102, 3, 32, "Input"],
Cell[71128, 2598, 116, 3, 32, "Input"],
Cell[71247, 2603, 102, 3, 32, "Input"],
Cell[71352, 2608, 241, 4, 48, "Text"],
Cell[71596, 2614, 822, 17, 248, "Input",
  Evaluatable->False],
Cell[72421, 2633, 71, 2, 31, "Input"],
Cell[72495, 2637, 42, 0, 28, "Text"],
Cell[72540, 2639, 94, 2, 31, "Input"],
Cell[72637, 2643, 27, 0, 28, "Text"],
Cell[72667, 2645, 104, 2, 31, "Input"],
Cell[72774, 2649, 104, 2, 31, "Input"],
Cell[72881, 2653, 104, 2, 31, "Input"],
Cell[72988, 2657, 93, 2, 31, "Input"],
Cell[73084, 2661, 93, 2, 31, "Input"],
Cell[73180, 2665, 88, 2, 28, "Text"],
Cell[73271, 2669, 71, 2, 31, "Input"],
Cell[73345, 2673, 577, 13, 169, "Input",
  Evaluatable->False],
Cell[73925, 2688, 113, 3, 28, "Text"],
Cell[74041, 2693, 72, 2, 31, "Input"],
Cell[74116, 2697, 511, 12, 128, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[74664, 2714, 52, 0, 37, "Subsubsection"],
Cell[74719, 2716, 275, 5, 46, "Text"],
Cell[74997, 2723, 74, 2, 32, "Input"],
Cell[75074, 2727, 138, 3, 27, "Text"],
Cell[75215, 2732, 1101, 20, 368, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[76353, 2757, 41, 0, 31, "Subsubsection"],
Cell[76397, 2759, 88, 2, 32, "Input"],
Cell[76488, 2763, 88, 2, 32, "Input"],
Cell[76579, 2767, 103, 2, 32, "Input"],
Cell[76685, 2771, 132, 3, 32, "Input"],
Cell[76820, 2776, 60, 0, 27, "Text"],
Cell[76883, 2778, 173, 3, 55, "Input"],
Cell[77059, 2783, 92, 2, 27, "Text"],
Cell[77154, 2787, 278, 6, 184, "Input"],
Cell[77435, 2795, 60, 0, 27, "Text"],
Cell[77498, 2797, 289, 6, 184, "Input"],
Cell[77790, 2805, 96, 2, 32, "Input"],
Cell[77889, 2809, 71, 0, 27, "Text"],
Cell[77963, 2811, 196, 5, 52, "Input"],
Cell[78162, 2818, 79, 2, 32, "Input"],
Cell[78244, 2822, 104, 2, 32, "Input"],
Cell[78351, 2826, 106, 2, 32, "Input"],
Cell[78460, 2830, 132, 3, 32, "Input"],
Cell[78595, 2835, 107, 2, 32, "Input"],
Cell[78705, 2839, 512, 8, 243, "Input"],
Cell[79220, 2849, 129, 3, 32, "Input"],
Cell[79352, 2854, 111, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[79500, 2861, 42, 0, 31, "Subsubsection"],
Cell[79545, 2863, 90, 2, 32, "Input"],
Cell[79638, 2867, 90, 2, 32, "Input"],
Cell[79731, 2871, 133, 3, 32, "Input"],
Cell[79867, 2876, 197, 5, 52, "Input"],
Cell[80067, 2883, 80, 2, 32, "Input"],
Cell[80150, 2887, 105, 2, 32, "Input"],
Cell[80258, 2891, 44, 0, 27, "Text"],
Cell[80305, 2893, 107, 2, 32, "Input"],
Cell[80415, 2897, 77, 2, 32, "Input"],
Cell[80495, 2901, 133, 3, 32, "Input"],
Cell[80631, 2906, 80, 2, 32, "Input"],
Cell[80714, 2910, 499, 9, 276, "Input"],
Cell[81216, 2921, 133, 4, 32, "Input"],
Cell[81352, 2927, 108, 2, 32, "Input"],
Cell[81463, 2931, 157, 3, 46, "Text"],
Cell[81623, 2936, 159, 3, 56, "Input"],
Cell[81785, 2941, 83, 2, 32, "Input"],
Cell[81871, 2945, 92, 2, 32, "Input"],
Cell[81966, 2949, 183, 4, 46, "Text"],
Cell[82152, 2955, 76, 2, 32, "Input"],
Cell[82231, 2959, 375, 7, 128, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[82643, 2971, 57, 1, 31, "Subsubsection"],
Cell[82703, 2974, 113, 3, 32, "Input"],
Cell[82819, 2979, 160, 4, 32, "Input"],
Cell[82982, 2985, 114, 3, 32, "Input"],
Cell[83099, 2990, 160, 4, 32, "Input"],
Cell[83262, 2996, 123, 3, 32, "Input"],
Cell[83388, 3001, 85, 2, 31, "Input"],
Cell[83476, 3005, 166, 4, 32, "Input"],
Cell[83645, 3011, 124, 3, 32, "Input"],
Cell[83772, 3016, 85, 2, 31, "Input"],
Cell[83860, 3020, 166, 4, 32, "Input"],
Cell[84029, 3026, 113, 3, 32, "Input"],
Cell[84145, 3031, 45, 0, 28, "Text"],
Cell[84193, 3033, 110, 3, 32, "Input"],
Cell[84306, 3038, 114, 3, 32, "Input"],
Cell[84423, 3043, 45, 0, 28, "Text"],
Cell[84471, 3045, 111, 3, 32, "Input"],
Cell[84585, 3050, 119, 3, 32, "Input"],
Cell[84707, 3055, 102, 3, 32, "Input"],
Cell[84812, 3060, 158, 4, 32, "Input"],
Cell[84973, 3066, 102, 3, 32, "Input"],
Cell[85078, 3071, 118, 3, 32, "Input"],
Cell[85199, 3076, 102, 3, 32, "Input"],
Cell[85304, 3081, 158, 4, 32, "Input"],
Cell[85465, 3087, 102, 3, 32, "Input"],
Cell[85570, 3092, 128, 3, 28, "Text"],
Cell[85701, 3097, 128, 3, 32, "Input"],
Cell[85832, 3102, 85, 2, 28, "Text"],
Cell[85920, 3106, 113, 3, 32, "Input"],
Cell[86036, 3111, 115, 3, 32, "Input"],
Cell[86154, 3116, 75, 0, 28, "Text"],
Cell[86232, 3118, 114, 3, 32, "Input"],
Cell[86349, 3123, 182, 4, 28, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[86568, 3132, 59, 1, 37, "Subsubsection"],
Cell[86630, 3135, 146, 3, 46, "Text"],
Cell[86779, 3140, 74, 2, 32, "Input"],
Cell[86856, 3144, 116, 3, 32, "Input"],
Cell[86975, 3149, 96, 3, 32, "Input"],
Cell[87074, 3154, 196, 4, 46, "Text"],
Cell[87273, 3160, 387, 8, 152, "Input"],
Cell[87663, 3170, 57, 2, 27, "Text"],
Cell[87723, 3174, 200, 4, 56, "Input"],
Cell[87926, 3180, 44, 0, 27, "Text"],
Cell[87973, 3182, 69, 2, 32, "Input"],
Cell[88045, 3186, 95, 2, 27, "Text"],
Cell[88143, 3190, 387, 8, 152, "Input"],
Cell[88533, 3200, 57, 2, 27, "Text"],
Cell[88593, 3204, 184, 4, 32, "Input"],
Cell[88780, 3210, 111, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[88940, 3219, 94, 1, 43, "Subsection"],

Cell[CellGroupData[{
Cell[89059, 3224, 62, 1, 37, "Subsubsection"],
Cell[89124, 3227, 263, 5, 65, "Text"],
Cell[89390, 3234, 341, 8, 65, "Text"],
Cell[89734, 3244, 70, 2, 32, "Input"],
Cell[89807, 3248, 570, 13, 152, "Input",
  Evaluatable->False],
Cell[90380, 3263, 56, 0, 27, "Text"],
Cell[90439, 3265, 187, 5, 32, "Input",
  Evaluatable->False],
Cell[90629, 3272, 97, 2, 27, "Text"],
Cell[90729, 3276, 131, 3, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[90897, 3284, 80, 2, 45, "Subsubsection",
  CellTags->"ex3.2_1"],
Cell[90980, 3288, 74, 0, 28, "Text"],
Cell[91057, 3290, 69, 2, 31, "Input"],
Cell[91129, 3294, 72, 2, 31, "Input"],
Cell[91204, 3298, 160, 3, 28, "Text"],
Cell[91367, 3303, 86, 2, 31, "Input"],
Cell[91456, 3307, 77, 0, 28, "Text"],
Cell[91536, 3309, 70, 2, 31, "Input"],
Cell[91609, 3313, 84, 2, 31, "Input"],
Cell[91696, 3317, 143, 3, 28, "Text"],
Cell[91842, 3322, 76, 2, 31, "Input"],
Cell[91921, 3326, 77, 2, 31, "Input"],
Cell[92001, 3330, 70, 2, 31, "Input"],
Cell[92074, 3334, 52, 0, 28, "Text"],
Cell[92129, 3336, 81, 2, 31, "Input"],
Cell[92213, 3340, 126, 3, 28, "Text"],
Cell[92342, 3345, 113, 2, 31, "Input"],
Cell[92458, 3349, 78, 2, 31, "Input"],
Cell[92539, 3353, 109, 3, 28, "Text"],
Cell[92651, 3358, 88, 2, 31, "Input"],
Cell[92742, 3362, 53, 0, 28, "Text"],
Cell[92798, 3364, 98, 2, 31, "Input"],
Cell[92899, 3368, 65, 0, 28, "Text"],
Cell[92967, 3370, 81, 2, 31, "Input"],
Cell[93051, 3374, 79, 2, 31, "Input"],
Cell[93133, 3378, 172, 3, 28, "Text"],
Cell[93308, 3383, 81, 2, 31, "Input"],
Cell[93392, 3387, 68, 2, 31, "Input"],
Cell[93463, 3391, 79, 2, 31, "Input"],
Cell[93545, 3395, 146, 3, 28, "Text"],
Cell[93694, 3400, 81, 2, 31, "Input"],
Cell[93778, 3404, 68, 2, 31, "Input"],
Cell[93849, 3408, 79, 2, 31, "Input"],
Cell[93931, 3412, 83, 2, 31, "Input"],
Cell[94017, 3416, 68, 2, 31, "Input"],
Cell[94088, 3420, 81, 2, 31, "Input"],
Cell[94172, 3424, 62, 0, 28, "Text"],
Cell[94237, 3426, 74, 2, 31, "Input"],
Cell[94314, 3430, 72, 2, 31, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[94423, 3437, 57, 1, 37, "Subsubsection"],
Cell[94483, 3440, 128, 3, 27, "Text"],
Cell[94614, 3445, 152, 4, 32, "Input"],
Cell[94769, 3451, 42, 0, 27, "Text"],
Cell[94814, 3453, 96, 3, 32, "Input"],
Cell[94913, 3458, 90, 2, 27, "Text"],
Cell[95006, 3462, 179, 5, 32, "Input"],
Cell[95188, 3469, 200, 4, 56, "Input"],
Cell[95391, 3475, 101, 2, 32, "Input"],
Cell[95495, 3479, 56, 0, 27, "Text"],
Cell[95554, 3481, 122, 3, 32, "Input"],
Cell[95679, 3486, 98, 2, 27, "Text"],
Cell[95780, 3490, 96, 3, 32, "Input"],
Cell[95879, 3495, 94, 2, 27, "Text"],
Cell[95976, 3499, 97, 2, 32, "Input"],
Cell[96076, 3503, 99, 2, 32, "Input"],
Cell[96178, 3507, 66, 0, 27, "Text"],
Cell[96247, 3509, 120, 3, 32, "Input"],
Cell[96370, 3514, 98, 2, 27, "Text"],
Cell[96471, 3518, 96, 3, 32, "Input"],
Cell[96570, 3523, 96, 3, 32, "Input"],
Cell[96669, 3528, 120, 3, 32, "Input"],
Cell[96792, 3533, 154, 3, 46, "Text"],
Cell[96949, 3538, 117, 3, 32, "Input"],
Cell[97069, 3543, 103, 2, 32, "Input"],
Cell[97175, 3547, 76, 2, 32, "Input"],
Cell[97254, 3551, 106, 2, 32, "Input"],
Cell[97363, 3555, 102, 2, 32, "Input"],
Cell[97468, 3559, 163, 3, 46, "Text"],
Cell[97634, 3564, 122, 3, 32, "Input"],
Cell[97759, 3569, 122, 3, 32, "Input"],
Cell[97884, 3574, 136, 3, 32, "Input"],
Cell[98023, 3579, 44, 0, 27, "Text"],
Cell[98070, 3581, 101, 3, 32, "Input"],
Cell[98174, 3586, 48, 0, 27, "Text"],
Cell[98225, 3588, 99, 3, 32, "Input"],
Cell[98327, 3593, 172, 3, 46, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[98548, 3602, 114, 3, 43, "Subsection"],

Cell[CellGroupData[{
Cell[98687, 3609, 35, 0, 36, "Subsubsection"],
Cell[98725, 3611, 102, 3, 27, "Text"],
Cell[98830, 3616, 111, 3, 32, "Input"],
Cell[98944, 3621, 90, 2, 27, "Text"],
Cell[99037, 3625, 70, 2, 32, "Input"],
Cell[99110, 3629, 121, 3, 32, "Input"],
Cell[99234, 3634, 101, 3, 32, "Input"],
Cell[99338, 3639, 61, 0, 27, "Text"],
Cell[99402, 3641, 201, 6, 61, "Input",
  InitializationCell->True],
Cell[99606, 3649, 54, 0, 27, "Text"],
Cell[99663, 3651, 106, 3, 32, "Input"],
Cell[99772, 3656, 132, 3, 32, "Input"],
Cell[99907, 3661, 50, 0, 27, "Text"],
Cell[99960, 3663, 106, 3, 32, "Input"],
Cell[100069, 3668, 382, 10, 66, "Text"],
Cell[100454, 3680, 114, 3, 32, "Input"],
Cell[100571, 3685, 86, 3, 32, "Input"],
Cell[100660, 3690, 415, 8, 96, "Text"],
Cell[101078, 3700, 205, 5, 56, "Input",
  Evaluatable->False],
Cell[101286, 3707, 111, 3, 32, "Input",
  InitializationCell->True],
Cell[101400, 3712, 162, 3, 46, "Text"],
Cell[101565, 3717, 190, 5, 46, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[101792, 3727, 66, 0, 30, "Subsubsection"],
Cell[101861, 3729, 97, 2, 27, "Text"],
Cell[101961, 3733, 108, 2, 32, "Input"],
Cell[102072, 3737, 74, 2, 32, "Input"],
Cell[102149, 3741, 35, 0, 27, "Text"],
Cell[102187, 3743, 192, 5, 56, "Input",
  InitializationCell->True],
Cell[102382, 3750, 158, 3, 46, "Text"],
Cell[102543, 3755, 838, 16, 296, "Input"],
Cell[103384, 3773, 109, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[103530, 3780, 33, 0, 30, "Subsubsection"],
Cell[103566, 3782, 130, 3, 27, "Text"],
Cell[103699, 3787, 106, 3, 32, "Input"],
Cell[103808, 3792, 303, 5, 65, "Text"],
Cell[104114, 3799, 116, 3, 32, "Input"],
Cell[104233, 3804, 180, 5, 32, "Input"],
Cell[104416, 3811, 42, 0, 27, "Text"],
Cell[104461, 3813, 102, 3, 32, "Input"],
Cell[104566, 3818, 91, 2, 27, "Text"],
Cell[104660, 3822, 153, 4, 56, "Input"],
Cell[104816, 3828, 92, 3, 32, "Input"],
Cell[104911, 3833, 205, 4, 46, "Text"],
Cell[105119, 3839, 119, 3, 32, "Input"],
Cell[105241, 3844, 126, 3, 32, "Input"],
Cell[105370, 3849, 122, 3, 32, "Input"],
Cell[105495, 3854, 37, 0, 27, "Text"],
Cell[105535, 3856, 104, 3, 32, "Input"],
Cell[105642, 3861, 92, 3, 32, "Input"],
Cell[105737, 3866, 64, 0, 27, "Text"],
Cell[105804, 3868, 99, 3, 32, "Input"],
Cell[105906, 3873, 36, 0, 27, "Text"],
Cell[105945, 3875, 99, 3, 32, "Input"],
Cell[106047, 3880, 102, 3, 27, "Text"],
Cell[106152, 3885, 92, 3, 32, "Input"],
Cell[106247, 3890, 102, 3, 27, "Text"],
Cell[106352, 3895, 99, 2, 32, "Input"],
Cell[106454, 3899, 73, 2, 32, "Input"],
Cell[106530, 3903, 79, 2, 32, "Input"],
Cell[106612, 3907, 89, 3, 32, "Input"],
Cell[106704, 3912, 115, 3, 27, "Text"],
Cell[106822, 3917, 98, 3, 32, "Input"],
Cell[106923, 3922, 98, 3, 32, "Input"],
Cell[107024, 3927, 92, 3, 32, "Input"],
Cell[107119, 3932, 106, 3, 32, "Input"],
Cell[107228, 3937, 101, 3, 32, "Input"],
Cell[107332, 3942, 106, 2, 32, "Input"],
Cell[107441, 3946, 134, 3, 32, "Input"],
Cell[107578, 3951, 134, 3, 32, "Input"],
Cell[107715, 3956, 129, 3, 32, "Input"],
Cell[107847, 3961, 291, 5, 65, "Text"],
Cell[108141, 3968, 180, 5, 32, "Input"],
Cell[108324, 3975, 88, 3, 32, "Input"],
Cell[108415, 3980, 91, 3, 32, "Input"],
Cell[108509, 3985, 131, 3, 56, "Input"],
Cell[108643, 3990, 96, 3, 32, "Input"],
Cell[108742, 3995, 93, 3, 32, "Input"],
Cell[108838, 4000, 175, 5, 32, "Input"],
Cell[109016, 4007, 70, 2, 32, "Input"],
Cell[109089, 4011, 99, 3, 32, "Input"],
Cell[109191, 4016, 93, 3, 32, "Input"],
Cell[109287, 4021, 101, 2, 32, "Input"],
Cell[109391, 4025, 72, 2, 32, "Input"],
Cell[109466, 4029, 89, 2, 27, "Text"],
Cell[109558, 4033, 103, 2, 32, "Input"],
Cell[109664, 4037, 105, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[109806, 4044, 74, 0, 30, "Subsubsection"],
Cell[109883, 4046, 319, 5, 65, "Text"],
Cell[110205, 4053, 71, 2, 32, "Input"],
Cell[110279, 4057, 74, 2, 32, "Input"],
Cell[110356, 4061, 66, 0, 27, "Text"],
Cell[110425, 4063, 99, 2, 32, "Input"],
Cell[110527, 4067, 130, 3, 56, "Input"],
Cell[110660, 4072, 72, 2, 32, "Input"],
Cell[110735, 4076, 109, 3, 27, "Text"],
Cell[110847, 4081, 78, 2, 32, "Input"],
Cell[110928, 4085, 78, 2, 32, "Input"],
Cell[111009, 4089, 151, 3, 27, "Text"],
Cell[111163, 4094, 86, 2, 32, "Input"],
Cell[111252, 4098, 223, 4, 46, "Text"],
Cell[111478, 4104, 71, 2, 32, "Input"],
Cell[111552, 4108, 70, 2, 32, "Input"],
Cell[111625, 4112, 69, 2, 32, "Input"],
Cell[111697, 4116, 128, 3, 27, "Text"],
Cell[111828, 4121, 103, 2, 32, "Input"],
Cell[111934, 4125, 110, 3, 27, "Text"],
Cell[112047, 4130, 70, 2, 32, "Input"],
Cell[112120, 4134, 63, 0, 27, "Text"],
Cell[112186, 4136, 90, 2, 32, "Input"],
Cell[112279, 4140, 71, 0, 27, "Text"],
Cell[112353, 4142, 87, 2, 32, "Input"],
Cell[112443, 4146, 108, 3, 27, "Text"],
Cell[112554, 4151, 147, 4, 32, "Input"],
Cell[112704, 4157, 69, 0, 27, "Text"],
Cell[112776, 4159, 96, 2, 32, "Input"],
Cell[112875, 4163, 87, 2, 27, "Text"],
Cell[112965, 4167, 74, 2, 32, "Input"],
Cell[113042, 4171, 150, 3, 46, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[113241, 4180, 62, 1, 37, "Subsection"],
Cell[113306, 4183, 683, 10, 122, "Text"],
Cell[113992, 4195, 557, 13, 97, "Text",
  CellTags->"prop2"],
Cell[114552, 4210, 642, 10, 122, "Text"],
Cell[115197, 4222, 108, 2, 32, "Input"],
Cell[115308, 4226, 197, 5, 46, "Text"],
Cell[115508, 4233, 110, 2, 32, "Input"],
Cell[115621, 4237, 164, 3, 46, "Text"],
Cell[115788, 4242, 109, 2, 32, "Input"],
Cell[115900, 4246, 26, 0, 27, "Text"],
Cell[115929, 4248, 101, 2, 32, "Input"],
Cell[116033, 4252, 273, 7, 46, "Text"],
Cell[116309, 4261, 259, 5, 46, "Text"],
Cell[116571, 4268, 390, 7, 115, "Text"],

Cell[CellGroupData[{
Cell[116986, 4279, 32, 0, 36, "Subsubsection"],
Cell[117021, 4281, 189, 4, 46, "Text"],
Cell[117213, 4287, 122, 3, 32, "Input"],
Cell[117338, 4292, 172, 3, 46, "Text"],
Cell[117513, 4297, 191, 5, 56, "Input"],
Cell[117707, 4304, 433, 7, 84, "Text"],
Cell[118143, 4313, 125, 3, 32, "Input"],
Cell[118271, 4318, 97, 3, 32, "Input"],
Cell[118371, 4323, 93, 3, 32, "Input"],
Cell[118467, 4328, 94, 3, 32, "Input"],
Cell[118564, 4333, 176, 5, 32, "Input"],
Cell[118743, 4340, 93, 2, 27, "Text"],
Cell[118839, 4344, 155, 4, 32, "Input"],
Cell[118997, 4350, 118, 3, 27, "Text"],
Cell[119118, 4355, 123, 3, 32, "Input"],
Cell[119244, 4360, 102, 3, 32, "Input"],
Cell[119349, 4365, 207, 4, 46, "Text"],
Cell[119559, 4371, 116, 3, 32, "Input"],
Cell[119678, 4376, 92, 3, 32, "Input"],
Cell[119773, 4381, 203, 4, 46, "Text"],
Cell[119979, 4387, 97, 3, 32, "Input"],
Cell[120079, 4392, 92, 3, 32, "Input"],
Cell[120174, 4397, 97, 3, 32, "Input"],
Cell[120274, 4402, 92, 3, 32, "Input"],
Cell[120369, 4407, 118, 3, 27, "Text"],
Cell[120490, 4412, 105, 3, 32, "Input"],
Cell[120598, 4417, 137, 3, 27, "Text"],
Cell[120738, 4422, 225, 5, 125, "Input"],
Cell[120966, 4429, 92, 3, 32, "Input"],
Cell[121061, 4434, 132, 3, 27, "Text"],
Cell[121196, 4439, 125, 3, 32, "Input"],
Cell[121324, 4444, 142, 4, 32, "Input"],
Cell[121469, 4450, 92, 3, 32, "Input"],
Cell[121564, 4455, 108, 3, 32, "Input"],
Cell[121675, 4460, 92, 3, 32, "Input"],
Cell[121770, 4465, 97, 3, 32, "Input"],
Cell[121870, 4470, 93, 3, 32, "Input"],
Cell[121966, 4475, 63, 0, 27, "Text"],
Cell[122032, 4477, 212, 5, 80, "Input"],
Cell[122247, 4484, 89, 3, 32, "Input"],
Cell[122339, 4489, 93, 3, 32, "Input"],
Cell[122435, 4494, 103, 3, 32, "Input"],
Cell[122541, 4499, 95, 3, 32, "Input"],
Cell[122639, 4504, 132, 3, 27, "Text"],
Cell[122774, 4509, 132, 3, 32, "Input"],
Cell[122909, 4514, 137, 3, 27, "Text"],
Cell[123049, 4519, 166, 4, 32, "Input"],
Cell[123218, 4525, 93, 3, 32, "Input"],
Cell[123314, 4530, 50, 0, 27, "Text"],
Cell[123367, 4532, 183, 4, 32, "Input"],
Cell[123553, 4538, 89, 3, 32, "Input"],
Cell[123645, 4543, 93, 3, 32, "Input"],
Cell[123741, 4548, 103, 3, 32, "Input"],
Cell[123847, 4553, 94, 3, 32, "Input"],
Cell[123944, 4558, 159, 3, 46, "Text"],
Cell[124106, 4563, 173, 4, 32, "Input"],
Cell[124282, 4569, 29, 0, 27, "Text"],
Cell[124314, 4571, 133, 3, 32, "Input"],
Cell[124450, 4576, 93, 3, 32, "Input"],
Cell[124546, 4581, 218, 6, 56, "Input"],
Cell[124767, 4589, 89, 3, 32, "Input"],
Cell[124859, 4594, 93, 3, 32, "Input"],
Cell[124955, 4599, 103, 3, 32, "Input"],
Cell[125061, 4604, 95, 3, 32, "Input"],
Cell[125159, 4609, 174, 4, 32, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[125394, 4620, 68, 1, 59, "Section"],

Cell[CellGroupData[{
Cell[125487, 4625, 32, 0, 37, "Subsubsection"],
Cell[125522, 4627, 757, 14, 88, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[126316, 4646, 63, 1, 37, "Subsection"],
Cell[126382, 4649, 639, 9, 88, "Text"],
Cell[127024, 4660, 69, 2, 31, "Input"],
Cell[127096, 4664, 49, 0, 28, "Text"],
Cell[127148, 4666, 129, 3, 32, "Input"],
Cell[127280, 4671, 178, 4, 28, "Text"],
Cell[127461, 4677, 75, 2, 31, "Input"],
Cell[127539, 4681, 68, 2, 31, "Input"],
Cell[127610, 4685, 116, 3, 28, "Text"],
Cell[127729, 4690, 136, 3, 32, "Input"],
Cell[127868, 4695, 165, 3, 28, "Text"],
Cell[128036, 4700, 95, 3, 32, "Input"],
Cell[128134, 4705, 133, 3, 32, "Input"],
Cell[128270, 4710, 133, 3, 32, "Input"],
Cell[128406, 4715, 229, 4, 48, "Text"],
Cell[128638, 4721, 245, 6, 32, "Input",
  InitializationCell->True],
Cell[128886, 4729, 30, 0, 28, "Text"],
Cell[128919, 4731, 167, 4, 32, "Input"],
Cell[129089, 4737, 92, 3, 32, "Input"],
Cell[129184, 4742, 238, 4, 48, "Text"],
Cell[129425, 4748, 225, 7, 28, "Text"],
Cell[129653, 4757, 272, 7, 32, "Input",
  InitializationCell->True],
Cell[129928, 4766, 119, 3, 32, "Input"],
Cell[130050, 4771, 74, 2, 31, "Input"],
Cell[130127, 4775, 74, 2, 31, "Input"],
Cell[130204, 4779, 74, 2, 31, "Input"],
Cell[130281, 4783, 440, 8, 48, "Text"],
Cell[130724, 4793, 77, 2, 31, "Input"],
Cell[130804, 4797, 66, 2, 31, "Input"],
Cell[130873, 4801, 70, 2, 31, "Input"],
Cell[130946, 4805, 147, 3, 28, "Text"],
Cell[131096, 4810, 69, 2, 31, "Input"],
Cell[131168, 4814, 233, 5, 54, "Input",
  InitializationCell->True],
Cell[131404, 4821, 120, 3, 28, "Text"],
Cell[131527, 4826, 210, 4, 54, "Input",
  InitializationCell->True],
Cell[131740, 4832, 136, 3, 31, "Input"],
Cell[131879, 4837, 74, 2, 31, "Input"],
Cell[131956, 4841, 74, 2, 31, "Input"],
Cell[132033, 4845, 133, 3, 31, "Input"],
Cell[132169, 4850, 116, 2, 31, "Input"],
Cell[132288, 4854, 106, 3, 28, "Text"],
Cell[132397, 4859, 1593, 26, 308, "Input"],
Cell[133993, 4887, 167, 4, 31, "Input"],
Cell[134163, 4893, 437, 7, 68, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[134637, 4905, 57, 1, 37, "Subsection"],

Cell[CellGroupData[{
Cell[134719, 4910, 54, 0, 36, "Subsubsection"],
Cell[134776, 4912, 55, 0, 27, "Text"],
Cell[134834, 4914, 185, 4, 32, "Input"],
Cell[135022, 4920, 53, 0, 27, "Text"],
Cell[135078, 4922, 185, 4, 32, "Input"],
Cell[135266, 4928, 75, 0, 27, "Text"],
Cell[135344, 4930, 247, 6, 80, "Input"],
Cell[135594, 4938, 247, 6, 80, "Input"],
Cell[135844, 4946, 469, 7, 84, "Text"],
Cell[136316, 4955, 249, 6, 51, "Text"],
Cell[136568, 4963, 202, 5, 56, "Input"],
Cell[136773, 4970, 92, 3, 32, "Input"],
Cell[136868, 4975, 220, 5, 56, "Input"],
Cell[137091, 4982, 555, 14, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[137683, 5001, 51, 0, 30, "Subsubsection"],
Cell[137737, 5003, 64, 0, 27, "Text"],
Cell[137804, 5005, 239, 6, 80, "Input"],
Cell[138046, 5013, 177, 4, 32, "Input"],
Cell[138226, 5019, 64, 2, 32, "Input"],
Cell[138293, 5023, 64, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[138394, 5030, 49, 0, 30, "Subsubsection"],
Cell[138446, 5032, 99, 2, 32, "Input"],
Cell[138548, 5036, 152, 3, 56, "Input"],
Cell[138703, 5041, 159, 3, 56, "Input"],
Cell[138865, 5046, 158, 3, 56, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[139060, 5054, 41, 0, 30, "Subsubsection"],
Cell[139104, 5056, 239, 6, 80, "Input"],
Cell[139346, 5064, 211, 5, 56, "Input"],
Cell[139560, 5071, 95, 3, 32, "Input"],
Cell[139658, 5076, 92, 3, 32, "Input"],
Cell[139753, 5081, 89, 3, 32, "Input"],
Cell[139845, 5086, 65, 2, 32, "Input"],
Cell[139913, 5090, 78, 2, 32, "Input"],
Cell[139994, 5094, 97, 3, 32, "Input"],
Cell[140094, 5099, 98, 3, 32, "Input"],
Cell[140195, 5104, 573, 11, 103, "Text"],
Cell[140771, 5117, 129, 3, 32, "Input"],
Cell[140903, 5122, 59, 0, 27, "Text"],
Cell[140965, 5124, 93, 3, 32, "Input"],
Cell[141061, 5129, 151, 4, 32, "Input"],
Cell[141215, 5135, 96, 3, 32, "Input"],
Cell[141314, 5140, 96, 3, 32, "Input"],
Cell[141413, 5145, 101, 3, 32, "Input"],
Cell[141517, 5150, 56, 0, 27, "Text"],
Cell[141576, 5152, 153, 4, 32, "Input",
  InitializationCell->True],
Cell[141732, 5158, 170, 5, 32, "Input",
  InitializationCell->True],
Cell[141905, 5165, 122, 4, 32, "Input",
  InitializationCell->True],
Cell[142030, 5171, 107, 3, 32, "Input"],
Cell[142140, 5176, 93, 3, 32, "Input"],
Cell[142236, 5181, 59, 0, 27, "Text"],
Cell[142298, 5183, 111, 3, 32, "Input"],
Cell[142412, 5188, 200, 5, 95, "Input"],
Cell[142615, 5195, 133, 3, 32, "Input"],
Cell[142751, 5200, 182, 4, 46, "Text"],
Cell[142936, 5206, 120, 3, 32, "Input"],
Cell[143059, 5211, 142, 4, 56, "Input"],
Cell[143204, 5217, 66, 2, 32, "Input"],
Cell[143273, 5221, 69, 2, 32, "Input"],
Cell[143345, 5225, 79, 2, 32, "Input"],
Cell[143427, 5229, 65, 0, 27, "Text"],
Cell[143495, 5231, 92, 2, 32, "Input"],
Cell[143590, 5235, 75, 2, 32, "Input"],
Cell[143668, 5239, 246, 7, 46, "Text"],
Cell[143917, 5248, 168, 4, 56, "Input"],
Cell[144088, 5254, 49, 0, 27, "Text"],
Cell[144140, 5256, 121, 3, 32, "Input"],
Cell[144264, 5261, 193, 4, 64, "Input"],
Cell[144460, 5267, 103, 3, 32, "Input"],
Cell[144566, 5272, 144, 4, 32, "Input"],
Cell[144713, 5278, 90, 2, 27, "Text"],
Cell[144806, 5282, 187, 5, 32, "Input"],
Cell[144996, 5289, 90, 3, 32, "Input"],
Cell[145089, 5294, 102, 3, 32, "Input"],
Cell[145194, 5299, 45, 0, 27, "Text"],
Cell[145242, 5301, 195, 5, 80, "Input"],
Cell[145440, 5308, 39, 0, 27, "Text"],
Cell[145482, 5310, 109, 3, 32, "Input"],
Cell[145594, 5315, 200, 5, 80, "Input"],
Cell[145797, 5322, 93, 3, 32, "Input"],
Cell[145893, 5327, 98, 3, 32, "Input"],
Cell[145994, 5332, 50, 0, 27, "Text"],
Cell[146047, 5334, 65, 2, 32, "Input"],
Cell[146115, 5338, 108, 3, 32, "Input"],
Cell[146226, 5343, 94, 3, 32, "Input"],
Cell[146323, 5348, 124, 3, 27, "Text"],
Cell[146450, 5353, 115, 3, 32, "Input"],
Cell[146568, 5358, 109, 3, 32, "Input"],
Cell[146680, 5363, 94, 3, 32, "Input"],
Cell[146777, 5368, 76, 0, 27, "Text"],
Cell[146856, 5370, 105, 3, 32, "Input"],
Cell[146964, 5375, 204, 4, 46, "Text"],
Cell[147171, 5381, 113, 3, 32, "Input"],
Cell[147287, 5386, 97, 3, 32, "Input"],
Cell[147387, 5391, 276, 7, 46, "Text"],
Cell[147666, 5400, 186, 4, 56, "Input"],
Cell[147855, 5406, 97, 2, 27, "Text"],
Cell[147955, 5410, 103, 3, 32, "Input"],
Cell[148061, 5415, 100, 3, 32, "Input"],
Cell[148164, 5420, 191, 5, 56, "Input"],
Cell[148358, 5427, 182, 4, 56, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[148577, 5436, 68, 0, 30, "Subsubsection"],
Cell[148648, 5438, 337, 6, 128, "Input"],
Cell[148988, 5446, 321, 6, 128, "Input"],
Cell[149312, 5454, 194, 4, 80, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[149555, 5464, 72, 1, 37, "Subsection"],
Cell[149630, 5467, 136, 3, 27, "Text"],
Cell[149769, 5472, 370, 8, 59, "Text",
  CellTags->"sepprop"],
Cell[150142, 5482, 127, 3, 27, "Text"],
Cell[150272, 5487, 64, 1, 27, "Text"],
Cell[150339, 5490, 74, 0, 27, "Text"],
Cell[150416, 5492, 64, 1, 27, "Text"],
Cell[150483, 5495, 148, 3, 27, "Text"],
Cell[150634, 5500, 99, 3, 27, "Text"],
Cell[150736, 5505, 433, 7, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[151206, 5517, 232, 9, 37, "Subsection"],
Cell[151441, 5528, 662, 12, 103, "Text"],
Cell[152106, 5542, 99, 3, 32, "Input"],
Cell[152208, 5547, 80, 2, 32, "Input"],
Cell[152291, 5551, 73, 2, 32, "Input"],
Cell[152367, 5555, 371, 8, 104, "Input",
  Evaluatable->False],
Cell[152741, 5565, 110, 3, 27, "Text"],
Cell[152854, 5570, 129, 3, 32, "Input"],

Cell[CellGroupData[{
Cell[153008, 5577, 57, 1, 36, "Subsubsection"],
Cell[153068, 5580, 80, 2, 32, "Input"],
Cell[153151, 5584, 169, 4, 27, "Text"],
Cell[153323, 5590, 135, 3, 32, "Input"],
Cell[153461, 5595, 47, 0, 27, "Text"],
Cell[153511, 5597, 107, 3, 32, "Input"],
Cell[153621, 5602, 94, 3, 32, "Input"],
Cell[153718, 5607, 35, 0, 27, "Text"],
Cell[153756, 5609, 142, 4, 32, "Input"],
Cell[153901, 5615, 87, 3, 32, "Input"],
Cell[153991, 5620, 91, 3, 32, "Input"],
Cell[154085, 5625, 102, 3, 32, "Input"],
Cell[154190, 5630, 96, 3, 32, "Input"],
Cell[154289, 5635, 92, 3, 32, "Input"],
Cell[154384, 5640, 96, 3, 32, "Input"],
Cell[154483, 5645, 92, 3, 32, "Input"],
Cell[154578, 5650, 46, 0, 27, "Text"],
Cell[154627, 5652, 87, 3, 32, "Input"],
Cell[154717, 5657, 49, 0, 27, "Text"],
Cell[154769, 5659, 107, 3, 32, "Input"],
Cell[154879, 5664, 94, 3, 32, "Input"],
Cell[154976, 5669, 108, 3, 32, "Input"],
Cell[155087, 5674, 332, 7, 46, "Text"],
Cell[155422, 5683, 98, 3, 32, "Input"],
Cell[155523, 5688, 92, 3, 32, "Input"],
Cell[155618, 5693, 97, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[155752, 5701, 57, 1, 30, "Subsubsection"],
Cell[155812, 5704, 95, 3, 32, "Input"],
Cell[155910, 5709, 86, 2, 27, "Text"],
Cell[155999, 5713, 91, 3, 32, "Input"],
Cell[156093, 5718, 55, 0, 27, "Text"],
Cell[156151, 5720, 132, 3, 32, "Input"],
Cell[156286, 5725, 93, 3, 32, "Input"],
Cell[156382, 5730, 180, 5, 32, "Input"],
Cell[156565, 5737, 52, 0, 23, "Text"],
Cell[156620, 5739, 418, 10, 111, "Input",
  InitializationCell->True],
Cell[157041, 5751, 93, 3, 32, "Input"],
Cell[157137, 5756, 136, 3, 28, "Input"],
Cell[157276, 5761, 87, 2, 23, "Text"],
Cell[157366, 5765, 171, 5, 32, "Input",
  InitializationCell->True],
Cell[157540, 5772, 95, 3, 32, "Input"],
Cell[157638, 5777, 95, 3, 28, "Input"],
Cell[157736, 5782, 124, 3, 28, "Input"],
Cell[157863, 5787, 205, 5, 34, "Input"],
Cell[158071, 5794, 107, 3, 28, "Input"],
Cell[158181, 5799, 135, 3, 32, "Input"],
Cell[158319, 5804, 272, 5, 60, "Text"],
Cell[158594, 5811, 189, 5, 32, "Input"],
Cell[158786, 5818, 189, 5, 32, "Input"],
Cell[158978, 5825, 122, 3, 27, "Text"],
Cell[159103, 5830, 221, 5, 56, "Input"],
Cell[159327, 5837, 96, 3, 32, "Input"],
Cell[159426, 5842, 113, 2, 32, "Input"],
Cell[159542, 5846, 37, 0, 27, "Text"],
Cell[159582, 5848, 136, 4, 61, "Input"],
Cell[159721, 5854, 96, 3, 32, "Input"],
Cell[159820, 5859, 336, 8, 42, "Text"],
Cell[160159, 5869, 137, 3, 27, "Text"],
Cell[160299, 5874, 112, 3, 32, "Input"],
Cell[160414, 5879, 110, 3, 28, "Input"],
Cell[160527, 5884, 65, 0, 23, "Text"],
Cell[160595, 5886, 176, 4, 56, "Input"],
Cell[160774, 5892, 159, 5, 23, "Text"],
Cell[160936, 5899, 159, 4, 57, "Input"],
Cell[161098, 5905, 27, 0, 23, "Text"],
Cell[161128, 5907, 96, 3, 32, "Input"],
Cell[161227, 5912, 151, 8, 23, "Text"],
Cell[161381, 5922, 135, 4, 32, "Input"],
Cell[161519, 5928, 28, 0, 27, "Text"],
Cell[161550, 5930, 226, 5, 56, "Input"],
Cell[161779, 5937, 96, 2, 28, "Input"],
Cell[161878, 5941, 113, 3, 23, "Text"],
Cell[161994, 5946, 168, 3, 72, "Input",
  Evaluatable->False],
Cell[162165, 5951, 1072, 26, 153, "Text"],
Cell[163240, 5979, 131, 3, 59, "Input",
  Evaluatable->False],
Cell[163374, 5984, 51, 1, 40, "Text",
  CellTags->"deg"],
Cell[163428, 5987, 170, 3, 46, "Text"],
Cell[163601, 5992, 96, 3, 32, "Input"],
Cell[163700, 5997, 118, 3, 32, "Input"],
Cell[163821, 6002, 137, 3, 28, "Input"],
Cell[163961, 6007, 199, 6, 23, "Text"],
Cell[164163, 6015, 106, 3, 32, "Input"],
Cell[164272, 6020, 60, 0, 23, "Text"],
Cell[164335, 6022, 135, 3, 32, "Input"],
Cell[164473, 6027, 164, 3, 23, "Text"],
Cell[164640, 6032, 122, 3, 32, "Input"],
Cell[164765, 6037, 137, 3, 28, "Input"],
Cell[164905, 6042, 111, 3, 28, "Input"],
Cell[165019, 6047, 126, 3, 28, "Input"],
Cell[165148, 6052, 32, 0, 23, "Text"],
Cell[165183, 6054, 106, 2, 32, "Input"],
Cell[165292, 6058, 127, 3, 28, "Input"],
Cell[165422, 6063, 73, 2, 28, "Input"],
Cell[165498, 6067, 123, 3, 23, "Text"],
Cell[165624, 6072, 91, 2, 32, "Input"],
Cell[165718, 6076, 96, 2, 28, "Input"],
Cell[165817, 6080, 151, 3, 42, "Text"],
Cell[165971, 6085, 86, 2, 32, "Input"],
Cell[166060, 6089, 101, 2, 28, "Input"],
Cell[166164, 6093, 75, 2, 28, "Input"],
Cell[166242, 6097, 107, 2, 32, "Input"],
Cell[166352, 6101, 95, 2, 28, "Input"],
Cell[166450, 6105, 96, 2, 28, "Input"],
Cell[166549, 6109, 261, 7, 42, "Text"],
Cell[166813, 6118, 101, 2, 32, "Input"],
Cell[166917, 6122, 90, 2, 28, "Input"],
Cell[167010, 6126, 90, 2, 28, "Input"],
Cell[167103, 6130, 106, 2, 28, "Input"],
Cell[167212, 6134, 95, 2, 28, "Input"],
Cell[167310, 6138, 95, 2, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[167442, 6145, 85, 1, 43, "Subsubsection",
  CellTags->"asseigsph"],
Cell[167530, 6148, 66, 0, 27, "Text"],
Cell[167599, 6150, 370, 7, 65, "Text"],
Cell[167972, 6159, 277, 5, 46, "Text"],
Cell[168252, 6166, 81, 2, 32, "Input"],
Cell[168336, 6170, 129, 3, 32, "Input"],
Cell[168468, 6175, 99, 2, 32, "Input"],
Cell[168570, 6179, 94, 2, 27, "Text"],
Cell[168667, 6183, 317, 6, 169, "Input"],
Cell[168987, 6191, 85, 2, 32, "Input"],
Cell[169075, 6195, 69, 2, 32, "Input"],
Cell[169147, 6199, 465, 8, 246, "Input"],
Cell[169615, 6209, 241, 6, 89, "Text"],
Cell[169859, 6217, 156, 3, 56, "Input"],
Cell[170018, 6222, 97, 2, 29, "Input"],
Cell[170118, 6226, 111, 2, 28, "Input"],
Cell[170232, 6230, 110, 2, 29, "Input"],
Cell[170345, 6234, 102, 2, 32, "Input"],
Cell[170450, 6238, 57, 0, 27, "Text"],
Cell[170510, 6240, 493, 10, 286, "Input"],
Cell[171006, 6252, 136, 3, 27, "Text"],
Cell[171145, 6257, 82, 2, 32, "Input"],
Cell[171230, 6261, 101, 2, 32, "Input"],
Cell[171334, 6265, 299, 5, 125, "Input"],
Cell[171636, 6272, 59, 0, 27, "Text"],
Cell[171698, 6274, 81, 2, 32, "Input"],
Cell[171782, 6278, 84, 2, 32, "Input"],
Cell[171869, 6282, 115, 3, 27, "Text"],
Cell[171987, 6287, 200, 4, 104, "Input"],
Cell[172190, 6293, 481, 11, 236, "Input"],
Cell[172674, 6306, 97, 2, 32, "Input"],
Cell[172774, 6310, 124, 3, 27, "Text"],
Cell[172901, 6315, 91, 2, 32, "Input"],
Cell[172995, 6319, 91, 2, 27, "Text"],
Cell[173089, 6323, 106, 2, 32, "Input"],
Cell[173198, 6327, 137, 3, 27, "Text"],
Cell[173338, 6332, 3703, 61, 1936, "Input"],
Cell[177044, 6395, 128, 3, 27, "Text"],
Cell[177175, 6400, 94, 2, 32, "Input"],
Cell[177272, 6404, 93, 2, 32, "Input"],
Cell[177368, 6408, 150, 3, 27, "Text"],
Cell[177521, 6413, 106, 2, 32, "Input"],
Cell[177630, 6417, 46, 0, 27, "Text"],
Cell[177679, 6419, 112, 2, 32, "Input"],
Cell[177794, 6423, 217, 5, 89, "Text"],
Cell[178014, 6430, 307, 7, 128, "Input"],
Cell[178324, 6439, 325, 5, 65, "Text"],
Cell[178652, 6446, 355, 8, 152, "Input"],
Cell[179010, 6456, 360, 8, 152, "Input"],
Cell[179373, 6466, 66, 0, 27, "Text"],
Cell[179442, 6468, 94, 2, 32, "Input"],
Cell[179539, 6472, 93, 2, 32, "Input"],
Cell[179635, 6476, 307, 7, 128, "Input"],
Cell[179945, 6485, 139, 4, 32, "Input"],
Cell[180087, 6491, 360, 8, 152, "Input"],
Cell[180450, 6501, 356, 8, 152, "Input"],
Cell[180809, 6511, 341, 7, 152, "Input"],
Cell[181153, 6520, 343, 7, 152, "Input"],
Cell[181499, 6529, 173, 3, 46, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[181721, 6538, 114, 2, 37, "Subsection"],
Cell[181838, 6542, 413, 8, 48, "Text"],

Cell[CellGroupData[{
Cell[182276, 6554, 105, 2, 37, "Subsubsection"],
Cell[182384, 6558, 222, 5, 28, "Text"],
Cell[182609, 6565, 105, 3, 32, "Input"],
Cell[182717, 6570, 163, 4, 32, "Input",
  InitializationCell->True],
Cell[182883, 6576, 71, 2, 31, "Input"],
Cell[182957, 6580, 75, 2, 31, "Input"],
Cell[183035, 6584, 82, 2, 31, "Input"],
Cell[183120, 6588, 105, 3, 32, "Input"],
Cell[183228, 6593, 71, 2, 31, "Input"],
Cell[183302, 6597, 132, 3, 31, "Input"],
Cell[183437, 6602, 105, 3, 32, "Input"],
Cell[183545, 6607, 130, 3, 31, "Input"],
Cell[183678, 6612, 130, 3, 31, "Input"],
Cell[183811, 6617, 71, 2, 31, "Input"],
Cell[183885, 6621, 119, 3, 32, "Input"],
Cell[184007, 6626, 105, 3, 32, "Input"],
Cell[184115, 6631, 69, 0, 28, "Text"],
Cell[184187, 6633, 84, 2, 31, "Input"],
Cell[184274, 6637, 48, 0, 28, "Text"],
Cell[184325, 6639, 79, 2, 31, "Input"],
Cell[184407, 6643, 339, 7, 60, "Text"],
Cell[184749, 6652, 194, 6, 61, "Input",
  InitializationCell->True],
Cell[184946, 6660, 92, 3, 32, "Input"],
Cell[185041, 6665, 173, 4, 31, "Input"],
Cell[185217, 6671, 83, 2, 31, "Input"],
Cell[185303, 6675, 200, 4, 48, "Text"],
Cell[185506, 6681, 170, 4, 31, "Input"],
Cell[185679, 6687, 83, 2, 31, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[185799, 6694, 109, 2, 31, "Subsubsection"],
Cell[185911, 6698, 387, 8, 48, "Text"],
Cell[186301, 6708, 104, 3, 32, "Input"],
Cell[186408, 6713, 85, 2, 31, "Input"],
Cell[186496, 6717, 157, 4, 32, "Input"],
Cell[186656, 6723, 103, 3, 32, "Input"],
Cell[186762, 6728, 171, 5, 28, "Text"],
Cell[186936, 6735, 93, 2, 31, "Input"],
Cell[187032, 6739, 252, 6, 28, "Text"],
Cell[187287, 6747, 109, 2, 31, "Input"],
Cell[187399, 6751, 67, 0, 28, "Text"],
Cell[187469, 6753, 333, 9, 131, "Input",
  InitializationCell->True],
Cell[187805, 6764, 30, 0, 28, "Text"],
Cell[187838, 6766, 92, 2, 31, "Input"],
Cell[187933, 6770, 85, 2, 31, "Input"],
Cell[188021, 6774, 94, 2, 31, "Input"],
Cell[188118, 6778, 113, 3, 28, "Text"],
Cell[188234, 6783, 81, 2, 31, "Input"],
Cell[188318, 6787, 73, 0, 28, "Text"],
Cell[188394, 6789, 83, 2, 31, "Input"],
Cell[188480, 6793, 180, 3, 49, "Input"],
Cell[188663, 6798, 56, 0, 28, "Text"],
Cell[188722, 6800, 191, 4, 28, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[188950, 6809, 53, 0, 31, "Subsubsection"],
Cell[189006, 6811, 104, 3, 28, "Text"],
Cell[189113, 6816, 92, 3, 32, "Input"],
Cell[189208, 6821, 180, 4, 31, "Input",
  InitializationCell->True],
Cell[189391, 6827, 88, 2, 31, "Input"],
Cell[189482, 6831, 65, 2, 31, "Input"],
Cell[189550, 6835, 111, 2, 31, "Input"],
Cell[189664, 6839, 69, 0, 28, "Text"],
Cell[189736, 6841, 373, 8, 131, "Input",
  InitializationCell->True],
Cell[190112, 6851, 42, 0, 28, "Text"],
Cell[190157, 6853, 92, 2, 31, "Input"],
Cell[190252, 6857, 111, 2, 31, "Input"],
Cell[190366, 6861, 75, 0, 28, "Text"],
Cell[190444, 6863, 338, 8, 131, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[190819, 6876, 41, 0, 31, "Subsubsection"],
Cell[190863, 6878, 273, 5, 48, "Text"],
Cell[191139, 6885, 81, 2, 31, "Input",
  Evaluatable->False],
Cell[191223, 6889, 660, 14, 48, "Text"],
Cell[191886, 6905, 184, 4, 28, "Text"],
Cell[192073, 6911, 117, 3, 31, "Input",
  Evaluatable->False],
Cell[192193, 6916, 45, 0, 28, "Text"],
Cell[192241, 6918, 127, 3, 31, "Input"],
Cell[192371, 6923, 171, 3, 43, "Input"],
Cell[192545, 6928, 156, 4, 31, "Input"],
Cell[192704, 6934, 115, 2, 31, "Input"],
Cell[192822, 6938, 62, 0, 28, "Text"],
Cell[192887, 6940, 330, 8, 131, "Input",
  InitializationCell->True],
Cell[193220, 6950, 85, 2, 31, "Input"],
Cell[193308, 6954, 86, 2, 28, "Text"],
Cell[193397, 6958, 85, 2, 31, "Input"],
Cell[193485, 6962, 124, 3, 28, "Text"],
Cell[193612, 6967, 51, 0, 28, "Text"],
Cell[193666, 6969, 121, 3, 31, "Input"],
Cell[193790, 6974, 104, 2, 31, "Input"],
Cell[193897, 6978, 99, 2, 31, "Input"],
Cell[193999, 6982, 158, 4, 31, "Input"],
Cell[194160, 6988, 115, 2, 31, "Input"],
Cell[194278, 6992, 52, 0, 28, "Text"],
Cell[194333, 6994, 215, 5, 59, "Input",
  InitializationCell->True],
Cell[194551, 7001, 30, 0, 28, "Text"],
Cell[194584, 7003, 84, 2, 31, "Input"],
Cell[194671, 7007, 124, 3, 28, "Text"],
Cell[194798, 7012, 78, 1, 28, "Text"],
Cell[194879, 7015, 115, 3, 28, "Text"],
Cell[194997, 7020, 107, 3, 28, "Text"],
Cell[195107, 7025, 60, 0, 28, "Text"],
Cell[195170, 7027, 141, 3, 28, "Text"],
Cell[195314, 7032, 126, 3, 28, "Text"],
Cell[195443, 7037, 106, 3, 28, "Text"],
Cell[195552, 7042, 147, 4, 28, "Text"],
Cell[195702, 7048, 112, 3, 31, "Input",
  InitializationCell->True],
Cell[195817, 7053, 40, 0, 28, "Text"],
Cell[195860, 7055, 111, 3, 31, "Input",
  InitializationCell->True],
Cell[195974, 7060, 228, 4, 48, "Text"],
Cell[196205, 7066, 259, 9, 28, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[196501, 7080, 39, 0, 31, "Subsubsection"],
Cell[196543, 7082, 89, 2, 28, "Text"],
Cell[196635, 7086, 44, 0, 28, "Text"],
Cell[196682, 7088, 142, 3, 31, "Input"],
Cell[196827, 7093, 44, 0, 28, "Text"],
Cell[196874, 7095, 353, 8, 155, "Input"],
Cell[197230, 7105, 99, 2, 28, "Text"],
Cell[197332, 7109, 72, 2, 31, "Input"],
Cell[197407, 7113, 248, 4, 48, "Text"],
Cell[197658, 7119, 81, 2, 31, "Input"],
Cell[197742, 7123, 157, 3, 28, "Text"],
Cell[197902, 7128, 374, 8, 100, "Input"],
Cell[198279, 7138, 290, 5, 48, "Text"],
Cell[198572, 7145, 633, 13, 192, "Input"],
Cell[199208, 7160, 107, 2, 31, "Input"],
Cell[199318, 7164, 298, 5, 48, "Text"],
Cell[199619, 7171, 1030, 19, 330, "Input"],
Cell[200652, 7192, 108, 2, 31, "Input"],
Cell[200763, 7196, 381, 6, 68, "Text"],
Cell[201147, 7204, 155, 3, 54, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[201363, 7214, 60, 1, 59, "Section"],

Cell[CellGroupData[{
Cell[201448, 7219, 76, 1, 43, "Subsection"],
Cell[201527, 7222, 1490, 26, 168, "Text"],

Cell[CellGroupData[{
Cell[203042, 7252, 75, 1, 37, "Subsubsection"],
Cell[203120, 7255, 157, 3, 28, "Text"],
Cell[203280, 7260, 540, 11, 152, "Input",
  InitializationCell->True],
Cell[203823, 7273, 59, 0, 28, "Text"],
Cell[203885, 7275, 214, 5, 32, "Input",
  InitializationCell->True],
Cell[204102, 7282, 110, 3, 28, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[204249, 7290, 62, 1, 37, "Subsubsection"],
Cell[204314, 7293, 163, 4, 32, "Input"],
Cell[204480, 7299, 152, 4, 32, "Input"],
Cell[204635, 7305, 120, 3, 32, "Input"],
Cell[204758, 7310, 72, 2, 31, "Input"],
Cell[204833, 7314, 121, 3, 32, "Input"],
Cell[204957, 7319, 91, 2, 31, "Input"],
Cell[205051, 7323, 93, 2, 31, "Input"],
Cell[205147, 7327, 76, 0, 28, "Text"],
Cell[205226, 7329, 161, 4, 32, "Input"],
Cell[205390, 7335, 143, 4, 32, "Input"],
Cell[205536, 7341, 115, 3, 32, "Input"],
Cell[205654, 7346, 158, 4, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[205861, 7356, 55, 1, 37, "Subsection"],

Cell[CellGroupData[{
Cell[205941, 7361, 90, 1, 37, "Subsubsection"],
Cell[206034, 7364, 486, 9, 68, "Text"],
Cell[206523, 7375, 156, 4, 32, "Input"],
Cell[206682, 7381, 138, 3, 32, "Input"],
Cell[206823, 7386, 39, 0, 28, "Text"],
Cell[206865, 7388, 371, 9, 61, "Input",
  InitializationCell->True],
Cell[207239, 7399, 106, 3, 32, "Input"],
Cell[207348, 7404, 48, 0, 28, "Text"],
Cell[207399, 7406, 99, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[207535, 7414, 64, 1, 37, "Subsubsection"],
Cell[207602, 7417, 92, 3, 32, "Input"],
Cell[207697, 7422, 94, 2, 28, "Text"],
Cell[207794, 7426, 94, 3, 32, "Input"],
Cell[207891, 7431, 141, 3, 28, "Text"],
Cell[208035, 7436, 139, 3, 32, "Input"],
Cell[208177, 7441, 98, 3, 32, "Input"],
Cell[208278, 7446, 96, 3, 32, "Input"],
Cell[208377, 7451, 118, 3, 28, "Text"],
Cell[208498, 7456, 102, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[208637, 7464, 69, 1, 31, "Subsubsection"],
Cell[208709, 7467, 107, 3, 32, "Input"],
Cell[208819, 7472, 56, 0, 28, "Text"],
Cell[208878, 7474, 105, 3, 32, "Input"],
Cell[208986, 7479, 92, 3, 32, "Input"],
Cell[209081, 7484, 268, 8, 32, "Input"],
Cell[209352, 7494, 269, 8, 32, "Input"],
Cell[209624, 7504, 216, 5, 32, "Input"],
Cell[209843, 7511, 219, 5, 32, "Input"],
Cell[210065, 7518, 183, 4, 32, "Input"],
Cell[210251, 7524, 201, 4, 28, "Text"],
Cell[210455, 7530, 92, 3, 32, "Input"],
Cell[210550, 7535, 118, 3, 32, "Input"],
Cell[210671, 7540, 100, 3, 32, "Input"],
Cell[210774, 7545, 94, 3, 32, "Input"],
Cell[210871, 7550, 99, 3, 32, "Input"],
Cell[210973, 7555, 221, 5, 32, "Input"],
Cell[211197, 7562, 232, 5, 32, "Input"],
Cell[211432, 7569, 232, 5, 32, "Input"],
Cell[211667, 7576, 106, 3, 32, "Input"],
Cell[211776, 7581, 93, 3, 32, "Input"],
Cell[211872, 7586, 49, 0, 28, "Text"],
Cell[211924, 7588, 113, 3, 32, "Input"],
Cell[212040, 7593, 158, 4, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[212235, 7602, 64, 1, 37, "Subsubsection"],
Cell[212302, 7605, 67, 0, 28, "Text"],
Cell[212372, 7607, 99, 3, 32, "Input"],
Cell[212474, 7612, 113, 3, 32, "Input"],
Cell[212590, 7617, 139, 3, 32, "Input"],
Cell[212732, 7622, 139, 3, 32, "Input"],
Cell[212874, 7627, 136, 3, 32, "Input"],
Cell[213013, 7632, 136, 3, 32, "Input"],
Cell[213152, 7637, 105, 3, 32, "Input"],
Cell[213260, 7642, 72, 0, 28, "Text"],
Cell[213335, 7644, 342, 9, 80, "Input"],
Cell[213680, 7655, 93, 3, 32, "Input"],
Cell[213776, 7660, 95, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[213920, 7669, 88, 1, 43, "Subsection"],
Cell[214011, 7672, 115, 3, 32, "Input"],
Cell[214129, 7677, 46, 0, 28, "Text"],
Cell[214178, 7679, 96, 3, 32, "Input"],
Cell[214277, 7684, 144, 4, 32, "Input"],
Cell[214424, 7690, 174, 4, 32, "Input"],

Cell[CellGroupData[{
Cell[214623, 7698, 56, 1, 37, "Subsubsection"],
Cell[214682, 7701, 162, 5, 28, "Text"],
Cell[214847, 7708, 118, 3, 32, "Input"],
Cell[214968, 7713, 117, 3, 32, "Input"],
Cell[215088, 7718, 218, 5, 32, "Input"],
Cell[215309, 7725, 100, 3, 32, "Input"],
Cell[215412, 7730, 100, 3, 32, "Input"],
Cell[215515, 7735, 166, 4, 32, "Input"],
Cell[215684, 7741, 181, 4, 28, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[215902, 7750, 60, 1, 31, "Subsubsection"],
Cell[215965, 7753, 108, 3, 28, "Text"],
Cell[216076, 7758, 93, 3, 32, "Input"],
Cell[216172, 7763, 92, 3, 32, "Input"],
Cell[216267, 7768, 119, 3, 28, "Text"],
Cell[216389, 7773, 95, 3, 32, "Input"],
Cell[216487, 7778, 59, 0, 28, "Text"],
Cell[216549, 7780, 98, 3, 32, "Input"],
Cell[216650, 7785, 205, 4, 28, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[216892, 7794, 67, 1, 37, "Subsubsection"],
Cell[216962, 7797, 111, 3, 32, "Input"],
Cell[217076, 7802, 112, 3, 32, "Input"],
Cell[217191, 7807, 50, 0, 28, "Text"],
Cell[217244, 7809, 129, 3, 32, "Input"],
Cell[217376, 7814, 102, 3, 32, "Input"],
Cell[217481, 7819, 118, 3, 32, "Input"],
Cell[217602, 7824, 118, 3, 32, "Input"],
Cell[217723, 7829, 118, 3, 32, "Input"],
Cell[217844, 7834, 134, 3, 32, "Input"],
Cell[217981, 7839, 134, 3, 32, "Input"],
Cell[218118, 7844, 208, 5, 32, "Input"],
Cell[218329, 7851, 96, 3, 32, "Input"],
Cell[218428, 7856, 164, 4, 32, "Input"],
Cell[218595, 7862, 89, 3, 32, "Input"],
Cell[218687, 7867, 96, 3, 32, "Input"],
Cell[218786, 7872, 136, 3, 32, "Input"],
Cell[218925, 7877, 94, 3, 32, "Input"],
Cell[219022, 7882, 110, 3, 32, "Input"],
Cell[219135, 7887, 94, 3, 32, "Input"],
Cell[219232, 7892, 162, 4, 32, "Input"],
Cell[219397, 7898, 94, 2, 28, "Text"],
Cell[219494, 7902, 123, 3, 32, "Input"],
Cell[219620, 7907, 128, 3, 32, "Input"],
Cell[219751, 7912, 138, 3, 28, "Text"],
Cell[219892, 7917, 166, 5, 32, "Input"],
Cell[220061, 7924, 94, 3, 32, "Input"],
Cell[220158, 7929, 165, 3, 28, "Text"],
Cell[220326, 7934, 127, 3, 32, "Input"],
Cell[220456, 7939, 94, 3, 32, "Input"],
Cell[220553, 7944, 73, 0, 28, "Text"],
Cell[220629, 7946, 114, 3, 32, "Input"],
Cell[220746, 7951, 94, 3, 32, "Input"],
Cell[220843, 7956, 162, 4, 32, "Input"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[221066, 7967, 168, 6, 59, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[221259, 7977, 61, 1, 43, "Subsection"],
Cell[221323, 7980, 504, 8, 68, "Text"],
Cell[221830, 7990, 139, 3, 32, "Input"],
Cell[221972, 7995, 635, 9, 88, "Text"],
Cell[222610, 8006, 93, 2, 28, "Text"],
Cell[222706, 8010, 92, 3, 32, "Input"],
Cell[222801, 8015, 264, 10, 28, "Text"],

Cell[CellGroupData[{
Cell[223090, 8029, 98, 1, 37, "Subsubsection"],
Cell[223191, 8032, 93, 2, 28, "Text"],
Cell[223287, 8036, 200, 6, 32, "Input",
  Evaluatable->False,
  InitializationCell->True],
Cell[223490, 8044, 104, 3, 32, "Input"],
Cell[223597, 8049, 53, 0, 28, "Text"],
Cell[223653, 8051, 108, 3, 32, "Input"],
Cell[223764, 8056, 137, 3, 28, "Text"],
Cell[223904, 8061, 177, 4, 32, "Input"],
Cell[224084, 8067, 135, 3, 28, "Text"],
Cell[224222, 8072, 109, 3, 32, "Input"],
Cell[224334, 8077, 142, 4, 32, "Input"],
Cell[224479, 8083, 136, 3, 32, "Input"],
Cell[224618, 8088, 102, 3, 32, "Input"],
Cell[224723, 8093, 214, 4, 48, "Text"],
Cell[224940, 8099, 110, 3, 32, "Input"],
Cell[225053, 8104, 110, 3, 32, "Input"],
Cell[225166, 8109, 187, 6, 32, "Input"],
Cell[225356, 8117, 155, 5, 32, "Input"],
Cell[225514, 8124, 143, 4, 32, "Input"],
Cell[225660, 8130, 102, 3, 32, "Input"],
Cell[225765, 8135, 249, 5, 48, "Text"],
Cell[226017, 8142, 160, 4, 32, "Input"],
Cell[226180, 8148, 142, 4, 32, "Input"],
Cell[226325, 8154, 142, 4, 32, "Input"],
Cell[226470, 8160, 102, 3, 32, "Input"],
Cell[226575, 8165, 89, 2, 28, "Text"],
Cell[226667, 8169, 113, 3, 32, "Input"],
Cell[226783, 8174, 193, 4, 28, "Text"],
Cell[226979, 8180, 113, 3, 32, "Input"],
Cell[227095, 8185, 119, 3, 28, "Text"],
Cell[227217, 8190, 113, 3, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[227379, 8199, 90, 2, 43, "Subsection",
  Evaluatable->False],
Cell[227472, 8203, 250, 4, 48, "Text"],
Cell[227725, 8209, 186, 4, 32, "Input"],
Cell[227914, 8215, 97, 3, 32, "Input"],
Cell[228014, 8220, 99, 3, 32, "Input"],
Cell[228116, 8225, 108, 3, 32, "Input"],
Cell[228227, 8230, 114, 3, 32, "Input"],
Cell[228344, 8235, 99, 3, 32, "Input"],
Cell[228446, 8240, 110, 3, 32, "Input"],
Cell[228559, 8245, 134, 3, 32, "Input"],
Cell[228696, 8250, 87, 3, 32, "Input"],
Cell[228786, 8255, 91, 3, 32, "Input"],
Cell[228880, 8260, 102, 3, 32, "Input"],
Cell[228985, 8265, 109, 3, 32, "Input"],
Cell[229097, 8270, 86, 3, 32, "Input"],
Cell[229186, 8275, 110, 3, 32, "Input"],
Cell[229299, 8280, 134, 3, 32, "Input"],
Cell[229436, 8285, 109, 3, 32, "Input"],
Cell[229548, 8290, 86, 3, 32, "Input"],
Cell[229637, 8295, 86, 2, 28, "Text"],
Cell[229726, 8299, 138, 3, 32, "Input"],
Cell[229867, 8304, 89, 3, 32, "Input"],
Cell[229959, 8309, 153, 4, 32, "Input"],
Cell[230115, 8315, 119, 3, 32, "Input"],
Cell[230237, 8320, 118, 3, 32, "Input"],
Cell[230358, 8325, 110, 3, 32, "Input"],
Cell[230471, 8330, 92, 2, 28, "Text"],
Cell[230566, 8334, 101, 3, 32, "Input"],
Cell[230670, 8339, 91, 3, 32, "Input"],
Cell[230764, 8344, 90, 3, 32, "Input"],
Cell[230857, 8349, 72, 0, 28, "Text"],
Cell[230932, 8351, 89, 3, 32, "Input"],
Cell[231024, 8356, 154, 3, 28, "Text"],
Cell[231181, 8361, 101, 3, 32, "Input"],
Cell[231285, 8366, 53, 0, 28, "Text"],
Cell[231341, 8368, 289, 7, 58, "Input"],
Cell[231633, 8377, 161, 4, 58, "Input"],
Cell[231797, 8383, 228, 6, 28, "Text"],
Cell[232028, 8391, 79, 2, 31, "Input"],
Cell[232110, 8395, 479, 8, 124, "Input"],
Cell[232592, 8405, 41, 0, 28, "Text"],
Cell[232636, 8407, 101, 3, 32, "Input"],
Cell[232740, 8412, 107, 3, 32, "Input"],
Cell[232850, 8417, 105, 3, 32, "Input"],
Cell[232958, 8422, 110, 3, 32, "Input"],
Cell[233071, 8427, 132, 3, 28, "Text"],
Cell[233206, 8432, 71, 2, 31, "Input"],
Cell[233280, 8436, 66, 2, 31, "Input"],
Cell[233349, 8440, 64, 2, 31, "Input"],
Cell[233416, 8444, 64, 2, 31, "Input"],
Cell[233483, 8448, 121, 3, 31, "Input"],
Cell[233607, 8453, 74, 2, 31, "Input"],
Cell[233684, 8457, 92, 2, 31, "Input"],
Cell[233779, 8461, 220, 6, 28, "Text"],
Cell[234002, 8469, 89, 2, 31, "Input"],
Cell[234094, 8473, 89, 2, 31, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[234220, 8480, 89, 2, 43, "Subsection",
  Evaluatable->False],
Cell[234312, 8484, 248, 4, 48, "Text"],
Cell[234563, 8490, 192, 4, 32, "Input"],
Cell[234758, 8496, 74, 2, 31, "Input"],
Cell[234835, 8500, 100, 3, 32, "Input"],
Cell[234938, 8505, 109, 3, 32, "Input"],
Cell[235050, 8510, 109, 3, 32, "Input"],
Cell[235162, 8515, 79, 2, 31, "Input"],
Cell[235244, 8519, 127, 3, 32, "Input"],
Cell[235374, 8524, 88, 3, 32, "Input"],
Cell[235465, 8529, 102, 3, 32, "Input"],
Cell[235570, 8534, 110, 3, 32, "Input"],
Cell[235683, 8539, 127, 3, 32, "Input"],
Cell[235813, 8544, 88, 3, 32, "Input"],
Cell[235904, 8549, 108, 3, 32, "Input"],
Cell[236015, 8554, 87, 3, 32, "Input"],
Cell[236105, 8559, 87, 3, 32, "Input"],
Cell[236195, 8564, 165, 4, 58, "Input"],
Cell[236363, 8570, 165, 4, 58, "Input"],
Cell[236531, 8576, 147, 3, 28, "Text"],
Cell[236681, 8581, 228, 5, 58, "Input"],
Cell[236912, 8588, 111, 3, 32, "Input"],
Cell[237026, 8593, 110, 3, 32, "Input"],
Cell[237139, 8598, 90, 3, 32, "Input"],
Cell[237232, 8603, 73, 0, 28, "Text"],
Cell[237308, 8605, 102, 3, 32, "Input"],
Cell[237413, 8610, 290, 7, 58, "Input"],
Cell[237706, 8619, 162, 4, 58, "Input"],
Cell[237871, 8625, 211, 4, 48, "Text"],
Cell[238085, 8631, 479, 8, 124, "Input"],
Cell[238567, 8641, 132, 3, 28, "Text"],
Cell[238702, 8646, 71, 2, 31, "Input"],
Cell[238776, 8650, 66, 2, 31, "Input"],
Cell[238845, 8654, 64, 2, 31, "Input"],
Cell[238912, 8658, 64, 2, 31, "Input"],
Cell[238979, 8662, 120, 3, 31, "Input"],
Cell[239102, 8667, 73, 2, 31, "Input"],
Cell[239178, 8671, 92, 2, 31, "Input"],
Cell[239273, 8675, 212, 6, 28, "Text"],
Cell[239488, 8683, 89, 2, 31, "Input"],
Cell[239580, 8687, 89, 2, 31, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[239706, 8694, 90, 2, 43, "Subsection",
  Evaluatable->False],
Cell[239799, 8698, 248, 4, 48, "Text"],
Cell[240050, 8704, 189, 4, 32, "Input"],
Cell[240242, 8710, 74, 2, 31, "Input"],
Cell[240319, 8714, 100, 3, 32, "Input"],
Cell[240422, 8719, 106, 3, 32, "Input"],
Cell[240531, 8724, 116, 3, 32, "Input"],
Cell[240650, 8729, 109, 3, 32, "Input"],
Cell[240762, 8734, 107, 3, 32, "Input"],
Cell[240872, 8739, 179, 5, 32, "Input"],
Cell[241054, 8746, 126, 3, 32, "Input"],
Cell[241183, 8751, 130, 3, 32, "Input"],
Cell[241316, 8756, 88, 3, 32, "Input"],
Cell[241407, 8761, 88, 3, 32, "Input"],
Cell[241498, 8766, 44, 0, 28, "Text"],
Cell[241545, 8768, 108, 3, 32, "Input"],
Cell[241656, 8773, 64, 2, 31, "Input"],
Cell[241723, 8777, 108, 3, 32, "Input"],
Cell[241834, 8782, 64, 2, 31, "Input"],
Cell[241901, 8786, 214, 4, 48, "Text"],
Cell[242118, 8792, 90, 3, 32, "Input"],
Cell[242211, 8797, 102, 3, 32, "Input"],
Cell[242316, 8802, 289, 7, 58, "Input"],
Cell[242608, 8811, 161, 4, 58, "Input"],
Cell[242772, 8817, 100, 3, 32, "Input"],
Cell[242875, 8822, 117, 2, 31, "Input"],
Cell[242995, 8826, 72, 2, 31, "Input"],
Cell[243070, 8830, 92, 2, 31, "Input"],
Cell[243165, 8834, 144, 3, 28, "Text"],
Cell[243312, 8839, 91, 2, 31, "Input"],
Cell[243406, 8843, 89, 2, 31, "Input"],
Cell[243498, 8847, 89, 2, 31, "Input"],
Cell[243590, 8851, 136, 3, 28, "Text"],
Cell[243729, 8856, 478, 8, 124, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[244256, 8870, 87, 2, 73, "Section",
  CellTags->"MathGL"],
Cell[244346, 8874, 269, 6, 48, "Text"],

Cell[CellGroupData[{
Cell[244640, 8884, 61, 1, 43, "Subsection"],
Cell[244704, 8887, 272, 6, 46, "Text",
  Evaluatable->False],
Cell[244979, 8895, 170, 4, 27, "Text",
  Evaluatable->False],
Cell[245152, 8901, 143, 4, 32, "Input",
  InitializationCell->True],
Cell[245298, 8907, 97, 3, 32, "Input"],
Cell[245398, 8912, 138, 4, 27, "Text",
  Evaluatable->False],
Cell[245539, 8918, 141, 4, 32, "Input",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[245717, 8927, 57, 1, 37, "Subsection"],
Cell[245777, 8930, 792, 17, 120, "Text"],
Cell[246572, 8949, 113, 3, 32, "Input"],
Cell[246688, 8954, 186, 4, 48, "Text"],
Cell[246877, 8960, 132, 3, 32, "Input"],
Cell[247012, 8965, 52, 0, 28, "Text"],
Cell[247067, 8967, 50, 1, 28, "Text"],
Cell[247120, 8970, 141, 3, 28, "Text"],
Cell[247264, 8975, 518, 11, 152, "Input"],
Cell[247785, 8988, 182, 4, 56, "Input"],
Cell[247970, 8994, 125, 3, 32, "Input"],
Cell[248098, 8999, 126, 3, 32, "Input"],
Cell[248227, 9004, 96, 3, 32, "Input"],
Cell[248326, 9009, 98, 3, 32, "Input"],
Cell[248427, 9014, 91, 3, 32, "Input"],
Cell[248521, 9019, 157, 3, 28, "Text"],
Cell[248681, 9024, 92, 3, 32, "Input"],
Cell[248776, 9029, 40, 0, 28, "Text"],
Cell[248819, 9031, 132, 3, 32, "Input"],
Cell[248954, 9036, 220, 4, 48, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[249223, 9046, 56, 1, 24, "Subsubtitle"],
Cell[249282, 9049, 207, 5, 62, "Text",
  Evaluatable->False,
  CellTags->"G1"],
Cell[249492, 9056, 147, 5, 42, "Text",
  Evaluatable->False,
  CellTags->"K2"],
Cell[249642, 9063, 186, 5, 42, "Text",
  Evaluatable->False,
  CellTags->"M3"],
Cell[249831, 9070, 246, 8, 42, "Text",
  CellTags->"O-S"],
Cell[250080, 9080, 140, 4, 42, "Text",
  CellTags->"S1"],
Cell[250223, 9086, 515, 15, 62, "Text",
  Evaluatable->False,
  CellTags->"S4"],
Cell[250741, 9103, 145, 5, 42, "Text",
  Evaluatable->False,
  CellTags->"S5"],
Cell[250889, 9110, 261, 9, 42, "Text",
  CellTags->"S8"]
}, Closed]],

Cell[CellGroupData[{
Cell[251187, 9124, 62, 1, 24, "Subsubtitle"],
Cell[251252, 9127, 107, 5, 106, "Text",
  CellTags->"HP"],
Cell[251362, 9134, 47, 0, 28, "Text"],
Cell[251412, 9136, 90, 2, 28, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

