(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 4.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     66405,       2481]*)
(*NotebookOutlinePosition[     94895,       3401]*)
(*  CellTagsIndexPosition[     94826,       3395]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Pseudo-Euclidean Vector Spaces", "Title",
  TextAlignment->Center,
  FontSize->35],

Cell["by Rolf Sulanke", "Subtitle",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontFamily->"Times New Roman"],

Cell["version 2, September 27, 2003", "Text",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center,
  FontSize->13,
  Background->None],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Left,
  FontFamily->"Times New Roman"],

Cell[TextData[{
  "This notebook contains the basic definition of vector operations in the \
n-dimensional pseudo-euclidean space, generalizing the euclidean vector \
algebra treated in the notebook ",
  ButtonBox["Euklid.nb",
    ButtonData:>{
      FrontEnd`FileName[ {"."}, "Euklid.nb", CharacterEncoding -> 
        "iso8859-1"], None},
    ButtonStyle->"Hyperlink"],
  "   After formalizing the basic concepts of pseudo-euclidean vector spaces \
including the cross product a general orthogonalization procedure is \
developed:fot any finite sequence of vectors of a pseudo-euclidean vector \
space the procedure orthonorm yields an orthonormal basis of the span of the \
sequence, also if the span is isotropic."
}], "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell["Version", "Subsubsection"],

Cell[TextData[{
  "This notebook is  version  2 of the notebook pseuklid.nb,  published first \
in the item Spheres  ",
  ButtonBox["[1]",
    ButtonData:>"S1",
    ButtonStyle->"Hyperlink"],
  " .The same is true for the accompanying packages euvec.m, pseuvec.m. The \
versions of the notebooks and packages of the item Spheres should not be \
mixed; this notebook  will not run correctly with the old version. ",
  "The notebook is developed with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " v. 4.200. "
}], "Text"],

Cell["\<\
Changes: The most interesting subject treated in this notebook is the \
orthogonalization of vector sequences in the pseudo-euclidean case, which has \
been corrected and refined.   Now the result of orthonorm is an orthogonal \
basis of the span of the vector sequence; linearely dependent isotropic \
vectors will not appear. Furthermore, the procedure psfilter has been \
simplified: now a repeated application of psfilter  is not necessary in any \
cases.\
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell["Keywords", "Subsubsection"],

Cell["\<\
Dimension dim, index ind, pseudo-euclidean scalar product, generalized cross \
product, spacelike, timelike, isotropic vectors, norming, orthogonalization, \
renorming, pseudo-orthogonal basis, psfilter, orthopairs.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Copyright", "Subsubsection"],

Cell["\<\
This notebook, the linked notebooks, and the accompanying packages are  \
public. Authors who intend to publish a changed or completed version of them \
should do it under their own names with the condition that they cite the \
original notebook with the Internet address or other source where they got \
it. I am not responsible for errors or damages originated by the use of the \
procedures contained in my notebooks or packages; anybody who applies them \
should test carefully whether they are appropriate for his purposes.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Subsection",
  FontFamily->"Times"],

Cell["\<\
First, if not done already,  copy the needed package  euvec.m, pseuvec.m,  \
this notebook pseuklid.nb, and the notebook Euklid.nb  into your working \
directory, and  insert the path of your working directory, e.g. under \
Windows, \"C:\\Eigene Dateien\\mymath\\spheres.v4\", into the next command \
line:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetDirectory["\<~/mymath/work\>"]\)], "Input",
  CellLabel->"In[1]:=",
  InitializationCell->True,
  FontFamily->"Times"],

Cell[BoxData[
    \("/home/rolf/mymath/work"\)], "Output",
  CellLabel->"Out[1]="]
}, Open  ]],

Cell[TextData[StyleBox["Now: Activite Kernel/Evaluation/Evaluate \
Initialization from the menu!",
  FontSize->18,
  FontColor->RGBColor[1, 0, 0]]], "Text"],

Cell[BoxData[
    \(Needs["\<pseuvec`\>"]\)], "Input",
  CellLabel->"In[2]:=",
  InitializationCell->True,
  FontFamily->"Times"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1. Introduction.  The usages", "Section"],

Cell[CellGroupData[{

Cell["1.1 Introduction", "Subsection"],

Cell["\<\
This notebook contains the basic definition of vector operations in the \
n-dimensional pseudo-euclidean space, including the euclidean case. The \
dimension dim and the index ind - the number of diagonal elements equal -1 in \
an orthogonalized basis-  are the characterising constants for the \
pseudo-euclidean vector spaces, which are vector spaces over the real \
numbers.  In special relativity theory the \"world\" = \"space-time\"  is \
based on the pseudo-euclidean vector space of dimension dim = 4 and index ind \
= 1, corresponding to the three-dimensionality of the physical space and the \
one-dimensionality of time. For the N-dimensional M\[ODoubleDot]bius space  \
we have to set dim = N +2 and ind = 1 . In the n-dimensional euclidean case \
we have, of course, dim = n and ind = 0. In the Lie geometry of spheres one \
has dim = 6 and ind = 2. As we wrote this notebook, we have been interested \
in the Moebius geometry of the 3-sphere. Thus, the default values of \
dimension and index are \
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(dim\  = \ 5; ind = 1;\)], "Input",
  CellLabel->"In[3]:=",
  InitializationCell->True,
  FontSize->15],

Cell["\<\
Always have in mind that almost all the defined concepts  depend on dim and \
ind; if you want to change the default values, simply enter the commands
dim = n; ind = m;
 where n and m are integers, 0 \[LessEqual] m \[LessEqual] n, are your \
preferred values. \
\>", "Text",
  FontSize->13],

Cell["\<\
The basic concepts used in the pseudo-euclidean vector algebra are contained  \
in the package pseuvec.m, which automatically imports the package euvec.m \
containing general definitions of  n-dimensional linear algebra. \
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell["\<\
If you want information about these  loaded concepts, enter e.g.\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(\(?ide\)\)], "Input",
  CellLabel->"In[4]:=",
  InitializationCell->True,
  FontSize->15],

Cell["\<\
 Often you can inform yourself about the definitions by evoking or applying \
them:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ide[]\)], "Input",
  CellLabel->"In[5]:=",
  InitializationCell->True],

Cell[BoxData[
    \({1, 1, 1, 1, \(-1\)}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell["The standard basis is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[stb[i], {i, \ dim}]\)], "Input",
  CellLabel->"In[6]:=",
  InitializationCell->True],

Cell[BoxData[
    \({{1, 0, 0, 0, 0}, {0, 1, 0, 0, 0}, {0, 0, 1, 0, 0}, {0, 0, 0, 1, 
        0}, {0, 0, 0, 0, 1}}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["\<\
and the matrix of the scalar products of the basis vectors is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[pssp[stb[i], \ stb[j]], \ {i, dim}, \ {j, dim}] // 
      MatrixForm\)], "Input",
  CellLabel->"In[7]:=",
  InitializationCell->True],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", \(-1\)}
            }], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[7]//MatrixForm="]
}, Open  ]],

Cell["Here pssp denotes the pseudo-euclidean scalar product.", "Text"],

Cell[BoxData[
    \(\(?pssp\)\)], "Input",
  CellLabel->"In[21]:="],

Cell["\<\
All the definitions contained in the packages euvec.m and pseuvec.m are \
listed in the next subsection 1.2.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["1.2 The usages", "Subsection"],

Cell[TextData[{
  "Here is an overview of the new introduced symbols, and their usages. In \
difference to the names used in  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " the new introduced names begin always with small letters. To read the \
usages first initialize the notebook. "
}], "Text"],

Cell[CellGroupData[{

Cell["Concepts in euvec.m", "Subsubsection",
  FontFamily->"Times"],

Cell["Valid for arbitrary values of the dimension dim are", "Text"],

Cell[BoxData[
    \(\(?null\)\)], "Input",
  CellLabel->"In[49]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?vec\)\)], "Input",
  CellLabel->"In[50]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?randomv\)\)], "Input",
  CellLabel->"In[8]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?stb\)\)], "Input",
  CellLabel->"In[52]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?cross\)\)], "Input",
  CellLabel->"In[53]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?outzero\)\)], "Input",
  CellLabel->"In[54]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?rank\)\)], "Input",
  CellLabel->"In[55]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?basis\)\)], "Input",
  CellLabel->"In[9]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?sterproj\)\)], "Input",
  CellLabel->"In[56]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?invsterproj\)\)], "Input",
  CellLabel->"In[57]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?hyperplane\)\)], "Input",
  CellLabel->"In[58]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?stb\)\)], "Input",
  CellLabel->"In[59]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?unit\)\)], "Input",
  CellLabel->"In[60]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?sphericalreflection\)\)], "Input",
  CellLabel->"In[61]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?esorthonorm\)\)], "Input",
  CellLabel->"In[62]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?innerprod\)\)], "Input",
  CellLabel->"In[63]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?orthocomplement\)\)], "Input",
  CellLabel->"In[64]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?normed\)\)], "Input",
  CellLabel->"In[65]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?print\)\)], "Input",
  CellLabel->"In[66]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?neglect\)\)], "Input",
  CellLabel->"In[67]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?renorm\)\)], "Input",
  CellLabel->"In[68]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?smoothing\)\)], "Input",
  CellLabel->"In[69]:=",
  FontFamily->"Times"],

Cell["The following commands work in dimensions  4 or 3  only:", "Text"],

Cell[BoxData[
    \(\(?tg4frame\)\)], "Input",
  CellLabel->"In[70]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?sphere\)\)], "Input",
  CellLabel->"In[71]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?sphereplot3D\)\)], "Input",
  CellLabel->"In[72]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?subsphere\)\)], "Input",
  CellLabel->"In[73]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(\(?subspheremf\)\)], "Input",
  CellLabel->"In[74]:=",
  FontFamily->"Times"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Concepts in pseuvec.m:",
  FontSize->12]], "Subsubsection",
  FontSize->10],

Cell[BoxData[
    \(\(?ide\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(\(?pssp\)\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(\(?dual\)\)], "Input",
  CellLabel->"In[27]:="],

Cell[BoxData[
    \(\(?psCross\)\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(\(?pscross\)\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(\(?ch\)\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(\(?pr\)\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(\(?orthonorm\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(Options[orthonorm]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(\(?normed\)\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(\(?print\)\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(\(?neglect\)\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(\(?psfilter\)\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(\(?normalize\)\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(\(?orthopair\)\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(\[IndentingNewLine]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Full definitions", "Subsubsection",
  FontFamily->"Times"],

Cell["\<\
For getting the usage together with the complete definition, enter the name \
prepended with two ?, e.g.\
\>", "Text"],

Cell[BoxData[
    \(?? ind\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(?? pscross\)], "Input",
  CellLabel->"In[23]:=",
  FontFamily->"Times"],

Cell[BoxData[
    \(?? esorthonorm\)], "Input",
  CellLabel->"In[24]:="],

Cell["\<\
Since the names are prepended by the ContextNames the definition obtained in \
this way are hard to read. Therefore you will find some of them in the \
original form in unevaluatable cells.  For other ones it is recommended to \
look into the package.\
\>", "Text",
  Evaluatable->False]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
2. Vector Operations in Euclidean and Pseudo-Euclidean Spaces\
\>", "Section",
  Evaluatable->False,
  Background->None],

Cell[CellGroupData[{

Cell["2.1 Basic definitions", "Subsection",
  Evaluatable->False,
  FontSize->14,
  Background->None],

Cell["\<\
Of course, we can apply all the operations of real linear vector algebra. We \
have the null vector:\
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(\(\(\n\)\(null[]\)\)\)], "Input",
  CellLabel->"In[13]:=",
  FontSize->15],

Cell[BoxData[
    \(null[]\)], "Input",
  CellLabel->"Out[13]="],

Cell["The standard basis is:", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(Table[stb[i], {i, \ dim}]\)], "Input",
  CellLabel->"In[14]:=",
  PageWidth->Infinity,
  FontFamily->"Courier New",
  FontSize->15,
  FontWeight->"Bold",
  FontColor->GrayLevel[0],
  Background->None],

Cell["\<\
The basic concept of pseudo-euclidean geometry is the indefinite scalar \
product pssp. 
The standard basis {stb[i]} is orthonormal with respect to this scalar \
product:\
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(MatrixForm[
      Table[pssp[stb[i], \ stb[j]], \ {i, \ dim}, \ {j, \ dim}]]\)], "Input",
  CellLabel->"In[15]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell["The diagonal of this matrix is", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(ide[]\)], "Input",
  CellLabel->"In[16]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell["The dualization of a vector ", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(vec[x]\)], "Input",
  CellLabel->"In[17]:=",
  FontSize->15],

Cell[" is given by", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(dual[vec[x]]\)], "Input",
  CellLabel->"In[18]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[TextData[{
  "This corresponds to the dual coordinates of a vector in Riemannian \
geometry. The scalar product pssp is related to the usual positive definite \
scalar product, denoted in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " by  Dot ., as follows"
}], "Text",
  FontSize->13],

Cell[BoxData[
    \(pssp[vec[x], \ vec[y]]\  == \ vec[x] . dual[vec[y]]\)], "Input",
  CellLabel->"In[19]:=",
  FontSize->15],

Cell["\<\
The definition of the pseudo-orthogonal scalar product of type (dim - ind, \
ind) implies the following rules:\
\>", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(pssp[x, y] == pssp[y, x]\)], "Input",
  CellLabel->"In[20]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pssp[x + y, u] == pssp[x, u] + pssp[y, u]\)], "Input",
  CellLabel->"In[21]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pssp[a\ k, l] == a\ pssp[k, l]\)], "Input",
  CellLabel->"In[22]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell["\<\
The Dot product is more general. Therefore commutativity is not valid, in \
general:\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(x . y\  == \ y . x\)], "Input",
  CellLabel->"In[23]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(\((vec[x] + vec[a])\) . vec[y]\  == \ 
      vec[y] . vec[x]\  + \ vec[y] . vec[a]\)], "Input",
  CellLabel->"In[25]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[26]:=",
  FontSize->15]
}, Closed]],

Cell[CellGroupData[{

Cell["2.2 Type of a vector", "Subsection",
  FontSize->14],

Cell["\<\
A non zero vector v is called  space-, time-, or light-like (in relativity \
theory),  if  its scalar square pssp[x,x]  is positive, negative, or zero, \
respectively. In geometrical context one mostly uses \"isotropic\" instead of \
\"lightlike\". This property of the vector can be indicated by the function \
ch (== character), which gives the sign of pssp[v, v].  \
\>", "Text",
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(\(?ch\)\)], "Input",
  CellLabel->"In[69]:=",
  FontSize->15],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  FontFamily->"Times",
  FontSize->11],

Cell["Error messages: The nullvector", "Text",
  FontSize->13],

Cell[BoxData[
    \(ch[null[]]\)], "Input",
  CellLabel->"In[8]:=",
  FontSize->15],

Cell["or a vector with incorrect dimension:", "Text",
  FontSize->13],

Cell[BoxData[
    \(ch[stb[1, 3]]\)], "Input",
  CellLabel->"In[10]:=",
  FontSize->15],

Cell["Timelike vectors", "Text",
  FontSize->13],

Cell[BoxData[
    StyleBox[\(ch[stb[dim]]\),
      FontSize->12]], "Input",
  CellLabel->"In[11]:=",
  FontSize->23,
  Background->None],

Cell[BoxData[
    \(ch[stb[5]*Cosh[t]\  + \ stb[1]*Sinh[t]]\)], "Input",
  CellLabel->"In[12]:=",
  FontSize->15],

Cell["Isotropic vectors:", "Text",
  FontSize->13],

Cell[BoxData[
    \(ch[stb[1]\ Cos[Pi/4]\  + \ stb[dim]\ Sin[Pi/4]]\)], "Input",
  CellLabel->"In[13]:=",
  FontSize->15],

Cell[BoxData[
    \(ch[stb[1]*a + \ stb[dim]*a\ ]\)], "Input",
  CellLabel->"In[14]:=",
  FontSize->15],

Cell["Spacelike vectors:", "Text",
  FontSize->13],

Cell[BoxData[
    \(ch[stb[1]]\)], "Input",
  CellLabel->"In[15]:=",
  FontSize->15],

Cell[BoxData[
    \(ch[stb[1]*Cosh[t]\  + \ stb[5]*Sinh[t]]\)], "Input",
  CellLabel->"In[16]:=",
  FontSize->15],

Cell["ch[stb[1]*Cos[t] + stb[2]*Sin[t]]", "Input",
  CellLabel->"In[17]:=",
  FontSize->14,
  Background->None],

Cell[BoxData[
    \(vec[x]\  - \ stb[dim]*x[dim]\)], "Input",
  CellLabel->"In[18]:="],

Cell["ch[vec[x] - stb[dim]*x[dim]]", "Input",
  CellLabel->"In[19]:=",
  FontSize->14,
  Background->None],

Cell["Type of a random vector", "Text"],

Cell[BoxData[
    \(ch[randomv[]]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(\(\(v1\)\(\ \)\(=\)\(\ \)\(randomv[]\)\(\ \ \)\)\)], "Input",
  CellLabel->"In[21]:="],

Cell[BoxData[
    \(ch[v1]\)], "Input",
  CellLabel->"In[22]:="],

Cell["\<\
The empirical probability that such a random vector is timelike equals \
approximately 0.06:\
\>", "Text"],

Cell[BoxData[
    \(zj\  = \ 0; 
    For[i = 1, 
      i < 10000, \ \(i++\), \n\t\((v1\  = \ randomv[]; 
        If[ch[v1] == \ \(-1\), \ zj\  = \ zj + 1])\)]; N[zj/10000]\)], "Input",\

  CellLabel->"In[23]:="],

Cell[BoxData[
    \(Remove[zj, \ v1, i]\)], "Input",
  CellLabel->"In[24]:="],

Cell["\<\
Sometimes, clearly, it is impossible to decide which character  the vector \
has, since it depends of the value of parameters:\
\>", "Text",
  FontSize->13],

Cell["ch[vec[x]]", "Input",
  CellLabel->"In[25]:=",
  FontSize->14,
  Background->None],

Cell[BoxData[
    \(ch[stb[1]\ Cos[t]\  + \ stb[dim]\ Sin[t]]\)], "Input",
  CellLabel->"In[26]:=",
  FontSize->15],

Cell["Plotting shows the character in dependence of the parameter:", "Text",
  FontSize->13],

Cell[BoxData[
    \(Plot[
      ch[stb[1]\ Cos[t]\  + \ stb[dim]\ Sin[t]], \ {t, 0, \ 
        2\ Pi}]\)], "Input",
  CellLabel->"In[27]:=",
  FontSize->15],

Cell["\<\
In the next example the character does not depend on the parameter; therefore \
it will be evaluated:\
\>", "Text"],

Cell[BoxData[
    \(ch[stb[1]\ Cos[t]\  + \ stb[dim - ind]\ Sin[t]]\)], "Input",
  CellLabel->"In[28]:=",
  FontSize->15]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.3 Norming", "Subsection",
  FontSize->14],

Cell["Now we consider the norming of the vector", "Text",
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(normalize[vec[x]]\)], "Input",
  CellLabel->"In[29]:=",
  FontSize->15,
  Background->None],

Cell[TextData[{
  "Since ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " often has difficulties with evaluations and simplifications of  Sqrt or \
Abs it is recommended to use ",
  "normalize",
  " only in unavoidable cases, and, if possible, only  at the end of a module \
or calculation."
}], "Text",
  FontSize->13],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  Evaluatable->False,
  FontFamily->"Times",
  FontSize->11,
  Background->None],

Cell[BoxData[
    \(\(?normalize\)\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(normalize[stb[1] + 2\ stb[2]]\)], "Input",
  CellLabel->"In[31]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell["\<\
Here you can see the problems if you want to norm general vectors:\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(normalize[stb[1]*Cosh[t] + stb[2]]\)], "Input",
  CellLabel->"In[32]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[33]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[34]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[%, \ t\  \[Element] \ Reals]\)], "Input",
  CellLabel->"In[35]:=",
  FontSize->15],

Cell[TextData[{
  "In newer versions, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " simplifies expressions with additional conditions, see Simplify in the \
help system. Sometimes the result depends on the place in the sequence of \
evaluations:"
}], "Text"],

Cell[BoxData[
    \(TrueQ[1 + \ Abs[\ Cosh[t]]\  >= \ 0]\)], "Input",
  CellLabel->"In[36]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[1 + \ Abs[\ Cosh[t]]\  >= \ 0, \ 
      t\  \[Element] \ Reals]\)], "Input",
  CellLabel->"In[37]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[Abs[\ Cosh[t]]\  >= \ 0, \ 
      t\  \[Element] \ Complexes]\)], "Input",
  CellLabel->"In[38]:=",
  FontSize->15],

Cell[BoxData[
    \(Simplify[Abs[t] >= \ 0, \ t\  \[Element] \ Complexes]\)], "Input",
  CellLabel->"In[39]:=",
  FontSize->15],

Cell[BoxData[
    \(TrueQ[Simplify[1 + Abs[Cosh[abcd]] >= \ 0]]\)], "Input",
  CellLabel->"In[40]:=",
  FontSize->15],

Cell["\<\
Mathematica does not return True, since generally t could be a complex \
parameter. But\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(TrueQ[Abs[1 + \ \ Cosh[t]^2\ ] >= \ 0]\)], "Input",
  CellLabel->"In[41]:=",
  FontSize->15],

Cell[BoxData[
    \(TrueQ[Simplify[Abs[1 + \ \ Cosh[t]^2\ ]] >= \ 0]\)], "Input",
  CellLabel->"In[42]:=",
  FontSize->15],

Cell["\<\
is not recognized, too.  In the next example the norming works ignoring the \
isotropic case t=0:\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(normalize[stb[1]*Cosh[t] + stb[5]]\)], "Input",
  CellLabel->"In[43]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(% /. \ t\  -> 0\)], "Input",
  CellLabel->"In[44]:="],

Cell["\<\
Norming an isotropic vector, or the nullvector, returns the vector itself\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(normalize[stb[1] + \ stb[5]]\)], "Input",
  CellLabel->"In[45]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(normalize[stb[1]*a + \ stb[5]*a]\)], "Input",
  CellLabel->"In[46]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(normalize[stb[5]*a + \ stb[2]*a\  + stb[3\ ]*b]\)], "Input",
  CellLabel->"In[47]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pssp[%, %]\)], "Input",
  CellLabel->"In[48]:=",
  FontSize->15],

Cell[BoxData[
    \(normalize[null[]]\)], "Input",
  CellLabel->"In[49]:=",
  FontSize->15,
  Background->None]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["2.4 The general cross product", "Subsection",
  Evaluatable->False,
  FontSize->14,
  Background->None],

Cell[TextData[{
  "As in euclidean geometry, the cross product of dim -1 vectors  ",
  Cell[BoxData[
      \(TraditionalForm\`a\_i\)]],
  "  is the vector v uniquely defined by\npssp[v, x] = Det[",
  Cell[BoxData[
      \(TraditionalForm\`a\_1\)]],
  ",..., ",
  Cell[BoxData[
      \(TraditionalForm\`a\_\(n - 1\)\)]],
  ", x]\t   (n = dim).\n First we remember our definition of  the euclidean \
cross product for arbitrary dimension, contained in euvec.m:"
}], "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(\(?cross\)\)], "Input",
  CellLabel->"In[86]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(cross[b_List]\  := \ 
      Module[{d\  = \ Length[b]\  + \ 1, v}, \n\t\tv\  = \ 
          null[d]; \n\t\t\tFor[i = 1, i < d, \(i++\), 
          If[Length[b[\([i]\)]\ ] != \ d, \ \n\t\t\t\t\t\t\t\tReturn[
              Print[b[\([i]\)], \ "\< is not a correct argument!\>"]], \n\t\t\
\t\t\t\t\t\tv[\([i]\)]\  = \ 
              Det[Append[b, \ stb[i, \ d]]]]]; \n\t\t\tv[\([d]\)]\  = \ 
          Det[Append[b, \ stb[d, \ d]]]; \n\t\t\tReturn[v]]\)], "Input",
  CellLabel->"In[17]:=",
  Evaluatable->False,
  FontSize->15],

Cell[TextData[{
  "The difference to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s function Cross is that cross' first argument is a list of lists, while \
Cross depends of dim -1 vectors."
}], "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(?? Cross\)], "Input",
  CellLabel->"In[87]:=",
  FontSize->15],

Cell["Here are the generalizations to the pseudo-Euclidean case:", "Text",
  Evaluatable->False,
  FontSize->13,
  Background->None],

Cell[BoxData[
    \(?? pscross\)], "Input",
  CellLabel->"In[88]:=",
  PageWidth->Infinity,
  FontSize->15,
  Background->None],

Cell["\<\
If  you want that the cross product depends of dim - 1 arguments, and not of \
the list of these arguments, you may use psCross:\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(psCross := Composition[dual, \ Cross]\)], "Input",
  CellLabel->"In[13]:=",
  PageWidth->Infinity,
  Evaluatable->False,
  FontSize->15,
  Background->None],

Cell[CellGroupData[{

Cell["Examples", "Subsubsection",
  Evaluatable->False,
  FontFamily->"Times",
  FontSize->11,
  Background->None],

Cell[BoxData[
    \(cross[{stb[1], stb[2], \ stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[50]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(Cross[stb[1], stb[2], \ stb[3], stb[4]]\)], "Input",
  CellLabel->"In[51]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pscross[{stb[1], stb[2], \ stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[52]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(vt\  = \ %\)], "Input",
  CellLabel->"In[53]:=",
  FontSize->15],

Cell[BoxData[
    \(Det[{stb[1], stb[2], \ stb[3], stb[4], vec[x]}]\)], "Input",
  CellLabel->"In[54]:=",
  FontSize->15],

Cell[BoxData[
    \(pssp[vt, \ vec[x]]\)], "Input",
  CellLabel->"In[55]:=",
  FontSize->15],

Cell[BoxData[
    \(pscross[{stb[5], stb[2], \ stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[56]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(psCross[stb[1], \ stb[2], \ stb[3], \ 
      stb[3]*Cos[t] + stb[4]*Sin[t]]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \(pscross[{stb[1], \ stb[2], \ stb[3], \ 
        stb[3]*Cos[t] + stb[4]*Sin[t]}]\)], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \(cross[{stb[1], \ stb[2], \ stb[3], \ 
        stb[3]*Cos[t] + stb[4]*Sin[t]}]\)], "Input",
  CellLabel->"In[59]:="],

Cell[BoxData[
    \(psCross[stb[5], stb[2], \ stb[3], stb[4]]\)], "Input",
  CellLabel->"In[60]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(cross[{stb[5], stb[2], \ stb[3], stb[4]}]\)], "Input",
  CellLabel->"In[61]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(pscross[{stb[2], \ stb[3]*Cos[t] + \ stb[4]*Sin[t], \ 
        stb[4]*Cos[t] - \ stb[3]*Sin[t], stb[5]}]\)], "Input",
  CellLabel->"In[62]:=",
  FontSize->15,
  Background->None],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[63]:=",
  FontSize->15],

Cell[BoxData[
    \(cross[{vec[a], vec[b], vec[c], 
          vec[d]}]\  == \ \(-cross[{vec[b], vec[a], vec[c], 
            vec[d]}]\)\)], "Input",
  CellLabel->"In[64]:="],

Cell[BoxData[
    \(Cross[vec[a], vec[b], vec[c], 
        vec[d]]\  == \ \(-Cross[vec[b], vec[a], vec[c], vec[d]]\)\)], "Input",\

  CellLabel->"In[65]:="],

Cell[BoxData[
    \(pscross[{vec[a], vec[b], vec[c], 
          vec[d]}]\  == \ \(-pscross[{vec[b], vec[a], vec[c], 
            vec[d]}]\)\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    \(pscross[{vec[a], vec[b], vec[c], vec[d]}]\  == \ \(-psCross[vec[b], 
          vec[a], vec[c], vec[d]]\)\)], "Input",
  CellLabel->"In[67]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["3. Orthogonality", "Section"],

Cell[CellGroupData[{

Cell["3.1 Definition", "Subsection",
  FontSize->14],

Cell[TextData[{
  "As in euclidean geometry a list {",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "} of non zero vectors is called orthogonal, if pssp[",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`v\_j\)]],
  " ] = 0 for i \[NotEqual] j; it is called orthonormal if it is orthogonal \
and for each i one has pssp[",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "] = 1, pssp[",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "] = -1, or pssp[",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "] = 0 with ",
  Cell[BoxData[
      \(TraditionalForm\`v\_i\)]],
  "\[NotEqual] o. An orthonormal sequence of vectors which does not contain \
isotropic vectors is linearly independent, therefore its length is less or  \
equal dim. Obviously, an orthonormal sequencewhich contains isotropic vectors \
needs not to be linearely independent.   By the theorem of inertia the number \
of timelike vectors in an orthonormal sequence is less or equal the index \
ind. An orthonormal sequence of maximal length dim which does not contain \
isotropic vectors is called an orthonormal frame; in any orthonormal frame \
the number of timelike vectors equals ind. If not another order  is mentioned \
explicitely, in an orthonormal frame the last ind vectors are assumed to be \
timelike.\nIn this section we collect definitions and modules for orthogonal \
vectors in the pseudo-euclidean space, which we need for certain \
applications, especially in M\[ODoubleDot]bius geometry.  The basic \
orthonormalization procedure orthonorm is contained in the package pseuvec.m. \
The Erhard Schmidt orthogonalization (for positive semidefinite scalar \
products) esorthonorm (contained in euvec.m) is tested in the notebook ",
  ButtonBox["Euklid.nb",
    ButtonData:>{"Euklid.nb", None},
    ButtonStyle->"Hyperlink"],
  ", and the general orthogonalization orthonorm  is treated below.  A \
generalization of orthonorm for scalar products in matrix spaces and \
applications to Killing forms can be found in the item Lie algebras, on my \
homepage, or in :"
}], "Text",
  FontSize->13],

Cell["http://www.mathsource.com/cgi-bin/msitem?0210-845", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2 Pseudo-euclidean orthogonalization", "Subsection",
  FontSize->14],

Cell[CellGroupData[{

Cell["3.2.1 General remarks", "Subsubsection"],

Cell[TextData[{
  "For definite scalar products J. M.Novak's GramSchmidt orthogonalization \
works well. Clearly, Novak's procedure GramSchmidt (see \
.../mathematica/AddOns/StandardPackages/LinearAlgebra/Orthogonalization.m) \
was not intended for applications to indefinite scalar products, and it did \
not work correctly for these. For pseudo-euclidean vector spaces we \
programmed a procedure orthonorm with the following properties:\nGiven a \
sequence of vectors ",
  Cell[BoxData[
      \(TraditionalForm\`{v\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  ",..., ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(v\_k\)\(}\)\)\)]],
  ". Construct an orthogonal basis  ",
  Cell[BoxData[
      \(TraditionalForm\`w\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w\_2\)]],
  ",...,",
  Cell[BoxData[
      \(TraditionalForm\`w\_m\)]],
  " of the  span \n                                                           \
    span[ ",
  Cell[BoxData[
      \(TraditionalForm\`v\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`v\_2\)]],
  ",..., ",
  Cell[BoxData[
      \(TraditionalForm\`v\_k\)]],
  "] = span[ ",
  Cell[BoxData[
      \(TraditionalForm\`w\_1\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`w\_2\)]],
  ",...,",
  Cell[BoxData[
      \(TraditionalForm\`w\_m\)]],
  "]. \nTo this aim we use  functions defined in euvec.m which can be useful \
also for other applications:"
}], "Text",
  TextAlignment->Left,
  FontSize->13],

Cell[BoxData[
    \(\(?outzero\)\)], "Input",
  CellLabel->"In[9]:=",
  FontSize->15],

Cell[BoxData[
    \(outzero[{null[], \ stb[1]}]\)], "Input",
  CellLabel->"In[69]:=",
  FontSize->15],

Cell[BoxData[
    \(\(?basis\)\)], "Input",
  CellLabel->"In[110]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2.2 Orthonormalization", "Subsubsection"],

Cell["\<\
The orthogonalization is more complicated as in the euclidean case; the \
following procedure is contained in pseuvec.m:\
\>", "Text"],

Cell[BoxData[
    \(\(?orthonorm\)\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(Options[orthonorm]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(\(?neglect\)\)], "Input",
  CellLabel->"In[72]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(orthonorm[b_List, opts___] := 
      Module[{v, w, va, vb, l, ort = {}, i, j, f, h, sm, aus, prod, nor, pr, 
          bn, follow, iso, 
          control}, {prod, nor, pr, 
            bn} = \({innerprod, normed, print, neglect} /. {opts}\) /. 
            Options[orthonorm]; \[IndentingNewLine]f[h_] := 
          smoothing[h, 10^bn]; \[IndentingNewLine]sm[aus_] := 
          MapAll[f, aus]; \[IndentingNewLine]w = 
          outzero[sm[b]]; \[IndentingNewLine]Label[
          follow]; \[IndentingNewLine]l = Length[w]; \[IndentingNewLine]If[
          l \[Equal] 0, Goto[control]]; \[IndentingNewLine]For[i = 1, 
          i \[LessEqual] l, \(i++\), 
          If[Not[Simplify[sm[prod[w[\([i]\)], w[\([i]\)]]]] \[Equal] 0], 
            AppendTo[ort, w[\([i]\)]]; \[IndentingNewLine]If[
              pr \[Equal] True, Print[w[\([i]\)]]]; \[IndentingNewLine]v = 
              Simplify[
                sm[Table[
                    w[\([j]\)] - 
                      w[\([i]\)]*
                        prod[w[\([i]\)], w[\([j]\)]]/
                          prod[w[\([i]\)], w[\([i]\)]], {j, 
                      l}]]]; \[IndentingNewLine]w = outzero[v]; \ 
            Goto[follow], Null, 
            AppendTo[ort, w[\([i]\)]]; \[IndentingNewLine]If[
              pr \[Equal] True, Print[w[\([i]\)]]]; \[IndentingNewLine]v = 
              Simplify[
                sm[Table[
                    w[\([j]\)] - 
                      w[\([i]\)]*
                        prod[w[\([i]\)], w[\([j]\)]]/
                          prod[w[\([i]\)], w[\([i]\)]], {j, 
                      l}]]]; \[IndentingNewLine]w = outzero[v]; \ 
            Goto[follow]]]; \[IndentingNewLine]Label[iso]; 
        l = Length[w]; \[IndentingNewLine]If[l \[Equal] 0, 
          Goto[control]]; \[IndentingNewLine]v = w; \[IndentingNewLine]If[
          l \[Equal] 1, AppendTo[ort, v[\([1]\)]]; \ 
          If[pr \[Equal] True, Print[v[\([1]\)]]]; \[IndentingNewLine]Goto[
            control]]; \[IndentingNewLine]For[i = 1, 
          i \[LessEqual] l, \(i++\), 
          For[j = i + 1, j \[LessEqual] l, \(j++\), 
            If[Not[Simplify[sm[prod[v[\([i]\)], v[\([j]\)]]]] \[Equal] 0], 
              va = v[\([j]\)] - v[\([i]\)]; \[IndentingNewLine]vb = 
                v[\([j]\)] + v[\([i]\)]; \ \t\t\t\tv[\([i]\)] = va; 
              v[\([j]\)] = vb; \[IndentingNewLine]w = 
                outzero[Simplify[sm[v]]]; 
              Goto[follow]]]]; \[IndentingNewLine]v = \ 
          basis[v]; \[IndentingNewLine]\ 
        ort = Join[ort, v]; \[IndentingNewLine]Label[
          control]; \[IndentingNewLine]l = Length[ort]; \[IndentingNewLine]If[
          l \[Equal] 0, Return[ort]]; \[IndentingNewLine]If[
          nor \[Equal] True, 
          ort = sm[
              Table[Simplify[normalize[ort[\([i]\)], prod]], {i, 
                  Length[ort]}]]]; \[IndentingNewLine]For[i = 1, 
          i \[LessEqual] l - 1, \(i++\), 
          For[j = i + 1, j \[LessEqual] l, \(j++\), 
            If[Not[Simplify[sm[prod[ort[\([i]\)], ort[\([j]\)]]]] \[Equal] 
                  0], Return[
                Print["\<I cannot orthogonalize the given sequence!\>"]], 
              Null, Return[
                Print["\<I cannot orthogonalize the given sequence!\>"]]]]]; \
\ \tReturn[ort]]\)], "Input",
  CellLabel->"In[9]:=",
  Evaluatable->False],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nor\)\" is similar to \
existing symbol \"\!\(Nor\)\"."\)], "Message",
  CellLabel->"From In[9]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.2.3  WARNINGS:", "Subsubsection"],

Cell["\<\
1. In certain cases the pseudo-euclidean orthonormalization procedure \
orthonorm cannot  be carried out. Then instead of the orthonormed matrix \
appears the message  \"I cannot orthogonalize the given sequence!\"  \
Sometimes the norming is the reason; then try the orthogonalization with the \
option normed -> False. Besides of the parameter dependence the reason can be \
a numerical badly conditioned matrix b (e.g. contains vectors with very \
small, or very different in magnitude, components). In this case one can try \
applying orthonorm  on the renormed matrix renorm[b]. \
\>", "Text"],

Cell["\<\
2. In the pseudo-euclidean vector spaces exist vector sequences which may not \
be orthogonalized preserving its flag structure. In difference to Erhard \
Schmidt's orthogonalization the procedure orthonorm does not preserve the \
flag structure of the given sequence in general.\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3 Examples, tests", "Subsection",
  FontSize->14],

Cell[CellGroupData[{

Cell["3.3.1 Simple, parameterfree vectors", "Subsubsection"],

Cell[BoxData[
    \(orthonorm[{null[]}]\)], "Input",
  CellLabel->"In[10]:="],

Cell["\<\
Isotropic vectors are treated correctly; here the orthonormal basis of the \
2-space is non isotropic:\
\>", "Text"],

Cell[BoxData[
    \(orthonorm[{stb[1] + stb[5], stb[5]}]\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(orthonorm[{stb[1] + stb[5], stb[2] + stb[5]}]\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    \(orthonorm[{stb[1] + stb[5], stb[1] - stb[5]}]\)], "Input",
  CellLabel->"In[13]:="],

Cell["\<\
In the new version,   orthonormal linearly dependent isotropic vectors don't \
appear:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(orthonorm[{stb[2], 
        stb[1] + stb[5], \((stb[1]\  + \ stb[5])\)*3}]\)\)\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(\(\(\ \)\(orthonorm[{stb[1], stb[5]\  - stb[2], null[], \ 
        stb[2]*5 + \ stb[5]}]\)\)\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(\(\(\ \)\(orthonorm[{stb[1], \((stb[5]\  - stb[2])\)*25, \ 
        stb[1]*5 + \ stb[4]}]\)\)\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \(orthonorm[{stb[1] + stb[4], stb[1]\  - \ stb[5], 
        stb[1]*3\  - stb[5]}]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[19]:="],

Cell["\<\
Clearly,  by numerical reason,  one may expect an approximative result only, \
if during the calculation appear floating point numbers.\
\>", "Text"],

Cell[BoxData[
    \(orthonorm[{stb[1] + stb[4], stb[1]\  - \ stb[5], 
        stb[1]*3.1\  - stb[5]}]\)], "Input",
  CellLabel->"In[20]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[21]:="],

Cell["Here is a test with a random floating point number:", "Text"],

Cell[BoxData[{
    \(\(t1\  = \ 10*Random[];\)\), "\n", 
    \(\(avt\  = 
        orthonorm[{\ stb[3], stb[5]\  + \ stb[2], \ null[], \ 
            stb[5] Cosh[t1]\  + \ 5*stb[1] Sinh[t1], 
            stb[5]\  + \ stb[2]}];\)\), "\n", 
    \(\tsmoothing[
      Table[pssp[avt[\([i]\)], avt[\([j]\)]], {i, Length[avt]}, {j, 
          Length[avt]}]]\)}], "Input",
  CellLabel->"In[22]:=",
  FontSize->15],

Cell["Repeat the evaluation of the next cell several times!", "Text"],

Cell[BoxData[{
    \(\(t1\  = \ 10*Random[];\)\), "\n", 
    \(\(avt\  = 
        orthonorm[{\ stb[3], stb[5]\  + \ stb[2], \ null[], \ 
            stb[5] Cosh[t1]\  + \ 5*stb[1] Sinh[t1], 
            stb[5]\  + \ stb[2]}];\)\), "\n", 
    \(\tTable[pssp[avt[\([i]\)], avt[\([j]\)]], {i, 3}, {j, 3}]\)}], "Input",
  CellLabel->"In[25]:=",
  FontSize->15],

Cell[BoxData[
    \(Remove[avt]\)], "Input",
  CellLabel->"In[28]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3.2 Vectors depending on parameters", "Subsubsection"],

Cell["\<\
The following examples show that orthonorm worked correctly also on sequences \
depending on parameters.\
\>", "Text"],

Cell[BoxData[
    \(\(\(\ \)\(orthonorm[{stb[
          1], \((stb[5]\  - stb[2])\)*25, \ \((stb[1]*5 + \ stb[4])\)*
          a}, \[IndentingNewLine]print \[Rule] True]\)\)\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(\(\(\ \)\(orthonorm[{stb[
          1], \((stb[5]\  - stb[2])\)*25, \ \((stb[1]*5 + \ stb[4])\)*
          a}, \[IndentingNewLine]print \[Rule] True, \ 
      normed\  \[Rule] \ False]\)\)\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(orthonorm[{stb[1]\ *c + \ stb[5]*3, stb[1]\  + \ stb[5]}, 
      print \[Rule] True, \ normed\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[31]:="],

Cell[BoxData[
    \(orthonorm[{stb[1]\ *c + \ stb[5]*3, stb[1]\  + \ stb[5]}, 
      print \[Rule] True]\)], "Input",
  CellLabel->"In[32]:="],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[33]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[34]:="],

Cell[BoxData[
    \(te[c_] = \ %\)], "Input",
  CellLabel->"In[35]:="],

Cell[BoxData[
    \(te[c]\)], "Input",
  CellLabel->"In[36]:="],

Cell[BoxData[
    \(te[3]\)], "Input",
  CellLabel->"In[37]:="],

Cell[BoxData[
    \(Limit[te[c], \ c\  \[Rule] \ 3]\)], "Input",
  CellLabel->"In[38]:="],

Cell[BoxData[
    \(Limit[te[c], \ c\  \[Rule] 3, \ 
      Direction\  \[Rule] \ \(-1\)]\)], "Input",
  CellLabel->"In[39]:="],

Cell[BoxData[
    \(Limit[te[c], \ c\  \[Rule] \ 3, \ Direction\  \[Rule] \ 1]\)], "Input",
  CellLabel->"In[40]:="],

Cell["\<\
The evaluation worked for general c, in spite of the fact that at c = 3  the \
character  of the constructed vectors changes. Moreover, for c= 3 the 2-space \
degenerates to an isotropic line. \
\>", "Text"],

Cell[BoxData[
    \(orthonorm[{null[], \ 3*stb[2], \ null[], \ 
        stb[1] Cosh[t]\  + \ 2*stb[5] Sinh[t], \n\ \ \ \ stb[1]\  + \ 
          stb[2]}, \ print\  \[Rule] \ True]\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    \(Table[
      pssp[%[\([i]\)], %[\([j]\)]], {i, Length[%]}, {j, 
        Length[%]}]\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    \(ftest[t_]\  = \ Simplify[Together[%]]\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    \(ftest[0]\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(Limit[ftest[t], \ t\  \[Rule] \ 0, \ Direction\  \[Rule] 1]\)], "Input",\

  CellLabel->"In[45]:="],

Cell[BoxData[
    \(Limit[ftest[t], \ t\  \[Rule] \ 0, \ 
      Direction\  \[Rule] \(-1\)]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    \(ftest[1. ]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(ftest[0.1]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(orthonorm[{null[], \ 3*stb[2], \ null[], \ 
        stb[2] Cosh[t]\  + \ stb[5] Sinh[t], \n\ \ \ \ stb[1]\  + \ 
          stb[2]}]\)], "Input",
  CellLabel->"In[49]:="],

Cell[BoxData[
    \(orthonorm[{\ stb[1] Cosh[t]\  + \ stb[5] Sinh[t], 
        stb[1]\  + \ \ stb[2], stb[2], \ null[], 
        stb[1]\  - \ stb[2]}]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \(Table[
      pssp[%[\([i]\)], %[\([j]\)]], {i, Length[%]}, {j, 
        Length[%]}]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \(Simplify[Together[%]]\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \(orthonorm[{null[], \ 3*stb[2], \ null[], \ 
        stb[1] Cosh[t]\  + \ stb[5] Sinh[t], \n\ \ \ \ stb[3]\  + \ 
          stb[2]}]\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(Remove[te, \ ftest]\)], "Input",
  CellLabel->"In[54]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3.3 Index ind = 2", "Subsubsection"],

Cell["\<\
If the index is greater than 1, you can meet also mutual orthogonal, \
isotropic,  linearly independent vectors. First we change the index:\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(ind\  = \ 2\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \(ch[stb[4] + stb[2]]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \(pssp[stb[4], stb[4]]\)], "Input",
  CellLabel->"In[57]:="],

Cell["\<\
Here we have two isotropic orthogonal vectors spanning a totally isotropic \
2-dimensional subspace:\
\>", "Text"],

Cell[BoxData[
    \(orthonorm[{\ stb[1]\  + \ stb[5], stb[4]\  + stb[2]}]\)], "Input",
  CellLabel->"In[58]:=",
  FontSize->15],

Cell["\<\
These vectors are orthogonal and have norm 0, therefore they have been \
returned correctly. Moreover, they are linearly independent.\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(orthonorm[{\ stb[1]\  + \ stb[5], stb[1]*2\  + \ stb[3], 
        stb[4]\  + stb[2]}]\)], "Input",
  CellLabel->"In[59]:=",
  FontSize->15],

Cell[BoxData[
    \(Table[pssp[%[\([i]\)], %[\([j]\)]], {i, 3}, {j, 3}]\)], "Input",
  CellLabel->"In[60]:="],

Cell["\<\
The next two isotropic vectors span a 2-dimensional pseudoeuclidean subspace:\
\
\>", "Text",
  FontSize->13],

Cell[BoxData[
    \(orthonorm[{\ stb[1]\  + \ stb[5], stb[5]\  + stb[2]}, 
      print\  \[Rule] \ True]\)], "Input",
  CellLabel->"In[61]:=",
  FontSize->15]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3.4 Tests with random vectors (case ind = 2)", "Subsubsection"],

Cell[BoxData[
    \(ind\)], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[{
    \(\(atest\  = Table[randomv[5], {i, 5}];\)\), "\n", 
    \(ot\  = orthonorm[atest]; Print[ot // MatrixForm];\), "\n", 
    \(Table[
      smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, 5}, {j, 5}]\)}], "Input",\

  CellLabel->"In[63]:="],

Cell[BoxData[{
    \(\(atest\  = 
        PrependTo[Table[randomv[5], {i, 7}], 
          stb[1]\  + \ stb[5]];\)\), "\n", 
    \(ot\  = orthonorm[atest]; Print[ot // MatrixForm];\), "\n", 
    \(Table[
      smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, Length[ot]}, {j, 
        Length[ot]}]\)}], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[{
    \(\(atest\  = Table[randomv[5], {i, 3}];\)\), "\n", 
    \(\(atest\  = \ 
        Join[atest, {stb[1]\  + \ stb[5], stb[2]\  + \ stb[4]}];\)\), "\n", 
    \(ot\  = orthonorm[atest]; Print[ot // MatrixForm];\), "\n", 
    \(Table[
      smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, 5}, {j, 5}]\)}], "Input",\

  CellLabel->"In[69]:="],

Cell[BoxData[{
    \(\(atest\  = Table[randomv[5], {i, 7}];\)\), "\n", 
    \(\(atest\  = \ 
        Join[{stb[1]\  + \ stb[5], stb[2]\  + \ stb[4]}, atest];\)\), "\n", 
    \(ot\  = orthonorm[atest]; Print[ot // MatrixForm];\), "\n", 
    \(Table[
      smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, 5}, {j, 5}]\)}], "Input",\

  CellLabel->"In[73]:="],

Cell[BoxData[{
    \(\(atest\  = Table[randomv[5], {i, 7}];\)\), "\n", 
    \(ot\  = orthonorm[atest, print\  \[Rule] \ True]; 
    Print[ot // MatrixForm];\), "\n", 
    \(Table[
      smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, Length[ot]}, {j, 
        Length[ot]}]\)}], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    \(Remove[atest, \ ot]\)], "Input",
  CellLabel->"In[80]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["3.3.5 Renorming of badly conditioned matrices", "Subsubsection"],

Cell["\<\
PRESERVE ind = 2, dim = 5 !
The comments are valid in this case only. For ind =1, dim = 5 the sequence ot \
will be orthonormed with approximative correctness, test it later!\
\>", "Text"],

Cell["\<\
The next matrix ot has vectors with coordinates of very different absolute \
values. Applying orthonorm ,  we  do not get orthogonal vectors:\
\>", "Text"],

Cell[BoxData[
    \(ot\  = {{0.675496095887281988`, 0.838111706002798051`, 
          0.0599127084283752431`, 0.0726205437662291686`, 
          0.396285246447809988`}, {2.90602662075336581`, \
\(-0.838111706002798761`\), \(-0.0599127084283752875`\), \
\(-0.0726205437662292307`\), 
          3.18523747019283787`}, {\(-9.19936356392773468`*^7\), 
          3.3554431999999994`*^7, \(-6.36335108454432329`*^-10\), 
          3.35544319999999984`*^7, \(-9.19936356392773468`*^7\)}}\)], "Input",\

  CellLabel->"In[81]:="],

Cell["The three vectors are \"almost\" orthogonal:", "Text"],

Cell[BoxData[
    \(Table[
        smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, Length[ot]}, {j, 
          Length[ot]}] // MatrixForm\)], "Input",
  CellLabel->"In[82]:="],

Cell[BoxData[
    \(at\  = orthonorm[ot]\)], "Input",
  CellLabel->"In[83]:="],

Cell["We try it without norming:", "Text"],

Cell[BoxData[
    \(at\  = orthonorm[ot, \ normed\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[84]:="],

Cell["\<\
If one renorms the vectors of ot, one preserves their span, and hopefully, \
can find  a nearly orthonormal basis:\
\>", "Text"],

Cell[BoxData[
    \(\(?renorm\)\)], "Input",
  CellLabel->"In[85]:="],

Cell[BoxData[
    \(renorm[b_?MatrixQ] := \ 
      Module[{bo\  = \ outzero[b], i\ }, \n\t
        Table[bo[\([i]\)]/Sqrt[bo[\([i]\)] . bo[\([i]\)]], 
          \ {i, \ Length[bo]}]]\)], "Input",
  CellLabel->"In[13]:=",
  Evaluatable->False],

Cell[BoxData[
    \(otre\  = \ renorm[ot]\)], "Input",
  CellLabel->"In[86]:="],

Cell[BoxData[
    \(orthonorm[otre, \ \ print\  \[Rule] \ True, \ 
      normed\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[87]:="],

Cell[BoxData[
    \(\(at\  = \ %;\)\)], "Input",
  CellLabel->"In[88]:="],

Cell[BoxData[
    \(Table[
        smoothing[pssp[at[\([i]\)], at[\([j]\)]]], {i, Length[at]}, {j, 
          Length[at]}] // \n\ \ MatrixForm\)], "Input",
  CellLabel->"In[89]:="],

Cell["\<\
Here  we succeeded,  but if we want to get normed vectors, the procedure does \
not work:. \
\>", "Text"],

Cell[BoxData[
    \(orthonorm[otre, \ \ print\  \[Rule] \ True]\)], "Input",
  CellLabel->"In[90]:="],

Cell["\<\
The reason is that the last vector may not be normalized correctly:\
\>", "Text"],

Cell[BoxData[
    \(atn = \ Table[normalize[at[\([i]\)]], {i, 3}]\)], "Input",
  CellLabel->"In[91]:="],

Cell["\<\
The scalar products after normalization are incorrect; therefore the \
procedure did not return the found vectors:\
\>", "Text"],

Cell[BoxData[
    \(Table[
        smoothing[pssp[atn[\([i]\)], atn[\([j]\)]]], {i, Length[atn]}, {j, 
          Length[atn]}] // \n\ \ MatrixForm\)], "Input",
  CellLabel->"In[92]:="],

Cell["\<\
The third vector of at seems to be isotropic; but copying it we get its \
'inner hidden' value:\
\>", "Text"],

Cell[BoxData[
    \(badv\  = {\(-0.6642969596426436`\), 0.24230053530593257`, 0, 
        0.24230053530593232`, \(-0.6642969596426437`\)}\)], "Input",
  CellLabel->"In[93]:="],

Cell[BoxData[
    \(pssp[badv, badv]\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    \(normalize[badv]\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    \(badnormv\  = \ %\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \(pssp[badnormv, badnormv]\)], "Input",
  CellLabel->"In[97]:="],

Cell["The hidden value of badnormv is", "Text"],

Cell[BoxData[
    \({\(-6.304594370522744`*^7\), 2.2995838964643177`*^7, 0, 
      2.299583896464315`*^7, \(-6.304594370522745`*^7\)}\)], "Input",
  CellLabel->"In[98]:="],

Cell["\<\
Here  we succeeded,  but in the next example we have certain difficulties. \
\>", "Text"],

Cell[BoxData[
    \(\(ot\  = {{0.675496095887281988`, 0.838111706002798051`, 
            0.0599127084283752431`, 0.0726205437662291686`, 
            0.396285246447809988`}, {2.90602662075336581`, \
\(-0.838111706002798761`\), \(-0.0599127084283752875`\), \
\(-0.0726205437662292307`\), 
            3.18523747019283787`}, {\(-9.19936356392773468`*^7\), 
            3.3554431999999994`*^7, \(-6.36335108454432329`*^-10\), 
            3.35544319999999984`*^7, \(-9.19936356392773468`*^7\)}, \
{6.82635841776287133`*^7, \(-2.48989593404715137`*^7\), 
            9.9150403743008848`*^-9, \(-2.48989593404715048`*^7\), 
            6.82635841776287133`*^7}, {\(-1.82640220915799815`*^7\), 
            6.66175309911068413`*^6, 2.6549032889775681`*^-7, 
            6.66175309911060686`*^6, \(-1.82640220915799815`*^7\)}};\)\)], \
"Input",
  CellLabel->"In[99]:="],

Cell["\<\
This matrix is bad conditioned too, but not nearly orthogonal:\
\>", "Text"],

Cell[BoxData[
    \(Table[
        smoothing[pssp[ot[\([i]\)], ot[\([j]\)]]], {i, Length[ot]}, {j, 
          Length[ot]}] // MatrixForm\)], "Input",
  CellLabel->"In[100]:="],

Cell[BoxData[
    \(orthonorm[ot]\)], "Input",
  CellLabel->"In[101]:="],

Cell[BoxData[
    \(otre\  = \ renorm[ot]\)], "Input",
  CellLabel->"In[102]:="],

Cell["\<\
The matrix  otre is badly conditioned again: The last three vectors are \
pairwise almost linearly dependent, and we have\
\>", "Text"],

Cell[BoxData[
    \(Det[otre]\)], "Input",
  CellLabel->"In[103]:="],

Cell[BoxData[
    \(Table[pssp[otre[\([i]\)], otre[\([j]\)]], {i, 5}, {j, 5}]\)], "Input",
  CellLabel->"In[104]:="],

Cell["With the default norming we do not succeed:", "Text"],

Cell[BoxData[
    \(at1\  = \ orthonorm[otre, \ print\  \[Rule] \ True]\)], "Input",
  CellLabel->"In[105]:="],

Cell["but without norming we get a reasonable result:", "Text"],

Cell[BoxData[
    \(at1\  = \ 
      orthonorm[otre, \ print\  \[Rule] \ True, 
        normed\  \[Rule] \ False]\)], "Input",
  CellLabel->"In[106]:="],

Cell[BoxData[
    \(Table[
        smoothing[pssp[at1[\([i]\)], at1[\([j]\)]]], {i, Length[at1]}, {j, 
          Length[at1]}] // MatrixForm\)], "Input",
  CellLabel->"In[107]:="],

Cell["\<\
That looks wrong: in the pseudo-euclidean vector space of index 2 there may \
not exist three mutual orthogonal linearly independent isotropic vectors! The \
numerical deviation from orthonormality one can see evaluating the scalar \
products not using smoothing:\
\>", "Text"],

Cell[BoxData[
    \(Table[
      pssp[at1[\([i]\)], at1[\([j]\)]], {i, Length[at1]}, {j, 
        Length[at1]}]\)], "Input",
  CellLabel->"In[108]:="],

Cell["\<\
Thus, orthonorm yields very small, almost orthogonal vectors, and the last \
three vectors are almost isotropic; the five vectors are \"almost linearly \
dependent\":\
\>", "Text"],

Cell[BoxData[
    \(Det[at1]\)], "Input",
  CellLabel->"In[109]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["3.4  psfilter", "Subsection",
  FontSize->14],

Cell["We now go back to index 1: ", "Text"],

Cell[BoxData[
    \(ind\  = \ 1\)], "Input",
  CellLabel->"In[113]:="],

Cell[BoxData[
    \({dim\ , \ ind}\)], "Input",
  CellLabel->"In[114]:="],

Cell["\<\
Remember that in a space of index ind  any orthogonal sequence of linearly \
independent vectors may contain not more than ind non spacelike vectors.\
\>", "Text"],

Cell["\<\
Sometimes it is necessary to place the spacelike vectors of a sequence b at \
the first places. The following procedure  realizes such a permutation: \
\>", "Text"],

Cell[BoxData[
    \(\(?psfilter\)\)], "Input",
  CellLabel->"In[115]:="],

Cell[BoxData[
    \(psfilter[b_List]\  := \ 
      Module[{i, \ lb\  = \ Length[b], \ bn = \ {}, qn\  = \ {}}, \n\t\t
        For[i = 1, i <= lb, \(i++\), \n\t\t\t
          If[Length[b[\([i]\)]\ ]\  != \ dim, \ 
            Return[\ Print["\<Incorrect argument \>", b[\([i]\)], 
                "\<!!!\>"]]]]; \n\t\t
        For[i = 1, \ i <= lb, \ \(i++\), \n\t\t\t
          If[ch[b[\([i]\)]\ ] == \ 1, \ AppendTo[bn, \ b[\([i]\)]], 
            AppendTo[qn, b[\([i]\)]], AppendTo[qn, b[\([i]\)]]]]; \n\t\t\t\t
        Return[Join[bn, qn]]]\)], "Input",
  CellLabel->"In[16]:=",
  Evaluatable->False],

Cell[BoxData[
    \(\(\(\t\t\)\(psfilter[{a}]\)\)\)], "Input",
  CellLabel->"In[116]:="],

Cell[BoxData[
    \(\(\(\t\t\)\(psfilter[{null[], \ stb[5], \ stb[1]}]\)\)\)], "Input",
  CellLabel->"In[117]:="],

Cell["\<\
psfilter  yields the expected result also for non orthogonal sequences:\
\>", "Text"],

Cell[BoxData[
    \(\(\(\t\t\)\(psfilter[{stb[2], stb[5]*Cos[t], \ stb[5], \ 
        stb[1]}]\)\)\)], "Input",
  CellLabel->"In[118]:="],

Cell[BoxData[
    \(psfilter[%]\)], "Input",
  CellLabel->"In[119]:="],

Cell[BoxData[
    \(psfilter[{\ stb[1]\  + \ stb[5], 
        stb[5]\  + stb[2], \ {Cos[t], \ Sin[t], \ 1, 0, 1}}]\)], "Input",
  CellLabel->"In[120]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["3.5 Orthogonal pairs", "Subsection",
  FontSize->14],

Cell["\<\
Now we generate a pair of orthonormal spacelike vectors starting from a given \
spacelike one; that we need for the geometry of circles on the 3-sphere.The \
definition is contained in the  package pseuvec.m.\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(\(?orthopair\)\)], "Input",
  CellLabel->"In[12]:=",
  FontSize->14],

Cell[BoxData[
    \(orthopair[l_List] := 
      Module[{a, l1 = l, m1 = null[], b = dim - ind, j, k}, 
          a = Simplify[pssp[l, l]]; \[IndentingNewLine]If[a \[LessEqual] 0, 
            Print["\<Vector \>", l, "\< is not spacelike!\>"]; Return[], 
            Null, Print["\<Maybe, Vector \>", l, "\< is not spacelike?\>"]; 
            Return[]]; \ 
          If[b < 2, Print["\<Orthogonal spacelike pairs don't exist!\>"]; 
            Return[]]; \ \t\ l1 = l1/Sqrt[a]; \ \tFor[k = 1, 
            k \[LessEqual] b, \(k++\), 
            If[l1[\([k]\)] \[Equal] 0, m1 = stb[k]; \ 
              Return[{l1, m1}]]]; \ \t\ For[j = 1, j \[LessEqual] b, \(j++\), 
            If[OddQ[j] && j < b, 
              m1[\([j]\)] = \(-l1[\([j + 1]\)]\)]; \ \ \t\tIf[EvenQ[j], 
              m1[\([j]\)] = l1[\([j - 1]\)]]]; \ \t\tm1 = 
            m1/Sqrt[pssp[m1, m1]]; \[IndentingNewLine]\ {l1, m1}] /; 
        Length[l] \[Equal] dim\)], "Input",
  Evaluatable->False],

Cell[" The following function controls orthonormality:", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[BoxData[
    \(control[v_, w_] := 
      Simplify[\((pssp[v, v] - 1)\)\^2 + 
          pssp[v, w]\^2 + \((pssp[w, w] - 1)\)\^2]\)], "Input",
  CellLabel->"In[8]:=",
  InitializationCell->True,
  FontSize->14],

Cell["\<\
If all is correct the result mus be 0, or numerically very small. If the \
result depends on a parameter, integrate!\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontSlant->"Plain",
  FontTracking->"Plain",
  FontColor->GrayLevel[0],
  Background->GrayLevel[1],
  FontVariations->{"Underline"->False,
  "Outline"->False,
  "Shadow"->False}],

Cell[CellGroupData[{

Cell["Tests", "Subsubsection",
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[BoxData[
    \(orthopair[stb[1]]\)], "Input",
  CellLabel->"In[14]:=",
  PageWidth->Infinity,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[BoxData[
    \(orthopair[stb[2]]\)], "Input",
  CellLabel->"In[15]:=",
  PageWidth->Infinity,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[BoxData[
    \(orthopair[stb[3]]\)], "Input",
  CellLabel->"In[16]:=",
  PageWidth->Infinity,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[BoxData[
    \(orthopair[stb[4]]\)], "Input",
  CellLabel->"In[17]:=",
  PageWidth->Infinity,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[BoxData[
    \(orthopair[stb[5]]\)], "Input",
  CellLabel->"In[18]:=",
  PageWidth->Infinity,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[BoxData[
    \(orthopair[{Cos[t], Sin[t], Cos[s], Sin[s], 0}\/\@2]\)], "Input",
  CellLabel->"In[19]:=",
  PageWidth->Infinity,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[20]:="],

Cell["\<\
The argument of orthopair must be a spacelike vector, but it needs not to be \
a unit vector:\
\>", "Text",
  Evaluatable->False,
  FontFamily->"Times New Roman"],

Cell[BoxData[
    \(orthopair[{Cos[t], Sin[t], Cos[s], Sin[s], 0}]\)], "Input",
  CellLabel->"In[21]:=",
  PageWidth->Infinity,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \(Simplify[orthopair[{1, Cos[t], Sin[t], Cos[s], Sin[s]}]]\)], "Input",
  CellLabel->"In[23]:=",
  PageWidth->Infinity,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell["\<\
In spite of the fact that the argument is spacelike for all real values of s \
and t!\
\>", "Text"],

Cell[BoxData[
    \(pssp[{1, Cos[t], Sin[t], Cos[s], Sin[s]}, {1, Cos[t], Sin[t], Cos[s], 
        Sin[s]}]\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    \(Simplify[%]\)], "Input",
  CellLabel->"In[25]:="],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can not know that s is assumed to be real."
}], "Text"],

Cell[BoxData[
    \(orthopair[\ 3*randomv[\ ]]\)], "Input",
  CellLabel->"In[26]:=",
  PageWidth->Infinity,
  FontFamily->"Times New Roman",
  FontSize->14],

Cell[BoxData[
    \(Table[
      Simplify[pssp[%[\([i]\)], \ %[\([j]\)]]], {i, 2}, {j, 2}]\)], "Input",
  CellLabel->"In[27]:=",
  FontSize->14],

Cell[BoxData[
    \(control[%%[\([1]\)], \ %%[\([2]\)]]\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(dim\  = \ 2\)], "Input",
  CellLabel->"In[29]:="],

Cell[BoxData[
    \(orthopair[{1, 0}]\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(dim\  = \ 5\)], "Input",
  CellLabel->"In[31]:="]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["References", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
[1] Sulanke, Rolf. Spheres.  1999.  \
http://mathsource.com/Content/Enhancements/Geometry/0210-092\
\>", "Text",
  CellTags->"S1"]
}, Closed]],

Cell[CellGroupData[{

Cell["Author's address", "Subsubtitle",
  FontFamily->"Times"],

Cell["\<\
Homepage:
http://www-irm.mathematik.hu-berlin.de/~sulanke
e-Mail:\
\>", "Text"],

Cell["sulanke@mathematik.hu-berlin.de", "Text"],

Cell["\<\
The author will be very thankful for hints, corrections, comments.\
\>", "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
AutoGeneratedPackage->Automatic,
WindowToolbars->"RulerBar",
WindowSize->{847, 668},
WindowMargins->{{62, Automatic}, {Automatic, 0}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.563, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{"home", "rolf", "mymath", \
"spheres.v3"}, "pseuklid.nb.ps", CharacterEncoding -> "WindowsANSI"],
"Magnification"->1},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
SpellingDictionaries->{"CorrectWords"->{
  "orthonormalization", "orthonorm", "Erhard", "parameterfree", "nul"}},
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the Notebook level. \
 \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{5, Inherited}, {2, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 13},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{0, 10}, {2, 0}},
    FontSize->28,
    Background->GrayLevel[0.6]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{7, 10}, {2, 4}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{7, 10}, {2, 8}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{6, 0.5}, {0.5, 0.5}},
    CellMargins->{{8, 4}, {2, 50}},
    CellElementSpacings->{"ClosedGroupTopMargin"->18},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CellFrameColor->RGBColor[0, 0, 1],
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Section", "Printout"],
    CellFrame->{{6, 0.5}, {0.5, 0.5}},
    CellMargins->{{6, 4}, {2, 70}},
    CellFrameColor->GrayLevel[0],
    FontSize->14,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    LineSpacing->{1, 5},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->15,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{19, 4}, {2, 18}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{7, 4}, {2, 18}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica", "webMathematica"->FormBox[ 
            RowBox[ {"web", 
              AdjustmentBox[ 
                StyleBox[ "Mathematica", FontSlant -> "Italic"], 
                BoxMargins -> {{-0.175, 0}, {0, 0}}]}], TextForm], Inherited},
    
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 12},
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{7, 0}, {0, 8}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{3, 0}, {0, 0.5}},
    CellMargins->{{47, 14}, {0, 14}},
    CellFrameColor->RGBColor[0, 0, 1],
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 54}, {0, 14}},
    CellFrameColor->GrayLevel[0],
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.    \
\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{54, 14}, {3, 8}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{43, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{55, 4}, {8, 3}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    FontSize->14],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{43, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{44, 4}, {3, 8}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{44, 4}, {3, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{42, 4}, {3, 8}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{26, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-19,
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{20, 4}, {0, 8}},
    ParagraphIndent->-14,
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{45, 4}, {0, 5}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 5},
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    CellMargins->{{34, 4}, {0, 4}},
    ParagraphSpacing->{0, 4},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{26, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontSize->14],
  
  Cell[StyleData["IndentedText", "Printout"],
    CellMargins->{{20, 4}, {0, 8}},
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    CellFrameColor->RGBColor[0, 0, 1],
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{7, 4}, {0, 8}},
    CellFrameColor->GrayLevel[0],
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{7, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{7, 50}, {2, 4}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{7, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{7, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{43, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{55, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontSize->14,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{43, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{7, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None",
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->GrayLevel[1],
    Background->RGBColor[0, 0.6, 1],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    Background->GrayLevel[1]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S1"->{
    Cell[65903, 2455, 140, 4, 27, "Text",
      CellTags->"S1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S1", 94735, 3388}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 88, 2, 72, "Title"],
Cell[1867, 57, 149, 4, 33, "Subtitle",
  Evaluatable->False],
Cell[2019, 63, 162, 5, 27, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[2206, 72, 144, 4, 37, "Subsubsection",
  Evaluatable->False],
Cell[2353, 78, 788, 17, 84, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[3178, 100, 32, 0, 37, "Subsubsection"],
Cell[3213, 102, 531, 13, 68, "Text"],
Cell[3747, 117, 541, 11, 84, "Text",
  Evaluatable->False]
}, Open  ]],

Cell[CellGroupData[{
Cell[4325, 133, 33, 0, 37, "Subsubsection"],
Cell[4361, 135, 239, 4, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4637, 144, 34, 0, 37, "Subsubsection"],
Cell[4674, 146, 552, 8, 84, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[5263, 159, 59, 1, 37, "Subsection"],
Cell[5325, 162, 330, 6, 68, "Text"],

Cell[CellGroupData[{
Cell[5680, 172, 141, 4, 32, "Input",
  InitializationCell->True],
Cell[5824, 178, 82, 2, 30, "Output"]
}, Open  ]],
Cell[5921, 183, 156, 3, 32, "Text"],
Cell[6080, 188, 129, 4, 32, "Input",
  InitializationCell->True]
}, Open  ]],

Cell[CellGroupData[{
Cell[6246, 197, 47, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[6318, 201, 38, 0, 43, "Subsection"],
Cell[6359, 203, 1093, 18, 141, "Text",
  Evaluatable->False],
Cell[7455, 223, 122, 4, 30, "Input",
  InitializationCell->True],
Cell[7580, 229, 300, 7, 108, "Text"],
Cell[7883, 238, 303, 7, 46, "Text",
  Evaluatable->False],
Cell[8189, 247, 104, 3, 27, "Text"],
Cell[8296, 252, 109, 4, 30, "Input",
  InitializationCell->True],
Cell[8408, 258, 107, 3, 28, "Text"],

Cell[CellGroupData[{
Cell[8540, 265, 90, 3, 31, "Input",
  InitializationCell->True],
Cell[8633, 270, 78, 2, 30, "Output"]
}, Open  ]],
Cell[8726, 275, 37, 0, 28, "Text"],

Cell[CellGroupData[{
Cell[8788, 279, 110, 3, 31, "Input",
  InitializationCell->True],
Cell[8901, 284, 152, 3, 30, "Output"]
}, Open  ]],
Cell[9068, 290, 85, 2, 28, "Text"],

Cell[CellGroupData[{
Cell[9178, 296, 159, 4, 31, "Input",
  InitializationCell->True],
Cell[9340, 302, 413, 11, 112, "Output"]
}, Open  ]],
Cell[9768, 316, 70, 0, 28, "Text"],
Cell[9841, 318, 67, 2, 31, "Input"],
Cell[9911, 322, 132, 3, 28, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10080, 330, 36, 0, 43, "Subsection"],
Cell[10119, 332, 308, 7, 48, "Text"],

Cell[CellGroupData[{
Cell[10452, 343, 67, 1, 37, "Subsubsection"],
Cell[10522, 346, 67, 0, 27, "Text"],
Cell[10592, 348, 90, 3, 32, "Input"],
Cell[10685, 353, 89, 3, 32, "Input"],
Cell[10777, 358, 92, 3, 32, "Input"],
Cell[10872, 363, 89, 3, 32, "Input"],
Cell[10964, 368, 91, 3, 32, "Input"],
Cell[11058, 373, 93, 3, 32, "Input"],
Cell[11154, 378, 90, 3, 32, "Input"],
Cell[11247, 383, 90, 3, 32, "Input"],
Cell[11340, 388, 94, 3, 32, "Input"],
Cell[11437, 393, 97, 3, 32, "Input"],
Cell[11537, 398, 96, 3, 32, "Input"],
Cell[11636, 403, 89, 3, 32, "Input"],
Cell[11728, 408, 90, 3, 32, "Input"],
Cell[11821, 413, 105, 3, 32, "Input"],
Cell[11929, 418, 97, 3, 32, "Input"],
Cell[12029, 423, 95, 3, 32, "Input"],
Cell[12127, 428, 101, 3, 32, "Input"],
Cell[12231, 433, 92, 3, 32, "Input"],
Cell[12326, 438, 91, 3, 32, "Input"],
Cell[12420, 443, 93, 3, 32, "Input"],
Cell[12516, 448, 92, 3, 32, "Input"],
Cell[12611, 453, 95, 3, 32, "Input"],
Cell[12709, 458, 72, 0, 27, "Text"],
Cell[12784, 460, 94, 3, 32, "Input"],
Cell[12881, 465, 92, 3, 32, "Input"],
Cell[12976, 470, 98, 3, 32, "Input"],
Cell[13077, 475, 95, 3, 32, "Input"],
Cell[13175, 480, 97, 3, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[13309, 488, 99, 2, 31, "Subsubsection"],
Cell[13411, 492, 66, 2, 32, "Input"],
Cell[13480, 496, 67, 2, 32, "Input"],
Cell[13550, 500, 67, 2, 32, "Input"],
Cell[13620, 504, 70, 2, 32, "Input"],
Cell[13693, 508, 70, 2, 32, "Input"],
Cell[13766, 512, 65, 2, 32, "Input"],
Cell[13834, 516, 65, 2, 32, "Input"],
Cell[13902, 520, 72, 2, 32, "Input"],
Cell[13977, 524, 76, 2, 32, "Input"],
Cell[14056, 528, 69, 2, 32, "Input"],
Cell[14128, 532, 68, 2, 32, "Input"],
Cell[14199, 536, 70, 2, 32, "Input"],
Cell[14272, 540, 71, 2, 32, "Input"],
Cell[14346, 544, 72, 2, 32, "Input"],
Cell[14421, 548, 72, 2, 32, "Input"],
Cell[14496, 552, 52, 1, 56, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14585, 558, 64, 1, 31, "Subsubsection"],
Cell[14652, 561, 128, 3, 27, "Text"],
Cell[14783, 566, 64, 2, 32, "Input"],
Cell[14850, 570, 91, 3, 32, "Input"],
Cell[14944, 575, 72, 2, 32, "Input"],
Cell[15019, 579, 297, 6, 46, "Text",
  Evaluatable->False]
}, Closed]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15377, 592, 130, 4, 60, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[15532, 600, 101, 3, 43, "Subsection",
  Evaluatable->False],
Cell[15636, 605, 182, 6, 27, "Text",
  Evaluatable->False],
Cell[15821, 613, 94, 3, 51, "Input"],
Cell[15918, 618, 64, 2, 28, "Input"],
Cell[15985, 622, 96, 3, 27, "Text",
  Evaluatable->False],
Cell[16084, 627, 220, 8, 30, "Input"],
Cell[16307, 637, 252, 8, 54, "Text",
  Evaluatable->False],
Cell[16562, 647, 193, 6, 30, "Input"],
Cell[16758, 655, 104, 3, 23, "Text",
  Evaluatable->False],
Cell[16865, 660, 122, 5, 30, "Input"],
Cell[16990, 667, 102, 3, 23, "Text",
  Evaluatable->False],
Cell[17095, 672, 80, 3, 30, "Input"],
Cell[17178, 677, 86, 3, 23, "Text",
  Evaluatable->False],
Cell[17267, 682, 129, 5, 30, "Input"],
Cell[17399, 689, 302, 8, 42, "Text"],
Cell[17704, 699, 125, 3, 30, "Input"],
Cell[17832, 704, 192, 6, 23, "Text",
  Evaluatable->False],
Cell[18027, 712, 141, 5, 30, "Input"],
Cell[18171, 719, 158, 5, 26, "Input"],
Cell[18332, 726, 147, 5, 26, "Input"],
Cell[18482, 733, 124, 4, 23, "Text"],
Cell[18609, 739, 92, 3, 30, "Input"],
Cell[18704, 744, 69, 2, 28, "Input"],
Cell[18776, 748, 156, 4, 26, "Input"],
Cell[18935, 754, 85, 3, 26, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[19057, 762, 58, 1, 37, "Subsection"],
Cell[19118, 765, 428, 8, 65, "Text"],
Cell[19549, 775, 81, 3, 30, "Input"],

Cell[CellGroupData[{
Cell[19655, 782, 72, 2, 35, "Subsubsection"],
Cell[19730, 786, 62, 1, 27, "Text"],
Cell[19795, 789, 83, 3, 30, "Input"],
Cell[19881, 794, 69, 1, 27, "Text"],
Cell[19953, 797, 87, 3, 30, "Input"],
Cell[20043, 802, 48, 1, 27, "Text"],
Cell[20094, 805, 136, 5, 26, "Input"],
Cell[20233, 812, 113, 3, 30, "Input"],
Cell[20349, 817, 50, 1, 27, "Text"],
Cell[20402, 820, 121, 3, 30, "Input"],
Cell[20526, 825, 103, 3, 30, "Input"],
Cell[20632, 830, 50, 1, 27, "Text"],
Cell[20685, 833, 84, 3, 30, "Input"],
Cell[20772, 838, 113, 3, 30, "Input"],
Cell[20888, 843, 111, 3, 30, "Input"],
Cell[21002, 848, 86, 2, 32, "Input"],
Cell[21091, 852, 106, 3, 30, "Input"],
Cell[21200, 857, 39, 0, 27, "Text"],
Cell[21242, 859, 71, 2, 32, "Input"],
Cell[21316, 863, 106, 2, 32, "Input"],
Cell[21425, 867, 64, 2, 32, "Input"],
Cell[21492, 871, 116, 3, 27, "Text"],
Cell[21611, 876, 211, 6, 80, "Input"],
Cell[21825, 884, 77, 2, 32, "Input"],
Cell[21905, 888, 166, 4, 27, "Text"],
Cell[22074, 894, 88, 3, 30, "Input"],
Cell[22165, 899, 115, 3, 30, "Input"],
Cell[22283, 904, 92, 1, 27, "Text"],
Cell[22378, 907, 156, 5, 30, "Input"],
Cell[22537, 914, 125, 3, 27, "Text"],
Cell[22665, 919, 121, 3, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22835, 928, 49, 1, 37, "Subsection"],
Cell[22887, 931, 93, 2, 27, "Text"],
Cell[22983, 935, 111, 4, 30, "Input"],
Cell[23097, 941, 329, 10, 46, "Text"],

Cell[CellGroupData[{
Cell[23451, 955, 114, 4, 35, "Subsubsection",
  Evaluatable->False],
Cell[23568, 961, 72, 2, 32, "Input"],
Cell[23643, 965, 146, 5, 30, "Input"],
Cell[23792, 972, 106, 3, 27, "Text"],
Cell[23901, 977, 151, 5, 30, "Input"],
Cell[24055, 984, 84, 3, 30, "Input"],
Cell[24142, 989, 85, 3, 30, "Input"],
Cell[24230, 994, 111, 3, 30, "Input"],
Cell[24344, 999, 271, 7, 46, "Text"],
Cell[24618, 1008, 110, 3, 30, "Input"],
Cell[24731, 1013, 146, 4, 30, "Input"],
Cell[24880, 1019, 144, 4, 30, "Input"],
Cell[25027, 1025, 127, 3, 30, "Input"],
Cell[25157, 1030, 117, 3, 30, "Input"],
Cell[25277, 1035, 127, 4, 27, "Text"],
Cell[25407, 1041, 112, 3, 30, "Input"],
Cell[25522, 1046, 122, 3, 30, "Input"],
Cell[25647, 1051, 137, 4, 27, "Text"],
Cell[25787, 1057, 151, 5, 30, "Input"],
Cell[25941, 1064, 73, 2, 32, "Input"],
Cell[26017, 1068, 113, 3, 27, "Text"],
Cell[26133, 1073, 145, 5, 30, "Input"],
Cell[26281, 1080, 149, 5, 30, "Input"],
Cell[26433, 1087, 164, 5, 30, "Input"],
Cell[26600, 1094, 84, 3, 30, "Input"],
Cell[26687, 1099, 111, 4, 30, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[26847, 1109, 109, 3, 37, "Subsection",
  Evaluatable->False],
Cell[26959, 1114, 529, 15, 89, "Text",
  Evaluatable->False],
Cell[27491, 1131, 127, 5, 30, "Input"],
Cell[27621, 1138, 544, 11, 177, "Input",
  Evaluatable->False],
Cell[28168, 1151, 274, 9, 46, "Text",
  Evaluatable->False],
Cell[28445, 1162, 82, 3, 30, "Input"],
Cell[28530, 1167, 132, 3, 27, "Text",
  Evaluatable->False],
Cell[28665, 1172, 127, 5, 30, "Input"],
Cell[28795, 1179, 168, 4, 27, "Text"],
Cell[28966, 1185, 176, 6, 30, "Input",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[29167, 1195, 114, 4, 35, "Subsubsection",
  Evaluatable->False],
Cell[29284, 1201, 135, 4, 30, "Input"],
Cell[29422, 1207, 133, 4, 30, "Input"],
Cell[29558, 1213, 137, 4, 30, "Input"],
Cell[29698, 1219, 84, 3, 30, "Input"],
Cell[29785, 1224, 121, 3, 30, "Input"],
Cell[29909, 1229, 92, 3, 30, "Input"],
Cell[30004, 1234, 137, 4, 30, "Input"],
Cell[30144, 1240, 133, 3, 32, "Input"],
Cell[30280, 1245, 137, 3, 32, "Input"],
Cell[30420, 1250, 135, 3, 32, "Input"],
Cell[30558, 1255, 135, 4, 30, "Input"],
Cell[30696, 1261, 135, 4, 30, "Input"],
Cell[30834, 1267, 198, 5, 51, "Input"],
Cell[31035, 1274, 85, 3, 30, "Input"],
Cell[31123, 1279, 173, 4, 56, "Input"],
Cell[31299, 1285, 156, 4, 56, "Input"],
Cell[31458, 1291, 177, 4, 56, "Input"],
Cell[31638, 1297, 162, 3, 56, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31861, 1307, 35, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[31921, 1311, 52, 1, 43, "Subsection"],
Cell[31976, 1314, 2326, 55, 286, "Text"],
Cell[34305, 1371, 65, 0, 27, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[34407, 1376, 76, 1, 37, "Subsection"],

Cell[CellGroupData[{
Cell[34508, 1381, 46, 0, 36, "Subsubsection"],
Cell[34557, 1383, 1485, 48, 177, "Text"],
Cell[36045, 1433, 85, 3, 30, "Input"],
Cell[36133, 1438, 101, 3, 30, "Input"],
Cell[36237, 1443, 69, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[36343, 1450, 49, 0, 36, "Subsubsection"],
Cell[36395, 1452, 144, 3, 27, "Text"],
Cell[36542, 1457, 72, 2, 32, "Input"],
Cell[36617, 1461, 76, 2, 32, "Input"],
Cell[36696, 1465, 70, 2, 32, "Input"],

Cell[CellGroupData[{
Cell[36791, 1471, 3375, 64, 1280, "Input",
  Evaluatable->False],
Cell[40169, 1537, 208, 4, 26, "Message"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[40426, 1547, 41, 0, 36, "Subsubsection"],
Cell[40470, 1549, 608, 9, 103, "Text"],
Cell[41081, 1560, 303, 5, 65, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[41433, 1571, 57, 1, 37, "Subsection"],

Cell[CellGroupData[{
Cell[41515, 1576, 60, 0, 36, "Subsubsection"],
Cell[41578, 1578, 77, 2, 32, "Input"],
Cell[41658, 1582, 126, 3, 27, "Text"],
Cell[41787, 1587, 94, 2, 32, "Input"],
Cell[41884, 1591, 103, 2, 32, "Input"],
Cell[41990, 1595, 103, 2, 32, "Input"],
Cell[42096, 1599, 110, 3, 27, "Text"],
Cell[42209, 1604, 146, 3, 32, "Input"],
Cell[42358, 1609, 150, 3, 32, "Input"],
Cell[42511, 1614, 109, 2, 32, "Input"],
Cell[42623, 1618, 151, 3, 32, "Input"],
Cell[42777, 1623, 137, 3, 32, "Input"],
Cell[42917, 1628, 109, 2, 32, "Input"],
Cell[43029, 1632, 159, 3, 27, "Text"],
Cell[43191, 1637, 139, 3, 32, "Input"],
Cell[43333, 1642, 109, 2, 32, "Input"],
Cell[43445, 1646, 67, 0, 27, "Text"],
Cell[43515, 1648, 405, 10, 114, "Input"],
Cell[43923, 1660, 69, 0, 27, "Text"],
Cell[43995, 1662, 356, 8, 93, "Input"],
Cell[44354, 1672, 69, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[44460, 1679, 62, 0, 36, "Subsubsection"],
Cell[44525, 1681, 128, 3, 27, "Text"],
Cell[44656, 1686, 211, 4, 56, "Input"],
Cell[44870, 1692, 246, 5, 56, "Input"],
Cell[45119, 1699, 170, 3, 56, "Input"],
Cell[45292, 1704, 142, 3, 32, "Input"],
Cell[45437, 1709, 109, 2, 32, "Input"],
Cell[45549, 1713, 79, 2, 32, "Input"],
Cell[45631, 1717, 70, 2, 32, "Input"],
Cell[45704, 1721, 63, 2, 32, "Input"],
Cell[45770, 1725, 63, 2, 32, "Input"],
Cell[45836, 1729, 89, 2, 32, "Input"],
Cell[45928, 1733, 126, 3, 32, "Input"],
Cell[46057, 1738, 116, 2, 32, "Input"],
Cell[46176, 1742, 217, 4, 46, "Text"],
Cell[46396, 1748, 217, 4, 80, "Input"],
Cell[46616, 1754, 141, 4, 32, "Input"],
Cell[46760, 1760, 95, 2, 32, "Input"],
Cell[46858, 1764, 66, 2, 32, "Input"],
Cell[46927, 1768, 119, 3, 32, "Input"],
Cell[47049, 1773, 129, 3, 32, "Input"],
Cell[47181, 1778, 68, 2, 32, "Input"],
Cell[47252, 1782, 68, 2, 32, "Input"],
Cell[47323, 1786, 189, 4, 56, "Input"],
Cell[47515, 1792, 188, 4, 56, "Input"],
Cell[47706, 1798, 141, 4, 32, "Input"],
Cell[47850, 1804, 79, 2, 32, "Input"],
Cell[47932, 1808, 189, 4, 56, "Input"],
Cell[48124, 1814, 77, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[48238, 1821, 44, 0, 30, "Subsubsection"],
Cell[48285, 1823, 179, 4, 46, "Text"],
Cell[48467, 1829, 69, 2, 32, "Input"],
Cell[48539, 1833, 77, 2, 32, "Input"],
Cell[48619, 1837, 78, 2, 32, "Input"],
Cell[48700, 1841, 124, 3, 27, "Text"],
Cell[48827, 1846, 127, 3, 30, "Input"],
Cell[48957, 1851, 173, 4, 46, "Text"],
Cell[49133, 1857, 159, 4, 30, "Input"],
Cell[49295, 1863, 109, 2, 32, "Input"],
Cell[49407, 1867, 119, 4, 27, "Text"],
Cell[49529, 1873, 158, 4, 30, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[49724, 1882, 71, 0, 36, "Subsubsection"],
Cell[49798, 1884, 61, 2, 32, "Input"],
Cell[49862, 1888, 256, 6, 80, "Input"],
Cell[50121, 1896, 333, 8, 104, "Input"],
Cell[50457, 1906, 354, 8, 104, "Input"],
Cell[50814, 1916, 354, 8, 104, "Input"],
Cell[51171, 1926, 310, 7, 104, "Input"],
Cell[51484, 1935, 77, 2, 32, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[51598, 1942, 70, 0, 36, "Subsubsection"],
Cell[51671, 1944, 198, 4, 77, "Text"],
Cell[51872, 1950, 165, 3, 46, "Text"],
Cell[52040, 1955, 520, 10, 224, "Input"],
Cell[52563, 1967, 60, 0, 27, "Text"],
Cell[52626, 1969, 174, 4, 56, "Input"],
Cell[52803, 1975, 78, 2, 32, "Input"],
Cell[52884, 1979, 42, 0, 27, "Text"],
Cell[52929, 1981, 106, 2, 32, "Input"],
Cell[53038, 1985, 138, 3, 27, "Text"],
Cell[53179, 1990, 69, 2, 32, "Input"],
Cell[53251, 1994, 242, 6, 56, "Input",
  Evaluatable->False],
Cell[53496, 2002, 79, 2, 32, "Input"],
Cell[53578, 2006, 136, 3, 32, "Input"],
Cell[53717, 2011, 73, 2, 32, "Input"],
Cell[53793, 2015, 180, 4, 80, "Input"],
Cell[53976, 2021, 115, 3, 27, "Text"],
Cell[54094, 2026, 101, 2, 32, "Input"],
Cell[54198, 2030, 91, 2, 27, "Text"],
Cell[54292, 2034, 103, 2, 32, "Input"],
Cell[54398, 2038, 138, 3, 27, "Text"],
Cell[54539, 2043, 184, 4, 80, "Input"],
Cell[54726, 2049, 119, 3, 27, "Text"],
Cell[54848, 2054, 175, 3, 56, "Input"],
Cell[55026, 2059, 74, 2, 32, "Input"],
Cell[55103, 2063, 73, 2, 32, "Input"],
Cell[55179, 2067, 74, 2, 32, "Input"],
Cell[55256, 2071, 82, 2, 32, "Input"],
Cell[55341, 2075, 47, 0, 27, "Text"],
Cell[55391, 2077, 171, 3, 56, "Input"],
Cell[55565, 2082, 99, 2, 27, "Text"],
Cell[55667, 2086, 863, 15, 368, "Input"],
Cell[56533, 2103, 86, 2, 27, "Text"],
Cell[56622, 2107, 175, 4, 56, "Input"],
Cell[56800, 2113, 72, 2, 32, "Input"],
Cell[56875, 2117, 80, 2, 32, "Input"],
Cell[56958, 2121, 145, 3, 27, "Text"],
Cell[57106, 2126, 68, 2, 32, "Input"],
Cell[57177, 2130, 116, 2, 32, "Input"],
Cell[57296, 2134, 59, 0, 27, "Text"],
Cell[57358, 2136, 110, 2, 32, "Input"],
Cell[57471, 2140, 63, 0, 27, "Text"],
Cell[57537, 2142, 152, 4, 32, "Input"],
Cell[57692, 2148, 179, 4, 56, "Input"],
Cell[57874, 2154, 287, 5, 46, "Text"],
Cell[58164, 2161, 150, 4, 32, "Input"],
Cell[58317, 2167, 190, 4, 46, "Text"],
Cell[58510, 2173, 67, 2, 32, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[58626, 2181, 51, 1, 37, "Subsection"],
Cell[58680, 2184, 43, 0, 27, "Text"],
Cell[58726, 2186, 70, 2, 32, "Input"],
Cell[58799, 2190, 73, 2, 28, "Input"],
Cell[58875, 2194, 173, 3, 42, "Text"],
Cell[59051, 2199, 174, 3, 46, "Text"],
Cell[59228, 2204, 72, 2, 32, "Input"],
Cell[59303, 2208, 603, 12, 196, "Input",
  Evaluatable->False],
Cell[59909, 2222, 88, 2, 32, "Input"],
Cell[60000, 2226, 113, 2, 28, "Input"],
Cell[60116, 2230, 95, 2, 23, "Text"],
Cell[60214, 2234, 137, 3, 32, "Input"],
Cell[60354, 2239, 70, 2, 28, "Input"],
Cell[60427, 2243, 153, 3, 28, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[60617, 2251, 58, 1, 37, "Subsection"],
Cell[60678, 2254, 287, 6, 46, "Text",
  Evaluatable->False],
Cell[60968, 2262, 88, 3, 28, "Input"],
Cell[61059, 2267, 969, 17, 320, "Input",
  Evaluatable->False],
Cell[62031, 2286, 323, 10, 27, "Text",
  Evaluatable->False],
Cell[62357, 2298, 213, 6, 30, "Input",
  InitializationCell->True],
Cell[62573, 2306, 399, 13, 27, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[62997, 2323, 79, 2, 37, "Subsubsection"],
Cell[63079, 2327, 147, 5, 28, "Input"],
Cell[63229, 2334, 147, 5, 28, "Input"],
Cell[63379, 2341, 147, 5, 28, "Input"],
Cell[63529, 2348, 147, 5, 28, "Input"],
Cell[63679, 2355, 147, 5, 28, "Input"],
Cell[63829, 2362, 181, 5, 50, "Input"],
Cell[64013, 2369, 69, 2, 32, "Input"],
Cell[64085, 2373, 172, 5, 27, "Text",
  Evaluatable->False],
Cell[64260, 2380, 176, 5, 28, "Input"],
Cell[64439, 2387, 69, 2, 32, "Input"],
Cell[64511, 2391, 186, 5, 28, "Input"],
Cell[64700, 2398, 109, 3, 27, "Text"],
Cell[64812, 2403, 145, 3, 56, "Input"],
Cell[64960, 2408, 69, 2, 32, "Input"],
Cell[65032, 2412, 127, 4, 27, "Text"],
Cell[65162, 2418, 156, 5, 28, "Input"],
Cell[65321, 2425, 144, 4, 28, "Input"],
Cell[65468, 2431, 93, 2, 32, "Input"],
Cell[65564, 2435, 69, 2, 32, "Input"],
Cell[65636, 2439, 75, 2, 32, "Input"],
Cell[65714, 2443, 69, 2, 32, "Input"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[65844, 2452, 56, 1, 32, "Subsubtitle"],
Cell[65903, 2455, 140, 4, 27, "Text",
  CellTags->"S1"]
}, Closed]],

Cell[CellGroupData[{
Cell[66080, 2464, 62, 1, 24, "Subsubtitle"],
Cell[66145, 2467, 89, 4, 89, "Text"],
Cell[66237, 2473, 47, 0, 27, "Text"],
Cell[66287, 2475, 90, 2, 27, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

